#define _GNU_SOURCE 1
#include <errno.h>
#include <fcntl.h>
#include <limits.h>
#include <setjmp.h>
#include <stdio.h>
#include <unistd.h>
#include <sys/stat.h>
#include <sys/mman.h>
#include <stdint.h>
#include <stdbool.h>
#include "fstest.h"

__attribute__((__unused__)) static void
init_map_anon(uintptr_t va, bool writable, char value)
{
  char *r = mmap((void*)va, 4096, PROT_READ | PROT_WRITE,
                 MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, -1, 0);
  if (r == MAP_FAILED) setup_error("mmap");
  *r = value;
  if (!writable) {
    int r2 = mprotect(r, 4096, PROT_READ);
    if (r2 < 0) setup_error("mprotect");
  }
  // Ensure test cores don't shoot down the setup core
  xinvalidate(r, 4096);
}

__attribute__((__unused__)) static void
init_map_file(uintptr_t va, bool writable, const char *fname, off_t offset)
{
  int fd = open(fname, O_RDWR);
  if (fd < 0) setup_error("open");
  void *r = mmap((void*)va, 4096, PROT_READ | (writable ? PROT_WRITE : 0),
                 MAP_SHARED | MAP_FIXED, fd, offset);
  if (r == MAP_FAILED) setup_error("mmap");
  close(fd);
}

__attribute__((__weak__)) const char dataval0[4096] = {0};
__attribute__((__weak__)) const char dataval1[4096] = {1};
__attribute__((__weak__)) const char dataval2[4096] = {2};
__attribute__((__weak__)) const char dataval3[4096] = {3};
__attribute__((__weak__)) const char dataval4[4096] = {4};
__attribute__((__weak__)) const char dataval5[4096] = {5};
__attribute__((__weak__)) const char dataval6[4096] = {6};
__attribute__((__weak__)) const char dataval7[4096] = {7};
__attribute__((__weak__)) char datavalbuf[4096];


/*
 * calls: close close
 */
static int test_close_close_pe_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_close_pe_0_1(void) {
  int r = close(11);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_close_close_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_close_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_close_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_close_pe_0_final(void) {
  unlink("__i0");
}
static void setup_close_close_pe_0_procfinal(void) {
  
}

/*
 * calls: close close
 */
// static int test_close_close_pe_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pe_1_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
static void setup_close_close_pe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_close_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_close_pe_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_close_pe_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_close_pe_1_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close close
 */
// static int test_close_close_pe_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pe_2_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
// static void setup_close_close_pe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_pe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_pe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pe_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pe_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pe_3_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
// static void setup_close_close_pe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_pe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_pe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_pe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pe_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pe_4_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
// static void setup_close_close_pe_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_pe_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_pe_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_pe_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pe_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pe_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pe_5_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
// static void setup_close_close_pe_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_pe_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_pe_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_pe_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pe_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pe_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pe_6_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
// static void setup_close_close_pe_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_pe_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_pe_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_pe_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pe_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pe_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pe_7_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
// static void setup_close_close_pe_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_pe_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_pe_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_pe_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pe_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pe_8_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pe_8_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
// static void setup_close_close_pe_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_pe_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_pe_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_pe_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pe_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
static int test_close_close_pc_0_1(void) {
  int r = close(11);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_close_close_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_close_pe_0_common
static void setup_close_close_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_close_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_close_pe_0_proc1
// static void setup_close_close_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_close_pe_0_final
// static void setup_close_close_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pc_1_1(void) {
//   int r = close(11);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_pc_0_1
// static void setup_close_close_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pc_2_1(void) {
//   int r = close(11);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_pc_0_1
// static void setup_close_close_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pa_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pa_0_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_close_pe_0_common
// static void setup_close_close_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_close_pc_0_proc0
// static void setup_close_close_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_close_pc_0_proc0
// static void setup_close_close_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_close_pe_0_final
// static void setup_close_close_pa_0_procfinal(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pa_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pa_1_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_1_proc0
static void setup_close_close_pa_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_pa_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pa_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pa_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pa_2_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_pa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_pa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pa_1_proc1
// static void setup_close_close_pa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_1_proc0
// static void setup_close_close_pa_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pa_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pa_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pa_3_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_pa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_pa_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_1_proc0
// static void setup_close_close_pa_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_1_proc0
// static void setup_close_close_pa_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pa_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pa_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pa_4_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_pa_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_pa_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_2_proc0
// static void setup_close_close_pa_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pa_1_proc1
// static void setup_close_close_pa_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pa_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pa_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pa_5_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_pa_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_pa_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_2_proc0
// static void setup_close_close_pa_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_1_proc0
// static void setup_close_close_pa_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pa_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pa_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pa_6_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_pa_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_pa_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pa_1_proc1
// static void setup_close_close_pa_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_2_proc0
// static void setup_close_close_pa_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pa_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pa_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pa_7_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_pa_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_pa_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_1_proc0
// static void setup_close_close_pa_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_2_proc0
// static void setup_close_close_pa_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pa_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_pa_8_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_pa_8_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_pa_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_pa_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_2_proc0
// static void setup_close_close_pa_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_2_proc0
// static void setup_close_close_pa_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_pa_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
static int test_close_close_p8_0_1(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_close_close_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_close_pe_0_common
// static void setup_close_close_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_close_pc_0_proc0
// static void setup_close_close_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_close_pe_0_proc1
// static void setup_close_close_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_close_pe_0_final
// static void setup_close_close_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_p8_1_1(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static void setup_close_close_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_1_proc0
// static void setup_close_close_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static int test_close_close_p8_2_1(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static void setup_close_close_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_2_proc0
// static void setup_close_close_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p6_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static int test_close_close_p6_0_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
// static void setup_close_close_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_close_pe_0_common
static void setup_close_close_p6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_close_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_close_pe_0_proc1
// static void setup_close_close_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_close_pe_0_final
// static void setup_close_close_p6_0_procfinal(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p6_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static int test_close_close_p6_1_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
// static void setup_close_close_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_p6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_p6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_p6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p6_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static int test_close_close_p6_2_1(void) {
//   int r = close(11);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_1
// static void setup_close_close_p6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
static void setup_close_close_p6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_close_p6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_p6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_p6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static int test_close_close_p4_0_1(void) {
//   int r = close(11);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_pc_0_1
static void setup_close_close_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_close_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_close_pe_0_proc1
// static void setup_close_close_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_close_pe_0_proc1
// static void setup_close_close_p4_0_final(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal
// static void setup_close_close_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static int test_close_close_p4_1_1(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static void setup_close_close_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_close_p4_0_common
// static void setup_close_close_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_close_pe_0_proc1
// static void setup_close_close_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_close_pe_0_proc1
// static void setup_close_close_p4_1_final(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal
// static void setup_close_close_p4_1_procfinal(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p2_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static int test_close_close_p2_0_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_close_pe_0_common
// static void setup_close_close_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_close_pe_0_proc1
// static void setup_close_close_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_close_pc_0_proc0
// static void setup_close_close_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_close_pe_0_final
// static void setup_close_close_p2_0_procfinal(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p2_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static int test_close_close_p2_1_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_1_proc0
// static void setup_close_close_p2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_p2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p2_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static int test_close_close_p2_2_1(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_close_pe_0_0
// static void setup_close_close_p2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_close_pe_1_common
// static void setup_close_close_p2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pe_1_proc1
// static void setup_close_close_p2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_close_pc_2_proc0
// static void setup_close_close_p2_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_final
// static void setup_close_close_p2_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_close_pe_1_procfinal

/*
 * calls: close close
 */
// static int test_close_close_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static int test_close_close_p0_0_1(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_close_p8_0_1
// static void setup_close_close_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_close_p4_0_common
// static void setup_close_close_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_close_pe_0_proc1
// static void setup_close_close_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_close_pe_0_proc1
// static void setup_close_close_p0_0_final(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal
// static void setup_close_close_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_close_pe_0_procfinal


/*
 * calls: close fstat
 */
static int test_close_fstat_pf_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_fstat_pf_0_1(void) {
  struct stat st;
  int r = fstat(11, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_close_fstat_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_fstat_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_fstat_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_fstat_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_fstat_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close fstat
 */
// static int test_close_fstat_pf_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pf_1_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pf_0_1
// static void setup_close_fstat_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pf_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pf_2_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pf_0_1
// static void setup_close_fstat_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_pf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pf_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pf_3_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pf_0_1
// static void setup_close_fstat_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_pf_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pf_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pf_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pf_4_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pf_0_1
// static void setup_close_fstat_pf_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_pf_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pf_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pf_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pf_5_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pf_0_1
// static void setup_close_fstat_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_pf_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pf_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pe_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
static int test_close_fstat_pe_0_1(void) {
  struct stat st;
  int r = fstat(11, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_close_fstat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_fstat_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_fstat_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_fstat_pe_0_final(void) {
  unlink("__i0");
}
static void setup_close_fstat_pe_0_procfinal(void) {
  
}

/*
 * calls: close fstat
 */
// static int test_close_fstat_pe_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pe_1_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pe_0_1
// static void setup_close_fstat_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pe_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pe_2_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pe_0_1
// static void setup_close_fstat_pe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_pe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_pe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pe_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
static int test_close_fstat_pc_0_1(void) {
  struct stat st;
  int r = fstat(11, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_close_fstat_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_fstat_pe_0_common
static void setup_close_fstat_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_fstat_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_fstat_pe_0_proc1
// static void setup_close_fstat_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_fstat_pe_0_final
// static void setup_close_fstat_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pc_1_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pc_0_1
// static void setup_close_fstat_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pc_2_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pc_0_1
// static void setup_close_fstat_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pb_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
static int test_close_fstat_pb_0_1(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_close_fstat_pb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_pb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_1_proc0
// static void setup_close_fstat_pb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pb_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pb_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pb_0_1
// static void setup_close_fstat_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_pb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pb_0_proc0
// static void setup_close_fstat_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_2_proc0
// static void setup_close_fstat_pb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pb_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pb_2_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pb_0_1
// static void setup_close_fstat_pb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_pb_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_1_proc0
// static void setup_close_fstat_pb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_1_proc0
// static void setup_close_fstat_pb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pb_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pb_3_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pb_0_1
// static void setup_close_fstat_pb_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_pb_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_2_proc0
// static void setup_close_fstat_pb_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_1_proc0
// static void setup_close_fstat_pb_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pb_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pb_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pb_4_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pb_0_1
// static void setup_close_fstat_pb_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_pb_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_1_proc0
// static void setup_close_fstat_pb_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_2_proc0
// static void setup_close_fstat_pb_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pb_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pb_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pb_5_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pb_0_1
// static void setup_close_fstat_pb_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_pb_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_2_proc0
// static void setup_close_fstat_pb_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_2_proc0
// static void setup_close_fstat_pb_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pb_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pa_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
static int test_close_fstat_pa_0_1(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_close_fstat_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_fstat_pe_0_common
// static void setup_close_fstat_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_fstat_pc_0_proc0
// static void setup_close_fstat_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_fstat_pc_0_proc0
// static void setup_close_fstat_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_fstat_pe_0_final
// static void setup_close_fstat_pa_0_procfinal(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pa_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pa_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pa_0_1
// static void setup_close_fstat_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_1_proc0
// static void setup_close_fstat_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pb_0_proc0
// static void setup_close_fstat_pa_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pa_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_pa_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_pa_2_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pa_0_1
// static void setup_close_fstat_pa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_pa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_2_proc0
// static void setup_close_fstat_pa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pb_0_proc0
// static void setup_close_fstat_pa_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_pa_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
static int test_close_fstat_p8_0_1(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_close_fstat_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_fstat_pe_0_common
// static void setup_close_fstat_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_fstat_pc_0_proc0
// static void setup_close_fstat_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_fstat_pe_0_proc1
// static void setup_close_fstat_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_fstat_pe_0_final
// static void setup_close_fstat_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_p8_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_p8_0_1
// static void setup_close_fstat_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_1_proc0
// static void setup_close_fstat_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_fstat_pf_0_0
// static int test_close_fstat_p8_2_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_p8_0_1
// static void setup_close_fstat_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_2_proc0
// static void setup_close_fstat_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
static int test_close_fstat_p7_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_fstat_p7_0_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pf_0_1
// static void setup_close_fstat_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p7_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_fstat_p7_0_0
// static int test_close_fstat_p7_1_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pf_0_1
// static void setup_close_fstat_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
static void setup_close_fstat_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_fstat_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p6_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_fstat_p7_0_0
// static int test_close_fstat_p6_0_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pe_0_1
// static void setup_close_fstat_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_fstat_pe_0_common
static void setup_close_fstat_p6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_fstat_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_fstat_pe_0_proc1
// static void setup_close_fstat_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_fstat_pe_0_final
// static void setup_close_fstat_p6_0_procfinal(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_fstat_p7_0_0
// static int test_close_fstat_p4_0_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pc_0_1
static void setup_close_fstat_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_fstat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_fstat_pe_0_proc1
// static void setup_close_fstat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_fstat_pe_0_proc1
// static void setup_close_fstat_p4_0_final(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal
// static void setup_close_fstat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_fstat_p7_0_0
// static int test_close_fstat_p4_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_p8_0_1
// static void setup_close_fstat_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_fstat_p4_0_common
// static void setup_close_fstat_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_fstat_pe_0_proc1
// static void setup_close_fstat_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_fstat_pe_0_proc1
// static void setup_close_fstat_p4_1_final(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal
// static void setup_close_fstat_p4_1_procfinal(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p3_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_fstat_p7_0_0
// static int test_close_fstat_p3_0_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pb_0_1
// static void setup_close_fstat_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_1_proc0
// static void setup_close_fstat_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p3_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_fstat_p7_0_0
// static int test_close_fstat_p3_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pb_0_1
// static void setup_close_fstat_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_fstat_pf_0_common
// static void setup_close_fstat_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pf_0_proc1
// static void setup_close_fstat_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_fstat_pc_2_proc0
// static void setup_close_fstat_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_final
// static void setup_close_fstat_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_fstat_pf_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p2_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_fstat_p7_0_0
// static int test_close_fstat_p2_0_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_pa_0_1
// static void setup_close_fstat_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_fstat_pe_0_common
// static void setup_close_fstat_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_fstat_pe_0_proc1
// static void setup_close_fstat_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_fstat_pc_0_proc0
// static void setup_close_fstat_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_fstat_pe_0_final
// static void setup_close_fstat_p2_0_procfinal(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal

/*
 * calls: close fstat
 */
// static int test_close_fstat_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_fstat_p7_0_0
// static int test_close_fstat_p0_0_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_fstat_p8_0_1
// static void setup_close_fstat_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_fstat_p4_0_common
// static void setup_close_fstat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_fstat_pe_0_proc1
// static void setup_close_fstat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_fstat_pe_0_proc1
// static void setup_close_fstat_p0_0_final(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal
// static void setup_close_fstat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_fstat_pe_0_procfinal


/*
 * calls: close link
 */
static int test_close_link_pe_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_link_pe_0_1(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_close_link_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_close_link_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_link_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_link_pe_0_final(void) {
  unlink("__i0");
}
static void setup_close_link_pe_0_procfinal(void) {
  
}

/*
 * calls: close link
 */
// static int test_close_link_pe_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
// static int test_close_link_pe_1_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_1
static void setup_close_link_pe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_close_link_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_link_pe_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_link_pe_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_link_pe_1_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close link
 */
// static int test_close_link_pe_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
static int test_close_link_pe_2_1(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_close_link_pe_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_close_link_pe_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_link_pe_0_proc0
// static void setup_close_link_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_pe_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_link_pe_0_final
// static void setup_close_link_pe_2_procfinal(void) {
//   
// }
// ^ See setup_close_link_pe_0_procfinal

/*
 * calls: close link
 */
// static int test_close_link_pe_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
// static int test_close_link_pe_3_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_2_1
static void setup_close_link_pe_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_close_link_pe_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_1_proc0
// static void setup_close_link_pe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_1_proc1
// static void setup_close_link_pe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_final
// static void setup_close_link_pe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_procfinal

/*
 * calls: close link
 */
// static int test_close_link_pe_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
// static int test_close_link_pe_4_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_1
// static void setup_close_link_pe_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_link_pe_1_common
static void setup_close_link_pe_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_link_pe_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_1_proc1
// static void setup_close_link_pe_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_final
// static void setup_close_link_pe_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_procfinal

/*
 * calls: close link
 */
// static int test_close_link_pe_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
// static int test_close_link_pe_5_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_2_1
// static void setup_close_link_pe_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_link_pe_3_common
// static void setup_close_link_pe_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_4_proc0
// static void setup_close_link_pe_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_1_proc1
// static void setup_close_link_pe_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_final
// static void setup_close_link_pe_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_procfinal

/*
 * calls: close link
 */
// static int test_close_link_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
static int test_close_link_pc_0_1(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_close_link_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_link_pe_2_common
static void setup_close_link_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_link_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_link_pe_0_final
// static void setup_close_link_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_link_pe_0_procfinal

/*
 * calls: close link
 */
// static int test_close_link_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
// static int test_close_link_pc_1_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pc_0_1
static void setup_close_link_pc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_close_link_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_1_proc0
// static void setup_close_link_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_1_proc1
// static void setup_close_link_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_final
// static void setup_close_link_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_procfinal

/*
 * calls: close link
 */
// static int test_close_link_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
// static int test_close_link_pc_2_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pc_0_1
// static void setup_close_link_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_link_pc_1_common
// static void setup_close_link_pc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_4_proc0
// static void setup_close_link_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_1_proc1
// static void setup_close_link_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_final
// static void setup_close_link_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_procfinal

/*
 * calls: close link
 */
// static int test_close_link_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
static int test_close_link_p8_0_1(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_close_link_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_close_link_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_link_pe_0_proc0
// static void setup_close_link_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_link_pe_0_final
// static void setup_close_link_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_link_pe_0_procfinal

/*
 * calls: close link
 */
// static int test_close_link_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
// static int test_close_link_p8_1_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_link_p8_0_1
static void setup_close_link_p8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_link_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_1_proc0
// static void setup_close_link_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_1_proc1
// static void setup_close_link_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_final
// static void setup_close_link_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_procfinal

/*
 * calls: close link
 */
// static int test_close_link_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_0
// static int test_close_link_p8_2_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_link_p8_0_1
// static void setup_close_link_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_link_p8_1_common
// static void setup_close_link_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_4_proc0
// static void setup_close_link_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_link_pe_1_proc1
// static void setup_close_link_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_final
// static void setup_close_link_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_link_pe_1_procfinal

/*
 * calls: close link
 */
static int test_close_link_p6_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_link_p6_0_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_0_1
// static void setup_close_link_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_link_pe_0_common
// static void setup_close_link_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_link_pe_0_final
// static void setup_close_link_p6_0_procfinal(void) {
//   
// }
// ^ See setup_close_link_pe_0_procfinal

/*
 * calls: close link
 */
// static int test_close_link_p6_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_link_p6_0_0
// static int test_close_link_p6_1_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_close_link_pe_2_1
// static void setup_close_link_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_link_pe_2_common
// static void setup_close_link_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_p6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_link_pe_0_final
// static void setup_close_link_p6_1_procfinal(void) {
//   
// }
// ^ See setup_close_link_pe_0_procfinal

/*
 * calls: close link
 */
// static int test_close_link_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_link_p6_0_0
// static int test_close_link_p4_0_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_link_pc_0_1
// static void setup_close_link_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_link_pe_2_common
// static void setup_close_link_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_link_pe_0_final
// static void setup_close_link_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_link_pe_0_procfinal

/*
 * calls: close link
 */
// static int test_close_link_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_link_p6_0_0
// static int test_close_link_p0_0_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_link_p8_0_1
static void setup_close_link_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_link_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_link_pe_0_proc1
// static void setup_close_link_p0_0_final(void) {
//   
// }
// ^ See setup_close_link_pe_0_procfinal
// static void setup_close_link_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_link_pe_0_procfinal


/*
 * calls: close lseek
 */
static int test_close_lseek_pf_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_lseek_pf_0_1(void) {
  int r = lseek(11, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_close_lseek_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_lseek_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_lseek_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_lseek_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_lseek_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close lseek
 */
// static int test_close_lseek_pf_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pf_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
static void setup_close_lseek_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pf_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pf_2_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
static void setup_close_lseek_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pf_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pf_3_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
static void setup_close_lseek_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pf_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pf_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pf_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pf_4_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_pf_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
static void setup_close_lseek_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pf_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pf_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pf_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pf_5_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
static void setup_close_lseek_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pf_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pf_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pec_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pec_0_1(void) {
  int r = lseek(11, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_close_lseek_pec_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_close_lseek_pec_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_lseek_pec_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_lseek_pec_0_final(void) {
  unlink("__i0");
}
static void setup_close_lseek_pec_0_procfinal(void) {
  
}

/*
 * calls: close lseek
 */
// static int test_close_lseek_pec_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pec_1_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pec_0_1
static void setup_close_lseek_pec_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_lseek_pec_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pec_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pec_2_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pec_0_1
// static void setup_close_lseek_pec_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pec_1_common
static void setup_close_lseek_pec_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pec_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pec_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pe8_0_1(void) {
  int r = lseek(11, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_close_lseek_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
static void setup_close_lseek_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_lseek_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe8_1_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe8_0_1
static void setup_close_lseek_pe8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_lseek_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe8_2_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe8_0_1
// static void setup_close_lseek_pe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
static void setup_close_lseek_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe8_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe8_3_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe8_0_1
// static void setup_close_lseek_pe8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
static void setup_close_lseek_pe8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pe8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe8_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe8_4_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe8_0_1
// static void setup_close_lseek_pe8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
static void setup_close_lseek_pe8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pe8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe8_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe8_5_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe8_0_1
// static void setup_close_lseek_pe8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
static void setup_close_lseek_pe8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_lseek_pe8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_pe8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pe8_5_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe6_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pe6_0_1(void) {
  int r = lseek(11, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_close_lseek_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pe8_5_proc0
// static void setup_close_lseek_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_pe6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pe6_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe6_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe6_1_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe6_0_1
// static void setup_close_lseek_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_3_proc0
// static void setup_close_lseek_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe6_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe6_2_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe6_0_1
// static void setup_close_lseek_pe6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pe6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_4_proc0
// static void setup_close_lseek_pe6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pe4_0_1(void) {
  int r = lseek(11, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_close_lseek_pe4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_pe4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pe8_5_proc0
// static void setup_close_lseek_pe4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_pe4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pe4_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe4_1_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe4_0_1
// static void setup_close_lseek_pe4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pe4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_3_proc0
// static void setup_close_lseek_pe4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe4_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe4_2_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe4_0_1
// static void setup_close_lseek_pe4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pe4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_4_proc0
// static void setup_close_lseek_pe4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe3_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pe3_0_1(void) {
  int r = lseek(11, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_close_lseek_pe3_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_close_lseek_pe3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pe8_0_proc0
// static void setup_close_lseek_pe3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_pe3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pe3_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe3_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe3_1_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe3_0_1
static void setup_close_lseek_pe3_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_lseek_pe3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_1_proc0
// static void setup_close_lseek_pe3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe3_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe3_2_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe3_0_1
// static void setup_close_lseek_pe3_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe3_1_common
// static void setup_close_lseek_pe3_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_2_proc0
// static void setup_close_lseek_pe3_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe3_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe3_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe2_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pe2_0_1(void) {
  int r = lseek(11, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_close_lseek_pe2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_pe2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pe8_0_proc0
// static void setup_close_lseek_pe2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_pe2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pe2_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe2_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe2_1_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe2_0_1
// static void setup_close_lseek_pe2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe3_1_common
// static void setup_close_lseek_pe2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_1_proc0
// static void setup_close_lseek_pe2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe2_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pe2_2_1(void) {
  int r = lseek(11, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static void setup_close_lseek_pe2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_pe2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pe8_5_proc0
// static void setup_close_lseek_pe2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_pe2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pe2_2_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe2_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe2_3_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe2_0_1
// static void setup_close_lseek_pe2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe3_1_common
// static void setup_close_lseek_pe2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_2_proc0
// static void setup_close_lseek_pe2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe2_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe2_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe2_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe2_4_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe2_2_1
// static void setup_close_lseek_pe2_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pe2_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_3_proc0
// static void setup_close_lseek_pe2_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe2_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe2_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe2_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe2_5_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe2_2_1
// static void setup_close_lseek_pe2_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pe2_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_4_proc0
// static void setup_close_lseek_pe2_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe2_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe2_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe0_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pe8_5_proc0
// static void setup_close_lseek_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe0_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_3_proc0
// static void setup_close_lseek_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pe0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pe0_2_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_pe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_pe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pe8_4_proc0
// static void setup_close_lseek_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pe0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pe0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pc_0_1(void) {
  int r = lseek(11, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_close_lseek_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
static void setup_close_lseek_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_lseek_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pc_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pc_0_1
// static void setup_close_lseek_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
static void setup_close_lseek_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pc_2_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pc_0_1
// static void setup_close_lseek_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
static void setup_close_lseek_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pb_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pb_0_1(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_close_lseek_pb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
static void setup_close_lseek_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pb_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pb_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_pb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pb_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pb_2_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_pb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_pb_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pb_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pb_3_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_pb_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_pb_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pb_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pb_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pb_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pb_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pb_4_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_pb_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_pb_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pb_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pb_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pb_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pb_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pb_5_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_pb_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_pb_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pb_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pb_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pb_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pac_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pac_0_1(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_close_lseek_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
static void setup_close_lseek_pac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_lseek_pac_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_lseek_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pac_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pac_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pac_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pac_0_1
static void setup_close_lseek_pac_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_close_lseek_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pac_1_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pac_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pac_2_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pac_0_1
static void setup_close_lseek_pac_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_lseek_pac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pac_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pac_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pac_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pac_3_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pac_0_1
// static void setup_close_lseek_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pec_1_common
// static void setup_close_lseek_pac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
static void setup_close_lseek_pac_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pac_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pac_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pa8_0_1(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_close_lseek_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
static void setup_close_lseek_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_lseek_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_lseek_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa8_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa8_0_1
// static void setup_close_lseek_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
static void setup_close_lseek_pa8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_pa8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa8_2_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa8_0_1
// static void setup_close_lseek_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa8_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa8_3_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa8_0_1
// static void setup_close_lseek_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pa8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pa8_1_proc1
// static void setup_close_lseek_pa8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa8_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa8_4_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa8_0_1
// static void setup_close_lseek_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pa8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa8_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa8_5_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa8_0_1
// static void setup_close_lseek_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pa8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa6_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pa6_0_1(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_close_lseek_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa6_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa6_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa6_0_1
// static void setup_close_lseek_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pa6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa6_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa6_2_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa6_0_1
// static void setup_close_lseek_pa6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pa6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pa6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pa6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pa4_0_1(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_close_lseek_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pa4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa4_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa4_0_1
// static void setup_close_lseek_pa4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pa4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pa4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pa4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa4_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa4_2_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa4_0_1
// static void setup_close_lseek_pa4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pa4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pa4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pa4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa3_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pa3_0_1(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_close_lseek_pa3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_pa3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pa8_0_proc1
// static void setup_close_lseek_pa3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pa8_0_proc1
// static void setup_close_lseek_pa3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pa3_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa3_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa3_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa3_0_1
// static void setup_close_lseek_pa3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe3_1_common
// static void setup_close_lseek_pa3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pa3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pa8_1_proc1
// static void setup_close_lseek_pa3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa3_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa3_2_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa3_0_1
// static void setup_close_lseek_pa3_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe3_1_common
// static void setup_close_lseek_pa3_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pa3_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pa8_1_proc1
// static void setup_close_lseek_pa3_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa3_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa2_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pa2_0_1(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_close_lseek_pa2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_pa2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pa8_0_proc1
// static void setup_close_lseek_pa2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pa8_0_proc1
// static void setup_close_lseek_pa2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pa2_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa2_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa2_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa2_0_1
// static void setup_close_lseek_pa2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe3_1_common
// static void setup_close_lseek_pa2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pa2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pa8_1_proc1
// static void setup_close_lseek_pa2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa2_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_pa2_2_1(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static void setup_close_lseek_pa2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_pa2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pa2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pa2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pa2_2_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa2_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa2_3_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa2_0_1
// static void setup_close_lseek_pa2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe3_1_common
// static void setup_close_lseek_pa2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pa2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pa8_1_proc1
// static void setup_close_lseek_pa2_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa2_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa2_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa2_4_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa2_2_1
// static void setup_close_lseek_pa2_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pa2_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pa2_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pa2_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa2_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa2_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa2_5_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa2_2_1
// static void setup_close_lseek_pa2_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pe8_1_common
// static void setup_close_lseek_pa2_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pa2_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pa2_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa2_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pa0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_pa0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_pa0_2_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_pa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_pa0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_pa0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pb_0_proc0
// static void setup_close_lseek_pa0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_pa0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
static int test_close_lseek_p8_0_1(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_close_lseek_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_p8_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p8_0_1
// static void setup_close_lseek_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_0
// static int test_close_lseek_p8_2_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p8_0_1
// static void setup_close_lseek_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
static int test_close_lseek_p7_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_lseek_p7_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
static void setup_close_lseek_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p7_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p7_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
static void setup_close_lseek_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_lseek_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p6c_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p6c_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pec_0_1
// static void setup_close_lseek_p6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
static void setup_close_lseek_p6c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_lseek_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p6c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p6c_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p68_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p68_0_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe8_0_1
// static void setup_close_lseek_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
static void setup_close_lseek_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_lseek_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p68_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p68_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p68_1_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe8_0_1
// static void setup_close_lseek_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
static void setup_close_lseek_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_lseek_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p68_1_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p66_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p66_0_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe6_0_1
// static void setup_close_lseek_p66_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_p66_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_p68_1_proc0
// static void setup_close_lseek_p66_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p66_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p66_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p64_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p64_0_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe4_0_1
// static void setup_close_lseek_p64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_p64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_p68_1_proc0
// static void setup_close_lseek_p64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p64_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p64_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p63_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p63_0_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe3_0_1
// static void setup_close_lseek_p63_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_p63_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_p68_0_proc0
// static void setup_close_lseek_p63_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p63_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p63_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p62_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p62_0_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe2_0_1
// static void setup_close_lseek_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_p68_0_proc0
// static void setup_close_lseek_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p62_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p62_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p62_1_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pe2_2_1
// static void setup_close_lseek_p62_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_p62_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_p68_1_proc0
// static void setup_close_lseek_p62_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p62_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p62_1_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p60_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p60_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pf_0_1
// static void setup_close_lseek_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_p68_1_proc0
// static void setup_close_lseek_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p60_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p4_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pc_0_1
static void setup_close_lseek_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_lseek_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p4_0_final(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal
// static void setup_close_lseek_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p4_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p8_0_1
// static void setup_close_lseek_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_lseek_p4_0_common
// static void setup_close_lseek_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p4_1_final(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal
// static void setup_close_lseek_p4_1_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p3_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p3_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_1_proc0
// static void setup_close_lseek_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p3_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p3_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_lseek_pf_0_common
// static void setup_close_lseek_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pf_0_proc1
// static void setup_close_lseek_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_lseek_pc_2_proc0
// static void setup_close_lseek_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_final
// static void setup_close_lseek_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_lseek_pf_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p2c_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p2c_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pac_0_1
// static void setup_close_lseek_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pac_0_proc1
// static void setup_close_lseek_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p28_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p28_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa8_0_1
// static void setup_close_lseek_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pa8_0_proc1
// static void setup_close_lseek_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p28_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p28_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p28_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa8_0_1
// static void setup_close_lseek_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p28_1_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p26_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p26_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa6_0_1
// static void setup_close_lseek_p26_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_p26_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p26_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_p26_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p26_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p24_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p24_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa4_0_1
// static void setup_close_lseek_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p24_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p23_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p23_0_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa3_0_1
// static void setup_close_lseek_p23_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_p23_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p23_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pa8_0_proc1
// static void setup_close_lseek_p23_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p23_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p22_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p22_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa2_0_1
// static void setup_close_lseek_p22_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_p22_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p22_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pa8_0_proc1
// static void setup_close_lseek_p22_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p22_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p22_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p22_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pa2_2_1
// static void setup_close_lseek_p22_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_lseek_pec_0_common
// static void setup_close_lseek_p22_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p22_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_p22_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p22_1_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p20_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p20_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_close_lseek_pb_0_1
// static void setup_close_lseek_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_lseek_pe3_0_common
// static void setup_close_lseek_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_lseek_pc_0_proc0
// static void setup_close_lseek_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_lseek_pec_0_final
// static void setup_close_lseek_p20_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal

/*
 * calls: close lseek
 */
// static int test_close_lseek_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p7_0_0
// static int test_close_lseek_p0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_lseek_p8_0_1
// static void setup_close_lseek_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_lseek_p4_0_common
// static void setup_close_lseek_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_lseek_pec_0_proc1
// static void setup_close_lseek_p0_0_final(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal
// static void setup_close_lseek_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_lseek_pec_0_procfinal


/*
 * calls: close memread
 */
static int test_close_memread_pf_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_memread_pf_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static void setup_close_memread_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_memread_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_close_memread_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_memread_pf_0_final(void) {
  unlink("__i0");
}
static void setup_close_memread_pf_0_procfinal(void) {
  
}

/*
 * calls: close memread
 */
// static int test_close_memread_pf_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pf_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
static void setup_close_memread_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_memread_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_pf_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pf_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pf_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pf_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
static void setup_close_memread_pf_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_memread_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_close_memread_pf_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_memread_pf_2_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_memread_pf_2_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close memread
 */
// static int test_close_memread_pf_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pf_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
static void setup_close_memread_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_memread_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pf_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pf_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pf_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pf_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pf_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
static void setup_close_memread_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_memread_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pf_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pf_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pf_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pf_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
static void setup_close_memread_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_memread_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pf_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pf_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
static int test_close_memread_pe8_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static void setup_close_memread_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
static void setup_close_memread_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memread_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
static void setup_close_memread_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memread_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
static void setup_close_memread_pe8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_memread_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memread_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pe8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pe8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe8_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pe8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pe8_2_common
static void setup_close_memread_pe8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memread_pe8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pe8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pe8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe8_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe8_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pe8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
static void setup_close_memread_pe8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memread_pe8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_pe8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pe8_4_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe8_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe8_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pe8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
static void setup_close_memread_pe8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memread_pe8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_pe8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pe8_5_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe8_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe8_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pe8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pe8_2_common
static void setup_close_memread_pe8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memread_pe8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pe8_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pe8_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe8_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe8_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pe8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pe8_2_common
static void setup_close_memread_pe8_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memread_pe8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pe8_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pe8_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
static void setup_close_memread_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_close_memread_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memread_pe8_0_proc0
// static void setup_close_memread_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
// static void setup_close_memread_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memread_pe8_1_proc0
// static void setup_close_memread_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
static void setup_close_memread_pe0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_memread_pe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memread_pe8_2_proc0
// static void setup_close_memread_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pe0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pe0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe0_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pe0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pe0_2_common
// static void setup_close_memread_pe0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memread_pe8_3_proc0
// static void setup_close_memread_pe0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pe0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pe0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe0_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe0_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pe0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
// static void setup_close_memread_pe0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memread_pe8_4_proc0
// static void setup_close_memread_pe0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_pe0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pe0_4_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe0_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe0_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pe0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
// static void setup_close_memread_pe0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memread_pe8_5_proc0
// static void setup_close_memread_pe0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_pe0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pe0_5_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe0_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe0_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pe0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pe0_2_common
// static void setup_close_memread_pe0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memread_pe8_6_proc0
// static void setup_close_memread_pe0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pe0_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pe0_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pe0_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pe0_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pe0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pe0_2_common
// static void setup_close_memread_pe0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memread_pe8_7_proc0
// static void setup_close_memread_pe0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pe0_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pe0_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
static int test_close_memread_pc_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_close_memread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
static void setup_close_memread_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_memread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pc_0_1
// static void setup_close_memread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
static void setup_close_memread_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_memread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pc_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pc_0_1
// static void setup_close_memread_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
static void setup_close_memread_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_memread_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pb_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pb_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
// static void setup_close_memread_pb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memread_pc_0_proc0
static void setup_close_memread_pb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_memread_pb_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pb_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pb_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pb_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
// static void setup_close_memread_pb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memread_pc_0_proc0
static void setup_close_memread_pb_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_memread_pb_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pb_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pb_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pb_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
// static void setup_close_memread_pb_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_1_proc0
static void setup_close_memread_pb_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_memread_pb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pb_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pb_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pb_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
// static void setup_close_memread_pb_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_2_proc0
// static void setup_close_memread_pb_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_close_memread_pb_2_proc1
// static void setup_close_memread_pb_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pb_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pb_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pb_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pb_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
// static void setup_close_memread_pb_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_1_proc0
static void setup_close_memread_pb_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_memread_pb_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pb_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pb_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pb_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pb_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
// static void setup_close_memread_pb_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_2_proc0
// static void setup_close_memread_pb_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_close_memread_pb_4_proc1
// static void setup_close_memread_pb_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pb_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
static void setup_close_memread_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_memread_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_close_memread_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
static void setup_close_memread_pa8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_memread_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_1_proc0
static void setup_close_memread_pa8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_close_memread_pa8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pa8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
static void setup_close_memread_pa8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_memread_pa8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
// static void setup_close_memread_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa8_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pa8_1_common
// static void setup_close_memread_pa8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_2_proc0
// static void setup_close_memread_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_close_memread_pa8_1_proc1
// static void setup_close_memread_pa8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pa8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa8_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa8_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
static void setup_close_memread_pa8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_memread_pa8_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_close_memread_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa8_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa8_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
// static void setup_close_memread_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memread_pa8_2_proc0
static void setup_close_memread_pa8_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x704000);
}
// static void setup_close_memread_pa8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa8_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa8_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pa8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pa8_1_common
// static void setup_close_memread_pa8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_1_proc0
static void setup_close_memread_pa8_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_close_memread_pa8_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pa8_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa8_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa8_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_pa8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pa8_1_common
// static void setup_close_memread_pa8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_2_proc0
// static void setup_close_memread_pa8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_close_memread_pa8_6_proc1
// static void setup_close_memread_pa8_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pa8_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
static void setup_close_memread_pa0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_memread_pa0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
// static void setup_close_memread_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memread_pa0_0_proc0
static void setup_close_memread_pa0_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memread_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pe0_2_common
// static void setup_close_memread_pa0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_1_proc0
static void setup_close_memread_pa0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memread_pa0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pa0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa0_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pa0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pe0_2_common
// static void setup_close_memread_pa0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_1_proc0
static void setup_close_memread_pa0_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memread_pa0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pa0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa0_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa0_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pa0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
// static void setup_close_memread_pa0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memread_pc_0_proc0
// static void setup_close_memread_pa0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memread_pa0_0_proc1
// static void setup_close_memread_pa0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pa0_4_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa0_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa0_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pa0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
// static void setup_close_memread_pa0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memread_pc_0_proc0
// static void setup_close_memread_pa0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memread_pa0_1_proc1
// static void setup_close_memread_pa0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_pa0_5_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa0_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa0_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pa0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pe0_2_common
// static void setup_close_memread_pa0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_2_proc0
// static void setup_close_memread_pa0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memread_pa0_2_proc1
// static void setup_close_memread_pa0_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pa0_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_pa0_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_pa0_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_pa0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pe0_2_common
// static void setup_close_memread_pa0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_2_proc0
// static void setup_close_memread_pa0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memread_pa0_3_proc1
// static void setup_close_memread_pa0_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_pa0_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_p8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pc_0_1
// static void setup_close_memread_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
// static void setup_close_memread_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memread_pc_0_proc0
// static void setup_close_memread_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_p8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pc_0_1
// static void setup_close_memread_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
// static void setup_close_memread_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_1_proc0
// static void setup_close_memread_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memread_pf_0_0
// static int test_close_memread_p8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pc_0_1
// static void setup_close_memread_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memread_pf_2_common
// static void setup_close_memread_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pc_2_proc0
// static void setup_close_memread_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memread_pf_2_proc1
// static void setup_close_memread_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_final
// static void setup_close_memread_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memread_pf_2_procfinal

/*
 * calls: close memread
 */
static int test_close_memread_p7_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_memread_p7_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
static void setup_close_memread_p7_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_memread_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_close_memread_pb_0_proc1
// static void setup_close_memread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p7_0_final(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal
// static void setup_close_memread_p7_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p7_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p7_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_memread_p7_0_common
// static void setup_close_memread_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_close_memread_pb_1_proc1
// static void setup_close_memread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p7_1_final(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal
// static void setup_close_memread_p7_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p68_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p68_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
// static void setup_close_memread_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memread_pa0_0_proc1
// static void setup_close_memread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p68_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p68_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
// static void setup_close_memread_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memread_pa0_1_proc1
// static void setup_close_memread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p60_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p60_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
// static void setup_close_memread_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memread_pa0_0_proc1
// static void setup_close_memread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p60_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p60_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
// static void setup_close_memread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memread_pa0_1_proc1
// static void setup_close_memread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pc_0_1
// static void setup_close_memread_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_memread_p7_0_common
// static void setup_close_memread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p4_0_final(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal
// static void setup_close_memread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p3_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p3_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_memread_p7_0_common
// static void setup_close_memread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_close_memread_pb_0_proc1
// static void setup_close_memread_p3_0_final(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal
// static void setup_close_memread_p3_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p3_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p3_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_memread_p7_0_common
// static void setup_close_memread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_close_memread_pb_1_proc1
// static void setup_close_memread_p3_1_final(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal
// static void setup_close_memread_p3_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p28_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p28_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
// static void setup_close_memread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_close_memread_pa8_0_proc1
// static void setup_close_memread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p28_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p28_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pe8_0_1
// static void setup_close_memread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memread_pf_0_common
// static void setup_close_memread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
static void setup_close_memread_p28_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_close_memread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p20_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p20_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
// static void setup_close_memread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memread_pa0_0_proc1
// static void setup_close_memread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p20_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p20_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_close_memread_pf_0_1
// static void setup_close_memread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memread_pe0_0_common
// static void setup_close_memread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memread_pa0_1_proc1
// static void setup_close_memread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memread_pf_0_final
// static void setup_close_memread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal

/*
 * calls: close memread
 */
// static int test_close_memread_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memread_p7_0_0
// static int test_close_memread_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memread_pc_0_1
// static void setup_close_memread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_memread_p7_0_common
// static void setup_close_memread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memread_pf_0_proc1
// static void setup_close_memread_p0_0_final(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal
// static void setup_close_memread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_memread_pf_0_procfinal


/*
 * calls: close memwrite
 */
static int test_close_memwrite_pf8_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_memwrite_pf8_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static void setup_close_memwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_memwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_close_memwrite_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_memwrite_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_close_memwrite_pf8_0_procfinal(void) {
  
}

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pf8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pf8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
static void setup_close_memwrite_pf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_memwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_close_memwrite_pf8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_memwrite_pf8_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_memwrite_pf8_1_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pf8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pf8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
static void setup_close_memwrite_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_memwrite_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pf4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
static int test_close_memwrite_pf4_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static void setup_close_memwrite_pf4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
static void setup_close_memwrite_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_close_memwrite_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_pf4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pf4_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pf4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pf4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pf4_0_1
// static void setup_close_memwrite_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
static void setup_close_memwrite_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x704000);
}
// static void setup_close_memwrite_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pf4_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pf4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pf4_0_1
static void setup_close_memwrite_pf4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_memwrite_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_close_memwrite_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pf4_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pf4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pf4_0_1
// static void setup_close_memwrite_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf4_2_common
static void setup_close_memwrite_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_close_memwrite_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pf0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pf0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
static void setup_close_memwrite_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_close_memwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pf0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pf0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
static void setup_close_memwrite_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_memwrite_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pf0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pf0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memwrite_pf0_0_common
static void setup_close_memwrite_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_pf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pf0_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pf0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf0_1_common
static void setup_close_memwrite_pf0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pe_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
static int test_close_memwrite_pe_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_close_memwrite_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
static void setup_close_memwrite_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pe_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pe_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pe_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
static void setup_close_memwrite_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_memwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pe_1_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pe_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pe_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
static void setup_close_memwrite_pe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memwrite_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pe_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pe_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pe_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
static void setup_close_memwrite_pe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memwrite_pe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pe_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pe_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pe_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
static void setup_close_memwrite_pe_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_memwrite_pe_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pe_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pe_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pe_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pe_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pe_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
static void setup_close_memwrite_pe_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_memwrite_pe_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pe_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pe_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
static void setup_close_memwrite_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_memwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
static void setup_close_memwrite_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_memwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pc_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
static void setup_close_memwrite_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_memwrite_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
// static void setup_close_memwrite_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memwrite_pc_0_proc0
static void setup_close_memwrite_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_memwrite_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
// static void setup_close_memwrite_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_1_proc0
static void setup_close_memwrite_pb8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_memwrite_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
// static void setup_close_memwrite_pb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_2_proc0
// static void setup_close_memwrite_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_close_memwrite_pb8_1_proc1
// static void setup_close_memwrite_pb8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pb8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pf4_0_1
// static void setup_close_memwrite_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
static void setup_close_memwrite_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_memwrite_pb4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memwrite_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pf4_0_1
static void setup_close_memwrite_pb4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_memwrite_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_1_proc0
static void setup_close_memwrite_pb4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_memwrite_pb4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pb4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb4_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pf4_0_1
// static void setup_close_memwrite_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
// static void setup_close_memwrite_pb4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memwrite_pc_0_proc0
// static void setup_close_memwrite_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pb4_0_proc1
// static void setup_close_memwrite_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb4_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pf4_0_1
// static void setup_close_memwrite_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pb4_1_common
// static void setup_close_memwrite_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_2_proc0
// static void setup_close_memwrite_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pb4_1_proc1
// static void setup_close_memwrite_pb4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pb4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memwrite_pf0_0_common
// static void setup_close_memwrite_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memwrite_pb4_0_proc0
// static void setup_close_memwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pb4_0_proc1
// static void setup_close_memwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf0_1_common
// static void setup_close_memwrite_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_1_proc0
// static void setup_close_memwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pb4_1_proc1
// static void setup_close_memwrite_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memwrite_pf0_0_common
// static void setup_close_memwrite_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memwrite_pc_0_proc0
// static void setup_close_memwrite_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pb4_0_proc1
// static void setup_close_memwrite_pb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pb0_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pb0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf0_1_common
// static void setup_close_memwrite_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_2_proc0
// static void setup_close_memwrite_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pb4_1_proc1
// static void setup_close_memwrite_pb0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pb0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pa_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pa_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
// static void setup_close_memwrite_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memwrite_pc_0_proc0
static void setup_close_memwrite_pa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memwrite_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pa_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pa_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pa_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
// static void setup_close_memwrite_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memwrite_pc_0_proc0
static void setup_close_memwrite_pa_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_memwrite_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_pa_1_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pa_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pa_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
// static void setup_close_memwrite_pa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_1_proc0
static void setup_close_memwrite_pa_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_memwrite_pa_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pa_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pa_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pa_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
// static void setup_close_memwrite_pa_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_2_proc0
// static void setup_close_memwrite_pa_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pa_2_proc1
// static void setup_close_memwrite_pa_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pa_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pa_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pa_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pa_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
// static void setup_close_memwrite_pa_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_1_proc0
static void setup_close_memwrite_pa_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_memwrite_pa_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pa_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_pa_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_pa_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_pa_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
// static void setup_close_memwrite_pa_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_2_proc0
// static void setup_close_memwrite_pa_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_close_memwrite_pa_4_proc1
// static void setup_close_memwrite_pa_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_pa_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_p8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
// static void setup_close_memwrite_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_memwrite_pc_0_proc0
// static void setup_close_memwrite_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_p8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
// static void setup_close_memwrite_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_1_proc0
// static void setup_close_memwrite_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_pf8_0_0
// static int test_close_memwrite_p8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_memwrite_pf8_1_common
// static void setup_close_memwrite_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pc_2_proc0
// static void setup_close_memwrite_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_memwrite_pf8_1_proc1
// static void setup_close_memwrite_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_final
// static void setup_close_memwrite_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_memwrite_pf8_1_procfinal

/*
 * calls: close memwrite
 */
static int test_close_memwrite_p78_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_memwrite_p78_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
static void setup_close_memwrite_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_memwrite_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_close_memwrite_pb8_0_proc1
// static void setup_close_memwrite_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p78_0_final(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal
// static void setup_close_memwrite_p78_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p74_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p74_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pf4_0_1
// static void setup_close_memwrite_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
static void setup_close_memwrite_p74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_close_memwrite_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p74_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_p74_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p70_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p70_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memwrite_pf0_0_common
// static void setup_close_memwrite_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pb4_0_proc1
// static void setup_close_memwrite_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_p70_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p6_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p6_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
// static void setup_close_memwrite_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pa_0_proc1
// static void setup_close_memwrite_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_p6_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p6_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p6_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_memwrite_p78_0_common
// static void setup_close_memwrite_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_close_memwrite_pa_1_proc1
// static void setup_close_memwrite_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p6_1_final(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal
// static void setup_close_memwrite_p6_1_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_memwrite_p78_0_common
// static void setup_close_memwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p4_0_final(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal
// static void setup_close_memwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p38_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p38_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_memwrite_p78_0_common
// static void setup_close_memwrite_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_close_memwrite_pb8_0_proc1
// static void setup_close_memwrite_p38_0_final(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal
// static void setup_close_memwrite_p38_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p34_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p34_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pf4_0_1
// static void setup_close_memwrite_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
// static void setup_close_memwrite_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pb4_0_proc1
// static void setup_close_memwrite_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_p34_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p30_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p30_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_close_memwrite_pf8_0_1
// static void setup_close_memwrite_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_memwrite_pf0_0_common
// static void setup_close_memwrite_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pb4_0_proc1
// static void setup_close_memwrite_p30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_p30_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p2_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p2_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_memwrite_pf8_0_common
// static void setup_close_memwrite_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_memwrite_pa_0_proc1
// static void setup_close_memwrite_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_memwrite_pf8_0_final
// static void setup_close_memwrite_p2_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p2_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p2_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_memwrite_p78_0_common
// static void setup_close_memwrite_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_close_memwrite_pa_1_proc1
// static void setup_close_memwrite_p2_1_final(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal
// static void setup_close_memwrite_p2_1_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal

/*
 * calls: close memwrite
 */
// static int test_close_memwrite_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_memwrite_p78_0_0
// static int test_close_memwrite_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_close_memwrite_pe_0_1
// static void setup_close_memwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_memwrite_p78_0_common
// static void setup_close_memwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_memwrite_pf8_0_proc1
// static void setup_close_memwrite_p0_0_final(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal
// static void setup_close_memwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_memwrite_pf8_0_procfinal


/*
 * calls: close mmap
 */
static int test_close_mmap_pf0_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_mmap_pf0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_close_mmap_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_mmap_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_mmap_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_mmap_pf0_0_final(void) {
  unlink("__i0");
}
static void setup_close_mmap_pf0_0_procfinal(void) {
  
}

/*
 * calls: close mmap
 */
// static int test_close_mmap_pf0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pf0_1_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_close_mmap_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pf0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pf0_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_1
static void setup_close_mmap_pf0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_mmap_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_mmap_pf0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_mmap_pf0_2_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_mmap_pf0_2_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close mmap
 */
// static int test_close_mmap_pf0_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pf0_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_1_1
// static void setup_close_mmap_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pf0_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pf0_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_1
// static void setup_close_mmap_pf0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
static void setup_close_mmap_pf0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pf0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pf0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pf0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pf0_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pf0_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_1_1
// static void setup_close_mmap_pf0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pf0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pf0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pf0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pf0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pec_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pec_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_close_mmap_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
static void setup_close_mmap_pec_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pec_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pec_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pec_0_1
// static void setup_close_mmap_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
static void setup_close_mmap_pec_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pec_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pec_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pec_0_1
// static void setup_close_mmap_pec_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
static void setup_close_mmap_pec_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pec_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pec_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pec_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pec_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pec_0_1
// static void setup_close_mmap_pec_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
static void setup_close_mmap_pec_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pec_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pec_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pec_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pec_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pec_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pec_0_1
// static void setup_close_mmap_pec_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
static void setup_close_mmap_pec_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pec_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pec_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pec_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pec_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pec_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pec_0_1
// static void setup_close_mmap_pec_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
static void setup_close_mmap_pec_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pec_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pec_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pec_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pe8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pe8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_close_mmap_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_close_mmap_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_mmap_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pe8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pe8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pe8_0_1
static void setup_close_mmap_pe8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_mmap_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pe8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pe8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pe8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pe8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pe8_0_1
// static void setup_close_mmap_pe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
static void setup_close_mmap_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pe8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pe8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pe0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pe0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_close_mmap_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pe0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pe0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pe0_0_1
// static void setup_close_mmap_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pe0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pe0_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pe0_0_1
// static void setup_close_mmap_pe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pe0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pe0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pd8_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_close_mmap_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pd8_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_close_mmap_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pd8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pd8_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pd8_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_0_1
// static void setup_close_mmap_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pd8_3_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_close_mmap_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pd8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pd8_3_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pd8_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_1_1
// static void setup_close_mmap_pd8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pd8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pd8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pd8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pd8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pd8_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_3_1
// static void setup_close_mmap_pd8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pd8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pd8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pd8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pd8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pd8_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_3_1
// static void setup_close_mmap_pd8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
static void setup_close_mmap_pd8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_mmap_pd8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pd8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pd8_6_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pd8_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_3_1
// static void setup_close_mmap_pd8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pd8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pec_0_proc0
// static void setup_close_mmap_pd8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pd8_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pd8_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_8_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pd8_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_0_1
// static void setup_close_mmap_pd8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pd8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pd8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pd8_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pd8_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_9_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pd8_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_1_1
// static void setup_close_mmap_pd8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pd8_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pd8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pd8_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pd8_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_10_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pd8_10_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_close_mmap_pd8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pd8_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pd8_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pd8_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pd8_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pd8_11_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pd8_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_3_1
// static void setup_close_mmap_pd8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pd8_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pd8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pd8_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pd8_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pcc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pcc_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_close_mmap_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pec_0_proc0
// static void setup_close_mmap_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pcc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pcc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pcc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pcc_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pcc_0_1
// static void setup_close_mmap_pcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pec_1_proc0
// static void setup_close_mmap_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pcc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pcc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pcc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pcc_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pcc_0_1
// static void setup_close_mmap_pcc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pcc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pec_2_proc0
// static void setup_close_mmap_pcc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pcc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pcc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pcc_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pcc_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pcc_0_1
// static void setup_close_mmap_pcc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pcc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pec_3_proc0
// static void setup_close_mmap_pcc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pcc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pcc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pcc_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pcc_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pcc_0_1
// static void setup_close_mmap_pcc_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pcc_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pec_4_proc0
// static void setup_close_mmap_pcc_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pcc_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pcc_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pcc_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pcc_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pcc_0_1
// static void setup_close_mmap_pcc_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pcc_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pec_5_proc0
// static void setup_close_mmap_pcc_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pcc_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pcc_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pca_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_close_mmap_pca_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_pca_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_proc0
// static void setup_close_mmap_pca_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pca_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pca_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pca_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_close_mmap_pca_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_pca_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_proc0
// static void setup_close_mmap_pca_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pca_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pca_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pca_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_0_1
// static void setup_close_mmap_pca_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_pca_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pd8_6_proc0
// static void setup_close_mmap_pca_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pca_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pca_2_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pca_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_1_1
// static void setup_close_mmap_pca_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_pca_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pd8_6_proc0
// static void setup_close_mmap_pca_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pca_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pca_3_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pca_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_0_1
// static void setup_close_mmap_pca_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_pca_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pe8_1_proc0
// static void setup_close_mmap_pca_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pca_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pca_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pca_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_1_1
// static void setup_close_mmap_pca_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_pca_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pe8_1_proc0
// static void setup_close_mmap_pca_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pca_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pca_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pca_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_0_1
// static void setup_close_mmap_pca_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
static void setup_close_mmap_pca_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pca_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pca_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pca_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pca_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_0_1
// static void setup_close_mmap_pca_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_pca_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pe8_2_proc0
// static void setup_close_mmap_pca_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pca_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pca_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_8_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pca_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_0_1
// static void setup_close_mmap_pca_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
static void setup_close_mmap_pca_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pca_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pca_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pca_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_9_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pca_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_1_1
// static void setup_close_mmap_pca_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_pca_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pca_6_proc0
// static void setup_close_mmap_pca_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pca_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pca_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_10_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pca_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_1_1
// static void setup_close_mmap_pca_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_pca_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pe8_2_proc0
// static void setup_close_mmap_pca_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pca_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pca_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pca_11_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pca_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_1_1
// static void setup_close_mmap_pca_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_pca_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pca_8_proc0
// static void setup_close_mmap_pca_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pca_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pca_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pc0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pc0_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_close_mmap_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pc0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pc0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pc0_0_1
// static void setup_close_mmap_pc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pc0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pc0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pc0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pc0_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pc0_0_1
// static void setup_close_mmap_pc0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pc0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pc0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pc0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pc0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pb0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pb0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_1
// static void setup_close_mmap_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pb0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pb0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_1
// static void setup_close_mmap_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pb0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pb0_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_1
// static void setup_close_mmap_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pb0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pb0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pac_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pac_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_close_mmap_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
static void setup_close_mmap_pac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pac_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pac_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pac_0_1
// static void setup_close_mmap_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pac_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pac_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pac_0_1
// static void setup_close_mmap_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pac_0_proc0
// static void setup_close_mmap_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pac_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pac_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pac_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pac_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pac_0_1
// static void setup_close_mmap_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pac_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pac_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pac_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pac_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pac_0_1
// static void setup_close_mmap_pac_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pac_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pac_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pac_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pac_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pac_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pac_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pac_0_1
// static void setup_close_mmap_pac_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pac_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pac_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pac_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pac_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pa8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pa8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_close_mmap_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
static void setup_close_mmap_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_mmap_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_mmap_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pa8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pa8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pa8_0_1
// static void setup_close_mmap_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
static void setup_close_mmap_pa8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_pa8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pa8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pa8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pa8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pa8_0_1
// static void setup_close_mmap_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pa8_1_proc1
// static void setup_close_mmap_pa8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pa8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pa0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_pa0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_close_mmap_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pa0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pa0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pa0_0_1
// static void setup_close_mmap_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pa0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pa0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_pa0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_pa0_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pa0_0_1
// static void setup_close_mmap_pa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_pa0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_pa0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_pa0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_pa0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p98_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p98_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_0_1
// static void setup_close_mmap_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p98_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p98_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p98_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_10_1
// static void setup_close_mmap_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p98_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p98_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p98_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_0_1
// static void setup_close_mmap_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p98_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p98_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p98_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p98_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p98_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_0_1
// static void setup_close_mmap_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p98_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p98_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p98_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p98_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_10_1
// static void setup_close_mmap_p98_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p98_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p98_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p98_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p98_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p98_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p98_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_10_1
// static void setup_close_mmap_p98_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p98_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p98_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p98_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p98_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8c_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_p8c_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_close_mmap_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pac_0_proc0
// static void setup_close_mmap_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8c_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8c_0_1
// static void setup_close_mmap_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8c_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8c_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8c_0_1
// static void setup_close_mmap_p8c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p8c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pac_0_proc0
// static void setup_close_mmap_p8c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p8c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8c_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8c_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8c_0_1
// static void setup_close_mmap_p8c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p8c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p8c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p8c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8c_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8c_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8c_0_1
// static void setup_close_mmap_p8c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p8c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p8c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p8c_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8c_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8c_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8c_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8c_0_1
// static void setup_close_mmap_p8c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p8c_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p8c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p8c_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8c_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_p8a_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_close_mmap_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pa8_0_proc1
// static void setup_close_mmap_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pa8_0_proc1
// static void setup_close_mmap_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_p8a_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_close_mmap_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pa8_0_proc1
// static void setup_close_mmap_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pa8_0_proc1
// static void setup_close_mmap_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8a_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_0_1
// static void setup_close_mmap_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_p8a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p8a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pa8_1_proc1
// static void setup_close_mmap_p8a_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8a_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8a_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_0_1
// static void setup_close_mmap_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_p8a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p8a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pac_0_proc0
// static void setup_close_mmap_p8a_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8a_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8a_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_0_1
// static void setup_close_mmap_p8a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_p8a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p8a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pa8_1_proc1
// static void setup_close_mmap_p8a_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8a_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8a_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_0_1
// static void setup_close_mmap_p8a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_p8a_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p8a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pac_0_proc0
// static void setup_close_mmap_p8a_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8a_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8a_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_1_1
// static void setup_close_mmap_p8a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_p8a_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p8a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pa8_1_proc1
// static void setup_close_mmap_p8a_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8a_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8a_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_1_1
// static void setup_close_mmap_p8a_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_p8a_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p8a_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pac_0_proc0
// static void setup_close_mmap_p8a_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8a_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_8_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8a_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_1_1
// static void setup_close_mmap_p8a_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_p8a_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p8a_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pa8_1_proc1
// static void setup_close_mmap_p8a_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8a_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_9_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8a_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_1_1
// static void setup_close_mmap_p8a_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pe8_1_common
// static void setup_close_mmap_p8a_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p8a_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pac_0_proc0
// static void setup_close_mmap_p8a_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p8a_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_10_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8a_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_0_1
// static void setup_close_mmap_p8a_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p8a_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_p8a_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_p8a_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p8a_10_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p8a_11_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p8a_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_1_1
// static void setup_close_mmap_p8a_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p8a_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_p8a_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_p8a_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p8a_11_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p80_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
static int test_close_mmap_p80_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_close_mmap_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p80_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p80_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p80_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p80_0_1
// static void setup_close_mmap_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p80_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p80_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p80_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_0
// static int test_close_mmap_p80_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p80_0_1
// static void setup_close_mmap_p80_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p80_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p80_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p80_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p80_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
static int test_close_mmap_p70_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_mmap_p70_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_1
static void setup_close_mmap_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_mmap_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p70_0_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p70_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p70_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p70_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_1_1
// static void setup_close_mmap_p70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
static void setup_close_mmap_p70_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_mmap_p70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p70_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p6c_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p6c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pec_0_1
// static void setup_close_mmap_p6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
static void setup_close_mmap_p6c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p6c_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p6c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pec_0_1
// static void setup_close_mmap_p6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
static void setup_close_mmap_p6c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mmap_p6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p6c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p6c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p68_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p68_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pe8_0_1
// static void setup_close_mmap_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
static void setup_close_mmap_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_mmap_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p68_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p60_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p60_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pe0_0_1
// static void setup_close_mmap_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p60_0_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p60_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p60_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p60_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pa0_0_1
// static void setup_close_mmap_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p60_1_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p60_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p58_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p58_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_0_1
// static void setup_close_mmap_p58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p58_0_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p58_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p58_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p58_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_10_1
// static void setup_close_mmap_p58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p58_1_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p58_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p58_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p58_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_1_1
// static void setup_close_mmap_p58_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_p58_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_p70_1_proc0
// static void setup_close_mmap_p58_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p58_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p58_2_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p58_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p58_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_3_1
// static void setup_close_mmap_p58_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_common
// static void setup_close_mmap_p58_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_p70_1_proc0
// static void setup_close_mmap_p58_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p58_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p58_3_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p4c_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p4c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pcc_0_1
// static void setup_close_mmap_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_p6c_0_proc0
// static void setup_close_mmap_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p4c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p4c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p4c_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p4c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pcc_0_1
// static void setup_close_mmap_p4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_p6c_1_proc0
// static void setup_close_mmap_p4c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p4c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p4c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p4a_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p4a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_0_1
// static void setup_close_mmap_p4a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p4a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_p68_0_proc0
// static void setup_close_mmap_p4a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p4a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p4a_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p4a_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p4a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_1_1
// static void setup_close_mmap_p4a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p4a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_p68_0_proc0
// static void setup_close_mmap_p4a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p4a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p4a_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p4a_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p4a_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_0_1
// static void setup_close_mmap_p4a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p4a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_p70_1_proc0
// static void setup_close_mmap_p4a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p4a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p4a_2_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p4a_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p4a_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pca_1_1
// static void setup_close_mmap_p4a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p4a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_p70_1_proc0
// static void setup_close_mmap_p4a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p4a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p4a_3_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p40_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p40_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pc0_0_1
// static void setup_close_mmap_p40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p40_0_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p40_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p40_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p40_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p80_0_1
// static void setup_close_mmap_p40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p40_1_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p40_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p30_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p30_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pf0_0_1
// static void setup_close_mmap_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p30_0_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p30_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p2c_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p2c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pac_0_1
// static void setup_close_mmap_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p2c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p2c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p2c_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p2c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pac_0_1
// static void setup_close_mmap_p2c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p2c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p2c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p2c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p2c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p28_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p28_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pa8_0_1
// static void setup_close_mmap_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pa8_0_proc1
// static void setup_close_mmap_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p28_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p20_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p20_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_pa0_0_1
// static void setup_close_mmap_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p20_0_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p20_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p18_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_0_1
// static void setup_close_mmap_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p18_0_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p18_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p18_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_pd8_10_1
// static void setup_close_mmap_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p18_1_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p18_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p0c_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p0c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8c_0_1
// static void setup_close_mmap_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc0
// static void setup_close_mmap_p0c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p0c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p0c_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p0c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8c_0_1
// static void setup_close_mmap_p0c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mmap_pf0_2_common
// static void setup_close_mmap_p0c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_2_proc1
// static void setup_close_mmap_p0c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mmap_pf0_4_proc0
// static void setup_close_mmap_p0c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_final
// static void setup_close_mmap_p0c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mmap_pf0_2_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p0a_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p0a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_0_1
// static void setup_close_mmap_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pa8_0_proc1
// static void setup_close_mmap_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p0a_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p0a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_1_1
// static void setup_close_mmap_p0a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p0a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p0a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pa8_0_proc1
// static void setup_close_mmap_p0a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p0a_1_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p0a_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p0a_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_0_1
// static void setup_close_mmap_p0a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p0a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p0a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_p0a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p0a_2_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p0a_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p0a_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_close_mmap_p8a_1_1
// static void setup_close_mmap_p0a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_mmap_pe8_0_common
// static void setup_close_mmap_p0a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p0a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mmap_pf0_0_proc0
// static void setup_close_mmap_p0a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mmap_pf0_0_final
// static void setup_close_mmap_p0a_3_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal

/*
 * calls: close mmap
 */
// static int test_close_mmap_p00_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p70_0_0
// static int test_close_mmap_p00_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mmap_p80_0_1
// static void setup_close_mmap_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mmap_p70_0_common
// static void setup_close_mmap_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mmap_pf0_0_proc1
// static void setup_close_mmap_p00_0_final(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal
// static void setup_close_mmap_p00_0_procfinal(void) {
//   
// }
// ^ See setup_close_mmap_pf0_0_procfinal


/*
 * calls: close mprotect
 */
static int test_close_mprotect_pe_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_mprotect_pe_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_close_mprotect_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_mprotect_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_close_mprotect_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_mprotect_pe_0_final(void) {
  unlink("__i0");
}
static void setup_close_mprotect_pe_0_procfinal(void) {
  
}

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
static void setup_close_mprotect_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_mprotect_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_pe_1_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
static void setup_close_mprotect_pe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_mprotect_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_pe_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_pe_2_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
static void setup_close_mprotect_pe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_mprotect_pe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_pe_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_pe_3_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
static void setup_close_mprotect_pe_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_mprotect_pe_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_close_mprotect_pe_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_mprotect_pe_4_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_mprotect_pe_4_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pe_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
static void setup_close_mprotect_pe_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_mprotect_pe_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_pe_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pe_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pe_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
static void setup_close_mprotect_pe_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_mprotect_pe_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_pe_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pe_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pe_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
static void setup_close_mprotect_pe_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_mprotect_pe_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_pe_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pe_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_8_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pe_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
static void setup_close_mprotect_pe_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_mprotect_pe_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_pe_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pe_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_9_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pe_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
static void setup_close_mprotect_pe_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_mprotect_pe_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_pe_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pe_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_10_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pe_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
static void setup_close_mprotect_pe_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_mprotect_pe_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_pe_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pe_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pe_11_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pe_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pe_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
static void setup_close_mprotect_pe_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_mprotect_pe_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_pe_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pe_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
static int test_close_mprotect_pc_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_close_mprotect_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
static void setup_close_mprotect_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_mprotect_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pc_0_1
// static void setup_close_mprotect_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
static void setup_close_mprotect_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mprotect_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pc_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pc_0_1
// static void setup_close_mprotect_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
static void setup_close_mprotect_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_mprotect_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
// static void setup_close_mprotect_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mprotect_pc_0_proc0
static void setup_close_mprotect_pa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_mprotect_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_pa_0_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
// static void setup_close_mprotect_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mprotect_pc_0_proc0
static void setup_close_mprotect_pa_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_mprotect_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_pa_1_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
// static void setup_close_mprotect_pa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pc_1_proc0
static void setup_close_mprotect_pa_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_close_mprotect_pa_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pa_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
// static void setup_close_mprotect_pa_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pc_1_proc0
static void setup_close_mprotect_pa_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_close_mprotect_pa_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pa_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
// static void setup_close_mprotect_pa_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mprotect_pc_0_proc0
static void setup_close_mprotect_pa_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_mprotect_pa_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_pa_4_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
// static void setup_close_mprotect_pa_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pc_1_proc0
static void setup_close_mprotect_pa_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_close_mprotect_pa_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pa_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
// static void setup_close_mprotect_pa_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mprotect_pc_0_proc0
static void setup_close_mprotect_pa_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_mprotect_pa_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_pa_6_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_7_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
// static void setup_close_mprotect_pa_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pc_1_proc0
static void setup_close_mprotect_pa_7_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_close_mprotect_pa_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pa_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_8_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
// static void setup_close_mprotect_pa_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pc_2_proc0
// static void setup_close_mprotect_pa_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_mprotect_pa_2_proc1
// static void setup_close_mprotect_pa_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pa_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_9_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
// static void setup_close_mprotect_pa_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pc_2_proc0
// static void setup_close_mprotect_pa_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_mprotect_pa_5_proc1
// static void setup_close_mprotect_pa_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pa_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_10_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
// static void setup_close_mprotect_pa_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pc_2_proc0
// static void setup_close_mprotect_pa_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_close_mprotect_pa_3_proc1
// static void setup_close_mprotect_pa_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pa_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_pa_11_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_pa_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_pa_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
// static void setup_close_mprotect_pa_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pc_2_proc0
// static void setup_close_mprotect_pa_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_close_mprotect_pa_7_proc1
// static void setup_close_mprotect_pa_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_pa_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_p8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pc_0_1
// static void setup_close_mprotect_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
// static void setup_close_mprotect_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_mprotect_pc_0_proc0
// static void setup_close_mprotect_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_p8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pc_0_1
// static void setup_close_mprotect_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
// static void setup_close_mprotect_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pc_1_proc0
// static void setup_close_mprotect_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_0
// static int test_close_mprotect_p8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pc_0_1
// static void setup_close_mprotect_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_mprotect_pe_4_common
// static void setup_close_mprotect_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pc_2_proc0
// static void setup_close_mprotect_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_mprotect_pe_4_proc1
// static void setup_close_mprotect_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_final
// static void setup_close_mprotect_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_mprotect_pe_4_procfinal

/*
 * calls: close mprotect
 */
static int test_close_mprotect_p6_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_mprotect_p6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
// static void setup_close_mprotect_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_mprotect_pa_0_proc1
// static void setup_close_mprotect_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_p6_0_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p6_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_p6_0_0
// static int test_close_mprotect_p6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
static void setup_close_mprotect_p6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_mprotect_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_close_mprotect_pa_1_proc1
// static void setup_close_mprotect_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p6_1_final(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal
// static void setup_close_mprotect_p6_1_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p6_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_p6_0_0
// static int test_close_mprotect_p6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_p6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
// static void setup_close_mprotect_p6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_mprotect_pa_4_proc1
// static void setup_close_mprotect_p6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_p6_2_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p6_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_p6_0_0
// static int test_close_mprotect_p6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_p6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mprotect_p6_1_common
// static void setup_close_mprotect_p6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_close_mprotect_pa_6_proc1
// static void setup_close_mprotect_p6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p6_3_final(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal
// static void setup_close_mprotect_p6_3_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_p6_0_0
// static int test_close_mprotect_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pc_0_1
// static void setup_close_mprotect_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mprotect_p6_1_common
// static void setup_close_mprotect_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p4_0_final(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal
// static void setup_close_mprotect_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p2_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_p6_0_0
// static int test_close_mprotect_p2_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
// static void setup_close_mprotect_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_close_mprotect_pa_0_proc1
// static void setup_close_mprotect_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_p2_0_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p2_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_p6_0_0
// static int test_close_mprotect_p2_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mprotect_p6_1_common
// static void setup_close_mprotect_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_close_mprotect_pa_1_proc1
// static void setup_close_mprotect_p2_1_final(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal
// static void setup_close_mprotect_p2_1_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p2_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_p6_0_0
// static int test_close_mprotect_p2_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_p2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_mprotect_pe_0_common
// static void setup_close_mprotect_p2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_close_mprotect_pa_4_proc1
// static void setup_close_mprotect_p2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_mprotect_pe_0_final
// static void setup_close_mprotect_p2_2_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p2_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_p6_0_0
// static int test_close_mprotect_p2_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pe_0_1
// static void setup_close_mprotect_p2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mprotect_p6_1_common
// static void setup_close_mprotect_p2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_close_mprotect_pa_6_proc1
// static void setup_close_mprotect_p2_3_final(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal
// static void setup_close_mprotect_p2_3_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal

/*
 * calls: close mprotect
 */
// static int test_close_mprotect_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_p6_0_0
// static int test_close_mprotect_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_close_mprotect_pc_0_1
// static void setup_close_mprotect_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_mprotect_p6_1_common
// static void setup_close_mprotect_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_mprotect_pe_0_proc1
// static void setup_close_mprotect_p0_0_final(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal
// static void setup_close_mprotect_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_mprotect_pe_0_procfinal


/*
 * calls: close munmap
 */
static int test_close_munmap_pc_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_munmap_pc_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_close_munmap_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_munmap_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_munmap_pc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_munmap_pc_0_final(void) {
  unlink("__i0");
}
static void setup_close_munmap_pc_0_procfinal(void) {
  
}

/*
 * calls: close munmap
 */
// static int test_close_munmap_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_0
// static int test_close_munmap_pc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_1
static void setup_close_munmap_pc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_munmap_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_munmap_pc_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_munmap_pc_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_munmap_pc_1_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close munmap
 */
// static int test_close_munmap_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_0
// static int test_close_munmap_pc_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_1
// static void setup_close_munmap_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_munmap_pc_1_common
static void setup_close_munmap_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_munmap_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_munmap_pc_1_proc1
// static void setup_close_munmap_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_munmap_pc_1_final
// static void setup_close_munmap_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_munmap_pc_1_procfinal

/*
 * calls: close munmap
 */
// static int test_close_munmap_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_0
// static int test_close_munmap_p8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_1
// static void setup_close_munmap_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_munmap_pc_0_common
// static void setup_close_munmap_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_munmap_pc_0_proc0
// static void setup_close_munmap_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_munmap_pc_0_proc1
// static void setup_close_munmap_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_munmap_pc_0_final
// static void setup_close_munmap_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_munmap_pc_0_procfinal

/*
 * calls: close munmap
 */
// static int test_close_munmap_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_0
// static int test_close_munmap_p8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_1
// static void setup_close_munmap_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_munmap_pc_1_common
// static void setup_close_munmap_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_munmap_pc_1_proc0
// static void setup_close_munmap_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_munmap_pc_1_proc1
// static void setup_close_munmap_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_munmap_pc_1_final
// static void setup_close_munmap_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_munmap_pc_1_procfinal

/*
 * calls: close munmap
 */
// static int test_close_munmap_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_0
// static int test_close_munmap_p8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_1
// static void setup_close_munmap_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_munmap_pc_1_common
// static void setup_close_munmap_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_munmap_pc_2_proc0
// static void setup_close_munmap_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_munmap_pc_1_proc1
// static void setup_close_munmap_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_munmap_pc_1_final
// static void setup_close_munmap_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_munmap_pc_1_procfinal

/*
 * calls: close munmap
 */
static int test_close_munmap_p4_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_munmap_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_1
static void setup_close_munmap_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_munmap_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_munmap_pc_0_proc1
// static void setup_close_munmap_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_munmap_pc_0_proc1
// static void setup_close_munmap_p4_0_final(void) {
//   
// }
// ^ See setup_close_munmap_pc_0_procfinal
// static void setup_close_munmap_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_munmap_pc_0_procfinal

/*
 * calls: close munmap
 */
// static int test_close_munmap_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_munmap_p4_0_0
// static int test_close_munmap_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_munmap_pc_0_1
// static void setup_close_munmap_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_munmap_p4_0_common
// static void setup_close_munmap_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_munmap_pc_0_proc1
// static void setup_close_munmap_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_munmap_pc_0_proc1
// static void setup_close_munmap_p0_0_final(void) {
//   
// }
// ^ See setup_close_munmap_pc_0_procfinal
// static void setup_close_munmap_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_munmap_pc_0_procfinal


/*
 * calls: close open
 */
static int test_close_open_pf_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_open_pf_0_1(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_close_open_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_open_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_open_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_open_pf_0_final(void) {
  unlink("__i0");
}
static void setup_close_open_pf_0_procfinal(void) {
  
}

/*
 * calls: close open
 */
// static int test_close_open_pf_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pf_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_1
static void setup_close_open_pf_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_open_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_open_pf_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_open_pf_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_open_pf_1_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close open
 */
// static int test_close_open_pf_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pf_2_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_1
// static void setup_close_open_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pf_1_common
static void setup_close_open_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_open_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pee_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
static int test_close_open_pee_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_close_open_pee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_open_pee_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4677632, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_open_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pee_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pee_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pee_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pee_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
static void setup_close_open_pee_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_close_open_pee_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pee_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pee_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pee_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pee_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pee_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
// static void setup_close_open_pee_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pee_1_common
// static void setup_close_open_pee_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pee_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pee_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pee_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pea_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pea_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
static void setup_close_open_pea_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_open_pea_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_open_pea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pea_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pea_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pea_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
static void setup_close_open_pea_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_close_open_pea_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pea_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pea_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pea_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pea_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pea_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
static void setup_close_open_pea_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_close_open_pea_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pea_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pea_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pea_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pe6_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
static int test_close_open_pe6_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_close_open_pe6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_open_pe6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_open_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pe6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pe6_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pe6_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pe6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
static void setup_close_open_pe6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_close_open_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pe6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pe6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pe6_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pe6_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_pe6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_1_common
// static void setup_close_open_pe6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pe6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pe6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pe6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pe2_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pe2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_pe2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_0_common
// static void setup_close_open_pe2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_open_pe6_0_proc0
// static void setup_close_open_pe2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pe2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pe2_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pe2_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pe2_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_pe2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_1_common
// static void setup_close_open_pe2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pe2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pe2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pe2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pe2_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pe2_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_pe2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_1_common
// static void setup_close_open_pe2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pe2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pe2_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pe2_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pdc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pdc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
static void setup_close_open_pdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_open_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pdc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pdc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
static void setup_close_open_pdc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_close_open_pdc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_open_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pdc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pdc_1_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pdc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pdc_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
// static void setup_close_open_pdc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_open_pdc_0_common
// static void setup_close_open_pdc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pdc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pdc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pdc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pd4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pd4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
// static void setup_close_open_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_open_pdc_0_common
// static void setup_close_open_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pd4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pd4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
static void setup_close_open_pd4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_close_open_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_open_pdc_1_proc0
// static void setup_close_open_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pd4_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pd4_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
// static void setup_close_open_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_open_pdc_0_common
// static void setup_close_open_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pd4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pcc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pcc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_open_pdc_0_common
// static void setup_close_open_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pcc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pcc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pcc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pcc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_pcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_open_pdc_1_common
// static void setup_close_open_pcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_open_pdc_1_proc0
// static void setup_close_open_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pcc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pcc_1_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pcc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pcc_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
static void setup_close_open_pcc_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_open_pcc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pcc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pcc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pcc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pc4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pc4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_pc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_open_pdc_0_common
// static void setup_close_open_pc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pc4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pc4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pc4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pc4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_pc4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_open_pd4_1_common
// static void setup_close_open_pc4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_open_pdc_1_proc0
// static void setup_close_open_pc4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pc4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pc4_1_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pc4_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pc4_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_pc4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_open_pcc_2_common
// static void setup_close_open_pc4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pc4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pc4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pc4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pbc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
static int test_close_open_pbc_0_1(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_close_open_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pee_0_common
// static void setup_close_open_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_open_pee_0_proc0
// static void setup_close_open_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pbc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pbc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pbc_0_1
// static void setup_close_open_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pee_1_common
// static void setup_close_open_pbc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pbc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pbc_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pbc_0_1
// static void setup_close_open_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pee_1_common
// static void setup_close_open_pbc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pbc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pbc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pb4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pb4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pbc_0_1
// static void setup_close_open_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pea_0_common
// static void setup_close_open_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_open_pea_0_proc0
// static void setup_close_open_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pb4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pb4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pbc_0_1
// static void setup_close_open_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pea_2_common
// static void setup_close_open_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pb4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pb4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pb4_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pb4_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pbc_0_1
// static void setup_close_open_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pea_2_common
// static void setup_close_open_pb4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pb4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pb4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pac_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
static int test_close_open_pac_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_close_open_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_0_common
// static void setup_close_open_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_open_pe6_0_proc0
// static void setup_close_open_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pac_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pac_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pac_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pac_0_1
// static void setup_close_open_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_1_common
// static void setup_close_open_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pac_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pac_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pac_0_1
// static void setup_close_open_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_1_common
// static void setup_close_open_pac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pac_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pac_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pa4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pa4_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pac_0_1
// static void setup_close_open_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_0_common
// static void setup_close_open_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_open_pe6_0_proc0
// static void setup_close_open_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_pa4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pa4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pa4_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pac_0_1
// static void setup_close_open_pa4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_1_common
// static void setup_close_open_pa4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_pa4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pa4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pa4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_pa4_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_pa4_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pac_0_1
// static void setup_close_open_pa4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_1_common
// static void setup_close_open_pa4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_pa4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_pa4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_pa4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
static int test_close_open_p8_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_close_open_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_close_open_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_open_pf_0_proc0
// static void setup_close_open_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_p8_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_open_p8_0_1
static void setup_close_open_p8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_open_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc0
// static void setup_close_open_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_0
// static int test_close_open_p8_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_open_p8_0_1
// static void setup_close_open_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_open_p8_1_common
// static void setup_close_open_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_2_proc0
// static void setup_close_open_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_open_pf_1_proc1
// static void setup_close_open_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_final
// static void setup_close_open_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_open_pf_1_procfinal

/*
 * calls: close open
 */
static int test_close_open_p7_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_open_p7_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_close_open_pf_0_1
// static void setup_close_open_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pf_0_common
// static void setup_close_open_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_p7_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p6d0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p6d0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
// static void setup_close_open_p6d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pf_0_common
// static void setup_close_open_p6d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p6d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p6d0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_p6d0_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p6a_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p6a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
// static void setup_close_open_p6a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pea_0_common
// static void setup_close_open_p6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p6a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_p6a_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p65_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p65_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_p65_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_0_common
// static void setup_close_open_p65_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p65_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p65_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_p65_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p62_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p62_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_0_common
// static void setup_close_open_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_p62_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p5a_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p5a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
static void setup_close_open_p5a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_open_p5a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p5a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p5a_0_final(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal
// static void setup_close_open_p5a_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p54_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p54_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pee_0_1
// static void setup_close_open_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_open_p5a_0_common
// static void setup_close_open_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p54_0_final(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal
// static void setup_close_open_p54_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p4a_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p4a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_p4a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_open_p5a_0_common
// static void setup_close_open_p4a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p4a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p4a_0_final(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal
// static void setup_close_open_p4a_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p44_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p44_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pe6_0_1
// static void setup_close_open_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_open_p5a_0_common
// static void setup_close_open_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p44_0_final(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal
// static void setup_close_open_p44_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p3a_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p3a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pbc_0_1
// static void setup_close_open_p3a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pf_0_common
// static void setup_close_open_p3a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p3a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p3a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_p3a_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p34_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p34_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pbc_0_1
// static void setup_close_open_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pea_0_common
// static void setup_close_open_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_p34_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p2a_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p2a_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pac_0_1
// static void setup_close_open_p2a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_0_common
// static void setup_close_open_p2a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p2a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p2a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_p2a_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p24_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p24_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_close_open_pac_0_1
// static void setup_close_open_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_open_pe6_0_common
// static void setup_close_open_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_open_pf_0_final
// static void setup_close_open_p24_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal

/*
 * calls: close open
 */
// static int test_close_open_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_open_p7_0_0
// static int test_close_open_p0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_open_p8_0_1
// static void setup_close_open_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_open_p5a_0_common
// static void setup_close_open_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_open_pf_0_proc1
// static void setup_close_open_p0_0_final(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal
// static void setup_close_open_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_open_pf_0_procfinal


/*
 * calls: close pipe
 */
static int test_close_pipe_pf0_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_pipe_pf0_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_close_pipe_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_pipe_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_pipe_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_pipe_pf0_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_pipe_pf0_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close pipe
 */
// static int test_close_pipe_pf0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_0
// static int test_close_pipe_pf0_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_1
static void setup_close_pipe_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_close_pipe_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_pipe_pf0_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_pipe_pf0_1_final(void) {
  unlink("__i0");
}
static void setup_close_pipe_pf0_1_procfinal(void) {
  
}

/*
 * calls: close pipe
 */
// static int test_close_pipe_pf0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_0
// static int test_close_pipe_pf0_2_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_1
// static void setup_close_pipe_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pipe_pf0_0_common
static void setup_close_pipe_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pipe_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pipe_pf0_0_proc1
// static void setup_close_pipe_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pipe_pf0_0_final
// static void setup_close_pipe_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pipe_pf0_0_procfinal

/*
 * calls: close pipe
 */
// static int test_close_pipe_pb0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_0
// static int test_close_pipe_pb0_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_1
static void setup_close_pipe_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_close_pipe_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pipe_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pipe_pf0_1_proc1
// static void setup_close_pipe_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pipe_pf0_1_final
// static void setup_close_pipe_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_close_pipe_pf0_1_procfinal

/*
 * calls: close pipe
 */
// static int test_close_pipe_pb0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_0
// static int test_close_pipe_pb0_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_1
static void setup_close_pipe_pb0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_pipe_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pipe_pf0_0_proc0
// static void setup_close_pipe_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pipe_pf0_0_proc1
// static void setup_close_pipe_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pipe_pf0_0_final
// static void setup_close_pipe_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pipe_pf0_0_procfinal

/*
 * calls: close pipe
 */
// static int test_close_pipe_pb0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_0
// static int test_close_pipe_pb0_2_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_1
// static void setup_close_pipe_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pipe_pb0_1_common
// static void setup_close_pipe_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pipe_pf0_2_proc0
// static void setup_close_pipe_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pipe_pf0_0_proc1
// static void setup_close_pipe_pb0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pipe_pf0_0_final
// static void setup_close_pipe_pb0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pipe_pf0_0_procfinal

/*
 * calls: close pipe
 */
static int test_close_pipe_p58_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_pipe_p58_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_1
static void setup_close_pipe_p58_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_pipe_p58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pipe_pf0_1_proc1
// static void setup_close_pipe_p58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pipe_pf0_1_proc1
// static void setup_close_pipe_p58_0_final(void) {
//   
// }
// ^ See setup_close_pipe_pf0_1_procfinal
// static void setup_close_pipe_p58_0_procfinal(void) {
//   
// }
// ^ See setup_close_pipe_pf0_1_procfinal

/*
 * calls: close pipe
 */
// static int test_close_pipe_p30_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pipe_p58_0_0
// static int test_close_pipe_p30_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pipe_pf0_0_1
// static void setup_close_pipe_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_pipe_p58_0_common
// static void setup_close_pipe_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pipe_pf0_1_proc1
// static void setup_close_pipe_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pipe_pf0_1_proc1
// static void setup_close_pipe_p30_0_final(void) {
//   
// }
// ^ See setup_close_pipe_pf0_1_procfinal
// static void setup_close_pipe_p30_0_procfinal(void) {
//   
// }
// ^ See setup_close_pipe_pf0_1_procfinal


/*
 * calls: close pread
 */
static int test_close_pread_pf_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_pread_pf_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_close_pread_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_pread_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_pread_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_pread_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_pread_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close pread
 */
// static int test_close_pread_pf_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pf_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pf_0_1
// static void setup_close_pread_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
static void setup_close_pread_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pf_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pf_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pf_0_1
// static void setup_close_pread_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
static void setup_close_pread_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pf_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pf_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pf_0_1
// static void setup_close_pread_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
static void setup_close_pread_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pf_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pf_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pf_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pf_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pf_0_1
// static void setup_close_pread_pf_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
static void setup_close_pread_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pf_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pf_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pf_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pf_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pf_0_1
// static void setup_close_pread_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
static void setup_close_pread_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pf_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pf_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
static int test_close_pread_pe8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_close_pread_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_pread_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_pread_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_pread_pe8_0_final(void) {
  unlink("__i0");
}
static void setup_close_pread_pe8_0_procfinal(void) {
  
}

/*
 * calls: close pread
 */
// static int test_close_pread_pe8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pe8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe8_0_1
static void setup_close_pread_pe8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_pread_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pe8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pe8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pe8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe8_0_1
// static void setup_close_pread_pe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pread_pe8_0_common
static void setup_close_pread_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pread_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_pe8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_pe8_2_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe8_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pe8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe8_0_1
// static void setup_close_pread_pe8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe8_1_common
static void setup_close_pread_pe8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pe8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pe8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pe8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe8_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pe8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe8_0_1
// static void setup_close_pread_pe8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe8_1_common
static void setup_close_pread_pe8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pe8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pe8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pe8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe8_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pe8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe8_0_1
// static void setup_close_pread_pe8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe8_1_common
static void setup_close_pread_pe8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pe8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pe8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pe8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
static int test_close_pread_pe0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_close_pread_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_close_pread_pe0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pread_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pe0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe0_0_1
static void setup_close_pread_pe0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_pread_pe0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pe0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe0_0_1
static void setup_close_pread_pe0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_pread_pe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pe8_4_proc0
// static void setup_close_pread_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pe0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pe0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe0_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pe0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe0_0_1
static void setup_close_pread_pe0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_pread_pe0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pe0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pe0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pe0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe0_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pe0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe0_0_1
// static void setup_close_pread_pe0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe0_2_common
// static void setup_close_pread_pe0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pe8_5_proc0
// static void setup_close_pread_pe0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pe0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pe0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pe0_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pe0_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe0_0_1
// static void setup_close_pread_pe0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pread_pe0_0_common
// static void setup_close_pread_pe0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_pe8_2_proc0
// static void setup_close_pread_pe0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_pe0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_pe0_5_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
static int test_close_pread_pc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_close_pread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pread_pe8_0_common
static void setup_close_pread_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pc_0_1
// static void setup_close_pread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
static void setup_close_pread_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pc_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pc_0_1
// static void setup_close_pread_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
static void setup_close_pread_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pb_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
static int test_close_pread_pb_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_close_pread_pb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
static void setup_close_pread_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
// static void setup_close_pread_pb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pb_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pb_0_1
// static void setup_close_pread_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
// static void setup_close_pread_pb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pb_0_proc0
// static void setup_close_pread_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_pb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pb_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pb_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pb_0_1
// static void setup_close_pread_pb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
// static void setup_close_pread_pb_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
// static void setup_close_pread_pb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
// static void setup_close_pread_pb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pb_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pb_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pb_0_1
// static void setup_close_pread_pb_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
// static void setup_close_pread_pb_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_pb_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
// static void setup_close_pread_pb_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pb_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pb_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pb_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pb_0_1
// static void setup_close_pread_pb_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
// static void setup_close_pread_pb_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
// static void setup_close_pread_pb_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_pb_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pb_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pb_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pb_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pb_0_1
// static void setup_close_pread_pb_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
// static void setup_close_pread_pb_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_pb_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_pb_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pb_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
static int test_close_pread_pa8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_close_pread_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pread_pe8_0_common
static void setup_close_pread_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_pread_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pread_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pa8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa8_0_1
// static void setup_close_pread_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe8_1_common
// static void setup_close_pread_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
static void setup_close_pread_pa8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pa8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pa8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pa8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa8_0_1
// static void setup_close_pread_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pread_pe8_0_common
// static void setup_close_pread_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_pc_0_proc0
// static void setup_close_pread_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_pc_0_proc0
// static void setup_close_pread_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa8_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pa8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa8_0_1
// static void setup_close_pread_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe8_1_common
// static void setup_close_pread_pa8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pa8_1_proc1
// static void setup_close_pread_pa8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pa8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa8_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pa8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa8_0_1
// static void setup_close_pread_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe8_1_common
// static void setup_close_pread_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
// static void setup_close_pread_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pb_0_proc0
// static void setup_close_pread_pa8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pa8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa8_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pa8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa8_0_1
// static void setup_close_pread_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe8_1_common
// static void setup_close_pread_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pb_0_proc0
// static void setup_close_pread_pa8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pa8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
static int test_close_pread_pa0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_close_pread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pread_pe0_0_common
static void setup_close_pread_pa0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_pread_pa0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa0_0_1
// static void setup_close_pread_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe0_1_common
// static void setup_close_pread_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
static void setup_close_pread_pa0_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_pa0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pa0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pa0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa0_0_1
// static void setup_close_pread_pa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe0_2_common
// static void setup_close_pread_pa0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
// static void setup_close_pread_pa0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pb_0_proc0
// static void setup_close_pread_pa0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pa0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa0_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pa0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa0_0_1
// static void setup_close_pread_pa0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe0_3_common
// static void setup_close_pread_pa0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_pa0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pa0_1_proc1
// static void setup_close_pread_pa0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pa0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa0_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pa0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa0_0_1
// static void setup_close_pread_pa0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pe0_2_common
// static void setup_close_pread_pa0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_pa0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pb_0_proc0
// static void setup_close_pread_pa0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_pa0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_pa0_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_pa0_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa0_0_1
// static void setup_close_pread_pa0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pread_pe0_0_common
// static void setup_close_pread_pa0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_pc_0_proc0
// static void setup_close_pread_pa0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_pc_0_proc0
// static void setup_close_pread_pa0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_pa0_5_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
static int test_close_pread_p8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_close_pread_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pread_pe8_0_common
// static void setup_close_pread_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_pc_0_proc0
// static void setup_close_pread_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_p8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_p8_0_1
// static void setup_close_pread_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
// static void setup_close_pread_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
// static void setup_close_pread_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pread_pf_0_0
// static int test_close_pread_p8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_p8_0_1
// static void setup_close_pread_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
// static void setup_close_pread_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
static int test_close_pread_p7_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_pread_p7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pf_0_1
// static void setup_close_pread_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
static void setup_close_pread_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p7_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pf_0_1
// static void setup_close_pread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
static void setup_close_pread_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p68_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe8_0_1
// static void setup_close_pread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pread_pe8_0_common
static void setup_close_pread_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p68_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe8_0_1
// static void setup_close_pread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pread_pe8_0_common
static void setup_close_pread_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p60_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe0_0_1
// static void setup_close_pread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pread_pe0_0_common
static void setup_close_pread_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p60_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p60_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pe0_0_1
// static void setup_close_pread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pread_pe0_0_common
// static void setup_close_pread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_p68_1_proc0
// static void setup_close_pread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pc_0_1
static void setup_close_pread_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_pread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p4_0_final(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal
// static void setup_close_pread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_p8_0_1
// static void setup_close_pread_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_pread_p4_0_common
// static void setup_close_pread_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p4_1_final(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal
// static void setup_close_pread_p4_1_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p3_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p3_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pb_0_1
// static void setup_close_pread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
// static void setup_close_pread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_1_proc0
// static void setup_close_pread_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p3_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p3_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pb_0_1
// static void setup_close_pread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pread_pf_0_common
// static void setup_close_pread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pf_0_proc1
// static void setup_close_pread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pread_pc_2_proc0
// static void setup_close_pread_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_final
// static void setup_close_pread_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pread_pf_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p28_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa8_0_1
// static void setup_close_pread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pread_pe8_0_common
// static void setup_close_pread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_pa8_0_proc1
// static void setup_close_pread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p28_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p28_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa8_0_1
// static void setup_close_pread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pread_pe8_0_common
// static void setup_close_pread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_pc_0_proc0
// static void setup_close_pread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p20_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa0_0_1
// static void setup_close_pread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pread_pe0_0_common
// static void setup_close_pread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_pa0_0_proc1
// static void setup_close_pread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p20_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p20_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_pa0_0_1
// static void setup_close_pread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pread_pe0_0_common
// static void setup_close_pread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pread_pc_0_proc0
// static void setup_close_pread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pread_pe8_0_final
// static void setup_close_pread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal

/*
 * calls: close pread
 */
// static int test_close_pread_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pread_p7_0_0
// static int test_close_pread_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_pread_p8_0_1
// static void setup_close_pread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_pread_p4_0_common
// static void setup_close_pread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pread_pe8_0_proc1
// static void setup_close_pread_p0_0_final(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal
// static void setup_close_pread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_pread_pe8_0_procfinal


/*
 * calls: close pwrite
 */
static int test_close_pwrite_pf_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_pwrite_pf_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_close_pwrite_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_pwrite_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_pwrite_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_pwrite_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_pwrite_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pf_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pf_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_1
// static void setup_close_pwrite_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
static void setup_close_pwrite_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pf_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pf_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_1
// static void setup_close_pwrite_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
static void setup_close_pwrite_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pf_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pf_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_1
// static void setup_close_pwrite_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
static void setup_close_pwrite_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pf_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pf_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pf_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pf_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_1
// static void setup_close_pwrite_pf_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
static void setup_close_pwrite_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pf_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pf_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pf_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pf_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_1
// static void setup_close_pwrite_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
static void setup_close_pwrite_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pf_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pf_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
static int test_close_pwrite_pe8_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_close_pwrite_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_pwrite_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_pwrite_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_pwrite_pe8_0_final(void) {
  unlink("__i0");
}
static void setup_close_pwrite_pe8_0_procfinal(void) {
  
}

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
static void setup_close_pwrite_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe8_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
static void setup_close_pwrite_pe8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_pwrite_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pe8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pe8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe8_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe8_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_pe8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
static void setup_close_pwrite_pe8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_pe8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_pe8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pe8_3_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe8_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe8_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_pe8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pe8_2_common
static void setup_close_pwrite_pe8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pe8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pe8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pe8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe8_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe8_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_pe8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pe8_2_common
static void setup_close_pwrite_pe8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pe8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pe8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pe8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe8_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe8_6_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_pe8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pe8_2_common
static void setup_close_pwrite_pe8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pe8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pe8_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pe8_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
static void setup_close_pwrite_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_close_pwrite_pe0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pwrite_pe0_0_common
// static void setup_close_pwrite_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_3_proc0
// static void setup_close_pwrite_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
static void setup_close_pwrite_pe0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_pwrite_pe0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pe0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pe0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe0_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_pe0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pe0_2_common
static void setup_close_pwrite_pe0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pe0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pe0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pe0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe0_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe0_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
static void setup_close_pwrite_pe0_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_pwrite_pe0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pe8_5_proc0
// static void setup_close_pwrite_pe0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pe0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pe0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pe0_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pe0_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_pe0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pe0_4_common
// static void setup_close_pwrite_pe0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pe8_6_proc0
// static void setup_close_pwrite_pe0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pe0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pe0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
static int test_close_pwrite_pc_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_close_pwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
static void setup_close_pwrite_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pc_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pc_0_1
// static void setup_close_pwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
static void setup_close_pwrite_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pc_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pc_0_1
// static void setup_close_pwrite_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
static void setup_close_pwrite_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pb_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
static int test_close_pwrite_pb_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
// static void setup_close_pwrite_pb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
static void setup_close_pwrite_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_1_proc0
// static void setup_close_pwrite_pb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pb_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pb_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pb_0_1
// static void setup_close_pwrite_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
// static void setup_close_pwrite_pb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pb_0_proc0
// static void setup_close_pwrite_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
// static void setup_close_pwrite_pb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pb_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pb_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pb_0_1
// static void setup_close_pwrite_pb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
// static void setup_close_pwrite_pb_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_1_proc0
// static void setup_close_pwrite_pb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_1_proc0
// static void setup_close_pwrite_pb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pb_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pb_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pb_0_1
// static void setup_close_pwrite_pb_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
// static void setup_close_pwrite_pb_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
// static void setup_close_pwrite_pb_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_1_proc0
// static void setup_close_pwrite_pb_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pb_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pb_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pb_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pb_0_1
// static void setup_close_pwrite_pb_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
// static void setup_close_pwrite_pb_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_1_proc0
// static void setup_close_pwrite_pb_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
// static void setup_close_pwrite_pb_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pb_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pb_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pb_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pb_0_1
// static void setup_close_pwrite_pb_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
// static void setup_close_pwrite_pb_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
// static void setup_close_pwrite_pb_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
// static void setup_close_pwrite_pb_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pb_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
static int test_close_pwrite_pa8_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_close_pwrite_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
static void setup_close_pwrite_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_pwrite_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pa8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
// static void setup_close_pwrite_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pa8_0_proc0
// static void setup_close_pwrite_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pa8_0_proc0
// static void setup_close_pwrite_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
static int test_close_pwrite_pa8_2_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_close_pwrite_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pe0_2_common
// static void setup_close_pwrite_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_1_proc0
static void setup_close_pwrite_pa8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pa8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pa8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa8_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
static int test_close_pwrite_pa8_3_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_close_pwrite_pa8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_close_pwrite_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_pwrite_pa8_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa8_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pa8_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
static void setup_close_pwrite_pa8_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_pwrite_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
static void setup_close_pwrite_pa8_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pa8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pa8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa8_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pa8_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pa8_4_common
// static void setup_close_pwrite_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
// static void setup_close_pwrite_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pb_0_proc0
// static void setup_close_pwrite_pa8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pa8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa8_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pa8_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_pa8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
// static void setup_close_pwrite_pa8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pc_0_proc0
// static void setup_close_pwrite_pa8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pc_0_proc0
// static void setup_close_pwrite_pa8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pa8_6_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pa0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pwrite_pe0_0_common
static void setup_close_pwrite_pa0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_pwrite_pa0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pa0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pwrite_pe0_0_common
// static void setup_close_pwrite_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pa8_0_proc0
// static void setup_close_pwrite_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pa8_0_proc0
// static void setup_close_pwrite_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pa0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
static void setup_close_pwrite_pa0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_pwrite_pa0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_1_proc0
// static void setup_close_pwrite_pa0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pb_0_proc0
// static void setup_close_pwrite_pa0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pa0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa0_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
static int test_close_pwrite_pa0_3_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_close_pwrite_pa0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_close_pwrite_pa0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_pwrite_pa0_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_pa0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pa0_3_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa0_4_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pa0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_pa0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pe0_2_common
// static void setup_close_pwrite_pa0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
static void setup_close_pwrite_pa0_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_pa0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pa0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa0_5_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pa0_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_pa0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pwrite_pe0_0_common
// static void setup_close_pwrite_pa0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pc_0_proc0
// static void setup_close_pwrite_pa0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pc_0_proc0
// static void setup_close_pwrite_pa0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_pa0_5_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_pa0_6_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_pa0_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_pa0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pe0_4_common
// static void setup_close_pwrite_pa0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
// static void setup_close_pwrite_pa0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pb_0_proc0
// static void setup_close_pwrite_pa0_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_pa0_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
static int test_close_pwrite_p8_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_close_pwrite_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
// static void setup_close_pwrite_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pc_0_proc0
// static void setup_close_pwrite_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_p8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p8_0_1
// static void setup_close_pwrite_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
// static void setup_close_pwrite_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_1_proc0
// static void setup_close_pwrite_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_0
// static int test_close_pwrite_p8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p8_0_1
// static void setup_close_pwrite_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
// static void setup_close_pwrite_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
// static void setup_close_pwrite_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
static int test_close_pwrite_p7_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_pwrite_p7_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_1
// static void setup_close_pwrite_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
static void setup_close_pwrite_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p7_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p7_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pf_0_1
// static void setup_close_pwrite_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
static void setup_close_pwrite_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_pwrite_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p68_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p68_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
static void setup_close_pwrite_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_p68_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p68_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p68_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
static void setup_close_pwrite_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_p68_1_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p60_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p60_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pwrite_pe0_0_common
static void setup_close_pwrite_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_pwrite_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_p60_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p60_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p60_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pe8_0_1
// static void setup_close_pwrite_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pwrite_pe0_0_common
// static void setup_close_pwrite_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_p68_1_proc0
// static void setup_close_pwrite_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_p60_1_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p4_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pc_0_1
static void setup_close_pwrite_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_pwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p4_0_final(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal
// static void setup_close_pwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p8_0_1
// static void setup_close_pwrite_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_pwrite_p4_0_common
// static void setup_close_pwrite_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p4_1_final(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal
// static void setup_close_pwrite_p4_1_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p3_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p3_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pb_0_1
// static void setup_close_pwrite_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
// static void setup_close_pwrite_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_1_proc0
// static void setup_close_pwrite_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p3_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p3_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pb_0_1
// static void setup_close_pwrite_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_pwrite_pf_0_common
// static void setup_close_pwrite_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pf_0_proc1
// static void setup_close_pwrite_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_pwrite_pc_2_proc0
// static void setup_close_pwrite_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_final
// static void setup_close_pwrite_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_pwrite_pf_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p28_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p28_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
// static void setup_close_pwrite_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pa8_0_proc1
// static void setup_close_pwrite_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_p28_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p28_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p28_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_pwrite_pe8_0_common
// static void setup_close_pwrite_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pc_0_proc0
// static void setup_close_pwrite_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_p28_1_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p20_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p20_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pwrite_pe0_0_common
// static void setup_close_pwrite_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pa0_0_proc1
// static void setup_close_pwrite_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_p20_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p20_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p20_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_pa8_0_1
// static void setup_close_pwrite_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_pwrite_pe0_0_common
// static void setup_close_pwrite_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_pwrite_pc_0_proc0
// static void setup_close_pwrite_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_pwrite_pe8_0_final
// static void setup_close_pwrite_p20_1_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal

/*
 * calls: close pwrite
 */
// static int test_close_pwrite_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p7_0_0
// static int test_close_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_pwrite_p8_0_1
// static void setup_close_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_pwrite_p4_0_common
// static void setup_close_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_pwrite_pe8_0_proc1
// static void setup_close_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal
// static void setup_close_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_pwrite_pe8_0_procfinal


/*
 * calls: close read
 */
static int test_close_read_pf8_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_read_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_close_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_read_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_read_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_read_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_read_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close read
 */
// static int test_close_read_pf8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf8_0_1
// static void setup_close_read_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
static void setup_close_read_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pf8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pf8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf8_0_1
// static void setup_close_read_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
static void setup_close_read_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pf6_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
static int test_close_read_pf6_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_close_read_pf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_read_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pf6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pf6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pf6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pf6_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pf6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf6_0_1
// static void setup_close_read_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf6_0_common
static void setup_close_read_pf6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pf6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pf6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pf6_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pf6_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf6_0_1
// static void setup_close_read_pf6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf6_0_common
static void setup_close_read_pf6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pf6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pf6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pf6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pf4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
static int test_close_read_pf4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_close_read_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_read_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_close_read_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pf4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf4_0_1
static void setup_close_read_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_read_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_close_read_pf4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_close_read_pf4_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_close_read_pf4_1_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: close read
 */
// static int test_close_read_pf4_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pf4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf4_0_1
// static void setup_close_read_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf4_0_common
// static void setup_close_read_pf4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf6_1_proc0
// static void setup_close_read_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pf4_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pf4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf4_0_1
// static void setup_close_read_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf4_1_common
static void setup_close_read_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf4_1_proc1
// static void setup_close_read_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_close_read_pf4_1_final
// static void setup_close_read_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_close_read_pf4_1_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pf0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
static int test_close_read_pf0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_close_read_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_read_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf6_1_proc0
// static void setup_close_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pf0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf0_0_1
// static void setup_close_read_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf0_0_common
// static void setup_close_read_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf6_2_proc0
// static void setup_close_read_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pf0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pf0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf0_0_1
// static void setup_close_read_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf0_0_common
// static void setup_close_read_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf6_0_proc0
// static void setup_close_read_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pe8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pe8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf4_0_1
static void setup_close_read_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_read_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_read_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_read_pe8_0_final(void) {
  unlink("__i0");
}
static void setup_close_read_pe8_0_procfinal(void) {
  
}

/*
 * calls: close read
 */
// static int test_close_read_pe8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pe8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf4_0_1
static void setup_close_read_pe8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_read_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pe8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pe8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pe8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pe8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf4_0_1
// static void setup_close_read_pe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pe8_1_common
static void setup_close_read_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pe8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pe8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pe0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pe0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf0_0_1
static void setup_close_read_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_close_read_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_read_pe8_0_proc0
// static void setup_close_read_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_read_pe8_0_final
// static void setup_close_read_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pe0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pe0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf0_0_1
static void setup_close_read_pe0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_read_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pe8_1_proc0
// static void setup_close_read_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pe0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pe0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf0_0_1
// static void setup_close_read_pe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pe0_1_common
// static void setup_close_read_pe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pe8_2_proc0
// static void setup_close_read_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pe0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pe0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pdc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
static int test_close_read_pdc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_close_read_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
static void setup_close_read_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf8_0_1
// static void setup_close_read_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_read_pe8_0_common
static void setup_close_read_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_read_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_read_pe8_0_final
// static void setup_close_read_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf8_0_1
// static void setup_close_read_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
static void setup_close_read_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pc_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf8_0_1
// static void setup_close_read_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
// static void setup_close_read_pc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pdc_0_1
// static void setup_close_read_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
static void setup_close_read_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pdc_0_1
// static void setup_close_read_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
// static void setup_close_read_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pb8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pdc_0_1
// static void setup_close_read_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
// static void setup_close_read_pb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_pb8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb6_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
static int test_close_read_pb6_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_close_read_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf6_0_common
// static void setup_close_read_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb6_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pb6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb6_0_1
// static void setup_close_read_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf6_0_common
// static void setup_close_read_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb6_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pb6_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb6_0_1
// static void setup_close_read_pb6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf6_0_common
static void setup_close_read_pb6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pb6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pb6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
static int test_close_read_pb4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_close_read_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf4_0_common
static void setup_close_read_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_close_read_pb4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pb4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pb4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb4_0_1
static void setup_close_read_pb4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_read_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_close_read_pb4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_close_read_pb4_1_final(void) {
  unlink("__i0");
  close(22);
  close(23);
  close(20);
  close(21);
}
static void setup_close_read_pb4_1_procfinal(void) {
  close(22);
  close(23);
  close(20);
  close(21);
}

/*
 * calls: close read
 */
// static int test_close_read_pb4_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pb4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb4_0_1
static void setup_close_read_pb4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_read_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_close_read_pb4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_pb4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_close_read_pf4_1_final
// static void setup_close_read_pb4_2_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_close_read_pf4_1_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb4_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pb4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb4_0_1
// static void setup_close_read_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf4_0_common
// static void setup_close_read_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pb4_0_proc1
// static void setup_close_read_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pb4_0_proc1
// static void setup_close_read_pb4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
static int test_close_read_pb0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_close_read_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf0_0_common
// static void setup_close_read_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pb6_2_proc0
// static void setup_close_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb0_0_1
// static void setup_close_read_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf0_0_common
// static void setup_close_read_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pb0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pb0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb0_0_1
// static void setup_close_read_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf0_0_common
// static void setup_close_read_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pb0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pb0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pa8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb4_0_1
// static void setup_close_read_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_read_pe8_0_common
// static void setup_close_read_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_read_pc_0_proc0
// static void setup_close_read_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_read_pc_0_proc0
// static void setup_close_read_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_read_pe8_0_final
// static void setup_close_read_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pa8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pa8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb4_0_1
// static void setup_close_read_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pe8_1_common
// static void setup_close_read_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pb8_0_proc0
// static void setup_close_read_pa8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pa8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pa8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pa8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb4_0_1
// static void setup_close_read_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pe8_1_common
// static void setup_close_read_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pb8_0_proc0
// static void setup_close_read_pa8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pa8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pa0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb0_0_1
// static void setup_close_read_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_read_pe0_0_common
// static void setup_close_read_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_read_pc_0_proc0
// static void setup_close_read_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_read_pc_0_proc0
// static void setup_close_read_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_read_pe8_0_final
// static void setup_close_read_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pa0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb0_0_1
// static void setup_close_read_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pe0_1_common
// static void setup_close_read_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pb8_0_proc0
// static void setup_close_read_pa0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pa0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_pa0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_pa0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb0_0_1
// static void setup_close_read_pa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pe0_1_common
// static void setup_close_read_pa0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_pa0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pb8_0_proc0
// static void setup_close_read_pa0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_pa0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_p8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pdc_0_1
// static void setup_close_read_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_read_pe8_0_common
// static void setup_close_read_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_read_pc_0_proc0
// static void setup_close_read_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_read_pe8_0_final
// static void setup_close_read_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_p8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pdc_0_1
// static void setup_close_read_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
// static void setup_close_read_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_read_pf8_0_0
// static int test_close_read_p8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pdc_0_1
// static void setup_close_read_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
// static void setup_close_read_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
static int test_close_read_p78_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_read_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf8_0_1
// static void setup_close_read_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
static void setup_close_read_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p76_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf6_0_1
// static void setup_close_read_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf6_0_common
static void setup_close_read_p76_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p74_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf4_0_1
// static void setup_close_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf6_0_common
static void setup_close_read_p74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_close_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf4_0_proc1
// static void setup_close_read_p74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_p74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p70_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf0_0_1
// static void setup_close_read_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf0_0_common
// static void setup_close_read_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_p76_0_proc0
// static void setup_close_read_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p68_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf4_0_1
// static void setup_close_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_read_pe8_0_common
static void setup_close_read_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_read_pe8_0_final
// static void setup_close_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p60_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf0_0_1
// static void setup_close_read_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_read_pe0_0_common
// static void setup_close_read_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_read_p68_0_proc0
// static void setup_close_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_read_pe8_0_final
// static void setup_close_read_p60_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pf8_0_1
static void setup_close_read_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_read_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p4_0_final(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal
// static void setup_close_read_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pdc_0_1
// static void setup_close_read_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_read_p4_0_common
// static void setup_close_read_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p4_1_final(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal
// static void setup_close_read_p4_1_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p38_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pdc_0_1
// static void setup_close_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf8_0_common
// static void setup_close_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pdc_0_proc0
// static void setup_close_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p36_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb6_0_1
// static void setup_close_read_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf6_0_common
// static void setup_close_read_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p34_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb4_0_1
// static void setup_close_read_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf4_0_common
// static void setup_close_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf4_0_proc1
// static void setup_close_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pb4_0_proc1
// static void setup_close_read_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p30_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb0_0_1
// static void setup_close_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_read_pf0_0_common
// static void setup_close_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pf8_0_proc1
// static void setup_close_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_read_pc_1_proc0
// static void setup_close_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_final
// static void setup_close_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_read_pf8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p28_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb4_0_1
// static void setup_close_read_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_read_pe8_0_common
// static void setup_close_read_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_read_pc_0_proc0
// static void setup_close_read_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_read_pe8_0_final
// static void setup_close_read_p28_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p20_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pb0_0_1
// static void setup_close_read_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_read_pe0_0_common
// static void setup_close_read_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_read_pc_0_proc0
// static void setup_close_read_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_read_pe8_0_final
// static void setup_close_read_p20_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal

/*
 * calls: close read
 */
// static int test_close_read_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_read_p78_0_0
// static int test_close_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_close_read_pdc_0_1
// static void setup_close_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_read_p4_0_common
// static void setup_close_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_read_pe8_0_proc1
// static void setup_close_read_p0_0_final(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal
// static void setup_close_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_read_pe8_0_procfinal


/*
 * calls: close rename
 */
static int test_close_rename_pe_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_rename_pe_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_close_rename_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_rename_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_rename_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_rename_pe_0_final(void) {
  unlink("__i0");
}
static void setup_close_rename_pe_0_procfinal(void) {
  
}

/*
 * calls: close rename
 */
// static int test_close_rename_pe_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
// static int test_close_rename_pe_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_1
static void setup_close_rename_pe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_rename_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_rename_pe_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_rename_pe_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_rename_pe_1_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close rename
 */
// static int test_close_rename_pe_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
// static int test_close_rename_pe_2_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_1
// static void setup_close_rename_pe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_rename_pe_1_common
static void setup_close_rename_pe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_rename_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_1_proc1
// static void setup_close_rename_pe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_final
// static void setup_close_rename_pe_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_pd0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
static int test_close_rename_pd0_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_close_rename_pd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_close_rename_pd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_rename_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_rename_pe_0_final
// static void setup_close_rename_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_close_rename_pe_0_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_pd0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
// static int test_close_rename_pd0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pd0_0_1
static void setup_close_rename_pd0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_close_rename_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_1_proc0
// static void setup_close_rename_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_1_proc1
// static void setup_close_rename_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_final
// static void setup_close_rename_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_pd0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
// static int test_close_rename_pd0_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pd0_0_1
// static void setup_close_rename_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_rename_pd0_1_common
// static void setup_close_rename_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_2_proc0
// static void setup_close_rename_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_1_proc1
// static void setup_close_rename_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_final
// static void setup_close_rename_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
// static int test_close_rename_pc_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pd0_0_1
// static void setup_close_rename_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_rename_pe_0_common
// static void setup_close_rename_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_rename_pe_0_proc0
// static void setup_close_rename_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_rename_pe_0_final
// static void setup_close_rename_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_rename_pe_0_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
// static int test_close_rename_pc_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pd0_0_1
// static void setup_close_rename_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_rename_pe_1_common
// static void setup_close_rename_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_1_proc0
// static void setup_close_rename_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_1_proc1
// static void setup_close_rename_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_final
// static void setup_close_rename_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
// static int test_close_rename_pc_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pd0_0_1
// static void setup_close_rename_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_rename_pe_1_common
// static void setup_close_rename_pc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_2_proc0
// static void setup_close_rename_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_1_proc1
// static void setup_close_rename_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_final
// static void setup_close_rename_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
static int test_close_rename_p8_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_close_rename_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_close_rename_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_rename_pe_0_proc0
// static void setup_close_rename_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_rename_pe_0_final
// static void setup_close_rename_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_rename_pe_0_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
// static int test_close_rename_p8_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_rename_p8_0_1
static void setup_close_rename_p8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_rename_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_1_proc0
// static void setup_close_rename_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_1_proc1
// static void setup_close_rename_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_final
// static void setup_close_rename_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_0
// static int test_close_rename_p8_2_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_rename_p8_0_1
// static void setup_close_rename_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_rename_p8_1_common
// static void setup_close_rename_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_2_proc0
// static void setup_close_rename_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_rename_pe_1_proc1
// static void setup_close_rename_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_final
// static void setup_close_rename_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_rename_pe_1_procfinal

/*
 * calls: close rename
 */
static int test_close_rename_p6_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_rename_p6_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pe_0_1
// static void setup_close_rename_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_rename_pe_0_common
// static void setup_close_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_rename_pe_0_final
// static void setup_close_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_close_rename_pe_0_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_p50_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_rename_p6_0_0
// static int test_close_rename_p50_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pd0_0_1
// static void setup_close_rename_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_rename_pd0_0_common
// static void setup_close_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_rename_pe_0_final
// static void setup_close_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_close_rename_pe_0_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_rename_p6_0_0
// static int test_close_rename_p4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_rename_pd0_0_1
// static void setup_close_rename_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_rename_pe_0_common
// static void setup_close_rename_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_rename_pe_0_final
// static void setup_close_rename_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_rename_pe_0_procfinal

/*
 * calls: close rename
 */
// static int test_close_rename_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_rename_p6_0_0
// static int test_close_rename_p0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_rename_p8_0_1
static void setup_close_rename_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_rename_pe_0_proc1
// static void setup_close_rename_p0_0_final(void) {
//   
// }
// ^ See setup_close_rename_pe_0_procfinal
// static void setup_close_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_rename_pe_0_procfinal


/*
 * calls: close stat
 */
static int test_close_stat_pc_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_close_stat_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_stat_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_stat_pc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_stat_pc_0_final(void) {
  unlink("__i0");
}
static void setup_close_stat_pc_0_procfinal(void) {
  
}

/*
 * calls: close stat
 */
// static int test_close_stat_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_stat_pc_0_0
// static int test_close_stat_pc_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_stat_pc_0_1
static void setup_close_stat_pc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_stat_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_stat_pc_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_stat_pc_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_stat_pc_1_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close stat
 */
// static int test_close_stat_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_stat_pc_0_0
// static int test_close_stat_pc_2_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_stat_pc_0_1
// static void setup_close_stat_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_stat_pc_1_common
static void setup_close_stat_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_stat_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_stat_pc_1_proc1
// static void setup_close_stat_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_stat_pc_1_final
// static void setup_close_stat_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_stat_pc_1_procfinal

/*
 * calls: close stat
 */
// static int test_close_stat_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_stat_pc_0_0
static int test_close_stat_p8_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_close_stat_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_close_stat_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_stat_pc_0_proc0
// static void setup_close_stat_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_stat_pc_0_proc1
// static void setup_close_stat_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_stat_pc_0_final
// static void setup_close_stat_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_stat_pc_0_procfinal

/*
 * calls: close stat
 */
// static int test_close_stat_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_stat_pc_0_0
// static int test_close_stat_p8_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_stat_p8_0_1
static void setup_close_stat_p8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_stat_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_stat_pc_1_proc0
// static void setup_close_stat_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_stat_pc_1_proc1
// static void setup_close_stat_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_stat_pc_1_final
// static void setup_close_stat_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_stat_pc_1_procfinal

/*
 * calls: close stat
 */
// static int test_close_stat_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_stat_pc_0_0
// static int test_close_stat_p8_2_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_stat_p8_0_1
// static void setup_close_stat_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_stat_p8_1_common
// static void setup_close_stat_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_stat_pc_2_proc0
// static void setup_close_stat_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_stat_pc_1_proc1
// static void setup_close_stat_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_stat_pc_1_final
// static void setup_close_stat_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_stat_pc_1_procfinal

/*
 * calls: close stat
 */
static int test_close_stat_p4_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_stat_pc_0_1
// static void setup_close_stat_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_stat_pc_0_common
// static void setup_close_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_stat_pc_0_proc1
// static void setup_close_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_stat_pc_0_proc1
// static void setup_close_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_stat_pc_0_final
// static void setup_close_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_stat_pc_0_procfinal

/*
 * calls: close stat
 */
// static int test_close_stat_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_stat_p4_0_0
// static int test_close_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_close_stat_p8_0_1
static void setup_close_stat_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_stat_pc_0_proc1
// static void setup_close_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_stat_pc_0_proc1
// static void setup_close_stat_p0_0_final(void) {
//   
// }
// ^ See setup_close_stat_pc_0_procfinal
// static void setup_close_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_stat_pc_0_procfinal


/*
 * calls: close unlink
 */
static int test_close_unlink_pc_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_unlink_pc_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_close_unlink_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_unlink_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_unlink_pc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_unlink_pc_0_final(void) {
  unlink("__i0");
}
static void setup_close_unlink_pc_0_procfinal(void) {
  
}

/*
 * calls: close unlink
 */
// static int test_close_unlink_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_unlink_pc_0_0
// static int test_close_unlink_pc_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_unlink_pc_0_1
static void setup_close_unlink_pc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_close_unlink_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_unlink_pc_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_unlink_pc_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_unlink_pc_1_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close unlink
 */
// static int test_close_unlink_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_unlink_pc_0_0
// static int test_close_unlink_pc_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_unlink_pc_0_1
// static void setup_close_unlink_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_unlink_pc_1_common
static void setup_close_unlink_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_unlink_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_unlink_pc_1_proc1
// static void setup_close_unlink_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_unlink_pc_1_final
// static void setup_close_unlink_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_unlink_pc_1_procfinal

/*
 * calls: close unlink
 */
// static int test_close_unlink_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_unlink_pc_0_0
static int test_close_unlink_p8_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_close_unlink_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_unlink_p8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_unlink_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_unlink_pc_0_proc1
// static void setup_close_unlink_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_unlink_pc_0_final
// static void setup_close_unlink_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_unlink_pc_0_procfinal

/*
 * calls: close unlink
 */
// static int test_close_unlink_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_unlink_pc_0_0
// static int test_close_unlink_p8_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_unlink_p8_0_1
static void setup_close_unlink_p8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_unlink_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_unlink_pc_1_proc0
// static void setup_close_unlink_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_unlink_pc_1_proc1
// static void setup_close_unlink_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_unlink_pc_1_final
// static void setup_close_unlink_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_unlink_pc_1_procfinal

/*
 * calls: close unlink
 */
// static int test_close_unlink_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_unlink_pc_0_0
// static int test_close_unlink_p8_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_unlink_p8_0_1
// static void setup_close_unlink_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_unlink_p8_1_common
// static void setup_close_unlink_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_unlink_pc_2_proc0
// static void setup_close_unlink_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_unlink_pc_1_proc1
// static void setup_close_unlink_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_unlink_pc_1_final
// static void setup_close_unlink_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_unlink_pc_1_procfinal

/*
 * calls: close unlink
 */
static int test_close_unlink_p4_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_unlink_p4_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_unlink_pc_0_1
// static void setup_close_unlink_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_close_unlink_pc_0_common
// static void setup_close_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_unlink_pc_0_proc1
// static void setup_close_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_unlink_pc_0_proc1
// static void setup_close_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_unlink_pc_0_final
// static void setup_close_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_unlink_pc_0_procfinal

/*
 * calls: close unlink
 */
// static int test_close_unlink_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_unlink_p4_0_0
// static int test_close_unlink_p0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_close_unlink_p8_0_1
static void setup_close_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_unlink_pc_0_proc1
// static void setup_close_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_unlink_pc_0_proc1
// static void setup_close_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_close_unlink_pc_0_procfinal
// static void setup_close_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_unlink_pc_0_procfinal


/*
 * calls: close write
 */
static int test_close_write_pfe_0_0(void) {
  int r = close(10);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_close_write_pfe_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_close_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_write_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_close_write_pfe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: close write
 */
// static int test_close_write_pfe_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pfe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pfe_0_1
static void setup_close_write_pfe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_write_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_write_pfe_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_write_pfe_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_close_write_pfe_1_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: close write
 */
// static int test_close_write_pfe_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pfe_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pfe_0_1
// static void setup_close_write_pfe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pfe_1_common
static void setup_close_write_pfe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pfe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pfe_1_proc1
// static void setup_close_write_pfe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_close_write_pfe_1_final
// static void setup_close_write_pfe_2_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_close_write_pfe_1_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pfe_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pfe_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pfe_0_1
// static void setup_close_write_pfe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pfe_0_common
static void setup_close_write_pfe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pfe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pfe_0_proc1
// static void setup_close_write_pfe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pfe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pf8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
static int test_close_write_pf8_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_close_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_write_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pf8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pf8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
// static void setup_close_write_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf8_0_common
static void setup_close_write_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pf8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pf8_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
// static void setup_close_write_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf8_0_common
static void setup_close_write_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pf0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
static int test_close_write_pf0_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_close_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_write_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pf0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pf0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf0_0_1
// static void setup_close_write_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
static void setup_close_write_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pf0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pf0_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf0_0_1
// static void setup_close_write_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
static void setup_close_write_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pe8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pe8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
static void setup_close_write_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_close_write_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_close_write_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_close_write_pe8_0_final(void) {
  unlink("__i0");
}
static void setup_close_write_pe8_0_procfinal(void) {
  
}

/*
 * calls: close write
 */
// static int test_close_write_pe8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pe8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
static void setup_close_write_pe8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_write_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pe8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pe8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pe8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pe8_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
// static void setup_close_write_pe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pe8_1_common
static void setup_close_write_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pe8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pe8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pe0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pe0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
static void setup_close_write_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_close_write_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_write_pe8_0_proc0
// static void setup_close_write_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_write_pe8_0_final
// static void setup_close_write_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pe0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pe0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
static void setup_close_write_pe0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_close_write_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pe8_1_proc0
// static void setup_close_write_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pe0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pe0_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
// static void setup_close_write_pe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pe0_1_common
// static void setup_close_write_pe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pe8_2_proc0
// static void setup_close_write_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pe0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pe0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pd8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
static int test_close_write_pd8_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_close_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
static void setup_close_write_pd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pc_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf0_0_1
// static void setup_close_write_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_write_pe8_0_common
static void setup_close_write_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_write_pe8_0_final
// static void setup_close_write_pc_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pc_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pc_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf0_0_1
// static void setup_close_write_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
// static void setup_close_write_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pd8_0_proc0
// static void setup_close_write_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pc_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pc_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf0_0_1
// static void setup_close_write_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
static void setup_close_write_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_pc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pbe_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
static int test_close_write_pbe_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_close_write_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_write_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_write_pbe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pbe_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pbe_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pbe_0_1
static void setup_close_write_pbe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_close_write_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_close_write_pbe_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_close_write_pfe_1_final
// static void setup_close_write_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_close_write_pfe_1_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pbe_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pbe_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pbe_0_1
// static void setup_close_write_pbe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pbe_1_common
static void setup_close_write_pbe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pbe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pbe_1_proc1
// static void setup_close_write_pbe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_close_write_pfe_1_final
// static void setup_close_write_pbe_2_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_close_write_pfe_1_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pbe_3_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pbe_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pbe_0_1
// static void setup_close_write_pbe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pbe_0_common
// static void setup_close_write_pbe_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pbe_0_proc1
// static void setup_close_write_pbe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pbe_0_proc1
// static void setup_close_write_pbe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pbe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pb8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
static int test_close_write_pb8_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_close_write_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf8_0_common
// static void setup_close_write_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pd8_0_proc0
// static void setup_close_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pc_2_proc0
// static void setup_close_write_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pb8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pb8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf8_0_common
static void setup_close_write_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pc_2_proc0
// static void setup_close_write_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pb8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pb8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf8_0_common
// static void setup_close_write_pb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pc_2_proc0
// static void setup_close_write_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pc_2_proc0
// static void setup_close_write_pb8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pb8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pb0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pd8_0_1
// static void setup_close_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
static void setup_close_write_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pd8_0_proc0
// static void setup_close_write_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pb0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pb0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pd8_0_1
// static void setup_close_write_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
// static void setup_close_write_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pd8_0_proc0
// static void setup_close_write_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pd8_0_proc0
// static void setup_close_write_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pb0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pb0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pd8_0_1
// static void setup_close_write_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
// static void setup_close_write_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pc_2_proc0
// static void setup_close_write_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pd8_0_proc0
// static void setup_close_write_pb0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pb0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pa8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pa8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_write_pe8_0_common
// static void setup_close_write_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_write_pc_0_proc0
// static void setup_close_write_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_write_pc_0_proc0
// static void setup_close_write_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_write_pe8_0_final
// static void setup_close_write_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pa8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pa8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pe8_1_common
// static void setup_close_write_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pd8_0_proc0
// static void setup_close_write_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pb0_0_proc0
// static void setup_close_write_pa8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pa8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pa8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pa8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pe8_1_common
// static void setup_close_write_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pc_2_proc0
// static void setup_close_write_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pb0_0_proc0
// static void setup_close_write_pa8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pa8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pa0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_write_pe0_0_common
// static void setup_close_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_write_pc_0_proc0
// static void setup_close_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_write_pc_0_proc0
// static void setup_close_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_write_pe8_0_final
// static void setup_close_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pa0_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pa0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pe0_1_common
// static void setup_close_write_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pd8_0_proc0
// static void setup_close_write_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pb0_0_proc0
// static void setup_close_write_pa0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pa0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_pa0_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_pa0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_pa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pe0_1_common
// static void setup_close_write_pa0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pc_2_proc0
// static void setup_close_write_pa0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pb0_0_proc0
// static void setup_close_write_pa0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_pa0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p8_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_p8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pd8_0_1
// static void setup_close_write_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_write_pe8_0_common
// static void setup_close_write_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_write_pc_0_proc0
// static void setup_close_write_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_write_pe8_0_final
// static void setup_close_write_p8_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p8_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_p8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pd8_0_1
// static void setup_close_write_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
// static void setup_close_write_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pd8_0_proc0
// static void setup_close_write_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_p8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_p8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p8_2_0(void) {
//   int r = close(10);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_close_write_pfe_0_0
// static int test_close_write_p8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pd8_0_1
// static void setup_close_write_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
// static void setup_close_write_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pc_2_proc0
// static void setup_close_write_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_p8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_p8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
static int test_close_write_p7c_0_0(void) {
  int r = close(10);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_close_write_p7c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pfe_0_1
// static void setup_close_write_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pfe_0_common
static void setup_close_write_p7c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pfe_0_proc1
// static void setup_close_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p78_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p78_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
// static void setup_close_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf8_0_common
static void setup_close_write_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p70_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p70_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf0_0_1
// static void setup_close_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
static void setup_close_write_p70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_close_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p68_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p68_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
// static void setup_close_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_write_pe8_0_common
static void setup_close_write_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_close_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_write_pe8_0_final
// static void setup_close_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p60_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p60_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf8_0_1
// static void setup_close_write_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_write_pe0_0_common
// static void setup_close_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_write_p68_0_proc0
// static void setup_close_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_write_pe8_0_final
// static void setup_close_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p4_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pf0_0_1
static void setup_close_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_close_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p4_0_final(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal
// static void setup_close_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p4_1_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pd8_0_1
// static void setup_close_write_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_write_p4_0_common
// static void setup_close_write_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p4_1_final(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal
// static void setup_close_write_p4_1_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p3c_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pbe_0_1
// static void setup_close_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pbe_0_common
// static void setup_close_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pfe_0_proc1
// static void setup_close_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pbe_0_proc1
// static void setup_close_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p38_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf8_0_common
// static void setup_close_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pc_2_proc0
// static void setup_close_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p30_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pd8_0_1
// static void setup_close_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_close_write_pf0_0_common
// static void setup_close_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pf8_0_proc1
// static void setup_close_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_close_write_pd8_0_proc0
// static void setup_close_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_final
// static void setup_close_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_close_write_pfe_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p28_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_close_write_pe8_0_common
// static void setup_close_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_write_pc_0_proc0
// static void setup_close_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_write_pe8_0_final
// static void setup_close_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p20_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pb8_0_1
// static void setup_close_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_close_write_pe0_0_common
// static void setup_close_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_close_write_pc_0_proc0
// static void setup_close_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_close_write_pe8_0_final
// static void setup_close_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal

/*
 * calls: close write
 */
// static int test_close_write_p0_0_0(void) {
//   int r = close(10);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_close_write_p7c_0_0
// static int test_close_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_close_write_pd8_0_1
// static void setup_close_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_close_write_p4_0_common
// static void setup_close_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_close_write_pe8_0_proc1
// static void setup_close_write_p0_0_final(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal
// static void setup_close_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_close_write_pe8_0_procfinal


/*
 * calls: fstat fstat
 */
static int test_fstat_fstat_pf8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_fstat_pf8_0_1(void) {
  struct stat st;
  int r = fstat(11, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_fstat_fstat_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_fstat_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_fstat_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_fstat_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_fstat_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pf8_1_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_1
// static void setup_fstat_fstat_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pf8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pf8_2_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_1
// static void setup_fstat_fstat_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pf8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pf8_3_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static void setup_fstat_fstat_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pf8_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pf8_4_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_1
// static void setup_fstat_fstat_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pf8_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pf8_5_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static void setup_fstat_fstat_pf8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_pf8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_pf8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pf8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pf8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pf0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
static int test_fstat_fstat_pf0_0_1(void) {
  struct stat st;
  int r = fstat(11, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_fstat_fstat_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pf0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pf0_1_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf0_0_1
// static void setup_fstat_fstat_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pe_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
static int test_fstat_fstat_pe_0_1(void) {
  struct stat st;
  int r = fstat(11, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_fstat_fstat_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_3_proc0
// static void setup_fstat_fstat_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pe_1_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pe_0_1
// static void setup_fstat_fstat_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_5_proc0
// static void setup_fstat_fstat_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pd8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pd8_0_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static void setup_fstat_fstat_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_3_proc0
// static void setup_fstat_fstat_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_3_proc0
// static void setup_fstat_fstat_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pd8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pd8_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static void setup_fstat_fstat_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_5_proc0
// static void setup_fstat_fstat_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_3_proc0
// static void setup_fstat_fstat_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pd8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pd8_2_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static void setup_fstat_fstat_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_3_proc0
// static void setup_fstat_fstat_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_5_proc0
// static void setup_fstat_fstat_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pd8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pd8_3_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static void setup_fstat_fstat_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_5_proc0
// static void setup_fstat_fstat_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_5_proc0
// static void setup_fstat_fstat_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pd0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
static int test_fstat_fstat_pd0_0_1(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_fstat_fstat_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_3_proc0
static void setup_fstat_fstat_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pd0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pd0_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static void setup_fstat_fstat_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_5_proc0
// static void setup_fstat_fstat_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pd0_0_proc1
// static void setup_fstat_fstat_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
static int test_fstat_fstat_pc_0_1(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_fstat_fstat_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_3_proc0
// static void setup_fstat_fstat_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static int test_fstat_fstat_pc_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static void setup_fstat_fstat_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_5_proc0
// static void setup_fstat_fstat_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pb8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static int test_fstat_fstat_pb8_0_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_1
// static void setup_fstat_fstat_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pb8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static int test_fstat_fstat_pb8_1_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_1
// static void setup_fstat_fstat_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pb0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static int test_fstat_fstat_pb0_0_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf0_0_1
static void setup_fstat_fstat_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_fstat_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_fstat_pb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_fstat_pb0_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_fstat_pb0_0_procfinal(void) {
  
}

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pb0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static int test_fstat_fstat_pb0_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static void setup_fstat_fstat_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_0_common
static void setup_fstat_fstat_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_fstat_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_fstat_pb0_0_final
// static void setup_fstat_fstat_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_pa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static int test_fstat_fstat_pa_0_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pe_0_1
// static void setup_fstat_fstat_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_0_common
// static void setup_fstat_fstat_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_1_proc0
// static void setup_fstat_fstat_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_fstat_pb0_0_final
// static void setup_fstat_fstat_pa_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p98_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static int test_fstat_fstat_p98_0_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static void setup_fstat_fstat_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pd0_0_proc1
// static void setup_fstat_fstat_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_3_proc0
// static void setup_fstat_fstat_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p98_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static int test_fstat_fstat_p98_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static void setup_fstat_fstat_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pd0_0_proc1
// static void setup_fstat_fstat_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_5_proc0
// static void setup_fstat_fstat_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p90_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static int test_fstat_fstat_p90_0_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static void setup_fstat_fstat_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_0_common
// static void setup_fstat_fstat_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_1_proc0
// static void setup_fstat_fstat_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_1_proc0
// static void setup_fstat_fstat_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_fstat_pb0_0_final
// static void setup_fstat_fstat_p90_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static int test_fstat_fstat_p8_0_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static void setup_fstat_fstat_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_0_common
// static void setup_fstat_fstat_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_1_proc0
// static void setup_fstat_fstat_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_fstat_pb0_0_final
// static void setup_fstat_fstat_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p7_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static int test_fstat_fstat_p7_0_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_1
// static void setup_fstat_fstat_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p7_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static int test_fstat_fstat_p7_1_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_1
// static void setup_fstat_fstat_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
static void setup_fstat_fstat_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_fstat_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static int test_fstat_fstat_p6_0_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf0_0_1
// static void setup_fstat_fstat_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_0_common
static void setup_fstat_fstat_p6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_fstat_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_fstat_pb0_0_final
// static void setup_fstat_fstat_p6_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static int test_fstat_fstat_p4_0_1(void) {
//   struct stat st;
//   int r = fstat(11, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pe_0_1
static void setup_fstat_fstat_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_fstat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_p4_0_final(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal
// static void setup_fstat_fstat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static int test_fstat_fstat_p4_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static void setup_fstat_fstat_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_fstat_p4_0_common
// static void setup_fstat_fstat_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_p4_1_final(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal
// static void setup_fstat_fstat_p4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p3_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static int test_fstat_fstat_p3_0_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static void setup_fstat_fstat_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_3_proc0
// static void setup_fstat_fstat_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p3_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static int test_fstat_fstat_p3_1_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pf8_0_0
// static void setup_fstat_fstat_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_fstat_pf8_0_common
// static void setup_fstat_fstat_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_0_proc1
// static void setup_fstat_fstat_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_fstat_pf8_5_proc0
// static void setup_fstat_fstat_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_final
// static void setup_fstat_fstat_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_fstat_pf8_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p2_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static int test_fstat_fstat_p2_0_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pd0_0_1
// static void setup_fstat_fstat_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_0_common
// static void setup_fstat_fstat_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_fstat_pb0_1_proc0
// static void setup_fstat_fstat_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_fstat_pb0_0_final
// static void setup_fstat_fstat_p2_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal

/*
 * calls: fstat fstat
 */
// static int test_fstat_fstat_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static int test_fstat_fstat_p0_0_1(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_fstat_pc_0_1
// static void setup_fstat_fstat_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_fstat_p4_0_common
// static void setup_fstat_fstat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_fstat_pb0_0_proc1
// static void setup_fstat_fstat_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal
// static void setup_fstat_fstat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_fstat_pb0_0_procfinal


/*
 * calls: fstat link
 */
static int test_fstat_link_pf_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_link_pf_0_1(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_fstat_link_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_fstat_link_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_link_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_link_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_link_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat link
 */
// static int test_fstat_link_pf_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_pf_0_0
// static int test_fstat_link_pf_1_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pf_0_1
// static void setup_fstat_link_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_link_pf_0_common
static void setup_fstat_link_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_link_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_0_proc1
// static void setup_fstat_link_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_final
// static void setup_fstat_link_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_procfinal

/*
 * calls: fstat link
 */
// static int test_fstat_link_pf_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_pf_0_0
static int test_fstat_link_pf_2_1(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_fstat_link_pf_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_link_pf_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_0_proc0
// static void setup_fstat_link_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_0_proc1
// static void setup_fstat_link_pf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_final
// static void setup_fstat_link_pf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_procfinal

/*
 * calls: fstat link
 */
// static int test_fstat_link_pf_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_pf_0_0
// static int test_fstat_link_pf_3_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pf_2_1
// static void setup_fstat_link_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_link_pf_2_common
// static void setup_fstat_link_pf_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_1_proc0
// static void setup_fstat_link_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_0_proc1
// static void setup_fstat_link_pf_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_final
// static void setup_fstat_link_pf_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_procfinal

/*
 * calls: fstat link
 */
// static int test_fstat_link_pe0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_pf_0_0
static int test_fstat_link_pe0_0_1(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_fstat_link_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_link_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_0_proc0
// static void setup_fstat_link_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_0_proc1
// static void setup_fstat_link_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_final
// static void setup_fstat_link_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_procfinal

/*
 * calls: fstat link
 */
// static int test_fstat_link_pe0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_pf_0_0
// static int test_fstat_link_pe0_1_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pe0_0_1
// static void setup_fstat_link_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_link_pe0_0_common
// static void setup_fstat_link_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_1_proc0
// static void setup_fstat_link_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_0_proc1
// static void setup_fstat_link_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_final
// static void setup_fstat_link_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_procfinal

/*
 * calls: fstat link
 */
// static int test_fstat_link_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_pf_0_0
static int test_fstat_link_pc_0_1(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_fstat_link_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_link_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_0_proc0
// static void setup_fstat_link_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_0_proc1
// static void setup_fstat_link_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_final
// static void setup_fstat_link_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_procfinal

/*
 * calls: fstat link
 */
// static int test_fstat_link_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_pf_0_0
// static int test_fstat_link_pc_1_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pc_0_1
// static void setup_fstat_link_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_link_pc_0_common
// static void setup_fstat_link_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_1_proc0
// static void setup_fstat_link_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_link_pf_0_proc1
// static void setup_fstat_link_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_final
// static void setup_fstat_link_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_link_pf_0_procfinal

/*
 * calls: fstat link
 */
static int test_fstat_link_pb_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_link_pb_0_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pf_0_1
static void setup_fstat_link_pb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_fstat_link_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_link_pb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_link_pb_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_link_pb_0_procfinal(void) {
  
}

/*
 * calls: fstat link
 */
// static int test_fstat_link_pb_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_pb_0_0
// static int test_fstat_link_pb_1_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pf_2_1
static void setup_fstat_link_pb_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_link_pb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_link_pb_0_proc0
// static void setup_fstat_link_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
// static void setup_fstat_link_pb_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_link_pb_0_final
// static void setup_fstat_link_pb_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_link_pb_0_procfinal

/*
 * calls: fstat link
 */
static int test_fstat_link_pa8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 16384);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_link_pa8_0_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pe0_0_1
static void setup_fstat_link_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_link_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_link_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
static void setup_fstat_link_pa8_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_fstat_link_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_link_pb_0_procfinal

/*
 * calls: fstat link
 */
// static int test_fstat_link_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_pb_0_0
// static int test_fstat_link_p8_0_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pc_0_1
static void setup_fstat_link_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_fstat_link_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_link_pb_0_proc0
// static void setup_fstat_link_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
// static void setup_fstat_link_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_link_pb_0_final
// static void setup_fstat_link_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_link_pb_0_procfinal

/*
 * calls: fstat link
 */
static int test_fstat_link_p6_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_link_p6_0_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pf_0_1
// static void setup_fstat_link_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_link_pb_0_common
// static void setup_fstat_link_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
// static void setup_fstat_link_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
// static void setup_fstat_link_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_link_pb_0_final
// static void setup_fstat_link_p6_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_link_pb_0_procfinal

/*
 * calls: fstat link
 */
// static int test_fstat_link_p6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_p6_0_0
// static int test_fstat_link_p6_1_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pf_2_1
// static void setup_fstat_link_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_link_pb_1_common
// static void setup_fstat_link_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
// static void setup_fstat_link_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
// static void setup_fstat_link_p6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_link_pb_0_final
// static void setup_fstat_link_p6_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_link_pb_0_procfinal

/*
 * calls: fstat link
 */
// static int test_fstat_link_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_p6_0_0
// static int test_fstat_link_p4_0_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pe0_0_1
// static void setup_fstat_link_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_link_pb_1_common
// static void setup_fstat_link_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
// static void setup_fstat_link_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
// static void setup_fstat_link_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_link_pb_0_final
// static void setup_fstat_link_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_link_pb_0_procfinal

/*
 * calls: fstat link
 */
// static int test_fstat_link_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_link_p6_0_0
// static int test_fstat_link_p0_0_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_link_pc_0_1
static void setup_fstat_link_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_link_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
// static void setup_fstat_link_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_link_pb_0_proc1
// static void setup_fstat_link_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_link_pb_0_procfinal
// static void setup_fstat_link_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_link_pb_0_procfinal


/*
 * calls: fstat lseek
 */
static int test_fstat_lseek_pf8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_lseek_pf8_0_1(void) {
  int r = lseek(11, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_fstat_lseek_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_lseek_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_lseek_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_lseek_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_lseek_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf8_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
static void setup_fstat_lseek_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf8_2_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
static void setup_fstat_lseek_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pf8_3_1(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_fstat_lseek_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
static void setup_fstat_lseek_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf8_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf8_4_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
static void setup_fstat_lseek_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf8_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf8_5_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_pf8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
static void setup_fstat_lseek_pf8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pf6_0_1(void) {
  int r = lseek(11, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_fstat_lseek_pf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_lseek_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf6_1_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf6_0_1
// static void setup_fstat_lseek_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf6_0_common
static void setup_fstat_lseek_pf6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pf4_0_1(void) {
  int r = lseek(11, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_fstat_lseek_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_lseek_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf4_1_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf4_0_1
// static void setup_fstat_lseek_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
static void setup_fstat_lseek_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf4_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf4_2_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf4_0_1
// static void setup_fstat_lseek_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
static void setup_fstat_lseek_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf4_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf4_3_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf4_0_1
// static void setup_fstat_lseek_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
static void setup_fstat_lseek_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf3_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pf3_0_1(void) {
  int r = lseek(11, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_fstat_lseek_pf3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pf3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_2_proc0
// static void setup_fstat_lseek_pf3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf3_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf3_1_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf3_0_1
// static void setup_fstat_lseek_pf3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pf3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_3_proc0
// static void setup_fstat_lseek_pf3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf2_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pf2_0_1(void) {
  int r = lseek(11, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_fstat_lseek_pf2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pf2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_2_proc0
// static void setup_fstat_lseek_pf2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf2_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf2_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf2_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf2_1_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf2_0_1
// static void setup_fstat_lseek_pf2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pf2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_3_proc0
// static void setup_fstat_lseek_pf2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf18_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pf18_0_1(void) {
  int r = lseek(11, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_fstat_lseek_pf18_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_lseek_pf18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_0_proc0
// static void setup_fstat_lseek_pf18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf18_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf18_1_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf18_0_1
// static void setup_fstat_lseek_pf18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf18_0_common
// static void setup_fstat_lseek_pf18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_1_proc0
// static void setup_fstat_lseek_pf18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf10_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pf10_0_1(void) {
  int r = lseek(11, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_fstat_lseek_pf10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf18_0_common
// static void setup_fstat_lseek_pf10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_0_proc0
// static void setup_fstat_lseek_pf10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf10_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf10_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf10_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf10_1_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf10_0_1
// static void setup_fstat_lseek_pf10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf18_0_common
// static void setup_fstat_lseek_pf10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_1_proc0
// static void setup_fstat_lseek_pf10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf10_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf10_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf10_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pf10_2_1(void) {
  int r = lseek(11, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static void setup_fstat_lseek_pf10_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pf10_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_2_proc0
// static void setup_fstat_lseek_pf10_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf10_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf10_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf10_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf10_3_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf10_2_1
// static void setup_fstat_lseek_pf10_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pf10_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_3_proc0
// static void setup_fstat_lseek_pf10_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf10_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf10_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf0_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_2_proc0
// static void setup_fstat_lseek_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pf0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pf0_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf4_3_proc0
// static void setup_fstat_lseek_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pe_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pe_0_1(void) {
  int r = lseek(11, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_fstat_lseek_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pe_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pe_0_1
// static void setup_fstat_lseek_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd8_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd8_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd8_2_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd8_3_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pd6_0_1(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_fstat_lseek_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf6_0_common
// static void setup_fstat_lseek_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
static void setup_fstat_lseek_pd6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd6_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd6_0_1
// static void setup_fstat_lseek_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf6_0_common
// static void setup_fstat_lseek_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd6_0_proc1
// static void setup_fstat_lseek_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pd4_0_1(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_fstat_lseek_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
static void setup_fstat_lseek_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd4_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd4_0_1
// static void setup_fstat_lseek_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_0_proc1
// static void setup_fstat_lseek_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd4_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd4_2_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd4_0_1
// static void setup_fstat_lseek_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
static void setup_fstat_lseek_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd4_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd4_3_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd4_0_1
// static void setup_fstat_lseek_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd3_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pd3_0_1(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_fstat_lseek_pd3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pd3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pd3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_pd3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd3_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd3_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd3_0_1
// static void setup_fstat_lseek_pd3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pd3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_pd3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd2_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pd2_0_1(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_fstat_lseek_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_pd2_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd2_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd2_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd2_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd2_0_1
// static void setup_fstat_lseek_pd2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pd2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_pd2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd18_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pd18_0_1(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_fstat_lseek_pd18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf18_0_common
// static void setup_fstat_lseek_pd18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pd18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_0_proc1
// static void setup_fstat_lseek_pd18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd18_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd18_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd18_0_1
// static void setup_fstat_lseek_pd18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf18_0_common
// static void setup_fstat_lseek_pd18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_0_proc1
// static void setup_fstat_lseek_pd18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd10_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pd10_0_1(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_fstat_lseek_pd10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf18_0_common
// static void setup_fstat_lseek_pd10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pd10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_0_proc1
// static void setup_fstat_lseek_pd10_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd10_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd10_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd10_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd10_0_1
// static void setup_fstat_lseek_pd10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf18_0_common
// static void setup_fstat_lseek_pd10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_0_proc1
// static void setup_fstat_lseek_pd10_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd10_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd10_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pd10_2_1(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static void setup_fstat_lseek_pd10_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pd10_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pd10_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_pd10_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd10_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd10_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd10_3_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd10_2_1
// static void setup_fstat_lseek_pd10_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf4_0_common
// static void setup_fstat_lseek_pd10_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd10_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_pd10_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd10_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pd0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pd0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
static int test_fstat_lseek_pc_0_1(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_fstat_lseek_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pf8_0_0
// static int test_fstat_lseek_pc_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pc_0_1
// static void setup_fstat_lseek_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
static int test_fstat_lseek_pb8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_lseek_pb8_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
static void setup_fstat_lseek_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_pb8_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
static void setup_fstat_lseek_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
static int test_fstat_lseek_pb6_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_lseek_pb6_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf6_0_1
static void setup_fstat_lseek_pb6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_lseek_pb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_lseek_pb6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_lseek_pb6_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_lseek_pb6_0_procfinal(void) {
  
}

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_pb6_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd6_0_1
// static void setup_fstat_lseek_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
static void setup_fstat_lseek_pb6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_lseek_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb6_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_pb4_0_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf4_0_1
// static void setup_fstat_lseek_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
static void setup_fstat_lseek_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_lseek_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_pb4_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd4_0_1
static void setup_fstat_lseek_pb4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_lseek_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_lseek_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb3_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_pb3_0_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf3_0_1
// static void setup_fstat_lseek_pb3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
static void setup_fstat_lseek_pb3_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_lseek_pb3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb3_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb3_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_pb3_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd3_0_1
// static void setup_fstat_lseek_pb3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_pb3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_pb3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb3_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb2_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_pb2_0_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf2_0_1
// static void setup_fstat_lseek_pb2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_pb2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb3_0_proc0
// static void setup_fstat_lseek_pb2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb2_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb2_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_pb2_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd2_0_1
// static void setup_fstat_lseek_pb2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_pb2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_pb2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb2_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb18_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_pb18_0_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf18_0_1
// static void setup_fstat_lseek_pb18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_pb18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_0_proc0
// static void setup_fstat_lseek_pb18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb18_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb18_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb18_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_pb18_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd18_0_1
// static void setup_fstat_lseek_pb18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
static void setup_fstat_lseek_pb18_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_lseek_pb18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb18_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb10_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_pb10_0_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf10_0_1
// static void setup_fstat_lseek_pb10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_pb10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_0_proc0
// static void setup_fstat_lseek_pb10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb10_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb10_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_pb10_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd10_0_1
// static void setup_fstat_lseek_pb10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_pb10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_pb10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb10_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_pb0_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb3_0_proc0
// static void setup_fstat_lseek_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pb0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_pb0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_pa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_pa_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pe_0_1
// static void setup_fstat_lseek_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_pa_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p98_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_p98_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p98_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_p98_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pd4_2_proc1
// static void setup_fstat_lseek_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p96_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_p96_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd6_0_1
// static void setup_fstat_lseek_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_1_proc0
static void setup_fstat_lseek_p96_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_lseek_p96_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p96_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
static int test_fstat_lseek_p96_1_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 20480);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_lseek_p96_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd6_0_1
static void setup_fstat_lseek_p96_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_fstat_lseek_p96_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p96_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p96_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p96_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p94_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_p94_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd4_0_1
// static void setup_fstat_lseek_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
static void setup_fstat_lseek_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_lseek_p94_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_lseek_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p94_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p94_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_p94_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd4_0_1
// static void setup_fstat_lseek_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p94_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p93_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_p93_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd3_0_1
// static void setup_fstat_lseek_p93_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p93_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p93_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p93_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p93_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p92_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_p92_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd2_0_1
// static void setup_fstat_lseek_p92_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p92_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p92_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p92_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p92_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p918_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_p918_0_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd18_0_1
// static void setup_fstat_lseek_p918_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_p918_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p94_0_proc1
// static void setup_fstat_lseek_p918_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p94_0_proc1
// static void setup_fstat_lseek_p918_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p918_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p910_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_p910_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd10_0_1
// static void setup_fstat_lseek_p910_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_p910_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p94_0_proc1
// static void setup_fstat_lseek_p910_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p94_0_proc1
// static void setup_fstat_lseek_p910_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p910_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p910_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb6_0_0
// static int test_fstat_lseek_p910_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd10_2_1
// static void setup_fstat_lseek_p910_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p910_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p910_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p910_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p910_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p90_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_p90_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p90_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_pb8_0_0
// static int test_fstat_lseek_p8_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pc_0_1
// static void setup_fstat_lseek_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
static int test_fstat_lseek_p7_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_lseek_p7_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
static void setup_fstat_lseek_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p7_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p7_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
static void setup_fstat_lseek_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_lseek_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p6c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p6c_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf6_0_1
// static void setup_fstat_lseek_p6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
static void setup_fstat_lseek_p6c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_lseek_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p6c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p6c_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p68_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p68_0_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf4_0_1
// static void setup_fstat_lseek_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
static void setup_fstat_lseek_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_lseek_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p68_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p68_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p68_1_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf4_0_1
// static void setup_fstat_lseek_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
static void setup_fstat_lseek_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_lseek_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p68_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p66_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p66_0_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf3_0_1
// static void setup_fstat_lseek_p66_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p66_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p68_1_proc0
// static void setup_fstat_lseek_p66_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p66_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p66_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p64_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p64_0_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf2_0_1
// static void setup_fstat_lseek_p64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p68_1_proc0
// static void setup_fstat_lseek_p64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p64_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p64_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p63_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p63_0_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf18_0_1
// static void setup_fstat_lseek_p63_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_p63_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p68_0_proc0
// static void setup_fstat_lseek_p63_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p63_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p63_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p62_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p62_0_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf10_0_1
// static void setup_fstat_lseek_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p68_0_proc0
// static void setup_fstat_lseek_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p62_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p62_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p62_1_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf10_2_1
// static void setup_fstat_lseek_p62_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p62_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p68_1_proc0
// static void setup_fstat_lseek_p62_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p62_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p62_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p60_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p60_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_0_1
// static void setup_fstat_lseek_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p68_1_proc0
// static void setup_fstat_lseek_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p60_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p4_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pe_0_1
static void setup_fstat_lseek_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_lseek_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p4_0_final(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal
// static void setup_fstat_lseek_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p4_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pc_0_1
// static void setup_fstat_lseek_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_lseek_p4_0_common
// static void setup_fstat_lseek_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p4_1_final(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal
// static void setup_fstat_lseek_p4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p3_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p3_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_3_proc0
// static void setup_fstat_lseek_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p3_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p3_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_lseek_pf8_0_common
// static void setup_fstat_lseek_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_0_proc1
// static void setup_fstat_lseek_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_lseek_pf8_5_proc0
// static void setup_fstat_lseek_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_final
// static void setup_fstat_lseek_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_lseek_pf8_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p2c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p2c_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd6_0_1
// static void setup_fstat_lseek_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p96_0_proc1
// static void setup_fstat_lseek_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p28_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p28_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd4_0_1
// static void setup_fstat_lseek_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p94_0_proc1
// static void setup_fstat_lseek_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p28_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p28_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p28_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd4_0_1
// static void setup_fstat_lseek_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p28_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p26_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p26_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd3_0_1
// static void setup_fstat_lseek_p26_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p26_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p26_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p26_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p26_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p24_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p24_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd2_0_1
// static void setup_fstat_lseek_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p24_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p23_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p23_0_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd18_0_1
// static void setup_fstat_lseek_p23_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_p23_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p23_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p94_0_proc1
// static void setup_fstat_lseek_p23_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p23_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p22_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p22_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd10_0_1
// static void setup_fstat_lseek_p22_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_p22_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p22_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_p94_0_proc1
// static void setup_fstat_lseek_p22_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p22_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p22_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p22_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pd10_2_1
// static void setup_fstat_lseek_p22_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb6_0_common
// static void setup_fstat_lseek_p22_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p22_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p22_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p22_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p20_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p20_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pf8_3_1
// static void setup_fstat_lseek_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_common
// static void setup_fstat_lseek_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_lseek_pb4_1_proc0
// static void setup_fstat_lseek_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_lseek_pb6_0_final
// static void setup_fstat_lseek_p20_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal

/*
 * calls: fstat lseek
 */
// static int test_fstat_lseek_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_lseek_p7_0_0
// static int test_fstat_lseek_p0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_lseek_pc_0_1
// static void setup_fstat_lseek_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_lseek_p4_0_common
// static void setup_fstat_lseek_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_lseek_pb6_0_proc1
// static void setup_fstat_lseek_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal
// static void setup_fstat_lseek_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_lseek_pb6_0_procfinal


/*
 * calls: fstat memread
 */
static int test_fstat_memread_pf8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_memread_pf8_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static void setup_fstat_memread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_memread_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_fstat_memread_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_memread_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_memread_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pf8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
static void setup_fstat_memread_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_memread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pf8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
static void setup_fstat_memread_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_memread_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pf8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
static void setup_fstat_memread_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_memread_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
static int test_fstat_memread_pf4_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
static void setup_fstat_memread_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_memread_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memread_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pf4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf4_0_common
static void setup_fstat_memread_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memread_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf4_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pf4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf4_0_common
static void setup_fstat_memread_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memread_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf4_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pf4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf4_0_common
static void setup_fstat_memread_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memread_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pf0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
static void setup_fstat_memread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_memread_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_pf4_0_proc0
// static void setup_fstat_memread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pf0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf0_0_common
// static void setup_fstat_memread_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_pf4_1_proc0
// static void setup_fstat_memread_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf0_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pf0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf0_0_common
// static void setup_fstat_memread_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_pf4_2_proc0
// static void setup_fstat_memread_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pf0_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pf0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf0_0_common
// static void setup_fstat_memread_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_pf4_3_proc0
// static void setup_fstat_memread_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pe_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
static int test_fstat_memread_pe_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_fstat_memread_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
static void setup_fstat_memread_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_memread_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pe_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pe_0_1
// static void setup_fstat_memread_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
static void setup_fstat_memread_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_memread_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
// static void setup_fstat_memread_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_0_proc0
static void setup_fstat_memread_pd8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_memread_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
// static void setup_fstat_memread_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_1_proc0
// static void setup_fstat_memread_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_fstat_memread_pd8_0_proc1
// static void setup_fstat_memread_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
// static void setup_fstat_memread_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_0_proc0
static void setup_fstat_memread_pd8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_memread_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
// static void setup_fstat_memread_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_1_proc0
// static void setup_fstat_memread_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_fstat_memread_pd8_2_proc1
// static void setup_fstat_memread_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
static void setup_fstat_memread_pd4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_memread_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_0_proc0
static void setup_fstat_memread_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_fstat_memread_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
static void setup_fstat_memread_pd4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_memread_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_0_proc0
static void setup_fstat_memread_pd4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_fstat_memread_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd4_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pd4_1_common
// static void setup_fstat_memread_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_1_proc0
static void setup_fstat_memread_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_fstat_memread_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd4_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pd4_0_common
// static void setup_fstat_memread_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_1_proc0
static void setup_fstat_memread_pd4_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_fstat_memread_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf0_0_common
// static void setup_fstat_memread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_0_proc0
static void setup_fstat_memread_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memread_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf0_0_common
// static void setup_fstat_memread_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_1_proc0
// static void setup_fstat_memread_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_pd0_0_proc1
// static void setup_fstat_memread_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd0_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf0_0_common
// static void setup_fstat_memread_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_0_proc0
static void setup_fstat_memread_pd0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memread_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pd0_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pd0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf0_0_common
// static void setup_fstat_memread_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_1_proc0
// static void setup_fstat_memread_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_pd0_2_proc1
// static void setup_fstat_memread_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pe_0_1
// static void setup_fstat_memread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
// static void setup_fstat_memread_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_0_proc0
// static void setup_fstat_memread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pf8_0_0
// static int test_fstat_memread_pc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pe_0_1
// static void setup_fstat_memread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memread_pf8_0_common
// static void setup_fstat_memread_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pe_1_proc0
// static void setup_fstat_memread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memread_pf8_0_proc1
// static void setup_fstat_memread_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_final
// static void setup_fstat_memread_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memread_pf8_0_procfinal

/*
 * calls: fstat memread
 */
static int test_fstat_memread_pb8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_memread_pb8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
static void setup_fstat_memread_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_memread_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_fstat_memread_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_memread_pb8_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_memread_pb8_0_procfinal(void) {
  
}

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pb8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_pb8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
static void setup_fstat_memread_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_memread_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pb4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_pb4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
static void setup_fstat_memread_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memread_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pb4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_pb4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
static void setup_fstat_memread_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memread_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pb4_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_pb4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
static void setup_fstat_memread_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memread_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pb4_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_pb4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
static void setup_fstat_memread_pb4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memread_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
static int test_fstat_memread_pb0_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_memread_pb0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
static void setup_fstat_memread_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_fstat_memread_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_pb4_0_proc0
// static void setup_fstat_memread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pb0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb0_0_0
// static int test_fstat_memread_pb0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
// static void setup_fstat_memread_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_pb4_1_proc0
// static void setup_fstat_memread_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pb0_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb0_0_0
// static int test_fstat_memread_pb0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
// static void setup_fstat_memread_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_pb4_2_proc0
// static void setup_fstat_memread_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_pb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pb0_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb0_0_0
// static int test_fstat_memread_pb0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
// static void setup_fstat_memread_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_pb4_3_proc0
// static void setup_fstat_memread_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_pa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_pa_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pe_0_1
// static void setup_fstat_memread_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
static void setup_fstat_memread_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_memread_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_pa_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p98_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_p98_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
// static void setup_fstat_memread_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memread_pa_0_proc0
static void setup_fstat_memread_p98_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_memread_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p98_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p98_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_p98_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
// static void setup_fstat_memread_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memread_pa_0_proc0
static void setup_fstat_memread_p98_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_memread_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p98_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p94_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_p94_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
static void setup_fstat_memread_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_memread_p94_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_fstat_memread_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p94_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p94_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_p94_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
static void setup_fstat_memread_p94_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_memread_p94_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
// static void setup_fstat_memread_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p94_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p94_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_p94_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_p94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
static void setup_fstat_memread_p94_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_memread_p94_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_fstat_memread_p94_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p94_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p94_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_p94_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_p94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
static void setup_fstat_memread_p94_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_memread_p94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_fstat_memread_p94_2_proc1
// static void setup_fstat_memread_p94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p94_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p90_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb0_0_0
// static int test_fstat_memread_p90_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
static void setup_fstat_memread_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_memread_p90_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memread_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p90_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p90_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb0_0_0
// static int test_fstat_memread_p90_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
// static void setup_fstat_memread_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memread_p90_0_proc0
static void setup_fstat_memread_p90_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memread_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p90_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p90_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb0_0_0
// static int test_fstat_memread_p90_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
// static void setup_fstat_memread_p90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memread_pa_0_proc0
// static void setup_fstat_memread_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_p90_0_proc1
// static void setup_fstat_memread_p90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p90_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p90_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb0_0_0
// static int test_fstat_memread_p90_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
// static void setup_fstat_memread_p90_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memread_pa_0_proc0
// static void setup_fstat_memread_p90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_p90_1_proc1
// static void setup_fstat_memread_p90_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p90_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_pb8_0_0
// static int test_fstat_memread_p8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pe_0_1
// static void setup_fstat_memread_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
// static void setup_fstat_memread_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memread_pa_0_proc0
// static void setup_fstat_memread_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
static int test_fstat_memread_p7_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_memread_p7_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
static void setup_fstat_memread_p7_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_memread_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_fstat_memread_p98_0_proc1
// static void setup_fstat_memread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p7_0_final(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal
// static void setup_fstat_memread_p7_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p7_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p7_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_memread_p7_0_common
// static void setup_fstat_memread_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_fstat_memread_p98_1_proc1
// static void setup_fstat_memread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p7_1_final(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal
// static void setup_fstat_memread_p7_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p68_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p68_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
// static void setup_fstat_memread_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_p90_0_proc1
// static void setup_fstat_memread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p68_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p68_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
// static void setup_fstat_memread_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_p90_1_proc1
// static void setup_fstat_memread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p60_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p60_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
// static void setup_fstat_memread_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_p90_0_proc1
// static void setup_fstat_memread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p60_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p60_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
// static void setup_fstat_memread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_p90_1_proc1
// static void setup_fstat_memread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pe_0_1
// static void setup_fstat_memread_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_memread_p7_0_common
// static void setup_fstat_memread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p4_0_final(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal
// static void setup_fstat_memread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p3_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p3_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_memread_p7_0_common
// static void setup_fstat_memread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_fstat_memread_p98_0_proc1
// static void setup_fstat_memread_p3_0_final(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal
// static void setup_fstat_memread_p3_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p3_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p3_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_memread_p7_0_common
// static void setup_fstat_memread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_fstat_memread_p98_1_proc1
// static void setup_fstat_memread_p3_1_final(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal
// static void setup_fstat_memread_p3_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p28_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p28_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
// static void setup_fstat_memread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_fstat_memread_p94_0_proc1
// static void setup_fstat_memread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p28_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p28_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pf4_0_1
// static void setup_fstat_memread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memread_pb8_0_common
// static void setup_fstat_memread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
static void setup_fstat_memread_p28_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_fstat_memread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p20_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p20_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
// static void setup_fstat_memread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_p90_0_proc1
// static void setup_fstat_memread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p20_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p20_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_fstat_memread_pf8_0_1
// static void setup_fstat_memread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memread_pb0_0_common
// static void setup_fstat_memread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memread_p90_1_proc1
// static void setup_fstat_memread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memread_pb8_0_final
// static void setup_fstat_memread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal

/*
 * calls: fstat memread
 */
// static int test_fstat_memread_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memread_p7_0_0
// static int test_fstat_memread_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memread_pe_0_1
// static void setup_fstat_memread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_memread_p7_0_common
// static void setup_fstat_memread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memread_pb8_0_proc1
// static void setup_fstat_memread_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal
// static void setup_fstat_memread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memread_pb8_0_procfinal


/*
 * calls: fstat memwrite
 */
static int test_fstat_memwrite_pfc_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_memwrite_pfc_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static void setup_fstat_memwrite_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_memwrite_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_fstat_memwrite_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_memwrite_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_memwrite_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pfc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pfc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
static void setup_fstat_memwrite_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_memwrite_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pfa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
static int test_fstat_memwrite_pfa_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
static void setup_fstat_memwrite_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_memwrite_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_fstat_memwrite_pfa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pfa_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pfa_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pfa_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pfa_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pfa_0_1
// static void setup_fstat_memwrite_pfa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfa_0_common
static void setup_fstat_memwrite_pfa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_fstat_memwrite_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pfa_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pfa_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pf8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pf8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
static void setup_fstat_memwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_memwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memwrite_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pf8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pf8_0_common
static void setup_fstat_memwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pf0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
static int test_fstat_memwrite_pf0_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_fstat_memwrite_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
static void setup_fstat_memwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pf0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pf0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
static void setup_fstat_memwrite_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pf0_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pf0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
static void setup_fstat_memwrite_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_memwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pf0_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pf0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
static void setup_fstat_memwrite_pf0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_memwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pe_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pe_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
static void setup_fstat_memwrite_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_memwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pe_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
static void setup_fstat_memwrite_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_memwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pdc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pdc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
// static void setup_fstat_memwrite_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_0_proc0
static void setup_fstat_memwrite_pdc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_memwrite_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pdc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pdc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
// static void setup_fstat_memwrite_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_1_proc0
// static void setup_fstat_memwrite_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_fstat_memwrite_pdc_0_proc1
// static void setup_fstat_memwrite_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pda_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pda_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pfa_0_1
static void setup_fstat_memwrite_pda_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_memwrite_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_0_proc0
static void setup_fstat_memwrite_pda_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memwrite_pda_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pda_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pda_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pda_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pfa_0_1
// static void setup_fstat_memwrite_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pda_0_common
// static void setup_fstat_memwrite_pda_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_1_proc0
// static void setup_fstat_memwrite_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_pda_0_proc1
// static void setup_fstat_memwrite_pda_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pda_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pd8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pd8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pf8_0_common
// static void setup_fstat_memwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_0_proc0
// static void setup_fstat_memwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_pda_0_proc1
// static void setup_fstat_memwrite_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pd8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pd8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pf8_0_common
// static void setup_fstat_memwrite_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_1_proc0
// static void setup_fstat_memwrite_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_pda_0_proc1
// static void setup_fstat_memwrite_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pd0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pd0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
// static void setup_fstat_memwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_0_proc0
static void setup_fstat_memwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memwrite_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pd0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pd0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
// static void setup_fstat_memwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_1_proc0
// static void setup_fstat_memwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_pd0_0_proc1
// static void setup_fstat_memwrite_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pd0_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pd0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
// static void setup_fstat_memwrite_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_0_proc0
static void setup_fstat_memwrite_pd0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_memwrite_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pd0_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pd0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
// static void setup_fstat_memwrite_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_1_proc0
// static void setup_fstat_memwrite_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_fstat_memwrite_pd0_2_proc1
// static void setup_fstat_memwrite_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
// static void setup_fstat_memwrite_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_0_proc0
// static void setup_fstat_memwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pfc_0_0
// static int test_fstat_memwrite_pc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_memwrite_pfc_0_common
// static void setup_fstat_memwrite_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pe_1_proc0
// static void setup_fstat_memwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_memwrite_pfc_0_proc1
// static void setup_fstat_memwrite_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_final
// static void setup_fstat_memwrite_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_memwrite_pfc_0_procfinal

/*
 * calls: fstat memwrite
 */
static int test_fstat_memwrite_pbc_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_memwrite_pbc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
static void setup_fstat_memwrite_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_memwrite_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_fstat_memwrite_pbc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_memwrite_pbc_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_memwrite_pbc_0_procfinal(void) {
  
}

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pba_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_pba_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pfa_0_1
// static void setup_fstat_memwrite_pba_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
static void setup_fstat_memwrite_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_fstat_memwrite_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_pba_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_pba_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pba_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_pba_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pfa_0_1
// static void setup_fstat_memwrite_pba_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
static void setup_fstat_memwrite_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_fstat_memwrite_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_pba_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_pba_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
static int test_fstat_memwrite_pb8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_memwrite_pb8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
static void setup_fstat_memwrite_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_memwrite_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pb8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pb8_0_0
// static int test_fstat_memwrite_pb8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pb8_0_common
static void setup_fstat_memwrite_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memwrite_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pb0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_pb0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
static void setup_fstat_memwrite_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pb0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_pb0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
static void setup_fstat_memwrite_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_memwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_pa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_pa_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
static void setup_fstat_memwrite_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_memwrite_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_pa_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p9c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_p9c_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
// static void setup_fstat_memwrite_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pa_0_proc0
static void setup_fstat_memwrite_p9c_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_memwrite_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p9a_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_p9a_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pfa_0_1
// static void setup_fstat_memwrite_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
static void setup_fstat_memwrite_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_memwrite_p9a_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_memwrite_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p9a_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_p9a_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pfa_0_1
// static void setup_fstat_memwrite_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
// static void setup_fstat_memwrite_p9a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pa_0_proc0
// static void setup_fstat_memwrite_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_p9a_0_proc1
// static void setup_fstat_memwrite_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p98_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pb8_0_0
// static int test_fstat_memwrite_p98_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pb8_0_common
// static void setup_fstat_memwrite_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_p9a_0_proc0
// static void setup_fstat_memwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_p9a_0_proc1
// static void setup_fstat_memwrite_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p98_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p98_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pb8_0_0
// static int test_fstat_memwrite_p98_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pb8_0_common
// static void setup_fstat_memwrite_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pa_0_proc0
// static void setup_fstat_memwrite_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_p9a_0_proc1
// static void setup_fstat_memwrite_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p98_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p90_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_p90_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
// static void setup_fstat_memwrite_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pa_0_proc0
static void setup_fstat_memwrite_p90_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_memwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p90_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_p90_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
// static void setup_fstat_memwrite_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pa_0_proc0
static void setup_fstat_memwrite_p90_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_memwrite_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p90_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_pbc_0_0
// static int test_fstat_memwrite_p8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
// static void setup_fstat_memwrite_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pa_0_proc0
// static void setup_fstat_memwrite_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
static int test_fstat_memwrite_p78_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_memwrite_p78_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
static void setup_fstat_memwrite_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_memwrite_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_fstat_memwrite_p9c_0_proc1
// static void setup_fstat_memwrite_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p78_0_final(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal
// static void setup_fstat_memwrite_p78_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p74_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p74_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pfa_0_1
// static void setup_fstat_memwrite_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
static void setup_fstat_memwrite_p74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_fstat_memwrite_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p74_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p74_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p70_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p70_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pb8_0_common
// static void setup_fstat_memwrite_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_p9a_0_proc1
// static void setup_fstat_memwrite_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p70_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p6_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
// static void setup_fstat_memwrite_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_p90_0_proc1
// static void setup_fstat_memwrite_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p6_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p6_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_p78_0_common
// static void setup_fstat_memwrite_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_fstat_memwrite_p90_1_proc1
// static void setup_fstat_memwrite_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p6_1_final(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal
// static void setup_fstat_memwrite_p6_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_p78_0_common
// static void setup_fstat_memwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p4_0_final(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal
// static void setup_fstat_memwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p38_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p38_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_p78_0_common
// static void setup_fstat_memwrite_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_fstat_memwrite_p9c_0_proc1
// static void setup_fstat_memwrite_p38_0_final(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal
// static void setup_fstat_memwrite_p38_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p34_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p34_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pfa_0_1
// static void setup_fstat_memwrite_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
// static void setup_fstat_memwrite_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_p9a_0_proc1
// static void setup_fstat_memwrite_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p34_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p30_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p30_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_fstat_memwrite_pfc_0_1
// static void setup_fstat_memwrite_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pb8_0_common
// static void setup_fstat_memwrite_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_p9a_0_proc1
// static void setup_fstat_memwrite_p30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p30_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p2_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p2_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_memwrite_pbc_0_common
// static void setup_fstat_memwrite_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_memwrite_p90_0_proc1
// static void setup_fstat_memwrite_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_memwrite_pbc_0_final
// static void setup_fstat_memwrite_p2_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p2_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p2_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_p78_0_common
// static void setup_fstat_memwrite_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_fstat_memwrite_p90_1_proc1
// static void setup_fstat_memwrite_p2_1_final(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal
// static void setup_fstat_memwrite_p2_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal

/*
 * calls: fstat memwrite
 */
// static int test_fstat_memwrite_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_memwrite_p78_0_0
// static int test_fstat_memwrite_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_fstat_memwrite_pf0_0_1
// static void setup_fstat_memwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_p78_0_common
// static void setup_fstat_memwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_memwrite_pbc_0_proc1
// static void setup_fstat_memwrite_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal
// static void setup_fstat_memwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_memwrite_pbc_0_procfinal


/*
 * calls: fstat mmap
 */
static int test_fstat_mmap_pf8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_mmap_pf8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_fstat_mmap_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_mmap_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_mmap_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_mmap_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_mmap_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pf8_1_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_fstat_mmap_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pf8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf8_0_1
// static void setup_fstat_mmap_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pf8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf8_1_1
// static void setup_fstat_mmap_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pf8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pf6_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_fstat_mmap_pf6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pf6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pf6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_0_1
// static void setup_fstat_mmap_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_pf6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf6_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pf6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_0_1
// static void setup_fstat_mmap_pf6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_pf6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pf6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf6_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pf6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_0_1
// static void setup_fstat_mmap_pf6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_pf6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pf6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf6_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pf6_4_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_fstat_mmap_pf6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pf6_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pf6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf6_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf6_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf6_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pf6_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_4_1
// static void setup_fstat_mmap_pf6_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pf6_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pf6_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf6_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf6_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pf4_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_fstat_mmap_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_mmap_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pf4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf4_0_1
// static void setup_fstat_mmap_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
static void setup_fstat_mmap_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pf0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_fstat_mmap_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pf0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pf0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf0_0_1
// static void setup_fstat_mmap_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pec_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_fstat_mmap_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pec_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_fstat_mmap_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pec_2_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_fstat_mmap_pec_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pec_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pec_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_1_1
// static void setup_fstat_mmap_pec_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pec_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pec_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pec_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_2_1
// static void setup_fstat_mmap_pec_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pec_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pec_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pec_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_1_1
// static void setup_fstat_mmap_pec_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pec_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf6_1_proc0
// static void setup_fstat_mmap_pec_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_6_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pec_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_1_1
// static void setup_fstat_mmap_pec_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_pec_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pec_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_7_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pec_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_2_1
// static void setup_fstat_mmap_pec_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pec_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf6_0_proc0
// static void setup_fstat_mmap_pec_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_8_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pec_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_2_1
// static void setup_fstat_mmap_pec_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_pec_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pec_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_9_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pec_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_2_1
// static void setup_fstat_mmap_pec_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pec_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf6_1_proc0
// static void setup_fstat_mmap_pec_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pec_10_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pec_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_2_1
// static void setup_fstat_mmap_pec_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pec_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pec_6_proc0
// static void setup_fstat_mmap_pec_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pec_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pec_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pe6_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_fstat_mmap_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf6_0_proc0
// static void setup_fstat_mmap_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_0_1
// static void setup_fstat_mmap_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf6_1_proc0
// static void setup_fstat_mmap_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe6_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_0_1
// static void setup_fstat_mmap_pe6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pe6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf6_3_proc0
// static void setup_fstat_mmap_pe6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe6_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pe6_3_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_fstat_mmap_pe6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pe6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pe6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe6_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe6_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_0_1
// static void setup_fstat_mmap_pe6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pe6_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf6_2_proc0
// static void setup_fstat_mmap_pe6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe6_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe6_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe6_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe6_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_3_1
// static void setup_fstat_mmap_pe6_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pe6_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pe6_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe6_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe6_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe5_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pe5_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_fstat_mmap_pe5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pe5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf4_0_proc0
// static void setup_fstat_mmap_pe5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe5_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe5_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe5_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pe5_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_fstat_mmap_pe5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pe5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf4_0_proc0
// static void setup_fstat_mmap_pe5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe5_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe5_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe5_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_0_1
// static void setup_fstat_mmap_pe5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pe5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pec_8_proc0
// static void setup_fstat_mmap_pe5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe5_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe5_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe5_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_1_1
// static void setup_fstat_mmap_pe5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pe5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pec_8_proc0
// static void setup_fstat_mmap_pe5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe5_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe5_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe5_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe5_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_0_1
// static void setup_fstat_mmap_pe5_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pe5_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf4_1_proc0
// static void setup_fstat_mmap_pe5_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe5_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe5_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe5_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe5_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_0_1
// static void setup_fstat_mmap_pe5_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pe5_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pec_6_proc0
// static void setup_fstat_mmap_pe5_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe5_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe5_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe5_6_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe5_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_1_1
// static void setup_fstat_mmap_pe5_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pe5_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf4_1_proc0
// static void setup_fstat_mmap_pe5_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe5_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe5_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe5_7_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe5_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_1_1
// static void setup_fstat_mmap_pe5_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pe5_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pec_6_proc0
// static void setup_fstat_mmap_pe5_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe5_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe5_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pe0_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_fstat_mmap_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pe0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pe0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe0_0_1
// static void setup_fstat_mmap_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pd8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pd8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf8_0_1
// static void setup_fstat_mmap_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pd8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pd8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf8_0_1
// static void setup_fstat_mmap_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pd6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pd6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_4_1
// static void setup_fstat_mmap_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pd6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pd6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_4_1
// static void setup_fstat_mmap_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pd6_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pd6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_4_1
// static void setup_fstat_mmap_pd6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pd6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pd6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pd6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pd6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pd6_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pd6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_4_1
// static void setup_fstat_mmap_pd6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pd6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pd6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pd6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pd6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pd4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pd4_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_fstat_mmap_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
static void setup_fstat_mmap_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pd4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pd4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pd4_0_1
// static void setup_fstat_mmap_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pd4_0_proc1
// static void setup_fstat_mmap_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pd0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pd0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_fstat_mmap_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pd0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pd0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pd0_0_1
// static void setup_fstat_mmap_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pcc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pcc_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_0_1
// static void setup_fstat_mmap_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pcc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pcc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pcc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pcc_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_fstat_mmap_pcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pcc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pcc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pcc_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pcc_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_0_1
// static void setup_fstat_mmap_pcc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pcc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pcc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pcc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pcc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pcc_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pcc_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pcc_1_1
// static void setup_fstat_mmap_pcc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pcc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pcc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pcc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pcc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_3_1
// static void setup_fstat_mmap_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pc6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_3_1
// static void setup_fstat_mmap_pc6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pc6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pc6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pc6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc6_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_3_1
// static void setup_fstat_mmap_pc6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pc6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pc6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pc6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc6_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_3_1
// static void setup_fstat_mmap_pc6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pc6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pc6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pc6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc5_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pc5_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_fstat_mmap_pc5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pc5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pc5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pd4_0_proc1
// static void setup_fstat_mmap_pc5_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc5_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc5_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pc5_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_fstat_mmap_pc5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pc5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pc5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pd4_0_proc1
// static void setup_fstat_mmap_pc5_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc5_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc5_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_0_1
// static void setup_fstat_mmap_pc5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pc5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pc5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pd4_0_proc1
// static void setup_fstat_mmap_pc5_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc5_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc5_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_1_1
// static void setup_fstat_mmap_pc5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pc5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pc5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pd4_0_proc1
// static void setup_fstat_mmap_pc5_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc5_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc5_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc5_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_0_1
// static void setup_fstat_mmap_pc5_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pc5_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
static void setup_fstat_mmap_pc5_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pc5_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc5_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc5_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc5_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_0_1
// static void setup_fstat_mmap_pc5_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pc5_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pc5_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pc5_4_proc1
// static void setup_fstat_mmap_pc5_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc5_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc5_6_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc5_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_1_1
// static void setup_fstat_mmap_pc5_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pc5_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pc5_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pc5_4_proc1
// static void setup_fstat_mmap_pc5_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc5_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc5_7_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc5_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_1_1
// static void setup_fstat_mmap_pc5_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf4_0_common
// static void setup_fstat_mmap_pc5_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pc5_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pc5_4_proc1
// static void setup_fstat_mmap_pc5_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc5_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
static int test_fstat_mmap_pc0_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_fstat_mmap_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pc0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pf8_0_0
// static int test_fstat_mmap_pc0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc0_0_1
// static void setup_fstat_mmap_pc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_pc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pc0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pc0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
static int test_fstat_mmap_pb8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_mmap_pb8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf8_0_1
static void setup_fstat_mmap_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_mmap_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_mmap_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_mmap_pb8_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_mmap_pb8_0_procfinal(void) {
  
}

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pb8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pb8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf8_1_1
// static void setup_fstat_mmap_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pb6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pb6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_0_1
// static void setup_fstat_mmap_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_pb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pb6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pb6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_0_1
// static void setup_fstat_mmap_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_pb6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
static int test_fstat_mmap_pb4_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_mmap_pb4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf4_0_1
static void setup_fstat_mmap_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_mmap_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_mmap_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pb4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pb4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pd4_0_1
// static void setup_fstat_mmap_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pb0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pb0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf0_0_1
// static void setup_fstat_mmap_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pac_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pac_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_0_1
// static void setup_fstat_mmap_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pac_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pac_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pac_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_1_1
// static void setup_fstat_mmap_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pac_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pac_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pac_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pcc_1_1
// static void setup_fstat_mmap_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_pac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pac_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pac_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pac_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pac_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_2_1
// static void setup_fstat_mmap_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_pac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pac_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pac_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pa6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pa6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_0_1
// static void setup_fstat_mmap_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pb6_0_proc0
// static void setup_fstat_mmap_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pa6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pa6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pa6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pa6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_0_1
// static void setup_fstat_mmap_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pb6_1_proc0
// static void setup_fstat_mmap_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_pa6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_pa6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pa5_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb4_0_0
// static int test_fstat_mmap_pa5_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_0_1
// static void setup_fstat_mmap_pa5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_pa5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_proc0
// static void setup_fstat_mmap_pa5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pa5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pa5_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pa5_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb4_0_0
// static int test_fstat_mmap_pa5_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_1_1
// static void setup_fstat_mmap_pa5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_pa5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_proc0
// static void setup_fstat_mmap_pa5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pa5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pa5_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pa5_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb4_0_0
// static int test_fstat_mmap_pa5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_0_1
// static void setup_fstat_mmap_pa5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
static void setup_fstat_mmap_pa5_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_mmap_pa5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pa5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pa5_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pa5_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb4_0_0
// static int test_fstat_mmap_pa5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_1_1
// static void setup_fstat_mmap_pa5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_pa5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pa5_2_proc0
// static void setup_fstat_mmap_pa5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pa5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pa5_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pa5_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pa5_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_0_1
// static void setup_fstat_mmap_pa5_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_pa5_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_pa5_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pa5_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pa5_4_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pa5_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pa5_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_1_1
// static void setup_fstat_mmap_pa5_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_pa5_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_pa5_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pa5_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pa5_5_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_pa0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_pa0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe0_0_1
// static void setup_fstat_mmap_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p98_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_p98_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf8_0_1
// static void setup_fstat_mmap_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p98_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p96_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_p96_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_4_1
// static void setup_fstat_mmap_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pc5_4_proc1
// static void setup_fstat_mmap_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_p96_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p96_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p96_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_p96_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_4_1
// static void setup_fstat_mmap_p96_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_p96_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pc5_4_proc1
// static void setup_fstat_mmap_p96_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_p96_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p96_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p94_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb4_0_0
// static int test_fstat_mmap_p94_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pd4_0_1
// static void setup_fstat_mmap_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
static void setup_fstat_mmap_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_mmap_p94_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_mmap_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p94_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p90_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_p90_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pd0_0_1
// static void setup_fstat_mmap_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p90_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p8c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_p8c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_0_1
// static void setup_fstat_mmap_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p8c_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_p8c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pcc_1_1
// static void setup_fstat_mmap_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p8c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p8c_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p86_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_p86_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_3_1
// static void setup_fstat_mmap_p86_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_p86_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pc5_4_proc1
// static void setup_fstat_mmap_p86_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_p86_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p86_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p86_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_p86_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_3_1
// static void setup_fstat_mmap_p86_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_p86_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pc5_4_proc1
// static void setup_fstat_mmap_p86_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_p86_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p86_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p85_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb4_0_0
// static int test_fstat_mmap_p85_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_0_1
// static void setup_fstat_mmap_p85_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p85_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p94_0_proc1
// static void setup_fstat_mmap_p85_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p94_0_proc1
// static void setup_fstat_mmap_p85_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p85_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p85_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb4_0_0
// static int test_fstat_mmap_p85_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_1_1
// static void setup_fstat_mmap_p85_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p85_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p94_0_proc1
// static void setup_fstat_mmap_p85_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p94_0_proc1
// static void setup_fstat_mmap_p85_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p85_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p85_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb4_0_0
// static int test_fstat_mmap_p85_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_0_1
// static void setup_fstat_mmap_p85_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p85_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p85_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p85_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p85_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p85_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb4_0_0
// static int test_fstat_mmap_p85_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_1_1
// static void setup_fstat_mmap_p85_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p85_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p85_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p85_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p85_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p80_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_pb8_0_0
// static int test_fstat_mmap_p80_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc0_0_1
// static void setup_fstat_mmap_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p80_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
static int test_fstat_mmap_p70_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_mmap_p70_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf8_0_1
static void setup_fstat_mmap_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_mmap_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p70_0_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p70_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p70_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p70_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf8_1_1
// static void setup_fstat_mmap_p70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
static void setup_fstat_mmap_p70_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_mmap_p70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p70_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p6c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p6c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_0_1
// static void setup_fstat_mmap_p6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_p6c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_p6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p6c_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p6c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_0_1
// static void setup_fstat_mmap_p6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
static void setup_fstat_mmap_p6c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mmap_p6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_p6c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p6c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p68_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p68_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf4_0_1
// static void setup_fstat_mmap_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
static void setup_fstat_mmap_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_mmap_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p68_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p60_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p60_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf0_0_1
// static void setup_fstat_mmap_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p60_0_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p60_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p60_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p60_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pd0_0_1
// static void setup_fstat_mmap_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p60_1_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p60_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p58_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p58_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_0_1
// static void setup_fstat_mmap_p58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p58_0_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p58_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p58_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p58_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pcc_1_1
// static void setup_fstat_mmap_p58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p58_1_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p58_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p58_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p58_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_1_1
// static void setup_fstat_mmap_p58_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_p58_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p70_1_proc0
// static void setup_fstat_mmap_p58_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p58_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p58_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p58_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p58_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_2_1
// static void setup_fstat_mmap_p58_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_common
// static void setup_fstat_mmap_p58_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p70_1_proc0
// static void setup_fstat_mmap_p58_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p58_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p58_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p4c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p4c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_0_1
// static void setup_fstat_mmap_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_p6c_0_proc0
// static void setup_fstat_mmap_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_p4c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p4c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p4c_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p4c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_0_1
// static void setup_fstat_mmap_p4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_p4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_p6c_1_proc0
// static void setup_fstat_mmap_p4c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_p4c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p4c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p4a_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p4a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_0_1
// static void setup_fstat_mmap_p4a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p4a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p68_0_proc0
// static void setup_fstat_mmap_p4a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p4a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p4a_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p4a_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p4a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_1_1
// static void setup_fstat_mmap_p4a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p4a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p68_0_proc0
// static void setup_fstat_mmap_p4a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p4a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p4a_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p4a_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p4a_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_0_1
// static void setup_fstat_mmap_p4a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p4a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p70_1_proc0
// static void setup_fstat_mmap_p4a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p4a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p4a_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p4a_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p4a_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe5_1_1
// static void setup_fstat_mmap_p4a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p4a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p70_1_proc0
// static void setup_fstat_mmap_p4a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p4a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p4a_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p40_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p40_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe0_0_1
// static void setup_fstat_mmap_p40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p40_0_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p40_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p40_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p40_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc0_0_1
// static void setup_fstat_mmap_p40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p40_1_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p40_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p30_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p30_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf8_0_1
// static void setup_fstat_mmap_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p30_0_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p30_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p2c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p2c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_4_1
// static void setup_fstat_mmap_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_p2c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p2c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p2c_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p2c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pf6_4_1
// static void setup_fstat_mmap_p2c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_p2c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_p2c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_p2c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p2c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p28_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p28_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pd4_0_1
// static void setup_fstat_mmap_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p94_0_proc1
// static void setup_fstat_mmap_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p28_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p20_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p20_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pd0_0_1
// static void setup_fstat_mmap_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p20_0_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p20_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p18_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pec_0_1
// static void setup_fstat_mmap_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p18_0_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p18_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p18_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pcc_1_1
// static void setup_fstat_mmap_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p18_1_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p18_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p0c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p0c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_3_1
// static void setup_fstat_mmap_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc0
// static void setup_fstat_mmap_p0c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p0c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p0c_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p0c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pe6_3_1
// static void setup_fstat_mmap_p0c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mmap_pf8_0_common
// static void setup_fstat_mmap_p0c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_0_proc1
// static void setup_fstat_mmap_p0c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mmap_pf8_2_proc0
// static void setup_fstat_mmap_p0c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_final
// static void setup_fstat_mmap_p0c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mmap_pf8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p0a_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p0a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_0_1
// static void setup_fstat_mmap_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p94_0_proc1
// static void setup_fstat_mmap_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p0a_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p0a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_1_1
// static void setup_fstat_mmap_p0a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p0a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p0a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_p94_0_proc1
// static void setup_fstat_mmap_p0a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p0a_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p0a_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p0a_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_0_1
// static void setup_fstat_mmap_p0a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p0a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p0a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p0a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p0a_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p0a_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p0a_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc5_1_1
// static void setup_fstat_mmap_p0a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb4_0_common
// static void setup_fstat_mmap_p0a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p0a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mmap_pb8_0_proc0
// static void setup_fstat_mmap_p0a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mmap_pb8_0_final
// static void setup_fstat_mmap_p0a_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal

/*
 * calls: fstat mmap
 */
// static int test_fstat_mmap_p00_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mmap_p70_0_0
// static int test_fstat_mmap_p00_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_mmap_pc0_0_1
// static void setup_fstat_mmap_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mmap_p70_0_common
// static void setup_fstat_mmap_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mmap_pb8_0_proc1
// static void setup_fstat_mmap_p00_0_final(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal
// static void setup_fstat_mmap_p00_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mmap_pb8_0_procfinal


/*
 * calls: fstat mprotect
 */
static int test_fstat_mprotect_pf_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_mprotect_pf_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_fstat_mprotect_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_mprotect_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_fstat_mprotect_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_mprotect_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_mprotect_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pf_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pf_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
static void setup_fstat_mprotect_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_mprotect_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pf_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pf_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
static void setup_fstat_mprotect_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_mprotect_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pf_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pf_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
static void setup_fstat_mprotect_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_mprotect_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pf_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pf_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pf_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pf_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pf_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
static void setup_fstat_mprotect_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_mprotect_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pf_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pf_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pf_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pf_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
static void setup_fstat_mprotect_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_mprotect_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pf_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pf_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pf_6_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pf_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pf_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
static void setup_fstat_mprotect_pf_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_mprotect_pf_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pf_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pf_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pf_7_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pf_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pf_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
static void setup_fstat_mprotect_pf_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_mprotect_pf_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pf_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pf_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pe_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
static int test_fstat_mprotect_pe_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_fstat_mprotect_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
static void setup_fstat_mprotect_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mprotect_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pe_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pe_0_1
// static void setup_fstat_mprotect_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
static void setup_fstat_mprotect_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_mprotect_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pd_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pd_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pd_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
// static void setup_fstat_mprotect_pd_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pe_0_proc0
static void setup_fstat_mprotect_pd_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_mprotect_pd_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pd_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pd_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pd_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
// static void setup_fstat_mprotect_pd_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pe_0_proc0
static void setup_fstat_mprotect_pd_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_mprotect_pd_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pd_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pd_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pd_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
// static void setup_fstat_mprotect_pd_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pe_1_proc0
// static void setup_fstat_mprotect_pd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_mprotect_pd_0_proc1
// static void setup_fstat_mprotect_pd_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pd_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pd_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pd_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pd_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
// static void setup_fstat_mprotect_pd_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pe_1_proc0
// static void setup_fstat_mprotect_pd_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_fstat_mprotect_pd_1_proc1
// static void setup_fstat_mprotect_pd_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pd_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pd_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pd_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pd_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
// static void setup_fstat_mprotect_pd_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pe_0_proc0
static void setup_fstat_mprotect_pd_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_mprotect_pd_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pd_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pd_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pd_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pd_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
// static void setup_fstat_mprotect_pd_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pe_1_proc0
// static void setup_fstat_mprotect_pd_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_mprotect_pd_4_proc1
// static void setup_fstat_mprotect_pd_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pd_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pd_6_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pd_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pd_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
// static void setup_fstat_mprotect_pd_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pe_0_proc0
static void setup_fstat_mprotect_pd_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_mprotect_pd_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pd_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pd_7_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pd_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pd_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
// static void setup_fstat_mprotect_pd_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pe_1_proc0
// static void setup_fstat_mprotect_pd_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_fstat_mprotect_pd_6_proc1
// static void setup_fstat_mprotect_pd_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pd_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pe_0_1
// static void setup_fstat_mprotect_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
// static void setup_fstat_mprotect_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pe_0_proc0
// static void setup_fstat_mprotect_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pf_0_0
// static int test_fstat_mprotect_pc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pe_0_1
// static void setup_fstat_mprotect_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_mprotect_pf_0_common
// static void setup_fstat_mprotect_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pe_1_proc0
// static void setup_fstat_mprotect_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_mprotect_pf_0_proc1
// static void setup_fstat_mprotect_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_final
// static void setup_fstat_mprotect_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_mprotect_pf_0_procfinal

/*
 * calls: fstat mprotect
 */
static int test_fstat_mprotect_pb_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_mprotect_pb_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
static void setup_fstat_mprotect_pb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_mprotect_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_fstat_mprotect_pb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_mprotect_pb_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_mprotect_pb_0_procfinal(void) {
  
}

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pb_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pb_0_0
// static int test_fstat_mprotect_pb_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
static void setup_fstat_mprotect_pb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_mprotect_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_pb_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_pb_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pb_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pb_0_0
// static int test_fstat_mprotect_pb_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
static void setup_fstat_mprotect_pb_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_mprotect_pb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_pb_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_pb_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pb_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pb_0_0
// static int test_fstat_mprotect_pb_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_pb_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
static void setup_fstat_mprotect_pb_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_mprotect_pb_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_pb_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_pb_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_pa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pb_0_0
// static int test_fstat_mprotect_pa_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pe_0_1
// static void setup_fstat_mprotect_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
static void setup_fstat_mprotect_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_mprotect_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_pa_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p9_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pb_0_0
// static int test_fstat_mprotect_p9_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p9_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
// static void setup_fstat_mprotect_p9_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pa_0_proc0
static void setup_fstat_mprotect_p9_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_fstat_mprotect_p9_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_p9_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p9_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pb_0_0
// static int test_fstat_mprotect_p9_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p9_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
// static void setup_fstat_mprotect_p9_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pa_0_proc0
static void setup_fstat_mprotect_p9_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_fstat_mprotect_p9_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_p9_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p9_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pb_0_0
// static int test_fstat_mprotect_p9_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p9_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
// static void setup_fstat_mprotect_p9_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pa_0_proc0
static void setup_fstat_mprotect_p9_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_fstat_mprotect_p9_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_p9_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p9_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pb_0_0
// static int test_fstat_mprotect_p9_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p9_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
// static void setup_fstat_mprotect_p9_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pa_0_proc0
static void setup_fstat_mprotect_p9_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_fstat_mprotect_p9_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_p9_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_pb_0_0
// static int test_fstat_mprotect_p8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pe_0_1
// static void setup_fstat_mprotect_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
// static void setup_fstat_mprotect_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pa_0_proc0
// static void setup_fstat_mprotect_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
static int test_fstat_mprotect_p6_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_mprotect_p6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
// static void setup_fstat_mprotect_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_mprotect_p9_0_proc1
// static void setup_fstat_mprotect_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_p6_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_p6_0_0
// static int test_fstat_mprotect_p6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
static void setup_fstat_mprotect_p6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_mprotect_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_fstat_mprotect_p9_1_proc1
// static void setup_fstat_mprotect_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p6_1_final(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal
// static void setup_fstat_mprotect_p6_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p6_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_p6_0_0
// static int test_fstat_mprotect_p6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
// static void setup_fstat_mprotect_p6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_mprotect_p9_2_proc1
// static void setup_fstat_mprotect_p6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_p6_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p6_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_p6_0_0
// static int test_fstat_mprotect_p6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_p6_1_common
// static void setup_fstat_mprotect_p6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_fstat_mprotect_p9_3_proc1
// static void setup_fstat_mprotect_p6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p6_3_final(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal
// static void setup_fstat_mprotect_p6_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_p6_0_0
// static int test_fstat_mprotect_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pe_0_1
// static void setup_fstat_mprotect_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_p6_1_common
// static void setup_fstat_mprotect_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p4_0_final(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal
// static void setup_fstat_mprotect_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p2_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_p6_0_0
// static int test_fstat_mprotect_p2_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
// static void setup_fstat_mprotect_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_fstat_mprotect_p9_0_proc1
// static void setup_fstat_mprotect_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_p2_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p2_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_p6_0_0
// static int test_fstat_mprotect_p2_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_p6_1_common
// static void setup_fstat_mprotect_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_fstat_mprotect_p9_1_proc1
// static void setup_fstat_mprotect_p2_1_final(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal
// static void setup_fstat_mprotect_p2_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p2_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_p6_0_0
// static int test_fstat_mprotect_p2_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_mprotect_pb_0_common
// static void setup_fstat_mprotect_p2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_fstat_mprotect_p9_2_proc1
// static void setup_fstat_mprotect_p2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_mprotect_pb_0_final
// static void setup_fstat_mprotect_p2_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p2_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_p6_0_0
// static int test_fstat_mprotect_p2_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pf_0_1
// static void setup_fstat_mprotect_p2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_p6_1_common
// static void setup_fstat_mprotect_p2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_fstat_mprotect_p9_3_proc1
// static void setup_fstat_mprotect_p2_3_final(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal
// static void setup_fstat_mprotect_p2_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal

/*
 * calls: fstat mprotect
 */
// static int test_fstat_mprotect_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_mprotect_p6_0_0
// static int test_fstat_mprotect_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_fstat_mprotect_pe_0_1
// static void setup_fstat_mprotect_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_p6_1_common
// static void setup_fstat_mprotect_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_mprotect_pb_0_proc1
// static void setup_fstat_mprotect_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal
// static void setup_fstat_mprotect_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_mprotect_pb_0_procfinal


/*
 * calls: fstat munmap
 */
static int test_fstat_munmap_pe_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_munmap_pe_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_fstat_munmap_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_munmap_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_munmap_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_munmap_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_munmap_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat munmap
 */
// static int test_fstat_munmap_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_munmap_pe_0_0
// static int test_fstat_munmap_pe_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_munmap_pe_0_1
// static void setup_fstat_munmap_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_munmap_pe_0_common
static void setup_fstat_munmap_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_munmap_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_munmap_pe_0_proc1
// static void setup_fstat_munmap_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_munmap_pe_0_final
// static void setup_fstat_munmap_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_munmap_pe_0_procfinal

/*
 * calls: fstat munmap
 */
// static int test_fstat_munmap_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_munmap_pe_0_0
// static int test_fstat_munmap_pc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_munmap_pe_0_1
// static void setup_fstat_munmap_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_munmap_pe_0_common
// static void setup_fstat_munmap_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_munmap_pe_0_proc0
// static void setup_fstat_munmap_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_munmap_pe_0_proc1
// static void setup_fstat_munmap_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_munmap_pe_0_final
// static void setup_fstat_munmap_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_munmap_pe_0_procfinal

/*
 * calls: fstat munmap
 */
// static int test_fstat_munmap_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_munmap_pe_0_0
// static int test_fstat_munmap_pc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_munmap_pe_0_1
// static void setup_fstat_munmap_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_munmap_pe_0_common
// static void setup_fstat_munmap_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_munmap_pe_1_proc0
// static void setup_fstat_munmap_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_munmap_pe_0_proc1
// static void setup_fstat_munmap_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_munmap_pe_0_final
// static void setup_fstat_munmap_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_munmap_pe_0_procfinal

/*
 * calls: fstat munmap
 */
static int test_fstat_munmap_pa_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_munmap_pa_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_munmap_pe_0_1
static void setup_fstat_munmap_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_munmap_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_munmap_pa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_munmap_pa_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_munmap_pa_0_procfinal(void) {
  
}

/*
 * calls: fstat munmap
 */
// static int test_fstat_munmap_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_munmap_pa_0_0
// static int test_fstat_munmap_p8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_munmap_pe_0_1
// static void setup_fstat_munmap_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_munmap_pa_0_common
// static void setup_fstat_munmap_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_munmap_pa_0_proc0
// static void setup_fstat_munmap_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_munmap_pa_0_proc1
// static void setup_fstat_munmap_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_munmap_pa_0_final
// static void setup_fstat_munmap_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_munmap_pa_0_procfinal

/*
 * calls: fstat munmap
 */
static int test_fstat_munmap_p4_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_munmap_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_munmap_pe_0_1
static void setup_fstat_munmap_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_munmap_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_munmap_pa_0_proc1
// static void setup_fstat_munmap_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_munmap_pa_0_proc1
// static void setup_fstat_munmap_p4_0_final(void) {
//   
// }
// ^ See setup_fstat_munmap_pa_0_procfinal
// static void setup_fstat_munmap_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_munmap_pa_0_procfinal

/*
 * calls: fstat munmap
 */
// static int test_fstat_munmap_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_munmap_p4_0_0
// static int test_fstat_munmap_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_munmap_pe_0_1
// static void setup_fstat_munmap_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_munmap_p4_0_common
// static void setup_fstat_munmap_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_munmap_pa_0_proc1
// static void setup_fstat_munmap_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_munmap_pa_0_proc1
// static void setup_fstat_munmap_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_munmap_pa_0_procfinal
// static void setup_fstat_munmap_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_munmap_pa_0_procfinal


/*
 * calls: fstat open
 */
static int test_fstat_open_pf8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_open_pf8_0_1(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_fstat_open_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_open_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_open_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_open_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_open_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat open
 */
// static int test_fstat_open_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pf8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf8_0_1
// static void setup_fstat_open_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf8_0_common
static void setup_fstat_open_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_open_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pf70_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
static int test_fstat_open_pf70_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_fstat_open_pf70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_open_pf70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pf70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pf70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pf70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pf70_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pf70_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
static void setup_fstat_open_pf70_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_open_pf70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pf70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pf70_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pf70_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pf50_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pf50_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
static void setup_fstat_open_pf50_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_open_pf50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pf50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pf50_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pf50_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pf50_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pf50_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
static void setup_fstat_open_pf50_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_open_pf50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pf50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pf50_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pf50_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pf3_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
static int test_fstat_open_pf3_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_fstat_open_pf3_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_open_pf3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pf3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pf3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pf3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pf3_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pf3_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_pf3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf3_0_common
// static void setup_fstat_open_pf3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pf3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pf3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pf3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pf1_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pf1_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
static void setup_fstat_open_pf1_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_open_pf1_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pf1_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pf1_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pf1_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pf1_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pf1_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_pf1_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf1_0_common
// static void setup_fstat_open_pf1_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pf1_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pf1_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pf1_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pee_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pee_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
static void setup_fstat_open_pee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_open_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pee_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pee_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
// static void setup_fstat_open_pee_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_open_pee_0_common
// static void setup_fstat_open_pee_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pee_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pee_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pee_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pea_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pea_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
static void setup_fstat_open_pea_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_open_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pea_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pea_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pea_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pea_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
// static void setup_fstat_open_pea_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_open_pea_0_common
// static void setup_fstat_open_pea_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pea_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pea_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pea_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pe6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pe6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
static void setup_fstat_open_pe6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_open_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pe6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pe6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pe6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pe6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_open_pe6_0_common
// static void setup_fstat_open_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pe6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pe6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pe2_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pe2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_pe2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_open_pea_0_common
// static void setup_fstat_open_pe2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pe2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pe2_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pe2_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pe2_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pe2_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_pe2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_open_pea_0_common
// static void setup_fstat_open_pe2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pe2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pe2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pe2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pde_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
static int test_fstat_open_pde_0_1(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_fstat_open_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf70_0_common
// static void setup_fstat_open_pde_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pde_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pde_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pde_0_1
// static void setup_fstat_open_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf70_1_common
// static void setup_fstat_open_pde_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pde_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pda_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pda_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pde_0_1
// static void setup_fstat_open_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf50_1_common
// static void setup_fstat_open_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pda_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pda_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pda_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pda_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pde_0_1
// static void setup_fstat_open_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf50_1_common
// static void setup_fstat_open_pda_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pda_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pda_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pd6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
static int test_fstat_open_pd6_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_fstat_open_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf3_0_common
// static void setup_fstat_open_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pd6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pd6_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pd6_0_1
// static void setup_fstat_open_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf3_0_common
// static void setup_fstat_open_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pd2_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pd2_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pd6_0_1
// static void setup_fstat_open_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf1_0_common
// static void setup_fstat_open_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pd2_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pd2_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pd2_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pd2_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pd6_0_1
// static void setup_fstat_open_pd2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pf1_0_common
// static void setup_fstat_open_pd2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pd2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pd2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pd2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
static int test_fstat_open_pc_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_fstat_open_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_open_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc0
// static void setup_fstat_open_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pf8_0_0
// static int test_fstat_open_pc_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_open_pc_0_1
// static void setup_fstat_open_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_open_pc_0_common
// static void setup_fstat_open_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_1_proc0
// static void setup_fstat_open_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_open_pf8_0_proc1
// static void setup_fstat_open_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_final
// static void setup_fstat_open_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_open_pf8_0_procfinal

/*
 * calls: fstat open
 */
static int test_fstat_open_pb8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_open_pb8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf8_0_1
static void setup_fstat_open_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_open_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_open_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_open_pb8_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_open_pb8_0_procfinal(void) {
  
}

/*
 * calls: fstat open
 */
static int test_fstat_open_pb7e_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_open_pb7e_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
static void setup_fstat_open_pb7e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_open_pb7e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1150976, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_open_pb7e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
static void setup_fstat_open_pb7e_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_fstat_open_pb7e_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pb7e_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb8_0_0
// static int test_fstat_open_pb7e_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
// static void setup_fstat_open_pb7e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb8_0_common
static void setup_fstat_open_pb7e_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1150976, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_open_pb7e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_pb7e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_pb7e_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
static int test_fstat_open_pb5e_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_open_pb5e_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
static void setup_fstat_open_pb5e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_open_pb5e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4677632, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_open_pb5e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_pb5e_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_fstat_open_pb7e_0_final
// static void setup_fstat_open_pb5e_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pb5e_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb8_0_0
// static int test_fstat_open_pb5e_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
// static void setup_fstat_open_pb5e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb8_0_common
static void setup_fstat_open_pb5e_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_open_pb5e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_pb5e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_pb5e_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pb3_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb5e_0_0
// static int test_fstat_open_pb3_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
static void setup_fstat_open_pb3_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_open_pb3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pb5e_1_proc0
// static void setup_fstat_open_pb3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_pb3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_pb3_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pb1_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb5e_0_0
// static int test_fstat_open_pb1_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_pb1_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb3_0_common
static void setup_fstat_open_pb1_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_open_pb1_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_pb1_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_pb1_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
static int test_fstat_open_pae_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 16384);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_open_pae_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
static void setup_fstat_open_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_open_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4677632, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_open_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_pae_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_paa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 16384);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pae_0_0
// static int test_fstat_open_paa_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
// static void setup_fstat_open_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_open_pae_0_common
// static void setup_fstat_open_paa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pb5e_1_proc0
// static void setup_fstat_open_paa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_paa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_paa_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pa6_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 16384);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pae_0_0
// static int test_fstat_open_pa6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_open_pae_0_common
// static void setup_fstat_open_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pae_0_proc0
// static void setup_fstat_open_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_pa2_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 16384);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pae_0_0
// static int test_fstat_open_pa2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_pa2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_open_pae_0_common
// static void setup_fstat_open_pa2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pb5e_1_proc0
// static void setup_fstat_open_pa2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_pa2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_pa2_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p9fc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb7e_0_0
// static int test_fstat_open_p9fc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pde_0_1
// static void setup_fstat_open_p9fc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb7e_0_common
// static void setup_fstat_open_p9fc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1150976, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pb7e_0_proc0
// static void setup_fstat_open_p9fc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p9fc_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_fstat_open_pb7e_0_final
// static void setup_fstat_open_p9fc_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p9fc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb8_0_0
// static int test_fstat_open_p9fc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pde_0_1
// static void setup_fstat_open_p9fc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb8_0_common
// static void setup_fstat_open_p9fc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1150976, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pb7e_1_proc0
// static void setup_fstat_open_p9fc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p9fc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p9fc_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p9bc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb5e_0_0
// static int test_fstat_open_p9bc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pde_0_1
// static void setup_fstat_open_p9bc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb5e_0_common
// static void setup_fstat_open_p9bc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pb5e_0_proc0
// static void setup_fstat_open_p9bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p9bc_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_fstat_open_pb7e_0_final
// static void setup_fstat_open_p9bc_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p9bc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb8_0_0
// static int test_fstat_open_p9bc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pde_0_1
// static void setup_fstat_open_p9bc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb8_0_common
// static void setup_fstat_open_p9bc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pb5e_1_proc0
// static void setup_fstat_open_p9bc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p9bc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p9bc_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p96_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb5e_0_0
// static int test_fstat_open_p96_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pd6_0_1
// static void setup_fstat_open_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb3_0_common
// static void setup_fstat_open_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pb5e_1_proc0
// static void setup_fstat_open_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p96_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p96_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p92_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb5e_0_0
// static int test_fstat_open_p92_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pd6_0_1
// static void setup_fstat_open_p92_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb3_0_common
// static void setup_fstat_open_p92_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pb1_0_proc0
// static void setup_fstat_open_p92_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p92_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p92_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_pb8_0_0
// static int test_fstat_open_p8_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_open_pc_0_1
static void setup_fstat_open_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_fstat_open_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_open_pb8_0_proc0
// static void setup_fstat_open_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
static int test_fstat_open_p7_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_open_p7_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf8_0_1
// static void setup_fstat_open_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb8_0_common
// static void setup_fstat_open_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p7_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p6d0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p6d0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
// static void setup_fstat_open_p6d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb3_0_common
// static void setup_fstat_open_p6d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p6d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p6d0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p6d0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p6a_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p6a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
static void setup_fstat_open_p6a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_open_p6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p6a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p6a_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p65_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p65_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_p65_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb3_0_common
// static void setup_fstat_open_p65_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p65_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p65_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p65_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p62_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p62_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb3_0_common
// static void setup_fstat_open_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p62_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p5a_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p5a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
static void setup_fstat_open_p5a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_open_p5a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p5a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p5a_0_final(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal
// static void setup_fstat_open_p5a_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p54_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p54_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf70_0_1
// static void setup_fstat_open_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_open_p5a_0_common
// static void setup_fstat_open_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p54_0_final(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal
// static void setup_fstat_open_p54_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p4a_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p4a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_p4a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_open_p5a_0_common
// static void setup_fstat_open_p4a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p4a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p4a_0_final(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal
// static void setup_fstat_open_p4a_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p44_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p44_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pf3_0_1
// static void setup_fstat_open_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_open_p5a_0_common
// static void setup_fstat_open_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p44_0_final(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal
// static void setup_fstat_open_p44_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p3a_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p3a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pde_0_1
// static void setup_fstat_open_p3a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb8_0_common
// static void setup_fstat_open_p3a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p3a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p3a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p3a_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p34_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p34_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pde_0_1
// static void setup_fstat_open_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_p6a_0_common
// static void setup_fstat_open_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p34_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p2a_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p2a_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pd6_0_1
// static void setup_fstat_open_p2a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb3_0_common
// static void setup_fstat_open_p2a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p2a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p2a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p2a_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p24_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p24_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_fstat_open_pd6_0_1
// static void setup_fstat_open_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_open_pb3_0_common
// static void setup_fstat_open_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_open_pb8_0_final
// static void setup_fstat_open_p24_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal

/*
 * calls: fstat open
 */
// static int test_fstat_open_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_open_p7_0_0
// static int test_fstat_open_p0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_open_pc_0_1
// static void setup_fstat_open_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_open_p5a_0_common
// static void setup_fstat_open_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_open_pb8_0_proc1
// static void setup_fstat_open_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal
// static void setup_fstat_open_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_open_pb8_0_procfinal


/*
 * calls: fstat pipe
 */
static int test_fstat_pipe_pf8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_pipe_pf8_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_fstat_pipe_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_pipe_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_pipe_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_pipe_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_pipe_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat pipe
 */
// static int test_fstat_pipe_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pipe_pf8_0_0
// static int test_fstat_pipe_pf8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_pipe_pf8_0_1
// static void setup_fstat_pipe_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pipe_pf8_0_common
static void setup_fstat_pipe_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pipe_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pipe_pf8_0_proc1
// static void setup_fstat_pipe_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pipe_pf8_0_final
// static void setup_fstat_pipe_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pipe_pf8_0_procfinal

/*
 * calls: fstat pipe
 */
// static int test_fstat_pipe_pd8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pipe_pf8_0_0
// static int test_fstat_pipe_pd8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_pipe_pf8_0_1
static void setup_fstat_pipe_pd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_pipe_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pipe_pf8_0_proc0
// static void setup_fstat_pipe_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pipe_pf8_0_proc1
// static void setup_fstat_pipe_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pipe_pf8_0_final
// static void setup_fstat_pipe_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pipe_pf8_0_procfinal

/*
 * calls: fstat pipe
 */
// static int test_fstat_pipe_pd8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pipe_pf8_0_0
// static int test_fstat_pipe_pd8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_pipe_pf8_0_1
// static void setup_fstat_pipe_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pipe_pd8_0_common
// static void setup_fstat_pipe_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pipe_pf8_1_proc0
// static void setup_fstat_pipe_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pipe_pf8_0_proc1
// static void setup_fstat_pipe_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pipe_pf8_0_final
// static void setup_fstat_pipe_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pipe_pf8_0_procfinal

/*
 * calls: fstat pipe
 */
static int test_fstat_pipe_pb8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 28672);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_pipe_pb8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_pipe_pf8_0_1
static void setup_fstat_pipe_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_pipe_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_pipe_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_pipe_pb8_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_pipe_pb8_0_procfinal(void) {
  
}

/*
 * calls: fstat pipe
 */
// static int test_fstat_pipe_p98_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 28672);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pipe_pb8_0_0
// static int test_fstat_pipe_p98_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_pipe_pf8_0_1
// static void setup_fstat_pipe_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pipe_pb8_0_common
// static void setup_fstat_pipe_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pipe_pb8_0_proc0
// static void setup_fstat_pipe_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pipe_pb8_0_proc1
// static void setup_fstat_pipe_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pipe_pb8_0_final
// static void setup_fstat_pipe_p98_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pipe_pb8_0_procfinal

/*
 * calls: fstat pipe
 */
static int test_fstat_pipe_p58_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_pipe_p58_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_pipe_pf8_0_1
static void setup_fstat_pipe_p58_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_pipe_p58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pipe_pb8_0_proc1
// static void setup_fstat_pipe_p58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pipe_pb8_0_proc1
// static void setup_fstat_pipe_p58_0_final(void) {
//   
// }
// ^ See setup_fstat_pipe_pb8_0_procfinal
// static void setup_fstat_pipe_p58_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pipe_pb8_0_procfinal

/*
 * calls: fstat pipe
 */
// static int test_fstat_pipe_p30_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pipe_p58_0_0
// static int test_fstat_pipe_p30_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_pipe_pf8_0_1
// static void setup_fstat_pipe_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_pipe_p58_0_common
// static void setup_fstat_pipe_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pipe_pb8_0_proc1
// static void setup_fstat_pipe_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pipe_pb8_0_proc1
// static void setup_fstat_pipe_p30_0_final(void) {
//   
// }
// ^ See setup_fstat_pipe_pb8_0_procfinal
// static void setup_fstat_pipe_p30_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pipe_pb8_0_procfinal


/*
 * calls: fstat pread
 */
static int test_fstat_pread_pf8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_pread_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_fstat_pread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_pread_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_pread_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_pread_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_pread_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_0_1
// static void setup_fstat_pread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
static void setup_fstat_pread_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pf8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_0_1
// static void setup_fstat_pread_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
static void setup_fstat_pread_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
static int test_fstat_pread_pf8_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_fstat_pread_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
static void setup_fstat_pread_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf8_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pf8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_3_1
// static void setup_fstat_pread_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
static void setup_fstat_pread_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
static int test_fstat_pread_pf4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_fstat_pread_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_pread_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf4_0_1
// static void setup_fstat_pread_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf4_0_common
static void setup_fstat_pread_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf4_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pf4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf4_0_1
// static void setup_fstat_pread_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf4_0_common
static void setup_fstat_pread_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf4_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pf4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf4_0_1
// static void setup_fstat_pread_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf4_0_common
static void setup_fstat_pread_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
static int test_fstat_pread_pf0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_fstat_pread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_pread_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf0_0_1
// static void setup_fstat_pread_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf0_0_common
static void setup_fstat_pread_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf0_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pf0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf0_0_1
static void setup_fstat_pread_pf0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_pread_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf4_2_proc0
// static void setup_fstat_pread_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pf0_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pf0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf0_0_1
// static void setup_fstat_pread_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf0_2_common
// static void setup_fstat_pread_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf4_3_proc0
// static void setup_fstat_pread_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pe_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
static int test_fstat_pread_pe_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_fstat_pread_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
// static void setup_fstat_pread_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pe_0_1
// static void setup_fstat_pread_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_3_1
// static void setup_fstat_pread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
// static void setup_fstat_pread_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
// static void setup_fstat_pread_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_3_1
// static void setup_fstat_pread_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
// static void setup_fstat_pread_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pd8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_3_1
// static void setup_fstat_pread_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
// static void setup_fstat_pread_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pd8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_3_1
// static void setup_fstat_pread_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
static int test_fstat_pread_pd4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_fstat_pread_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf4_0_common
// static void setup_fstat_pread_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
static void setup_fstat_pread_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd4_0_1
// static void setup_fstat_pread_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf4_0_common
// static void setup_fstat_pread_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pd4_0_proc1
// static void setup_fstat_pread_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd4_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pd4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd4_0_1
// static void setup_fstat_pread_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf4_0_common
// static void setup_fstat_pread_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
static void setup_fstat_pread_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd4_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pd4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd4_0_1
// static void setup_fstat_pread_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf4_0_common
// static void setup_fstat_pread_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pd4_2_proc1
// static void setup_fstat_pread_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
static int test_fstat_pread_pd0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_fstat_pread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf0_0_common
// static void setup_fstat_pread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
static void setup_fstat_pread_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd0_0_1
// static void setup_fstat_pread_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf0_0_common
// static void setup_fstat_pread_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pd0_0_proc1
// static void setup_fstat_pread_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd0_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pd0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd0_0_1
// static void setup_fstat_pread_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf0_2_common
// static void setup_fstat_pread_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
// static void setup_fstat_pread_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pd4_2_proc1
// static void setup_fstat_pread_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pd0_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pd0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd0_0_1
static void setup_fstat_pread_pd0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_pread_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pd4_2_proc1
// static void setup_fstat_pread_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
static int test_fstat_pread_pc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_fstat_pread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
// static void setup_fstat_pread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pf8_0_0
// static int test_fstat_pread_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pc_0_1
// static void setup_fstat_pread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
static int test_fstat_pread_pb8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_pread_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_0_1
// static void setup_fstat_pread_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
static void setup_fstat_pread_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pb8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_0_1
// static void setup_fstat_pread_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
static void setup_fstat_pread_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pb4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_pb4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf4_0_1
static void setup_fstat_pread_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_pread_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_pread_pb4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_pread_pb4_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_pread_pb4_0_procfinal(void) {
  
}

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pb4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_pb4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd4_0_1
// static void setup_fstat_pread_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
static void setup_fstat_pread_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pread_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pb4_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_pb4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf4_0_1
// static void setup_fstat_pread_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
static void setup_fstat_pread_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pread_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pb4_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_pb4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd4_0_1
// static void setup_fstat_pread_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
static void setup_fstat_pread_pb4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pread_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
static int test_fstat_pread_pb2_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_pread_pb2_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf0_0_1
static void setup_fstat_pread_pb2_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_pread_pb2_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pread_pb2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
static void setup_fstat_pread_pb2_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_fstat_pread_pb2_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pb2_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb2_0_0
// static int test_fstat_pread_pb2_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf0_0_1
static void setup_fstat_pread_pb2_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_pread_pb2_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pread_pb2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_pb2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_pb2_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pb2_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb2_0_0
// static int test_fstat_pread_pb2_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd0_0_1
// static void setup_fstat_pread_pb2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pread_pb2_1_common
// static void setup_fstat_pread_pb2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_1_proc0
// static void setup_fstat_pread_pb2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_pb2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_pb2_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pb2_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb2_0_0
// static int test_fstat_pread_pb2_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf0_0_1
// static void setup_fstat_pread_pb2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pread_pb2_1_common
// static void setup_fstat_pread_pb2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_2_proc0
// static void setup_fstat_pread_pb2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_pb2_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_pb2_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pb2_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb2_0_0
// static int test_fstat_pread_pb2_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd0_0_1
// static void setup_fstat_pread_pb2_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pread_pb2_1_common
// static void setup_fstat_pread_pb2_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_3_proc0
// static void setup_fstat_pread_pb2_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_pb2_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_pb2_4_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_pa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_pa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pe_0_1
// static void setup_fstat_pread_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
// static void setup_fstat_pread_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_3_proc0
// static void setup_fstat_pread_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_pa_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p98_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_3_1
// static void setup_fstat_pread_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pd4_2_proc1
// static void setup_fstat_pread_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
// static void setup_fstat_pread_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p98_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_p98_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_3_1
// static void setup_fstat_pread_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pd4_2_proc1
// static void setup_fstat_pread_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p94_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_p94_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd4_0_1
// static void setup_fstat_pread_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
// static void setup_fstat_pread_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_1_proc0
// static void setup_fstat_pread_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_1_proc0
// static void setup_fstat_pread_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p94_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p94_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_p94_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd4_0_1
// static void setup_fstat_pread_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
// static void setup_fstat_pread_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_3_proc0
// static void setup_fstat_pread_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_3_proc0
// static void setup_fstat_pread_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p94_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p92_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb2_0_0
// static int test_fstat_pread_p92_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd0_0_1
// static void setup_fstat_pread_p92_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pread_pb2_0_common
static void setup_fstat_pread_p92_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_pread_p92_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pread_p92_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_fstat_pread_pb2_0_final
// static void setup_fstat_pread_p92_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p92_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb2_0_0
// static int test_fstat_pread_p92_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd0_0_1
// static void setup_fstat_pread_p92_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pread_pb2_1_common
// static void setup_fstat_pread_p92_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_p92_0_proc1
// static void setup_fstat_pread_p92_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_p92_0_proc1
// static void setup_fstat_pread_p92_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p92_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p92_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb2_0_0
// static int test_fstat_pread_p92_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd0_0_1
// static void setup_fstat_pread_p92_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pread_pb2_1_common
// static void setup_fstat_pread_p92_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_3_proc0
// static void setup_fstat_pread_p92_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_3_proc0
// static void setup_fstat_pread_p92_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p92_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_pb8_0_0
// static int test_fstat_pread_p8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pc_0_1
// static void setup_fstat_pread_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
// static void setup_fstat_pread_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_3_proc0
// static void setup_fstat_pread_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
static int test_fstat_pread_p7_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_pread_p7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_0_1
// static void setup_fstat_pread_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
static void setup_fstat_pread_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p7_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_0_1
// static void setup_fstat_pread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
static void setup_fstat_pread_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p68_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf4_0_1
// static void setup_fstat_pread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
static void setup_fstat_pread_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p68_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf4_0_1
// static void setup_fstat_pread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
static void setup_fstat_pread_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p60_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf0_0_1
// static void setup_fstat_pread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pread_pb2_1_common
static void setup_fstat_pread_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p60_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p60_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf0_0_1
// static void setup_fstat_pread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pread_pb2_1_common
// static void setup_fstat_pread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_p68_1_proc0
// static void setup_fstat_pread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pe_0_1
static void setup_fstat_pread_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_pread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p4_0_final(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal
// static void setup_fstat_pread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pc_0_1
// static void setup_fstat_pread_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_pread_p4_0_common
// static void setup_fstat_pread_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p4_1_final(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal
// static void setup_fstat_pread_p4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p3_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p3_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_3_1
// static void setup_fstat_pread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_3_proc0
// static void setup_fstat_pread_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p3_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p3_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pf8_3_1
// static void setup_fstat_pread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pread_pf8_0_common
// static void setup_fstat_pread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_0_proc1
// static void setup_fstat_pread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pread_pf8_4_proc0
// static void setup_fstat_pread_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_final
// static void setup_fstat_pread_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pread_pf8_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p28_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd4_0_1
// static void setup_fstat_pread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
// static void setup_fstat_pread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_1_proc0
// static void setup_fstat_pread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p28_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p28_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd4_0_1
// static void setup_fstat_pread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_0_common
// static void setup_fstat_pread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_3_proc0
// static void setup_fstat_pread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p20_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd0_0_1
// static void setup_fstat_pread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pread_pb2_1_common
// static void setup_fstat_pread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_p92_0_proc1
// static void setup_fstat_pread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p20_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p20_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pd0_0_1
// static void setup_fstat_pread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pread_pb2_1_common
// static void setup_fstat_pread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pread_pb4_3_proc0
// static void setup_fstat_pread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pread_pb4_0_final
// static void setup_fstat_pread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal

/*
 * calls: fstat pread
 */
// static int test_fstat_pread_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pread_p7_0_0
// static int test_fstat_pread_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_pread_pc_0_1
// static void setup_fstat_pread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_pread_p4_0_common
// static void setup_fstat_pread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pread_pb4_0_proc1
// static void setup_fstat_pread_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal
// static void setup_fstat_pread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pread_pb4_0_procfinal


/*
 * calls: fstat pwrite
 */
static int test_fstat_pwrite_pf8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_pwrite_pf8_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_fstat_pwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_pwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_pwrite_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_pwrite_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_pwrite_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_0_1
// static void setup_fstat_pwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
static void setup_fstat_pwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf8_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_0_1
// static void setup_fstat_pwrite_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
static void setup_fstat_pwrite_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
static int test_fstat_pwrite_pf8_3_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
// static void setup_fstat_pwrite_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
static void setup_fstat_pwrite_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf8_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf8_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_0_1
// static void setup_fstat_pwrite_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
static void setup_fstat_pwrite_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf8_5_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf8_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_3_1
// static void setup_fstat_pwrite_pf8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
static void setup_fstat_pwrite_pf8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
static int test_fstat_pwrite_pf4_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_fstat_pwrite_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_pwrite_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf4_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
static void setup_fstat_pwrite_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_pwrite_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf4_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf4_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
// static void setup_fstat_pwrite_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf4_1_common
static void setup_fstat_pwrite_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf4_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf4_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
// static void setup_fstat_pwrite_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf4_1_common
static void setup_fstat_pwrite_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
static void setup_fstat_pwrite_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_pwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
static void setup_fstat_pwrite_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_pwrite_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf4_1_proc0
// static void setup_fstat_pwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf0_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
// static void setup_fstat_pwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf0_1_common
static void setup_fstat_pwrite_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pf0_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pf0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
static void setup_fstat_pwrite_pf0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_pwrite_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf4_3_proc0
// static void setup_fstat_pwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pe_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
static int test_fstat_pwrite_pe_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_fstat_pwrite_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
// static void setup_fstat_pwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pe_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pe_0_1
// static void setup_fstat_pwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_3_1
// static void setup_fstat_pwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
// static void setup_fstat_pwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
// static void setup_fstat_pwrite_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_3_1
// static void setup_fstat_pwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
// static void setup_fstat_pwrite_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_3_1
// static void setup_fstat_pwrite_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
// static void setup_fstat_pwrite_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd8_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_3_1
// static void setup_fstat_pwrite_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
static int test_fstat_pwrite_pd4_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_fstat_pwrite_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf4_0_common
// static void setup_fstat_pwrite_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
static void setup_fstat_pwrite_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf4_1_common
// static void setup_fstat_pwrite_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
static void setup_fstat_pwrite_pd4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd4_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd4_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf4_1_common
// static void setup_fstat_pwrite_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
static void setup_fstat_pwrite_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd4_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd4_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf4_0_common
// static void setup_fstat_pwrite_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pd4_1_proc1
// static void setup_fstat_pwrite_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf0_0_common
// static void setup_fstat_pwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
static void setup_fstat_pwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf0_1_common
// static void setup_fstat_pwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
// static void setup_fstat_pwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pd4_1_proc1
// static void setup_fstat_pwrite_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd0_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf0_1_common
// static void setup_fstat_pwrite_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pd4_0_proc1
// static void setup_fstat_pwrite_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pd0_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pd0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf0_1_common
// static void setup_fstat_pwrite_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pd4_1_proc1
// static void setup_fstat_pwrite_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
static int test_fstat_pwrite_pc_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_fstat_pwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
// static void setup_fstat_pwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pf8_0_0
// static int test_fstat_pwrite_pc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pc_0_1
// static void setup_fstat_pwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
static int test_fstat_pwrite_pb8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_pwrite_pb8_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_0_1
// static void setup_fstat_pwrite_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
static void setup_fstat_pwrite_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pb8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb8_0_0
// static int test_fstat_pwrite_pb8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_0_1
// static void setup_fstat_pwrite_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
static void setup_fstat_pwrite_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
static int test_fstat_pwrite_pb6_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 28672);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_pwrite_pb6_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
static void setup_fstat_pwrite_pb6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_pwrite_pb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23973888, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23973888, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_pwrite_pb6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_pwrite_pb6_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_fstat_pwrite_pb6_0_procfinal(void) {
  
}

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pb6_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb8_0_0
static int test_fstat_pwrite_pb6_1_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_fstat_pwrite_pb6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_pwrite_pb6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_pb6_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_fstat_pwrite_pb6_0_final
// static void setup_fstat_pwrite_pb6_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
static int test_fstat_pwrite_pb30_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_pwrite_pb30_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
static void setup_fstat_pwrite_pb30_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_pwrite_pb30_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_pb30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_pb30_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_fstat_pwrite_pb6_0_final
// static void setup_fstat_pwrite_pb30_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pb30_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb30_0_0
// static int test_fstat_pwrite_pb30_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
static void setup_fstat_pwrite_pb30_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_pwrite_pb30_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_pb30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
static void setup_fstat_pwrite_pb30_1_final(void) {
  unlink("__i0");
}
// static void setup_fstat_pwrite_pb30_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pb30_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb30_0_0
// static int test_fstat_pwrite_pb30_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_pb30_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_1_common
static void setup_fstat_pwrite_pb30_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_pb30_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_pb30_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_pb30_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pb30_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb30_0_0
// static int test_fstat_pwrite_pb30_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
// static void setup_fstat_pwrite_pb30_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_1_common
static void setup_fstat_pwrite_pb30_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_pb30_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_pb30_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_pb30_3_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pb30_4_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb30_0_0
// static int test_fstat_pwrite_pb30_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_pb30_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_1_common
static void setup_fstat_pwrite_pb30_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_pb30_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_pb30_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_pb30_4_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_pa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb8_0_0
// static int test_fstat_pwrite_pa_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pe_0_1
static void setup_fstat_pwrite_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_fstat_pwrite_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_4_proc0
// static void setup_fstat_pwrite_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_pa_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p98_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb8_0_0
// static int test_fstat_pwrite_p98_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_3_1
// static void setup_fstat_pwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pd4_1_proc1
// static void setup_fstat_pwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
// static void setup_fstat_pwrite_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p98_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb8_0_0
// static int test_fstat_pwrite_p98_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_3_1
// static void setup_fstat_pwrite_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pd4_1_proc1
// static void setup_fstat_pwrite_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p96_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 28672);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb6_0_0
// static int test_fstat_pwrite_p96_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb6_0_common
static void setup_fstat_pwrite_p96_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23973888, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_pwrite_p96_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_p96_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_fstat_pwrite_pb6_0_final
// static void setup_fstat_pwrite_p96_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p96_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb8_0_0
static int test_fstat_pwrite_p96_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_fstat_pwrite_p96_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb6_1_common
static void setup_fstat_pwrite_p96_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_pwrite_p96_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_p96_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_fstat_pwrite_pb6_0_final
// static void setup_fstat_pwrite_p96_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p930_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb30_0_0
// static int test_fstat_pwrite_p930_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_p930_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_0_common
static void setup_fstat_pwrite_p930_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_pwrite_p930_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_p930_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_fstat_pwrite_pb6_0_final
// static void setup_fstat_pwrite_p930_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p930_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb30_0_0
// static int test_fstat_pwrite_p930_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_p930_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_1_common
// static void setup_fstat_pwrite_p930_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_2_proc0
// static void setup_fstat_pwrite_p930_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_2_proc0
// static void setup_fstat_pwrite_p930_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p930_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p930_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb30_0_0
// static int test_fstat_pwrite_p930_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_p930_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_1_common
// static void setup_fstat_pwrite_p930_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_4_proc0
// static void setup_fstat_pwrite_p930_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_4_proc0
// static void setup_fstat_pwrite_p930_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p930_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_pb8_0_0
// static int test_fstat_pwrite_p8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pc_0_1
// static void setup_fstat_pwrite_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pa_0_common
// static void setup_fstat_pwrite_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_4_proc0
// static void setup_fstat_pwrite_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
static int test_fstat_pwrite_p7_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_pwrite_p7_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_0_1
// static void setup_fstat_pwrite_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
static void setup_fstat_pwrite_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p7_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p7_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_0_1
// static void setup_fstat_pwrite_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
static void setup_fstat_pwrite_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_pwrite_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p68_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p68_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
// static void setup_fstat_pwrite_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pa_0_common
static void setup_fstat_pwrite_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p68_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p68_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p68_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
// static void setup_fstat_pwrite_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pa_0_common
static void setup_fstat_pwrite_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p68_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p60_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p60_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
// static void setup_fstat_pwrite_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_1_common
static void setup_fstat_pwrite_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p60_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p60_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p60_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf4_0_1
// static void setup_fstat_pwrite_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_1_common
// static void setup_fstat_pwrite_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_p68_1_proc0
// static void setup_fstat_pwrite_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p60_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p4_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pe_0_1
static void setup_fstat_pwrite_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_pwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p4_0_final(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal
// static void setup_fstat_pwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pc_0_1
// static void setup_fstat_pwrite_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_p4_0_common
// static void setup_fstat_pwrite_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p4_1_final(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal
// static void setup_fstat_pwrite_p4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p3_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p3_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_3_1
// static void setup_fstat_pwrite_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_3_proc0
// static void setup_fstat_pwrite_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p3_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p3_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pf8_3_1
// static void setup_fstat_pwrite_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_pwrite_pf8_0_common
// static void setup_fstat_pwrite_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_0_proc1
// static void setup_fstat_pwrite_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_pwrite_pf8_5_proc0
// static void setup_fstat_pwrite_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_final
// static void setup_fstat_pwrite_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_pwrite_pf8_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p28_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p28_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pa_0_common
// static void setup_fstat_pwrite_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_p930_0_proc1
// static void setup_fstat_pwrite_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p28_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p28_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p28_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pa_0_common
// static void setup_fstat_pwrite_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_4_proc0
// static void setup_fstat_pwrite_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p28_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p20_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p20_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_1_common
// static void setup_fstat_pwrite_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
static void setup_fstat_pwrite_p20_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_pwrite_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p20_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p20_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p20_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pd4_0_1
// static void setup_fstat_pwrite_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_1_common
// static void setup_fstat_pwrite_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_pwrite_pb30_4_proc0
// static void setup_fstat_pwrite_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_pwrite_pb30_1_final
// static void setup_fstat_pwrite_p20_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal

/*
 * calls: fstat pwrite
 */
// static int test_fstat_pwrite_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_pwrite_p7_0_0
// static int test_fstat_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_fstat_pwrite_pc_0_1
// static void setup_fstat_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_p4_0_common
// static void setup_fstat_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_pwrite_pb6_0_proc1
// static void setup_fstat_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal
// static void setup_fstat_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_pwrite_pb6_0_procfinal


/*
 * calls: fstat read
 */
static int test_fstat_read_pfc_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_read_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_fstat_read_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_read_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_read_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_read_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_read_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat read
 */
// static int test_fstat_read_pfc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pfc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_0_1
// static void setup_fstat_read_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
static void setup_fstat_read_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pfc_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
static int test_fstat_read_pfc_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_fstat_read_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
static void setup_fstat_read_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pfb_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
static int test_fstat_read_pfb_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_fstat_read_pfb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_read_pfb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pfb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pfb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pfb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pfb_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pfb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfb_0_1
// static void setup_fstat_read_pfb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
static void setup_fstat_read_pfb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pfb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pfb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pfb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pfb_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
static int test_fstat_read_pfb_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_fstat_read_pfb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
static void setup_fstat_read_pfb_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pfb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pfb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pfb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pfa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
static int test_fstat_read_pfa_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_fstat_read_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_read_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_read_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_read_pfa_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_fstat_read_pfa_0_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: fstat read
 */
// static int test_fstat_read_pfa_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pfa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_0_1
static void setup_fstat_read_pfa_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_read_pfa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_0_proc0
// static void setup_fstat_read_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pfa_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pfa_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pfa_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pfa_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_0_1
// static void setup_fstat_read_pfa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfa_0_common
static void setup_fstat_read_pfa_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pfa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfa_0_proc1
// static void setup_fstat_read_pfa_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_fstat_read_pfa_0_final
// static void setup_fstat_read_pfa_2_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_fstat_read_pfa_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pfa_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
static int test_fstat_read_pfa_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_fstat_read_pfa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
static void setup_fstat_read_pfa_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_read_pfa_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pfa_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pfa_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pf8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
static int test_fstat_read_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_fstat_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_read_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_0_proc0
// static void setup_fstat_read_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_0_1
// static void setup_fstat_read_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf8_0_common
// static void setup_fstat_read_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_1_proc0
// static void setup_fstat_read_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pf8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
static int test_fstat_read_pf8_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_fstat_read_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf8_0_common
// static void setup_fstat_read_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pf4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pf4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_0_1
static void setup_fstat_read_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_read_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pf4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_0_1
// static void setup_fstat_read_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf4_0_common
static void setup_fstat_read_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pf0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_0_1
static void setup_fstat_read_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_read_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pf4_0_proc0
// static void setup_fstat_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pf0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_0_1
static void setup_fstat_read_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_read_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pf4_1_proc0
// static void setup_fstat_read_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pe_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_0_1
// static void setup_fstat_read_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
// static void setup_fstat_read_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_0_1
// static void setup_fstat_read_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
// static void setup_fstat_read_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pdc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_2_1
// static void setup_fstat_read_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
// static void setup_fstat_read_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pdc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pdc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_2_1
// static void setup_fstat_read_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
// static void setup_fstat_read_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pdb_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pdb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfb_2_1
// static void setup_fstat_read_pdb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
// static void setup_fstat_read_pdb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_pdb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_pdb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pdb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pdb_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pdb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfb_2_1
// static void setup_fstat_read_pdb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
// static void setup_fstat_read_pdb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_pdb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_pdb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pdb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pda_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pda_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_3_1
static void setup_fstat_read_pda_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_read_pda_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_read_pda_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_read_pda_0_final(void) {
  unlink("__i0");
  close(22);
  close(23);
  close(20);
  close(21);
}
static void setup_fstat_read_pda_0_procfinal(void) {
  close(22);
  close(23);
  close(20);
  close(21);
}

/*
 * calls: fstat read
 */
// static int test_fstat_read_pda_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pda_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_3_1
static void setup_fstat_read_pda_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_read_pda_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_read_pda_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pda_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_fstat_read_pfa_0_final
// static void setup_fstat_read_pda_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_fstat_read_pfa_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pda_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pda_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_3_1
// static void setup_fstat_read_pda_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfa_1_common
// static void setup_fstat_read_pda_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfa_3_proc0
// static void setup_fstat_read_pda_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfa_3_proc0
// static void setup_fstat_read_pda_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pda_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pd8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_2_1
// static void setup_fstat_read_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf8_0_common
// static void setup_fstat_read_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pd8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_2_1
// static void setup_fstat_read_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf8_0_common
// static void setup_fstat_read_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pd4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_3_1
static void setup_fstat_read_pd4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_read_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
static void setup_fstat_read_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pd4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_3_1
// static void setup_fstat_read_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pd4_0_common
// static void setup_fstat_read_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pd4_0_proc1
// static void setup_fstat_read_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pd0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_2_1
// static void setup_fstat_read_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf0_0_common
// static void setup_fstat_read_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
static void setup_fstat_read_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pd0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_2_1
// static void setup_fstat_read_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf0_0_common
// static void setup_fstat_read_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pd0_0_proc1
// static void setup_fstat_read_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_2_1
// static void setup_fstat_read_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
// static void setup_fstat_read_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pfc_0_0
// static int test_fstat_read_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_2_1
// static void setup_fstat_read_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
// static void setup_fstat_read_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
static int test_fstat_read_pbc_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_read_pbc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_0_1
// static void setup_fstat_read_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
static void setup_fstat_read_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
static int test_fstat_read_pbb_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_read_pbb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfb_0_1
// static void setup_fstat_read_pbb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
static void setup_fstat_read_pbb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pbb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pbb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pbb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pba_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pbb_0_0
// static int test_fstat_read_pba_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_0_1
// static void setup_fstat_read_pba_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
static void setup_fstat_read_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfa_3_proc1
// static void setup_fstat_read_pba_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pba_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pb8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pbb_0_0
// static int test_fstat_read_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_0_1
// static void setup_fstat_read_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf8_0_common
// static void setup_fstat_read_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pbb_0_proc0
// static void setup_fstat_read_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pb4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pbc_0_0
// static int test_fstat_read_pb4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_0_1
static void setup_fstat_read_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_read_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_read_pb4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_read_pb4_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_read_pb4_0_procfinal(void) {
  
}

/*
 * calls: fstat read
 */
// static int test_fstat_read_pb4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pbc_0_0
// static int test_fstat_read_pb4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_3_1
// static void setup_fstat_read_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_0_common
static void setup_fstat_read_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_read_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
static int test_fstat_read_pb2_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_read_pb2_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_0_1
static void setup_fstat_read_pb2_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_read_pb2_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_read_pb2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
static void setup_fstat_read_pb2_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_fstat_read_pb2_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pb2_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pb2_0_0
// static int test_fstat_read_pb2_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_0_1
static void setup_fstat_read_pb2_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_fstat_read_pb2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_0_proc0
// static void setup_fstat_read_pb2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_pb2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_pb2_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pb2_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pb2_0_0
// static int test_fstat_read_pb2_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_2_1
// static void setup_fstat_read_pb2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_read_pb2_1_common
// static void setup_fstat_read_pb2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_1_proc0
// static void setup_fstat_read_pb2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_pb2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_pb2_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_pa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pbc_0_0
// static int test_fstat_read_pa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_0_1
// static void setup_fstat_read_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_0_common
// static void setup_fstat_read_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_1_proc0
// static void setup_fstat_read_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_pa_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p9c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pbc_0_0
// static int test_fstat_read_p9c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_2_1
// static void setup_fstat_read_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
// static void setup_fstat_read_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pd0_0_proc1
// static void setup_fstat_read_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p9b_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pbb_0_0
// static int test_fstat_read_p9b_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfb_2_1
// static void setup_fstat_read_p9b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
static void setup_fstat_read_p9b_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_p9b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_p9b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p9b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
static int test_fstat_read_p9a_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 20480);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_read_p9a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_3_1
// static void setup_fstat_read_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfa_1_common
static void setup_fstat_read_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfa_3_proc0
// static void setup_fstat_read_p9a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p9a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p98_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pbb_0_0
// static int test_fstat_read_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_2_1
// static void setup_fstat_read_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf8_0_common
// static void setup_fstat_read_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_p9b_0_proc0
// static void setup_fstat_read_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p94_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pbc_0_0
// static int test_fstat_read_p94_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_3_1
// static void setup_fstat_read_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_0_common
static void setup_fstat_read_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_read_p94_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_read_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_p94_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p92_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pb2_0_0
// static int test_fstat_read_p92_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_2_1
// static void setup_fstat_read_p92_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_read_pb2_0_common
// static void setup_fstat_read_p92_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_1_proc0
static void setup_fstat_read_p92_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_read_p92_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb2_0_final
// static void setup_fstat_read_p92_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p92_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pb2_0_0
// static int test_fstat_read_p92_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_2_1
// static void setup_fstat_read_p92_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_read_pb2_1_common
// static void setup_fstat_read_p92_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_1_proc0
// static void setup_fstat_read_p92_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_1_proc0
// static void setup_fstat_read_p92_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_p92_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_pbc_0_0
// static int test_fstat_read_p8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_2_1
// static void setup_fstat_read_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_0_common
// static void setup_fstat_read_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_1_proc0
// static void setup_fstat_read_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
static int test_fstat_read_p78_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_read_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_0_1
// static void setup_fstat_read_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
static void setup_fstat_read_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p76_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfb_0_1
// static void setup_fstat_read_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
static void setup_fstat_read_p76_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p74_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_0_1
// static void setup_fstat_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
static void setup_fstat_read_p74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfa_3_proc1
// static void setup_fstat_read_p74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p70_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_0_1
// static void setup_fstat_read_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf8_0_common
// static void setup_fstat_read_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_p76_0_proc0
// static void setup_fstat_read_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p68_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_0_1
// static void setup_fstat_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_0_common
static void setup_fstat_read_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p60_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_0_1
// static void setup_fstat_read_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_read_pb2_1_common
// static void setup_fstat_read_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_read_p68_0_proc0
// static void setup_fstat_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_p60_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_0_1
static void setup_fstat_read_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_read_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p4_0_final(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal
// static void setup_fstat_read_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_2_1
// static void setup_fstat_read_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_read_p4_0_common
// static void setup_fstat_read_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p4_1_final(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal
// static void setup_fstat_read_p4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p38_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_2_1
// static void setup_fstat_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfc_0_common
// static void setup_fstat_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_2_proc0
// static void setup_fstat_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p36_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfb_2_1
// static void setup_fstat_read_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfb_0_common
// static void setup_fstat_read_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p34_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_3_1
// static void setup_fstat_read_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pfa_1_common
// static void setup_fstat_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfa_3_proc1
// static void setup_fstat_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfa_3_proc0
// static void setup_fstat_read_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p30_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_2_1
// static void setup_fstat_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_read_pf8_0_common
// static void setup_fstat_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfc_0_proc1
// static void setup_fstat_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_read_pfb_2_proc0
// static void setup_fstat_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_final
// static void setup_fstat_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_read_pfc_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p28_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfa_3_1
// static void setup_fstat_read_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_0_common
// static void setup_fstat_read_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_read_p94_0_proc1
// static void setup_fstat_read_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_p28_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p20_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pf8_2_1
// static void setup_fstat_read_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_read_pb2_1_common
// static void setup_fstat_read_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_read_pb4_1_proc0
// static void setup_fstat_read_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_read_pb4_0_final
// static void setup_fstat_read_p20_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal

/*
 * calls: fstat read
 */
// static int test_fstat_read_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_read_p78_0_0
// static int test_fstat_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_fstat_read_pfc_2_1
// static void setup_fstat_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_read_p4_0_common
// static void setup_fstat_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_read_pb4_0_proc1
// static void setup_fstat_read_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal
// static void setup_fstat_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_read_pb4_0_procfinal


/*
 * calls: fstat rename
 */
static int test_fstat_rename_pf_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_rename_pf_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_fstat_rename_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_rename_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_rename_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_rename_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_rename_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_pf_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_pf_0_0
// static int test_fstat_rename_pf_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pf_0_1
// static void setup_fstat_rename_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_rename_pf_0_common
static void setup_fstat_rename_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_rename_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_0_proc1
// static void setup_fstat_rename_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_final
// static void setup_fstat_rename_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_pe8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_pf_0_0
static int test_fstat_rename_pe8_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_fstat_rename_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_rename_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_0_proc0
// static void setup_fstat_rename_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_0_proc1
// static void setup_fstat_rename_pe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_final
// static void setup_fstat_rename_pe8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_pe8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_pf_0_0
// static int test_fstat_rename_pe8_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pe8_0_1
// static void setup_fstat_rename_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_rename_pe8_0_common
// static void setup_fstat_rename_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_1_proc0
// static void setup_fstat_rename_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_0_proc1
// static void setup_fstat_rename_pe8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_final
// static void setup_fstat_rename_pe8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_pe0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_pf_0_0
// static int test_fstat_rename_pe0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pe8_0_1
// static void setup_fstat_rename_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_rename_pf_0_common
// static void setup_fstat_rename_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_0_proc0
// static void setup_fstat_rename_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_0_proc1
// static void setup_fstat_rename_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_final
// static void setup_fstat_rename_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_pe0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_pf_0_0
// static int test_fstat_rename_pe0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pe8_0_1
// static void setup_fstat_rename_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_rename_pf_0_common
// static void setup_fstat_rename_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_1_proc0
// static void setup_fstat_rename_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_0_proc1
// static void setup_fstat_rename_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_final
// static void setup_fstat_rename_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_pf_0_0
static int test_fstat_rename_pc_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_fstat_rename_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_rename_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_0_proc0
// static void setup_fstat_rename_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_0_proc1
// static void setup_fstat_rename_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_final
// static void setup_fstat_rename_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_pf_0_0
// static int test_fstat_rename_pc_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pc_0_1
// static void setup_fstat_rename_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_rename_pc_0_common
// static void setup_fstat_rename_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_1_proc0
// static void setup_fstat_rename_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_rename_pf_0_proc1
// static void setup_fstat_rename_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_final
// static void setup_fstat_rename_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_rename_pf_0_procfinal

/*
 * calls: fstat rename
 */
static int test_fstat_rename_pb_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_rename_pb_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pf_0_1
static void setup_fstat_rename_pb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_rename_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_rename_pb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_rename_pb_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_rename_pb_0_procfinal(void) {
  
}

/*
 * calls: fstat rename
 */
static int test_fstat_rename_pac_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 16384);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_rename_pac_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pe8_0_1
static void setup_fstat_rename_pac_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_fstat_rename_pac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_rename_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
static void setup_fstat_rename_pac_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_fstat_rename_pac_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_rename_pb_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_pac_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 16384);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_pac_0_0
// static int test_fstat_rename_pac_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pe8_0_1
static void setup_fstat_rename_pac_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_fstat_rename_pac_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_rename_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
static void setup_fstat_rename_pac_1_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_fstat_rename_pac_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_rename_pb_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_pa0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_pb_0_0
// static int test_fstat_rename_pa0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pe8_0_1
// static void setup_fstat_rename_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_rename_pb_0_common
// static void setup_fstat_rename_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_rename_pb_0_proc0
// static void setup_fstat_rename_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
// static void setup_fstat_rename_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_rename_pb_0_final
// static void setup_fstat_rename_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_rename_pb_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_pb_0_0
// static int test_fstat_rename_p8_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pc_0_1
static void setup_fstat_rename_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_fstat_rename_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_rename_pb_0_proc0
// static void setup_fstat_rename_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
// static void setup_fstat_rename_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_rename_pb_0_final
// static void setup_fstat_rename_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_rename_pb_0_procfinal

/*
 * calls: fstat rename
 */
static int test_fstat_rename_p6_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_rename_p6_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pf_0_1
// static void setup_fstat_rename_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_rename_pb_0_common
// static void setup_fstat_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
// static void setup_fstat_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
// static void setup_fstat_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_rename_pb_0_final
// static void setup_fstat_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_rename_pb_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_p50_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_p6_0_0
// static int test_fstat_rename_p50_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pe8_0_1
static void setup_fstat_rename_p50_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
// static void setup_fstat_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
// static void setup_fstat_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_rename_pb_0_final
// static void setup_fstat_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_rename_pb_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_p6_0_0
// static int test_fstat_rename_p4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pe8_0_1
// static void setup_fstat_rename_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_rename_pb_0_common
// static void setup_fstat_rename_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
// static void setup_fstat_rename_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
// static void setup_fstat_rename_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_rename_pb_0_final
// static void setup_fstat_rename_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_rename_pb_0_procfinal

/*
 * calls: fstat rename
 */
// static int test_fstat_rename_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_rename_p6_0_0
// static int test_fstat_rename_p0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_rename_pc_0_1
static void setup_fstat_rename_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
// static void setup_fstat_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_rename_pb_0_proc1
// static void setup_fstat_rename_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_rename_pb_0_procfinal
// static void setup_fstat_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_rename_pb_0_procfinal


/*
 * calls: fstat stat
 */
static int test_fstat_stat_pe_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_fstat_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_stat_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_stat_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_stat_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_stat_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat stat
 */
// static int test_fstat_stat_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_pe_0_0
// static int test_fstat_stat_pe_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_pe_0_1
// static void setup_fstat_stat_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_stat_pe_0_common
static void setup_fstat_stat_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_stat_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_stat_pe_0_proc1
// static void setup_fstat_stat_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_stat_pe_0_final
// static void setup_fstat_stat_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_stat_pe_0_procfinal

/*
 * calls: fstat stat
 */
// static int test_fstat_stat_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_pe_0_0
static int test_fstat_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_fstat_stat_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_stat_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_stat_pe_0_proc0
// static void setup_fstat_stat_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_stat_pe_0_proc1
// static void setup_fstat_stat_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_stat_pe_0_final
// static void setup_fstat_stat_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_stat_pe_0_procfinal

/*
 * calls: fstat stat
 */
// static int test_fstat_stat_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_pe_0_0
// static int test_fstat_stat_pc_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_pc_0_1
// static void setup_fstat_stat_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_stat_pc_0_common
// static void setup_fstat_stat_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_stat_pe_1_proc0
// static void setup_fstat_stat_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_stat_pe_0_proc1
// static void setup_fstat_stat_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_stat_pe_0_final
// static void setup_fstat_stat_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_stat_pe_0_procfinal

/*
 * calls: fstat stat
 */
static int test_fstat_stat_pa_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_stat_pa_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_pe_0_1
static void setup_fstat_stat_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_stat_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_stat_pa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_stat_pa_0_final(void) {
  unlink("__i0");
}
static void setup_fstat_stat_pa_0_procfinal(void) {
  
}

/*
 * calls: fstat stat
 */
// static int test_fstat_stat_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_pa_0_0
// static int test_fstat_stat_p8_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_pc_0_1
static void setup_fstat_stat_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_fstat_stat_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_stat_pa_0_proc0
// static void setup_fstat_stat_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_stat_pa_0_proc1
// static void setup_fstat_stat_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_stat_pa_0_final
// static void setup_fstat_stat_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_stat_pa_0_procfinal

/*
 * calls: fstat stat
 */
static int test_fstat_stat_p4_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_pe_0_1
// static void setup_fstat_stat_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_stat_pa_0_common
// static void setup_fstat_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_stat_pa_0_proc1
// static void setup_fstat_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_stat_pa_0_proc1
// static void setup_fstat_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_stat_pa_0_final
// static void setup_fstat_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_stat_pa_0_procfinal

/*
 * calls: fstat stat
 */
// static int test_fstat_stat_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_p4_0_0
// static int test_fstat_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_stat_pc_0_1
static void setup_fstat_stat_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_stat_pa_0_proc1
// static void setup_fstat_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_stat_pa_0_proc1
// static void setup_fstat_stat_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_stat_pa_0_procfinal
// static void setup_fstat_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_stat_pa_0_procfinal


/*
 * calls: fstat unlink
 */
static int test_fstat_unlink_pe_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_unlink_pe_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_fstat_unlink_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_unlink_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_unlink_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_unlink_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_unlink_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat unlink
 */
// static int test_fstat_unlink_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_unlink_pe_0_0
// static int test_fstat_unlink_pe_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_unlink_pe_0_1
// static void setup_fstat_unlink_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_fstat_unlink_pe_0_common
static void setup_fstat_unlink_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_unlink_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_unlink_pe_0_proc1
// static void setup_fstat_unlink_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_unlink_pe_0_final
// static void setup_fstat_unlink_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_unlink_pe_0_procfinal

/*
 * calls: fstat unlink
 */
// static int test_fstat_unlink_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_unlink_pe_0_0
static int test_fstat_unlink_pc_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_fstat_unlink_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_unlink_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_unlink_pe_0_proc0
// static void setup_fstat_unlink_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_unlink_pe_0_proc1
// static void setup_fstat_unlink_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_unlink_pe_0_final
// static void setup_fstat_unlink_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_unlink_pe_0_procfinal

/*
 * calls: fstat unlink
 */
// static int test_fstat_unlink_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_unlink_pe_0_0
// static int test_fstat_unlink_pc_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_unlink_pc_0_1
// static void setup_fstat_unlink_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_unlink_pc_0_common
// static void setup_fstat_unlink_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_unlink_pe_1_proc0
// static void setup_fstat_unlink_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_unlink_pe_0_proc1
// static void setup_fstat_unlink_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_unlink_pe_0_final
// static void setup_fstat_unlink_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_unlink_pe_0_procfinal

/*
 * calls: fstat unlink
 */
static int test_fstat_unlink_pb0_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 16384);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_unlink_pb0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_unlink_pe_0_1
static void setup_fstat_unlink_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_fstat_unlink_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_unlink_pb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_unlink_pb0_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_fstat_unlink_pb0_0_procfinal(void) {
  
}

/*
 * calls: fstat unlink
 */
static int test_fstat_unlink_p8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_unlink_p8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_unlink_pc_0_1
static void setup_fstat_unlink_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_fstat_unlink_p8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_unlink_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_unlink_pb0_0_proc1
static void setup_fstat_unlink_p8_0_final(void) {
  unlink("__i0");
}
// static void setup_fstat_unlink_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_unlink_pb0_0_procfinal

/*
 * calls: fstat unlink
 */
static int test_fstat_unlink_p4_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_unlink_p4_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_fstat_unlink_pe_0_1
static void setup_fstat_unlink_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_fstat_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_unlink_pb0_0_proc1
// static void setup_fstat_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_unlink_pb0_0_proc1
// static void setup_fstat_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_unlink_p8_0_final
// static void setup_fstat_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_unlink_pb0_0_procfinal

/*
 * calls: fstat unlink
 */
// static int test_fstat_unlink_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_unlink_p4_0_0
// static int test_fstat_unlink_p0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_fstat_unlink_pc_0_1
static void setup_fstat_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_unlink_pb0_0_proc1
// static void setup_fstat_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_unlink_pb0_0_proc1
// static void setup_fstat_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_unlink_pb0_0_procfinal
// static void setup_fstat_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_unlink_pb0_0_procfinal


/*
 * calls: fstat write
 */
static int test_fstat_write_pfe_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_fstat_write_pfe_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_fstat_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_write_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_fstat_write_pfe_0_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: fstat write
 */
// static int test_fstat_write_pfe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pfe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfe_0_1
static void setup_fstat_write_pfe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_write_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_write_pfe_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_write_pfe_1_final(void) {
  unlink("__i0");
  close(22);
  close(23);
  close(20);
  close(21);
}
static void setup_fstat_write_pfe_1_procfinal(void) {
  close(22);
  close(23);
  close(20);
  close(21);
}

/*
 * calls: fstat write
 */
// static int test_fstat_write_pfe_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pfe_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfe_0_1
static void setup_fstat_write_pfe_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_write_pfe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_write_pfe_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_write_pfe_2_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_fstat_write_pfe_2_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: fstat write
 */
// static int test_fstat_write_pfe_3_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
static int test_fstat_write_pfe_3_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_fstat_write_pfe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfe_2_common
static void setup_fstat_write_pfe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pfe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfe_2_proc1
// static void setup_fstat_write_pfe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pfe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pfc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
static int test_fstat_write_pfc_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_fstat_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_write_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pfc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pfc_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
// static void setup_fstat_write_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfc_0_common
static void setup_fstat_write_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pfc_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
static int test_fstat_write_pfc_2_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_fstat_write_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfc_0_common
static void setup_fstat_write_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pf8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
static int test_fstat_write_pf8_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_fstat_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pf8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pf8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_0_1
// static void setup_fstat_write_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
static void setup_fstat_write_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pf8_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
static int test_fstat_write_pf8_2_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_fstat_write_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
static void setup_fstat_write_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pf4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pf4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
static void setup_fstat_write_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_write_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pf4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pf4_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
static void setup_fstat_write_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_write_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pf0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
static void setup_fstat_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf4_0_proc0
// static void setup_fstat_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pf0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pf0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
static void setup_fstat_write_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_write_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf4_1_proc0
// static void setup_fstat_write_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pe_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pe_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_0_1
// static void setup_fstat_write_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
// static void setup_fstat_write_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf8_2_proc0
// static void setup_fstat_write_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pe_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_0_1
// static void setup_fstat_write_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
// static void setup_fstat_write_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_2_proc0
// static void setup_fstat_write_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pde_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pde_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfe_3_1
static void setup_fstat_write_pde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_fstat_write_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_fstat_write_pde_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_fstat_write_pfe_0_final
// static void setup_fstat_write_pde_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_fstat_write_pfe_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pde_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pde_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfe_3_1
// static void setup_fstat_write_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pde_0_common
static void setup_fstat_write_pde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pde_0_proc1
// static void setup_fstat_write_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_fstat_write_pfe_0_final
// static void setup_fstat_write_pde_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_fstat_write_pfe_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pde_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pde_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfe_3_1
static void setup_fstat_write_pde_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_fstat_write_pde_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfe_3_proc0
// static void setup_fstat_write_pde_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfe_3_proc0
// static void setup_fstat_write_pde_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pde_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pdc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pdc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfc_0_common
// static void setup_fstat_write_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf8_2_proc0
// static void setup_fstat_write_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_2_proc0
// static void setup_fstat_write_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pdc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pdc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfc_0_common
// static void setup_fstat_write_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_2_proc0
// static void setup_fstat_write_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_2_proc0
// static void setup_fstat_write_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pd8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_2_1
// static void setup_fstat_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
// static void setup_fstat_write_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf8_2_proc0
// static void setup_fstat_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf8_2_proc0
// static void setup_fstat_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pd8_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pd8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_2_1
// static void setup_fstat_write_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
// static void setup_fstat_write_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_2_proc0
// static void setup_fstat_write_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf8_2_proc0
// static void setup_fstat_write_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pd4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pd4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf4_0_common
// static void setup_fstat_write_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf8_2_proc0
static void setup_fstat_write_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pd4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pd4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf4_0_common
// static void setup_fstat_write_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_2_proc0
// static void setup_fstat_write_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pd4_0_proc1
// static void setup_fstat_write_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pd0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf0_0_common
// static void setup_fstat_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf8_2_proc0
// static void setup_fstat_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pd4_0_proc1
// static void setup_fstat_write_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pd0_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pd0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf0_0_common
// static void setup_fstat_write_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_2_proc0
// static void setup_fstat_write_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pd4_0_proc1
// static void setup_fstat_write_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_2_1
// static void setup_fstat_write_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
// static void setup_fstat_write_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf8_2_proc0
// static void setup_fstat_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pc_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("!!S_ISFIFO(st.st_mode)", !!S_ISFIFO(st.st_mode), 1);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pfe_0_0
// static int test_fstat_write_pc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_2_1
// static void setup_fstat_write_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
// static void setup_fstat_write_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_2_proc0
// static void setup_fstat_write_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
static int test_fstat_write_pbe_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_write_pbe_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfe_0_1
// static void setup_fstat_write_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfe_2_common
static void setup_fstat_write_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfe_2_proc1
// static void setup_fstat_write_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pbc_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pbe_0_0
// static int test_fstat_write_pbc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
// static void setup_fstat_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfc_0_common
static void setup_fstat_write_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
static int test_fstat_write_pb8_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_write_pb8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_0_1
// static void setup_fstat_write_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
static void setup_fstat_write_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
static int test_fstat_write_pb6_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 28672);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_write_pb6_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
static void setup_fstat_write_pb6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_write_pb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_fstat_write_pb6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_fstat_write_pb6_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
static void setup_fstat_write_pb6_0_procfinal(void) {
  
}

/*
 * calls: fstat write
 */
static int test_fstat_write_pb30_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_write_pb30_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
static void setup_fstat_write_pb30_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_fstat_write_pb30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_pb6_0_proc0
// static void setup_fstat_write_pb30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_pb30_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb6_0_final
// static void setup_fstat_write_pb30_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pb30_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pb30_0_0
// static int test_fstat_write_pb30_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
static void setup_fstat_write_pb30_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_fstat_write_pb30_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_write_pb30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
static void setup_fstat_write_pb30_1_final(void) {
  unlink("__i0");
}
// static void setup_fstat_write_pb30_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pb30_2_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pb30_0_0
// static int test_fstat_write_pb30_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_pb30_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_1_common
static void setup_fstat_write_pb30_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_write_pb30_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_pb30_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb30_1_final
// static void setup_fstat_write_pb30_2_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_pa_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pb8_0_0
// static int test_fstat_write_pa_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_0_1
static void setup_fstat_write_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_fstat_write_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_2_proc0
// static void setup_fstat_write_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb30_1_final
// static void setup_fstat_write_pa_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
static int test_fstat_write_p9e_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 20480);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_write_p9e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfe_3_1
// static void setup_fstat_write_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pde_2_common
static void setup_fstat_write_p9e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfe_3_proc0
// static void setup_fstat_write_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p9c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pbe_0_0
// static int test_fstat_write_p9c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfc_0_common
static void setup_fstat_write_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_2_proc0
// static void setup_fstat_write_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p98_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pb8_0_0
// static int test_fstat_write_p98_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_2_1
// static void setup_fstat_write_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
// static void setup_fstat_write_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pd4_0_proc1
// static void setup_fstat_write_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf8_2_proc0
// static void setup_fstat_write_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p96_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 28672);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pb6_0_0
// static int test_fstat_write_p96_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_write_pb6_0_common
// static void setup_fstat_write_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_2_proc0
static void setup_fstat_write_p96_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_write_p96_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb6_0_final
// static void setup_fstat_write_p96_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p930_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pb30_0_0
// static int test_fstat_write_p930_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_p930_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_0_common
// static void setup_fstat_write_p930_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_2_proc0
// static void setup_fstat_write_p930_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_p96_0_proc1
// static void setup_fstat_write_p930_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb6_0_final
// static void setup_fstat_write_p930_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p930_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pb30_0_0
// static int test_fstat_write_p930_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_p930_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_1_common
// static void setup_fstat_write_p930_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_2_proc0
// static void setup_fstat_write_p930_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_2_proc0
// static void setup_fstat_write_p930_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb30_1_final
// static void setup_fstat_write_p930_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p8_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_pb8_0_0
// static int test_fstat_write_p8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_2_1
// static void setup_fstat_write_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_write_pa_0_common
// static void setup_fstat_write_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_2_proc0
// static void setup_fstat_write_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb30_1_final
// static void setup_fstat_write_p8_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
static int test_fstat_write_p7c_0_0(void) {
  struct stat st;
  int r = fstat(10, &st);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_fstat_write_p7c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfe_0_1
// static void setup_fstat_write_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfe_2_common
static void setup_fstat_write_p7c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfe_2_proc1
// static void setup_fstat_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p78_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p78_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
// static void setup_fstat_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfc_0_common
static void setup_fstat_write_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p70_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p70_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_0_1
// static void setup_fstat_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
static void setup_fstat_write_p70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_fstat_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p68_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p68_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
// static void setup_fstat_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_write_pa_0_common
static void setup_fstat_write_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_fstat_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb30_1_final
// static void setup_fstat_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p60_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p60_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_0_1
// static void setup_fstat_write_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_1_common
// static void setup_fstat_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_p68_0_proc0
// static void setup_fstat_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb30_1_final
// static void setup_fstat_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p4_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_0_1
static void setup_fstat_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_fstat_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p4_0_final(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal
// static void setup_fstat_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p4_1_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_2_1
// static void setup_fstat_write_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_write_p4_0_common
// static void setup_fstat_write_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p4_1_final(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal
// static void setup_fstat_write_p4_1_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p3c_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfe_3_1
// static void setup_fstat_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pde_2_common
// static void setup_fstat_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfe_2_proc1
// static void setup_fstat_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfe_3_proc0
// static void setup_fstat_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p38_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pfc_0_common
// static void setup_fstat_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_2_proc0
// static void setup_fstat_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p30_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_2_1
// static void setup_fstat_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_fstat_write_pf8_0_common
// static void setup_fstat_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pfc_0_proc1
// static void setup_fstat_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_fstat_write_pf8_2_proc0
// static void setup_fstat_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_final
// static void setup_fstat_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_fstat_write_pfe_2_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p28_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_fstat_write_pa_0_common
// static void setup_fstat_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_2_proc0
// static void setup_fstat_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb30_1_final
// static void setup_fstat_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p20_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pfc_2_1
// static void setup_fstat_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_1_common
// static void setup_fstat_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_fstat_write_pb30_2_proc0
// static void setup_fstat_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_fstat_write_pb30_1_final
// static void setup_fstat_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal

/*
 * calls: fstat write
 */
// static int test_fstat_write_p0_0_0(void) {
//   struct stat st;
//   int r = fstat(10, &st);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_fstat_write_p7c_0_0
// static int test_fstat_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_fstat_write_pf8_2_1
// static void setup_fstat_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_fstat_write_p4_0_common
// static void setup_fstat_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_fstat_write_pb6_0_proc1
// static void setup_fstat_write_p0_0_final(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal
// static void setup_fstat_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_fstat_write_pb6_0_procfinal


/*
 * calls: link link
 */
static int test_link_link_pf_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_link_pf_0_1(void) {
  int r = link("__f2", "__f3");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_link_link_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f3");
  if (r < 0) setup_error("link");
}
static void setup_link_link_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_link_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_link_pf_0_final(void) {
  unlink("__i0");
}
static void setup_link_link_pf_0_procfinal(void) {
  
}

/*
 * calls: link link
 */
// static int test_link_link_pf_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_0_0
static int test_link_link_pf_1_1(void) {
  int r = link("__f0", "__f2");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_link_link_pf_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_link_pf_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pf_1_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
static int test_link_link_pf_2_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_link_pf_2_1(void) {
  int r = link("__f1", "__f2");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static void setup_link_link_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_1_common
// static void setup_link_link_pf_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pf_2_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pf_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_0_0
static int test_link_link_pf_3_1(void) {
  int r = link("__f2", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static void setup_link_link_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_1_common
// static void setup_link_link_pf_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pf_3_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pf_4_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_0_0
static int test_link_link_pf_4_1(void) {
  int r = link("__f1", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_link_link_pf_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_link_pf_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pf_4_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pf_5_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_2_0
// static int test_link_link_pf_5_1(void) {
//   int r = link("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_4_1
// static void setup_link_link_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_4_common
// static void setup_link_link_pf_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pf_5_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pf_6_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_2_0
// static int test_link_link_pf_6_1(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_0_0
// static void setup_link_link_pf_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_4_common
// static void setup_link_link_pf_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pf_6_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pf_7_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_2_0
// static int test_link_link_pf_7_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_2_0
static void setup_link_link_pf_7_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_link_pf_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pf_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pf_7_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pe0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_0_0
static int test_link_link_pe0_0_1(void) {
  int r = link("__f2", "__f3");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_link_link_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_1_common
// static void setup_link_link_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pe0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_0_0
static int test_link_link_pe0_1_1(void) {
  int r = link("__f0", "__f2");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_link_link_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_4_common
// static void setup_link_link_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pe0_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_2_0
static int test_link_link_pe0_2_1(void) {
  int r = link("__f1", "__f2");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_link_link_pe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_4_common
// static void setup_link_link_pe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pe0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pe0_2_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pe0_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_2_0
static int test_link_link_pe0_3_1(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_link_link_pe0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_7_common
// static void setup_link_link_pe0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pe0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pe0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pe0_3_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_0_0
static int test_link_link_pc_0_1(void) {
  int r = link("__f2", "__f2");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_link_link_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_4_common
// static void setup_link_link_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_2_0
static int test_link_link_pc_1_1(void) {
  int r = link("__f1", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_link_link_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_7_common
// static void setup_link_link_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pbc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_3_1
// static int test_link_link_pbc_0_1(void) {
//   int r = link("__f2", "__f3");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_0_1
static void setup_link_link_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f3");
  if (r < 0) setup_error("link");
}
// static void setup_link_link_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pbc_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_3_1
// static int test_link_link_pbc_1_1(void) {
//   int r = link("__f0", "__f2");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_1_1
static void setup_link_link_pbc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_link_pbc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pbc_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_3_1
// static int test_link_link_pbc_2_1(void) {
//   int r = link("__f2", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_3_1
// static void setup_link_link_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pbc_1_common
// static void setup_link_link_pbc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pbc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pbc_2_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pbc_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_3_1
// static int test_link_link_pbc_3_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_link_pf_2_0
// static void setup_link_link_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_7_common
// static void setup_link_link_pbc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pbc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pbc_3_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pa8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_3_1
// static int test_link_link_pa8_0_1(void) {
//   int r = link("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_0_1
static void setup_link_link_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_link_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
static void setup_link_link_pa8_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_link_link_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pa8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_3_1
// static int test_link_link_pa8_1_1(void) {
//   int r = link("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_0_1
// static void setup_link_link_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pbc_1_common
// static void setup_link_link_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_pa8_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_3_1
// static int test_link_link_pa8_2_1(void) {
//   int r = link("__f0", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_1_1
static void setup_link_link_pa8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_link_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_p8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_3_1
// static int test_link_link_p8_0_1(void) {
//   int r = link("__f2", "__f2");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_link_pc_0_1
// static void setup_link_link_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_pf_7_common
// static void setup_link_link_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_p8_0_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
static int test_link_link_p6_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static int test_link_link_p6_0_1(void) {
  int r = link("__f2", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_link_link_p6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_link_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_p6_0_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
static int test_link_link_p6_1_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static int test_link_link_p6_1_1(void) {
  int r = link("__f1", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_link_link_p6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_link_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_p6_1_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_p40_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_link_p6_0_0
static int test_link_link_p40_0_1(void) {
  int r = link("__f2", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_link_p40_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_link_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_p40_0_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_p40_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_link_p6_0_0
// static int test_link_link_p40_1_1(void) {
//   int r = link("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_link_pe0_0_1
// static void setup_link_link_p40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_link_p6_0_common
// static void setup_link_link_p40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_link_pf_0_final
// static void setup_link_link_p40_1_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_link_p6_1_0
// static int test_link_link_p0_0_1(void) {
//   int r = link("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_link_pc_1_1
static void setup_link_link_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_link_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p0_0_final(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal
// static void setup_link_link_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal

/*
 * calls: link link
 */
// static int test_link_link_p0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_link_p6_1_0
// static int test_link_link_p0_1_1(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_link_p6_1_0
// static void setup_link_link_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_link_p0_0_common
// static void setup_link_link_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_link_pf_0_proc1
// static void setup_link_link_p0_1_final(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal
// static void setup_link_link_p0_1_procfinal(void) {
//   
// }
// ^ See setup_link_link_pf_0_procfinal


/*
 * calls: link lseek
 */
static int test_link_lseek_pf8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_lseek_pf8_0_1(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_link_lseek_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_lseek_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_lseek_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_lseek_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_link_lseek_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pf8_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf8_0_common
static void setup_link_lseek_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_link_lseek_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
static int test_link_lseek_pf8_2_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_lseek_pf8_2_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
static void setup_link_lseek_pf8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_lseek_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc0
// static void setup_link_lseek_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf8_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pf8_3_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf8_2_common
// static void setup_link_lseek_pf8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_1_proc0
// static void setup_link_lseek_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
static int test_link_lseek_pf6_0_1(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_link_lseek_pf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_lseek_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_link_lseek_pf6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_lseek_pf6_0_final(void) {
  unlink("__i0");
}
static void setup_link_lseek_pf6_0_procfinal(void) {
  
}

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf6_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pf6_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf6_0_1
static void setup_link_lseek_pf6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_lseek_pf6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf6_0_proc0
// static void setup_link_lseek_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf6_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
static int test_link_lseek_pf4_0_1(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_lseek_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_lseek_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_lseek_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf4_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pf4_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf4_0_1
static void setup_link_lseek_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_lseek_pf4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf3_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
static int test_link_lseek_pf3_0_1(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_link_lseek_pf3_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_lseek_pf3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pf3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf3_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf3_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pf3_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf3_0_1
// static void setup_link_lseek_pf3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf6_1_common
// static void setup_link_lseek_pf3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pf3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf3_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf2_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
static int test_link_lseek_pf2_0_1(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_link_lseek_pf2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
// static void setup_link_lseek_pf2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pf2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf2_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf2_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pf2_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf2_0_1
// static void setup_link_lseek_pf2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pf2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pf2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf2_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf18_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
static int test_link_lseek_pf18_0_1(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_link_lseek_pf18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
static void setup_link_lseek_pf18_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_lseek_pf18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf18_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf18_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf18_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pf18_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf18_0_1
// static void setup_link_lseek_pf18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pf18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf18_0_proc0
// static void setup_link_lseek_pf18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf18_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf10_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
static int test_link_lseek_pf10_0_1(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_link_lseek_pf10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
// static void setup_link_lseek_pf10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pf10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf10_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf10_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pf10_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf10_0_1
// static void setup_link_lseek_pf10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pf10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pf10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf10_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pf0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
// static void setup_link_lseek_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pf0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pf0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pe_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
static int test_link_lseek_pe_0_1(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_link_lseek_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
// static void setup_link_lseek_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pe_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pe_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pe_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pe_0_1
// static void setup_link_lseek_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pe_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pd8_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf8_0_common
// static void setup_link_lseek_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc0
// static void setup_link_lseek_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pd8_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf8_0_common
// static void setup_link_lseek_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_1_proc0
// static void setup_link_lseek_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd8_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pd8_2_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf8_2_common
// static void setup_link_lseek_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc0
// static void setup_link_lseek_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd8_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pd8_3_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf8_2_common
// static void setup_link_lseek_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_1_proc0
// static void setup_link_lseek_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pd6_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf6_0_1
// static void setup_link_lseek_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf6_0_common
// static void setup_link_lseek_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
static void setup_link_lseek_pd6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_lseek_pd6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd6_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd6_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pd6_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf6_0_1
// static void setup_link_lseek_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf6_1_common
// static void setup_link_lseek_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pd6_0_proc1
// static void setup_link_lseek_pd6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd6_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pd4_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf4_0_1
// static void setup_link_lseek_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
// static void setup_link_lseek_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pd4_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf4_0_1
// static void setup_link_lseek_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd3_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pd3_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf3_0_1
// static void setup_link_lseek_pd3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf3_0_common
// static void setup_link_lseek_pd3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pd3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd3_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd3_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pd3_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf3_0_1
// static void setup_link_lseek_pd3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf6_1_common
// static void setup_link_lseek_pd3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pd3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd3_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd2_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pd2_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf2_0_1
// static void setup_link_lseek_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
// static void setup_link_lseek_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pd2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd2_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd2_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pd2_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf2_0_1
// static void setup_link_lseek_pd2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pd2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pd2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd2_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd18_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pd18_0_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf18_0_1
// static void setup_link_lseek_pd18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
// static void setup_link_lseek_pd18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
static void setup_link_lseek_pd18_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_lseek_pd18_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd18_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd18_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pd18_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf18_0_1
// static void setup_link_lseek_pd18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pd18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pd18_0_proc1
// static void setup_link_lseek_pd18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd18_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd10_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pd10_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf10_0_1
// static void setup_link_lseek_pd10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
// static void setup_link_lseek_pd10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pd10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd10_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd10_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pd10_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf10_0_1
// static void setup_link_lseek_pd10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pd10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pd10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd10_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pd0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
// static void setup_link_lseek_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pd0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pd0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_0
// static int test_link_lseek_pc_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pe_0_1
// static void setup_link_lseek_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_0_common
// static void setup_link_lseek_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_2_0
// static int test_link_lseek_pc_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pe_0_1
// static void setup_link_lseek_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
static int test_link_lseek_pb8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_lseek_pb8_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
static void setup_link_lseek_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_lseek_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc0
// static void setup_link_lseek_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_pb8_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pb8_0_common
// static void setup_link_lseek_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_1_proc0
// static void setup_link_lseek_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_pb6_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf6_0_1
// static void setup_link_lseek_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
static void setup_link_lseek_pb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_lseek_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pb6_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_pb4_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf4_0_1
// static void setup_link_lseek_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb4_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
static int test_link_lseek_pb4_1_1(void) {
  int r = lseek(10, 31617024, SEEK_SET);
  expect_result("r", r, 31617024);
  return xerrno(r);
}
// static void setup_link_lseek_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
static void setup_link_lseek_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_lseek_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb30_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
static int test_link_lseek_pb30_0_1(void) {
  int r = lseek(10, -31621120, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_link_lseek_pb30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pb30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb4_1_proc0
// static void setup_link_lseek_pb30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pb30_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb20_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
static int test_link_lseek_pb20_0_1(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 155648);
  return xerrno(r);
}
// static void setup_link_lseek_pb20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
static void setup_link_lseek_pb20_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_lseek_pb20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pb20_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb20_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
static int test_link_lseek_pb20_1_1(void) {
  int r = lseek(10, 9981952, SEEK_CUR);
  expect_result("r", r, 19963904);
  return xerrno(r);
}
// static void setup_link_lseek_pb20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pb20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pd18_0_proc1
// static void setup_link_lseek_pb20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pb20_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb18_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
static int test_link_lseek_pb18_0_1(void) {
  int r = lseek(10, -28672, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_link_lseek_pb18_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_lseek_pb18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_pb18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
static void setup_link_lseek_pb18_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_link_lseek_pb18_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb18_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_pb18_1_1(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb18_0_1
static void setup_link_lseek_pb18_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_lseek_pb18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_pb18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pb18_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb10_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
static int test_link_lseek_pb10_0_1(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
static void setup_link_lseek_pb10_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_lseek_pb10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_pb10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb10_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pb18_0_final
// static void setup_link_lseek_pb10_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb10_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
static int test_link_lseek_pb10_1_1(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 28672);
  return xerrno(r);
}
static void setup_link_lseek_pb10_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_lseek_pb10_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_lseek_pb10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pb10_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb10_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
static int test_link_lseek_pb10_2_1(void) {
  int r = lseek(10, 7356416, SEEK_END);
  expect_result("r", r, 7389184);
  return xerrno(r);
}
static void setup_link_lseek_pb10_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_lseek_pb10_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf18_0_proc0
// static void setup_link_lseek_pb10_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb10_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pb18_0_final
// static void setup_link_lseek_pb10_2_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb10_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_pb10_3_1(void) {
//   int r = lseek(10, 7356416, SEEK_END);
//   expect_result("r", r, 7389184);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb10_2_1
static void setup_link_lseek_pb10_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_lseek_pb10_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf18_0_proc0
// static void setup_link_lseek_pb10_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb10_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pb10_3_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pb00_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_pb00_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_pb00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pb00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_pb00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pb00_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pb00_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_pa0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_pa0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pe_0_1
// static void setup_link_lseek_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p98_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p98_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pb8_0_common
// static void setup_link_lseek_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc0
// static void setup_link_lseek_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p98_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p98_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pb8_0_common
// static void setup_link_lseek_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_1_proc0
// static void setup_link_lseek_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p96_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p96_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf6_0_1
// static void setup_link_lseek_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_p96_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p96_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p94_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p94_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf4_0_1
// static void setup_link_lseek_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p94_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p94_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p94_1_1(void) {
//   int r = lseek(10, 31617024, SEEK_SET);
//   expect_result("r", r, 31617024);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb4_1_1
// static void setup_link_lseek_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb4_1_proc0
// static void setup_link_lseek_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p94_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p930_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p930_0_1(void) {
//   int r = lseek(10, -31621120, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb30_0_1
// static void setup_link_lseek_p930_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_p930_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p930_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb4_1_proc0
// static void setup_link_lseek_p930_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p930_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p920_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p920_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb20_0_1
// static void setup_link_lseek_p920_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_p920_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p920_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb20_0_proc0
// static void setup_link_lseek_p920_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p920_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p920_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
static int test_link_lseek_p920_1_1(void) {
  int r = lseek(10, 31617024, SEEK_CUR);
  expect_result("r", r, 63234048);
  return xerrno(r);
}
// static void setup_link_lseek_p920_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_p920_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p920_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb4_1_proc0
// static void setup_link_lseek_p920_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p920_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p918_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p918_0_1(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb18_0_1
// static void setup_link_lseek_p918_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pb18_0_common
// static void setup_link_lseek_p918_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p918_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_p918_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pb18_0_final
// static void setup_link_lseek_p918_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p918_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p918_1_1(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb18_0_1
// static void setup_link_lseek_p918_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pb18_1_common
// static void setup_link_lseek_p918_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p918_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_p918_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p918_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p910_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p910_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb10_0_1
// static void setup_link_lseek_p910_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pb10_0_common
// static void setup_link_lseek_p910_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p910_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_p910_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pb18_0_final
// static void setup_link_lseek_p910_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p910_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p910_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 28672);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb10_1_1
// static void setup_link_lseek_p910_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pb10_1_common
// static void setup_link_lseek_p910_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p910_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb10_1_proc0
// static void setup_link_lseek_p910_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p910_1_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p910_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p910_2_1(void) {
//   int r = lseek(10, 7356416, SEEK_END);
//   expect_result("r", r, 7389184);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb10_2_1
// static void setup_link_lseek_p910_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pb10_2_common
// static void setup_link_lseek_p910_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p910_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf18_0_proc0
// static void setup_link_lseek_p910_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pb18_0_final
// static void setup_link_lseek_p910_2_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p910_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
static int test_link_lseek_p910_3_1(void) {
  int r = lseek(10, 5062656, SEEK_END);
  expect_result("r", r, 5087232);
  return xerrno(r);
}
// static void setup_link_lseek_p910_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pb18_1_common
// static void setup_link_lseek_p910_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p910_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pd6_0_proc1
// static void setup_link_lseek_p910_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p910_3_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p900_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p900_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_p900_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_p900_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p900_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pb6_0_proc0
// static void setup_link_lseek_p900_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p900_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p80_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pb8_0_0
// static int test_link_lseek_p80_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pe_0_1
// static void setup_link_lseek_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_lseek_pf4_1_common
// static void setup_link_lseek_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p80_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
static int test_link_lseek_p7_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_lseek_p7_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
static void setup_link_lseek_p7_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_lseek_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc0
// static void setup_link_lseek_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p7_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p7_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_lseek_p7_0_common
// static void setup_link_lseek_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_1_proc0
// static void setup_link_lseek_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p6c_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p6c_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf6_0_1
static void setup_link_lseek_p6c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_link_lseek_p6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf6_0_proc0
// static void setup_link_lseek_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p6c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p6c_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p68_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p68_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf4_0_1
static void setup_link_lseek_p68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_link_lseek_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p68_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p66_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p66_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf3_0_1
static void setup_link_lseek_p66_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_link_lseek_p66_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_p66_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p66_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p66_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p64_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p64_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf2_0_1
// static void setup_link_lseek_p64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_lseek_p68_0_common
// static void setup_link_lseek_p64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_p64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p64_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p64_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p63_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p63_0_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf18_0_1
// static void setup_link_lseek_p63_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_lseek_p68_0_common
// static void setup_link_lseek_p63_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf18_0_proc0
// static void setup_link_lseek_p63_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p63_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p63_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p62_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p62_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf10_0_1
// static void setup_link_lseek_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_lseek_p68_0_common
// static void setup_link_lseek_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p62_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p60_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p60_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_lseek_p68_0_common
// static void setup_link_lseek_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p60_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p4_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p4_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pe_0_1
static void setup_link_lseek_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_lseek_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p4_0_final(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal
// static void setup_link_lseek_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p3_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p3_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_lseek_p7_0_common
// static void setup_link_lseek_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc0
// static void setup_link_lseek_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p3_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p3_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_lseek_p7_0_common
// static void setup_link_lseek_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_0_proc1
// static void setup_link_lseek_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_lseek_pf8_1_proc0
// static void setup_link_lseek_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_final
// static void setup_link_lseek_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_lseek_pf8_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p2c_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p2c_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf6_0_1
// static void setup_link_lseek_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_lseek_p6c_0_common
// static void setup_link_lseek_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pd6_0_proc1
// static void setup_link_lseek_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p28_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p28_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf4_0_1
// static void setup_link_lseek_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_lseek_p68_0_common
// static void setup_link_lseek_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p28_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p26_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p26_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf3_0_1
// static void setup_link_lseek_p26_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_lseek_p66_0_common
// static void setup_link_lseek_p26_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p26_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_p26_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p26_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p24_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p24_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf2_0_1
// static void setup_link_lseek_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_lseek_p68_0_common
// static void setup_link_lseek_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p24_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p23_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p23_0_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf18_0_1
// static void setup_link_lseek_p23_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_lseek_p68_0_common
// static void setup_link_lseek_p23_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p23_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pd18_0_proc1
// static void setup_link_lseek_p23_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p23_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p22_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p22_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf10_0_1
// static void setup_link_lseek_p22_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_lseek_p68_0_common
// static void setup_link_lseek_p22_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p22_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_p22_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p22_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p20_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p20_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pf8_0_1
// static void setup_link_lseek_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_lseek_p68_0_common
// static void setup_link_lseek_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_lseek_pf4_0_proc0
// static void setup_link_lseek_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_lseek_pf6_0_final
// static void setup_link_lseek_p20_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal

/*
 * calls: link lseek
 */
// static int test_link_lseek_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_lseek_p7_0_0
// static int test_link_lseek_p0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_lseek_pe_0_1
// static void setup_link_lseek_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_lseek_p4_0_common
// static void setup_link_lseek_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_lseek_pf6_0_proc1
// static void setup_link_lseek_p0_0_final(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal
// static void setup_link_lseek_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_lseek_pf6_0_procfinal


/*
 * calls: link memread
 */
static int test_link_memread_pf8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_memread_pf8_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static void setup_link_memread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_memread_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_link_memread_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_memread_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_link_memread_pf8_0_procfinal(void) {
  
}

/*
 * calls: link memread
 */
// static int test_link_memread_pf8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pf8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_0_common
static void setup_link_memread_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_link_memread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
static int test_link_memread_pf8_2_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_memread_pf8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
static void setup_link_memread_pf8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_memread_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memread_pf8_0_proc0
// static void setup_link_memread_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf8_2_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pf8_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pf8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pf8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memread_pf8_1_proc0
// static void setup_link_memread_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf8_3_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pf4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
static int test_link_memread_pf4_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static void setup_link_memread_pf4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_0_common
static void setup_link_memread_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_link_memread_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf4_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pf4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pf4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
static void setup_link_memread_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_link_memread_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pf4_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pf4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_0_common
static void setup_link_memread_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_link_memread_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf4_2_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pf4_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pf4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
static void setup_link_memread_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_link_memread_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf4_3_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pf0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pf0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
static void setup_link_memread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_memread_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_link_memread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pf0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pf0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf0_0_common
static void setup_link_memread_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_link_memread_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pf0_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pf0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
static void setup_link_memread_pf0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_memread_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_0_proc0
// static void setup_link_memread_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pf0_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pf0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf0_2_common
// static void setup_link_memread_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_1_proc0
// static void setup_link_memread_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pe_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
static int test_link_memread_pe_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_link_memread_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_0_common
// static void setup_link_memread_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pe_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pe_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pe_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pe_0_1
// static void setup_link_memread_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pe_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pd8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_0_common
// static void setup_link_memread_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memread_pf8_0_proc0
// static void setup_link_memread_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pd8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_0_common
// static void setup_link_memread_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memread_pf8_1_proc0
// static void setup_link_memread_pd8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd8_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd8_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pd8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memread_pf8_0_proc0
// static void setup_link_memread_pd8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd8_2_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd8_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pd8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memread_pf8_1_proc0
// static void setup_link_memread_pd8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd8_3_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pd4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_0_common
// static void setup_link_memread_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_0_proc0
// static void setup_link_memread_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pd4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
static void setup_link_memread_pd4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_link_memread_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd4_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pd4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_0_common
// static void setup_link_memread_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
static void setup_link_memread_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_link_memread_pd4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd4_2_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd4_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pd4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_1_proc0
// static void setup_link_memread_pd4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd4_3_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pd0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf0_0_common
// static void setup_link_memread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_0_proc0
// static void setup_link_memread_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pd0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf0_0_common
// static void setup_link_memread_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_1_proc0
// static void setup_link_memread_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd0_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pd0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf0_2_common
// static void setup_link_memread_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_0_proc0
// static void setup_link_memread_pd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd0_2_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pd0_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pd0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf0_2_common
// static void setup_link_memread_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_1_proc0
// static void setup_link_memread_pd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pd0_3_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_0_0
// static int test_link_memread_pc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pe_0_1
// static void setup_link_memread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_0_common
// static void setup_link_memread_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memread_pf8_2_0
// static int test_link_memread_pc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pe_0_1
// static void setup_link_memread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
static int test_link_memread_pb8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_memread_pb8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memread_pf8_0_proc0
// static void setup_link_memread_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pb8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_pb8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memread_pf8_1_proc0
// static void setup_link_memread_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pb4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_pb4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
static void setup_link_memread_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_memread_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_link_memread_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
static void setup_link_memread_pb4_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_link_memread_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pb4_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_pb4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_link_memread_pf4_0_proc0
// static void setup_link_memread_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pb4_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_pb4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pb4_0_common
static void setup_link_memread_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_link_memread_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pb4_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_memread_pb4_0_final
// static void setup_link_memread_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pb4_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_pb4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_link_memread_pf4_3_proc0
// static void setup_link_memread_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pb0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_pb0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
static void setup_link_memread_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_memread_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x6000);
}
// static void setup_link_memread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pb0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_memread_pb4_0_final
// static void setup_link_memread_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pb0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_pb0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pb0_0_common
static void setup_link_memread_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
}
// static void setup_link_memread_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pb0_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_memread_pb4_0_final
// static void setup_link_memread_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pb0_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_pb0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
static void setup_link_memread_pb0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_memread_pb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_link_memread_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pb0_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_pb0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pb0_2_common
static void setup_link_memread_pb0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_link_memread_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_pa0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_pa0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pe_0_1
// static void setup_link_memread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p98_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p98_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memread_pf8_0_proc0
// static void setup_link_memread_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p98_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p98_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p98_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memread_pf8_1_proc0
// static void setup_link_memread_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p98_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p94_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p94_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
static void setup_link_memread_p94_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_memread_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x26000);
// }
// ^ See setup_link_memread_pb4_0_proc0
// static void setup_link_memread_p94_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_memread_pb4_0_final
// static void setup_link_memread_p94_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p94_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p94_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pb0_2_common
// static void setup_link_memread_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
static void setup_link_memread_p94_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
// static void setup_link_memread_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p94_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p94_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p94_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_p94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pb0_0_common
// static void setup_link_memread_p94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
static void setup_link_memread_p94_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x4d4000);
}
// static void setup_link_memread_p94_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_memread_pb4_0_final
// static void setup_link_memread_p94_2_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p94_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p94_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_p94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pb0_2_common
// static void setup_link_memread_p94_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
static void setup_link_memread_p94_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
}
// static void setup_link_memread_p94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p94_3_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p90_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p90_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pb0_0_common
// static void setup_link_memread_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x6000);
// }
// ^ See setup_link_memread_pb0_0_proc0
// static void setup_link_memread_p90_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_memread_pb4_0_final
// static void setup_link_memread_p90_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p90_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p90_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pb0_0_common
// static void setup_link_memread_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x6000);
// }
// ^ See setup_link_memread_pb0_1_proc0
// static void setup_link_memread_p90_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_memread_pb4_0_final
// static void setup_link_memread_p90_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p90_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p90_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pb0_2_common
// static void setup_link_memread_p90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x6000);
// }
// ^ See setup_link_memread_pb0_2_proc0
// static void setup_link_memread_p90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p90_2_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p90_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p90_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pb0_2_common
// static void setup_link_memread_p90_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_link_memread_pb0_3_proc0
// static void setup_link_memread_p90_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p90_3_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p80_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memread_pb8_0_0
// static int test_link_memread_p80_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pe_0_1
// static void setup_link_memread_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memread_pf8_2_common
// static void setup_link_memread_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p80_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
static int test_link_memread_p7_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_memread_p7_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
static void setup_link_memread_p7_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_memread_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memread_pf8_0_proc0
// static void setup_link_memread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p7_0_final(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal
// static void setup_link_memread_p7_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p7_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p7_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_memread_p7_0_common
// static void setup_link_memread_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memread_pf8_1_proc0
// static void setup_link_memread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p7_1_final(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal
// static void setup_link_memread_p7_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p68_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p68_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
static void setup_link_memread_p68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_link_memread_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_link_memread_pf4_0_proc0
// static void setup_link_memread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p68_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p68_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_memread_p68_0_common
// static void setup_link_memread_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_link_memread_pf4_3_proc0
// static void setup_link_memread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p60_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p60_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
static void setup_link_memread_p60_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_link_memread_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_0_proc0
// static void setup_link_memread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p60_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p60_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_memread_p60_0_common
// static void setup_link_memread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_1_proc0
// static void setup_link_memread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p4_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pe_0_1
// static void setup_link_memread_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_memread_p7_0_common
// static void setup_link_memread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p4_0_final(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal
// static void setup_link_memread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p3_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p3_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_memread_p7_0_common
// static void setup_link_memread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memread_pf8_0_proc0
// static void setup_link_memread_p3_0_final(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal
// static void setup_link_memread_p3_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p3_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p3_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_memread_p7_0_common
// static void setup_link_memread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memread_pf8_1_proc0
// static void setup_link_memread_p3_1_final(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal
// static void setup_link_memread_p3_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p28_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p28_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_memread_p68_0_common
// static void setup_link_memread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_0_proc0
// static void setup_link_memread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p28_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p28_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pf4_0_1
// static void setup_link_memread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_memread_p68_0_common
// static void setup_link_memread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_1_proc0
// static void setup_link_memread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p20_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p20_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_memread_p60_0_common
// static void setup_link_memread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_0_proc0
// static void setup_link_memread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p20_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p20_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_link_memread_pf8_0_1
// static void setup_link_memread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_memread_p60_0_common
// static void setup_link_memread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memread_pf0_1_proc0
// static void setup_link_memread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memread_pf8_0_final
// static void setup_link_memread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal

/*
 * calls: link memread
 */
// static int test_link_memread_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memread_p7_0_0
// static int test_link_memread_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memread_pe_0_1
// static void setup_link_memread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_memread_p7_0_common
// static void setup_link_memread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memread_pf8_0_proc1
// static void setup_link_memread_p0_0_final(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal
// static void setup_link_memread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_memread_pf8_0_procfinal


/*
 * calls: link memwrite
 */
static int test_link_memwrite_pfc_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_memwrite_pfc_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static void setup_link_memwrite_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_memwrite_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_link_memwrite_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_memwrite_pfc_0_final(void) {
  unlink("__i0");
}
static void setup_link_memwrite_pfc_0_procfinal(void) {
  
}

/*
 * calls: link memwrite
 */
static int test_link_memwrite_pfc_1_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_memwrite_pfc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
static void setup_link_memwrite_pfc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_memwrite_pfc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memwrite_pfc_0_proc0
// static void setup_link_memwrite_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pfc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pfc_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pfa_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
static int test_link_memwrite_pfa_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static void setup_link_memwrite_pfa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_0_common
static void setup_link_memwrite_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_link_memwrite_pfa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pfa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pfa_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pfa_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pfa_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pfa_0_1
// static void setup_link_memwrite_pfa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pfa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_link_memwrite_pfa_0_proc0
// static void setup_link_memwrite_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pfa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pfa_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pf8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
// static int test_link_memwrite_pf8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
static void setup_link_memwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_memwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_link_memwrite_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pf8_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pf8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
static void setup_link_memwrite_pf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_memwrite_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf8_0_proc0
// static void setup_link_memwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pf0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
static int test_link_memwrite_pf0_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_link_memwrite_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_0_common
static void setup_link_memwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_link_memwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pf0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
// static int test_link_memwrite_pf0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_0_common
static void setup_link_memwrite_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_link_memwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pf0_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pf0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf0_0_proc0
// static void setup_link_memwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pf0_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pf0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memwrite_pf0_1_proc0
// static void setup_link_memwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pe_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
// static int test_link_memwrite_pe_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_0_common
// static void setup_link_memwrite_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pe_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pe_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pe_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pe_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pdc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
// static int test_link_memwrite_pdc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
// static void setup_link_memwrite_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_0_common
// static void setup_link_memwrite_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memwrite_pfc_0_proc0
// static void setup_link_memwrite_pdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pdc_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pdc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pdc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
// static void setup_link_memwrite_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memwrite_pfc_0_proc0
// static void setup_link_memwrite_pdc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pdc_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pda_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
// static int test_link_memwrite_pda_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pfa_0_1
// static void setup_link_memwrite_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_0_common
// static void setup_link_memwrite_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf8_0_proc0
// static void setup_link_memwrite_pda_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pda_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pda_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pda_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pfa_0_1
// static void setup_link_memwrite_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pda_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf8_0_proc0
// static void setup_link_memwrite_pda_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pda_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pd8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
// static int test_link_memwrite_pd8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
// static void setup_link_memwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pf8_0_common
// static void setup_link_memwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf8_0_proc0
// static void setup_link_memwrite_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pd8_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pd8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
// static void setup_link_memwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pf8_1_common
// static void setup_link_memwrite_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf8_0_proc0
// static void setup_link_memwrite_pd8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pd8_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pd0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
// static int test_link_memwrite_pd0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_0_common
// static void setup_link_memwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf0_0_proc0
// static void setup_link_memwrite_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pd0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
// static int test_link_memwrite_pd0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_0_common
// static void setup_link_memwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memwrite_pf0_1_proc0
// static void setup_link_memwrite_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pd0_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pd0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf0_0_proc0
// static void setup_link_memwrite_pd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pd0_2_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pd0_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pd0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memwrite_pf0_1_proc0
// static void setup_link_memwrite_pd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pd0_3_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_0_0
// static int test_link_memwrite_pc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_0_common
// static void setup_link_memwrite_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pfc_1_0
// static int test_link_memwrite_pc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
static int test_link_memwrite_pbc_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_memwrite_pbc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
// static void setup_link_memwrite_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memwrite_pfc_0_proc0
// static void setup_link_memwrite_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pba_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_pba_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pfa_0_1
static void setup_link_memwrite_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_memwrite_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_link_memwrite_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
static void setup_link_memwrite_pba_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_link_memwrite_pba_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pba_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_pba_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pfa_0_1
// static void setup_link_memwrite_pba_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pba_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_link_memwrite_pfa_0_proc0
// static void setup_link_memwrite_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pba_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pba_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pb8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_pb8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
static void setup_link_memwrite_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_memwrite_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
}
// static void setup_link_memwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pb8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_memwrite_pba_0_final
// static void setup_link_memwrite_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pb8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_pb8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
static void setup_link_memwrite_pb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_memwrite_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_link_memwrite_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pb0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_pb0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
static void setup_link_memwrite_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_link_memwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pb0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_pb0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memwrite_pf0_1_proc0
// static void setup_link_memwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_pa0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_pa0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p9c_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_p9c_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
// static void setup_link_memwrite_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memwrite_pfc_0_proc0
// static void setup_link_memwrite_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p9a_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_p9a_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pfa_0_1
static void setup_link_memwrite_p9a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_memwrite_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x26000);
// }
// ^ See setup_link_memwrite_pba_0_proc0
// static void setup_link_memwrite_p9a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_memwrite_pba_0_final
// static void setup_link_memwrite_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p9a_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_p9a_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pfa_0_1
// static void setup_link_memwrite_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pb8_1_common
// static void setup_link_memwrite_p9a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
static void setup_link_memwrite_p9a_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
}
// static void setup_link_memwrite_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p98_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_p98_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
// static void setup_link_memwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pb8_0_common
// static void setup_link_memwrite_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x6000);
// }
// ^ See setup_link_memwrite_pb8_0_proc0
// static void setup_link_memwrite_p98_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_memwrite_pba_0_final
// static void setup_link_memwrite_p98_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p98_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_p98_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
// static void setup_link_memwrite_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pb8_1_common
// static void setup_link_memwrite_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_link_memwrite_pb8_1_proc0
// static void setup_link_memwrite_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p98_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p90_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_p90_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_link_memwrite_pb0_0_proc0
// static void setup_link_memwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p90_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_p90_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memwrite_pf0_1_proc0
// static void setup_link_memwrite_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p90_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p80_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_pbc_0_0
// static int test_link_memwrite_p80_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_memwrite_pfc_1_common
// static void setup_link_memwrite_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p80_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
static int test_link_memwrite_p78_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_memwrite_p78_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
static void setup_link_memwrite_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_memwrite_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memwrite_pfc_0_proc0
// static void setup_link_memwrite_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p78_0_final(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal
// static void setup_link_memwrite_p78_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p74_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p74_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pfa_0_1
static void setup_link_memwrite_p74_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_link_memwrite_p74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_link_memwrite_pfa_0_proc0
// static void setup_link_memwrite_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p74_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p74_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p70_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p70_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
static void setup_link_memwrite_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_link_memwrite_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf8_0_proc0
// static void setup_link_memwrite_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p70_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p6_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p6_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_memwrite_p74_0_common
// static void setup_link_memwrite_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf0_0_proc0
// static void setup_link_memwrite_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p6_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p6_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p6_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_memwrite_p78_0_common
// static void setup_link_memwrite_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memwrite_pf0_1_proc0
// static void setup_link_memwrite_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p6_1_final(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal
// static void setup_link_memwrite_p6_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p4_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_memwrite_p78_0_common
// static void setup_link_memwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p4_0_final(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal
// static void setup_link_memwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p38_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p38_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
// static void setup_link_memwrite_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_memwrite_p78_0_common
// static void setup_link_memwrite_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_memwrite_pfc_0_proc0
// static void setup_link_memwrite_p38_0_final(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal
// static void setup_link_memwrite_p38_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p34_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p34_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pfa_0_1
// static void setup_link_memwrite_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_memwrite_p74_0_common
// static void setup_link_memwrite_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf8_0_proc0
// static void setup_link_memwrite_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p34_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p30_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p30_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_link_memwrite_pfc_0_1
// static void setup_link_memwrite_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_memwrite_p70_0_common
// static void setup_link_memwrite_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf8_0_proc0
// static void setup_link_memwrite_p30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p30_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p2_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p2_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_memwrite_p74_0_common
// static void setup_link_memwrite_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_memwrite_pf0_0_proc0
// static void setup_link_memwrite_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_memwrite_pfc_0_final
// static void setup_link_memwrite_p2_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p2_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p2_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_memwrite_p78_0_common
// static void setup_link_memwrite_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_memwrite_pf0_1_proc0
// static void setup_link_memwrite_p2_1_final(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal
// static void setup_link_memwrite_p2_1_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal

/*
 * calls: link memwrite
 */
// static int test_link_memwrite_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_memwrite_p78_0_0
// static int test_link_memwrite_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_link_memwrite_pf0_0_1
// static void setup_link_memwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_memwrite_p78_0_common
// static void setup_link_memwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_memwrite_pfc_0_proc1
// static void setup_link_memwrite_p0_0_final(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal
// static void setup_link_memwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_memwrite_pfc_0_procfinal


/*
 * calls: link mmap
 */
static int test_link_mmap_pf8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_mmap_pf8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_link_mmap_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_mmap_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_mmap_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_mmap_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_link_mmap_pf8_0_procfinal(void) {
  
}

/*
 * calls: link mmap
 */
static int test_link_mmap_pf8_1_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_mmap_pf8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_1
static void setup_link_mmap_pf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_mmap_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pf6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
static int test_link_mmap_pf6_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
static void setup_link_mmap_pf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_mmap_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_mmap_pf6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_mmap_pf6_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_link_mmap_pf6_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: link mmap
 */
// static int test_link_mmap_pf6_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pf6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_0_common
static void setup_link_mmap_pf6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_link_mmap_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pf6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pf6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pf6_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pf6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
static void setup_link_mmap_pf6_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_mmap_pf6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_pf6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pf6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pf6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pf6_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pf6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_pf6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_2_common
// static void setup_link_mmap_pf6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_pf6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pf6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pf6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pf4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
static int test_link_mmap_pf4_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_link_mmap_pf4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
static void setup_link_mmap_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_mmap_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pf4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pf4_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pf4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pf4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf4_0_1
// static void setup_link_mmap_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pf4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pf0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
static int test_link_mmap_pf0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_link_mmap_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pf0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pf0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf0_0_1
// static void setup_link_mmap_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pec_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
static int test_link_mmap_pec_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_link_mmap_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pec_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pec_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pec_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
static int test_link_mmap_pec_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_link_mmap_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pec_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pec_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pec_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pec_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_0_1
// static void setup_link_mmap_pec_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pec_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pec_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pec_2_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pec_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pec_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_1_1
// static void setup_link_mmap_pec_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pec_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pec_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pec_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pec_3_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pe6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
static int test_link_mmap_pe6_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_link_mmap_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_0_common
// static void setup_link_mmap_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pe6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pe6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pe6_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pe6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_0_common
// static void setup_link_mmap_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pe6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pe6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pe6_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pe6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_pe6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_2_common
// static void setup_link_mmap_pe6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_pe6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pe6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pe6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pe6_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pe6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_pe6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_2_common
// static void setup_link_mmap_pe6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_pe6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pe6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pe6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pe5_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
static int test_link_mmap_pe5_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_link_mmap_pe5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pe5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pe5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pe5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pe5_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pe5_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
static int test_link_mmap_pe5_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_link_mmap_pe5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pe5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pe5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pe5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pe5_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pe5_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pe5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_0_1
// static void setup_link_mmap_pe5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pe5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pe5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pe5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pe5_2_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pe5_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pe5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_1_1
// static void setup_link_mmap_pe5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pe5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pe5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pe5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pe5_3_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pe0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
static int test_link_mmap_pe0_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_link_mmap_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pe0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pe0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe0_0_1
// static void setup_link_mmap_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pd8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pd8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_1
// static void setup_link_mmap_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pd8_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pd8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_1
// static void setup_link_mmap_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pd8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pd8_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pd6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pd6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_0_common
// static void setup_link_mmap_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pd6_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pd6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_0_common
// static void setup_link_mmap_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pd6_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pd6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_pd6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_2_common
// static void setup_link_mmap_pd6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pd6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_pd6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pd6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pd6_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pd6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_pd6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_2_common
// static void setup_link_mmap_pd6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pd6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_pd6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pd6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pd4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pd4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf4_0_1
// static void setup_link_mmap_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pd4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pd4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf4_0_1
// static void setup_link_mmap_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pd0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pd0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf0_0_1
// static void setup_link_mmap_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pd0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pd0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf0_0_1
// static void setup_link_mmap_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pcc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pcc_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_0_1
// static void setup_link_mmap_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pcc_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pcc_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_1_1
// static void setup_link_mmap_pcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pcc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pcc_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pcc_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pcc_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_0_1
// static void setup_link_mmap_pcc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pcc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pcc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pcc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pcc_2_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pcc_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pcc_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_1_1
// static void setup_link_mmap_pcc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pcc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pcc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pcc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pcc_3_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pc6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pc6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_0_common
// static void setup_link_mmap_pc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_pc6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pc6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pc6_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pc6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_pc6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_0_common
// static void setup_link_mmap_pc6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pc6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_pc6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pc6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pc6_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pc6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_pc6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_2_common
// static void setup_link_mmap_pc6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pc6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_pc6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pc6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pc6_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pc6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_pc6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf6_2_common
// static void setup_link_mmap_pc6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pc6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_pc6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pc6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pc5_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pc5_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_0_1
// static void setup_link_mmap_pc5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pc5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pc5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pc5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pc5_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pc5_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pc5_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_1_1
// static void setup_link_mmap_pc5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pc5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pc5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pc5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pc5_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pc5_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pc5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_0_1
// static void setup_link_mmap_pc5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pc5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pc5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pc5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pc5_2_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pc5_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pc5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_1_1
// static void setup_link_mmap_pc5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pc5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pc5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_pc5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pc5_3_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pc0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_0
// static int test_link_mmap_pc0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe0_0_1
// static void setup_link_mmap_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_0_common
// static void setup_link_mmap_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pc0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_1_0
// static int test_link_mmap_pc0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe0_0_1
// static void setup_link_mmap_pc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pc0_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
static int test_link_mmap_pb8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_mmap_pb8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_1
// static void setup_link_mmap_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pb6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pb6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
static void setup_link_mmap_pb6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_mmap_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pb6_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pb6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pb6_0_common
// static void setup_link_mmap_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pb4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pb4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf4_0_1
// static void setup_link_mmap_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
static void setup_link_mmap_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_mmap_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pb0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pb0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf0_0_1
// static void setup_link_mmap_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pac_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pac_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_0_1
// static void setup_link_mmap_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pac_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pac_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pac_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_1_1
// static void setup_link_mmap_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pac_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pa6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pa6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pb6_0_common
// static void setup_link_mmap_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pa6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pa6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pa6_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pa6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pb6_0_common
// static void setup_link_mmap_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_pa6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_pa6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pa50_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pa50_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_0_1
// static void setup_link_mmap_pa50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pa50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pb4_0_proc0
// static void setup_link_mmap_pa50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pa50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pa50_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pa50_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pa50_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_1_1
// static void setup_link_mmap_pa50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pa50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pb4_0_proc0
// static void setup_link_mmap_pa50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pa50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pa50_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pa50_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
static int test_link_mmap_pa50_2_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1e27000UL);
  
  return xerrno(r);
}
// static void setup_link_mmap_pa50_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
static void setup_link_mmap_pa50_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_mmap_pa50_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pa50_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pa50_2_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pa50_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
static int test_link_mmap_pa50_3_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
  
  return xerrno(r);
}
// static void setup_link_mmap_pa50_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pa50_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pa50_2_proc0
// static void setup_link_mmap_pa50_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pa50_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pa50_3_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_pa0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_pa0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe0_0_1
// static void setup_link_mmap_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p98_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p98_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_1
// static void setup_link_mmap_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p98_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p96_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p96_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pb6_0_common
// static void setup_link_mmap_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_p96_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p96_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p96_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p96_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_p96_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pb6_0_common
// static void setup_link_mmap_p96_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p96_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_p96_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p96_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p94_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p94_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf4_0_1
// static void setup_link_mmap_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pb4_0_proc0
// static void setup_link_mmap_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p94_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p90_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p90_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf0_0_1
// static void setup_link_mmap_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p90_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p8c_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p8c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_0_1
// static void setup_link_mmap_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p8c_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p8c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_1_1
// static void setup_link_mmap_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p8c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p8c_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p86_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p86_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_p86_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pb6_0_common
// static void setup_link_mmap_p86_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p86_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_p86_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p86_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p86_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p86_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_p86_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pb6_0_common
// static void setup_link_mmap_p86_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p86_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_p86_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p86_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p850_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p850_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_0_1
// static void setup_link_mmap_p850_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_p850_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p850_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pb4_0_proc0
// static void setup_link_mmap_p850_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p850_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p850_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p850_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_1_1
// static void setup_link_mmap_p850_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_p850_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p850_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pb4_0_proc0
// static void setup_link_mmap_p850_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p850_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p850_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p850_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pa50_2_1
// static void setup_link_mmap_p850_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_p850_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p850_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pa50_2_proc0
// static void setup_link_mmap_p850_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p850_2_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p850_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p850_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pa50_3_1
// static void setup_link_mmap_p850_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_p850_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p850_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pa50_2_proc0
// static void setup_link_mmap_p850_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p850_3_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p80_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pb8_0_0
// static int test_link_mmap_p80_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe0_0_1
// static void setup_link_mmap_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mmap_pf8_1_common
// static void setup_link_mmap_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p80_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
static int test_link_mmap_p70_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_mmap_p70_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_1
static void setup_link_mmap_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_mmap_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p70_0_final(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal
// static void setup_link_mmap_p70_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p6c_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p6c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
static void setup_link_mmap_p6c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_mmap_p6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p6c_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p6c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_p6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_mmap_p6c_0_common
// static void setup_link_mmap_p6c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_p6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p6c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p6c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p68_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p68_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf4_0_1
static void setup_link_mmap_p68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_link_mmap_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p68_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p60_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p60_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf0_0_1
// static void setup_link_mmap_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mmap_p70_0_common
// static void setup_link_mmap_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p60_0_final(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal
// static void setup_link_mmap_p60_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p58_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p58_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_0_1
// static void setup_link_mmap_p58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mmap_p70_0_common
// static void setup_link_mmap_p58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p58_0_final(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal
// static void setup_link_mmap_p58_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p58_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p58_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_1_1
// static void setup_link_mmap_p58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mmap_p70_0_common
// static void setup_link_mmap_p58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p58_1_final(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal
// static void setup_link_mmap_p58_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p4c_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p4c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_mmap_p6c_0_common
// static void setup_link_mmap_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p4c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p4c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p4c_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p4c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_p4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_mmap_p6c_0_common
// static void setup_link_mmap_p4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_p4c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p4c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p4c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p4a_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p4a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_0_1
// static void setup_link_mmap_p4a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_mmap_p68_0_common
// static void setup_link_mmap_p4a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_p4a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p4a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p4a_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p4a_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p4a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_1_1
// static void setup_link_mmap_p4a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_mmap_p68_0_common
// static void setup_link_mmap_p4a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_p4a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p4a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p4a_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p40_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p40_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe0_0_1
// static void setup_link_mmap_p40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mmap_p70_0_common
// static void setup_link_mmap_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p40_0_final(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal
// static void setup_link_mmap_p40_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p30_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p30_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf8_0_1
// static void setup_link_mmap_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mmap_p70_0_common
// static void setup_link_mmap_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p30_0_final(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal
// static void setup_link_mmap_p30_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p2c_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p2c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_mmap_p6c_0_common
// static void setup_link_mmap_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_p2c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p2c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p2c_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p2c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf6_0_1
// static void setup_link_mmap_p2c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_mmap_p6c_0_common
// static void setup_link_mmap_p2c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p2c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_p2c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p2c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p28_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p28_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf4_0_1
// static void setup_link_mmap_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_mmap_p68_0_common
// static void setup_link_mmap_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p28_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p20_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p20_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pf0_0_1
// static void setup_link_mmap_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mmap_p70_0_common
// static void setup_link_mmap_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p20_0_final(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal
// static void setup_link_mmap_p20_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p18_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_0_1
// static void setup_link_mmap_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mmap_p70_0_common
// static void setup_link_mmap_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p18_0_final(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal
// static void setup_link_mmap_p18_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p18_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pec_1_1
// static void setup_link_mmap_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mmap_p70_0_common
// static void setup_link_mmap_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p18_1_final(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal
// static void setup_link_mmap_p18_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p0c_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p0c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_mmap_p6c_0_common
// static void setup_link_mmap_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc0
// static void setup_link_mmap_p0c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p0c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p0c_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p0c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe6_0_1
// static void setup_link_mmap_p0c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_mmap_p6c_0_common
// static void setup_link_mmap_p0c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_0_proc1
// static void setup_link_mmap_p0c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_mmap_pf6_1_proc0
// static void setup_link_mmap_p0c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_final
// static void setup_link_mmap_p0c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_mmap_pf6_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p0a_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p0a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_0_1
// static void setup_link_mmap_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_mmap_p68_0_common
// static void setup_link_mmap_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p0a_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p0a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe5_1_1
// static void setup_link_mmap_p0a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_mmap_p68_0_common
// static void setup_link_mmap_p0a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p0a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_mmap_pf4_0_proc0
// static void setup_link_mmap_p0a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mmap_pf8_0_final
// static void setup_link_mmap_p0a_1_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal

/*
 * calls: link mmap
 */
// static int test_link_mmap_p00_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mmap_p70_0_0
// static int test_link_mmap_p00_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_mmap_pe0_0_1
// static void setup_link_mmap_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mmap_p70_0_common
// static void setup_link_mmap_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mmap_pf8_0_proc1
// static void setup_link_mmap_p00_0_final(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal
// static void setup_link_mmap_p00_0_procfinal(void) {
//   
// }
// ^ See setup_link_mmap_pf8_0_procfinal


/*
 * calls: link mprotect
 */
static int test_link_mprotect_pf_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_mprotect_pf_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_mprotect_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_mprotect_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_link_mprotect_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_mprotect_pf_0_final(void) {
  unlink("__i0");
}
static void setup_link_mprotect_pf_0_procfinal(void) {
  
}

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pf_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_0
// static int test_link_mprotect_pf_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_0_common
static void setup_link_mprotect_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_link_mprotect_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pf_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pf_1_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pf_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_0
// static int test_link_mprotect_pf_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_0_common
static void setup_link_mprotect_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_link_mprotect_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pf_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pf_2_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pf_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_0
// static int test_link_mprotect_pf_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_0_common
static void setup_link_mprotect_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_link_mprotect_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pf_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pf_3_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
static int test_link_mprotect_pf_4_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_mprotect_pf_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
static void setup_link_mprotect_pf_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_mprotect_pf_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_mprotect_pf_0_proc0
// static void setup_link_mprotect_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pf_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pf_4_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pf_5_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_4_0
// static int test_link_mprotect_pf_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pf_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_mprotect_pf_2_proc0
// static void setup_link_mprotect_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pf_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pf_5_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pf_6_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_4_0
// static int test_link_mprotect_pf_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pf_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pf_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_mprotect_pf_1_proc0
// static void setup_link_mprotect_pf_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pf_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pf_6_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pf_7_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_4_0
// static int test_link_mprotect_pf_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pf_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pf_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_mprotect_pf_3_proc0
// static void setup_link_mprotect_pf_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pf_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pf_7_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pe_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_0
static int test_link_mprotect_pe_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_link_mprotect_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_0_common
// static void setup_link_mprotect_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pe_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pe_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_4_0
// static int test_link_mprotect_pe_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pe_0_1
// static void setup_link_mprotect_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pe_1_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pd_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_0
// static int test_link_mprotect_pd_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pd_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_0_common
// static void setup_link_mprotect_pd_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_mprotect_pf_0_proc0
// static void setup_link_mprotect_pd_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pd_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pd_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_0
// static int test_link_mprotect_pd_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_0_common
// static void setup_link_mprotect_pd_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_mprotect_pf_1_proc0
// static void setup_link_mprotect_pd_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pd_1_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pd_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_0
// static int test_link_mprotect_pd_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_0_common
// static void setup_link_mprotect_pd_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_mprotect_pf_2_proc0
// static void setup_link_mprotect_pd_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pd_2_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pd_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_0
// static int test_link_mprotect_pd_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pd_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_0_common
// static void setup_link_mprotect_pd_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pd_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_mprotect_pf_3_proc0
// static void setup_link_mprotect_pd_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pd_3_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pd_4_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_4_0
// static int test_link_mprotect_pd_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pd_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pd_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pd_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_mprotect_pf_0_proc0
// static void setup_link_mprotect_pd_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pd_4_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pd_5_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_4_0
// static int test_link_mprotect_pd_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pd_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pd_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pd_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_mprotect_pf_2_proc0
// static void setup_link_mprotect_pd_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pd_5_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pd_6_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_4_0
// static int test_link_mprotect_pd_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pd_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pd_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pd_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_mprotect_pf_1_proc0
// static void setup_link_mprotect_pd_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pd_6_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pd_7_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_4_0
// static int test_link_mprotect_pd_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pd_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pd_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pd_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_mprotect_pf_3_proc0
// static void setup_link_mprotect_pd_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pd_7_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_0
// static int test_link_mprotect_pc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pe_0_1
// static void setup_link_mprotect_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_0_common
// static void setup_link_mprotect_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_4_0
// static int test_link_mprotect_pc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pe_0_1
// static void setup_link_mprotect_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
static int test_link_mprotect_pb0_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_mprotect_pb0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
static void setup_link_mprotect_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_link_mprotect_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pb0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pb0_0_0
// static int test_link_mprotect_pb0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
static void setup_link_mprotect_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_link_mprotect_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pb0_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pb0_0_0
// static int test_link_mprotect_pb0_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_mprotect_pf_1_proc0
// static void setup_link_mprotect_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pb0_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pb0_0_0
// static int test_link_mprotect_pb0_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_mprotect_pf_3_proc0
// static void setup_link_mprotect_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_pa0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pb0_0_0
// static int test_link_mprotect_pa0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pe_0_1
// static void setup_link_mprotect_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p90_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pb0_0_0
// static int test_link_mprotect_p90_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_link_mprotect_pb0_0_proc0
// static void setup_link_mprotect_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_p90_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p90_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pb0_0_0
// static int test_link_mprotect_p90_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_link_mprotect_pb0_1_proc0
// static void setup_link_mprotect_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_p90_1_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p90_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pb0_0_0
// static int test_link_mprotect_p90_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_p90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_mprotect_pf_1_proc0
// static void setup_link_mprotect_p90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_p90_2_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p90_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pb0_0_0
// static int test_link_mprotect_p90_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_p90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_p90_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_mprotect_pf_3_proc0
// static void setup_link_mprotect_p90_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_p90_3_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p80_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pb0_0_0
// static int test_link_mprotect_p80_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pe_0_1
// static void setup_link_mprotect_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_mprotect_pf_4_common
// static void setup_link_mprotect_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_p80_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
static int test_link_mprotect_p6_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_mprotect_p6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
static void setup_link_mprotect_p6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_link_mprotect_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_mprotect_pf_0_proc0
// static void setup_link_mprotect_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_p6_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p6_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_p6_0_0
// static int test_link_mprotect_p6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_mprotect_p6_0_common
// static void setup_link_mprotect_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_mprotect_pf_2_proc0
// static void setup_link_mprotect_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_p6_1_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p6_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_p6_0_0
// static int test_link_mprotect_p6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
static void setup_link_mprotect_p6_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_mprotect_p6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_mprotect_pf_1_proc0
// static void setup_link_mprotect_p6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p6_2_final(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal
// static void setup_link_mprotect_p6_2_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p6_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_p6_0_0
// static int test_link_mprotect_p6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_p6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mprotect_p6_2_common
// static void setup_link_mprotect_p6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_mprotect_pf_3_proc0
// static void setup_link_mprotect_p6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p6_3_final(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal
// static void setup_link_mprotect_p6_3_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p4_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_p6_0_0
// static int test_link_mprotect_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pe_0_1
// static void setup_link_mprotect_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mprotect_p6_2_common
// static void setup_link_mprotect_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p4_0_final(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal
// static void setup_link_mprotect_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p2_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_p6_0_0
// static int test_link_mprotect_p2_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_mprotect_p6_0_common
// static void setup_link_mprotect_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_link_mprotect_pf_0_proc0
// static void setup_link_mprotect_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_p2_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p2_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_p6_0_0
// static int test_link_mprotect_p2_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mprotect_p6_2_common
// static void setup_link_mprotect_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_link_mprotect_pf_1_proc0
// static void setup_link_mprotect_p2_1_final(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal
// static void setup_link_mprotect_p2_1_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p2_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_p6_0_0
// static int test_link_mprotect_p2_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_p2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_mprotect_p6_0_common
// static void setup_link_mprotect_p2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_link_mprotect_pf_2_proc0
// static void setup_link_mprotect_p2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_mprotect_pf_0_final
// static void setup_link_mprotect_p2_2_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p2_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_p6_0_0
// static int test_link_mprotect_p2_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pf_0_1
// static void setup_link_mprotect_p2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mprotect_p6_2_common
// static void setup_link_mprotect_p2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_link_mprotect_pf_3_proc0
// static void setup_link_mprotect_p2_3_final(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal
// static void setup_link_mprotect_p2_3_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal

/*
 * calls: link mprotect
 */
// static int test_link_mprotect_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_p6_0_0
// static int test_link_mprotect_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_link_mprotect_pe_0_1
// static void setup_link_mprotect_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_mprotect_p6_2_common
// static void setup_link_mprotect_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_mprotect_pf_0_proc1
// static void setup_link_mprotect_p0_0_final(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal
// static void setup_link_mprotect_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_mprotect_pf_0_procfinal


/*
 * calls: link munmap
 */
static int test_link_munmap_pe_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_munmap_pe_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_munmap_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_munmap_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_munmap_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_munmap_pe_0_final(void) {
  unlink("__i0");
}
static void setup_link_munmap_pe_0_procfinal(void) {
  
}

/*
 * calls: link munmap
 */
static int test_link_munmap_pe_1_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_munmap_pe_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_munmap_pe_0_1
static void setup_link_munmap_pe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_munmap_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_munmap_pe_0_final
// static void setup_link_munmap_pe_1_procfinal(void) {
//   
// }
// ^ See setup_link_munmap_pe_0_procfinal

/*
 * calls: link munmap
 */
// static int test_link_munmap_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_munmap_pe_0_0
// static int test_link_munmap_pc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_munmap_pe_0_1
// static void setup_link_munmap_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_munmap_pe_0_common
// static void setup_link_munmap_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_munmap_pe_0_final
// static void setup_link_munmap_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_munmap_pe_0_procfinal

/*
 * calls: link munmap
 */
// static int test_link_munmap_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_munmap_pe_1_0
// static int test_link_munmap_pc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_munmap_pe_0_1
// static void setup_link_munmap_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_munmap_pe_1_common
// static void setup_link_munmap_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_munmap_pe_0_final
// static void setup_link_munmap_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_munmap_pe_0_procfinal

/*
 * calls: link munmap
 */
static int test_link_munmap_pa_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_munmap_pa_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_munmap_pe_0_1
// static void setup_link_munmap_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_munmap_pe_1_common
// static void setup_link_munmap_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_munmap_pe_0_final
// static void setup_link_munmap_pa_0_procfinal(void) {
//   
// }
// ^ See setup_link_munmap_pe_0_procfinal

/*
 * calls: link munmap
 */
// static int test_link_munmap_p8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_munmap_pa_0_0
// static int test_link_munmap_p8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_munmap_pe_0_1
// static void setup_link_munmap_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_munmap_pe_1_common
// static void setup_link_munmap_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_munmap_pe_0_final
// static void setup_link_munmap_p8_0_procfinal(void) {
//   
// }
// ^ See setup_link_munmap_pe_0_procfinal

/*
 * calls: link munmap
 */
static int test_link_munmap_p4_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_munmap_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_munmap_pe_0_1
static void setup_link_munmap_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_munmap_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_p4_0_final(void) {
//   
// }
// ^ See setup_link_munmap_pe_0_procfinal
// static void setup_link_munmap_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_munmap_pe_0_procfinal

/*
 * calls: link munmap
 */
// static int test_link_munmap_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_munmap_p4_0_0
// static int test_link_munmap_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_munmap_pe_0_1
// static void setup_link_munmap_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_munmap_p4_0_common
// static void setup_link_munmap_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_munmap_pe_0_proc1
// static void setup_link_munmap_p0_0_final(void) {
//   
// }
// ^ See setup_link_munmap_pe_0_procfinal
// static void setup_link_munmap_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_munmap_pe_0_procfinal


/*
 * calls: link open
 */
static int test_link_open_pf8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_open_pf8_0_1(void) {
  int r = open("__f2", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_link_open_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
static void setup_link_open_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_open_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_open_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_link_open_pf8_0_procfinal(void) {
  
}

/*
 * calls: link open
 */
// static int test_link_open_pf8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
static int test_link_open_pf8_1_1(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_link_open_pf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
static int test_link_open_pf8_2_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_open_pf8_2_1(void) {
  int r = open("__f1", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static void setup_link_open_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_1_common
// static void setup_link_open_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf8_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf8_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pf8_3_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_1_1
static void setup_link_open_pf8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pf8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf8_3_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf70_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
static int test_link_open_pf70_0_1(void) {
  int r = open("__f2", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_link_open_pf70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pf70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf70_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf70_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
static int test_link_open_pf70_1_1(void) {
  int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_link_open_pf70_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pf70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf70_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf70_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pf70_2_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_1_1
// static void setup_link_open_pf70_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_1_common
// static void setup_link_open_pf70_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf70_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf70_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf70_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf70_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
static int test_link_open_pf70_3_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_link_open_pf70_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_pf70_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf70_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf70_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf70_3_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf50_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pf50_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_0_1
// static void setup_link_open_pf50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_0_common
// static void setup_link_open_pf50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf50_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf50_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pf50_1_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_1_1
// static void setup_link_open_pf50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_1_common
// static void setup_link_open_pf50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf50_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf50_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pf50_2_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_1_1
// static void setup_link_open_pf50_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf70_1_common
// static void setup_link_open_pf50_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf50_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf50_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf50_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf50_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pf50_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_3_1
static void setup_link_open_pf50_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pf50_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf50_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf50_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf50_3_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf3_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
static int test_link_open_pf3_0_1(void) {
  int r = open("__f2", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_link_open_pf3_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pf3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf3_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf3_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
static int test_link_open_pf3_1_1(void) {
  int r = open("__f1", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_link_open_pf3_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pf3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf3_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf3_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pf3_2_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_1_1
// static void setup_link_open_pf3_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_1_common
// static void setup_link_open_pf3_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf3_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf3_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf3_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf3_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
static int test_link_open_pf3_3_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_link_open_pf3_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pf3_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf3_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf3_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf3_3_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf1_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pf1_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
// static void setup_link_open_pf1_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_0_common
// static void setup_link_open_pf1_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf1_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf1_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf1_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf1_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pf1_1_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_1_1
// static void setup_link_open_pf1_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_1_common
// static void setup_link_open_pf1_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf1_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf1_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf1_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf1_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pf1_2_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_1_1
// static void setup_link_open_pf1_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_1_common
// static void setup_link_open_pf1_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf1_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf1_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf1_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pf1_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pf1_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_3_1
// static void setup_link_open_pf1_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_3_common
// static void setup_link_open_pf1_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf1_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pf1_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pf1_3_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pee_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pee_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_0_1
static void setup_link_open_pee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
static void setup_link_open_pee_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_link_open_pee_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pee_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pee_1_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_0_1
// static void setup_link_open_pee_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_1_common
// static void setup_link_open_pee_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pee_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pee_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pee_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pee_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pee_2_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_1_1
// static void setup_link_open_pee_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_pee_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pee_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pee_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pee_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pea_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pea_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_0_1
// static void setup_link_open_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pee_0_common
// static void setup_link_open_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pea_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_open_pee_0_final
// static void setup_link_open_pea_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pea_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pea_1_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_0_1
static void setup_link_open_pea_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pea_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pea_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pea_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pea_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pea_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pea_2_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_1_1
static void setup_link_open_pea_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pea_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pea_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pea_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pea_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pe6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pe6_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
static void setup_link_open_pe6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe6_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_open_pee_0_final
// static void setup_link_open_pe6_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pe6_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pe6_1_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
// static void setup_link_open_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pea_1_common
// static void setup_link_open_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pe6_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pe6_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pe6_2_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_1_1
// static void setup_link_open_pe6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_pe6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pe6_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pe2_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pe2_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
// static void setup_link_open_pe2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pee_0_common
// static void setup_link_open_pe2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe2_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_open_pee_0_final
// static void setup_link_open_pe2_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pe2_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pe2_1_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
// static void setup_link_open_pe2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pea_1_common
// static void setup_link_open_pe2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pe2_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pe2_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pe2_2_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_1_1
// static void setup_link_open_pe2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pea_2_common
// static void setup_link_open_pe2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pe2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pe2_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pde_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
static int test_link_open_pde_0_1(void) {
  int r = open("__f2", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_link_open_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf70_0_common
// static void setup_link_open_pde_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pde_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pde_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pde_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
static int test_link_open_pde_1_1(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_link_open_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pea_1_common
// static void setup_link_open_pde_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pde_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pde_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pde_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
static int test_link_open_pde_2_1(void) {
  int r = open("__f1", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_link_open_pde_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf70_1_common
// static void setup_link_open_pde_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pde_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pde_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pde_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pde_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pde_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_1_1
// static void setup_link_open_pde_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf50_3_common
// static void setup_link_open_pde_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pde_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pde_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pde_3_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pda_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pda_0_1(void) {
//   int r = open("__f2", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_0_1
// static void setup_link_open_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_0_common
// static void setup_link_open_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pda_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pda_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pda_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pda_1_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_2_1
// static void setup_link_open_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf70_1_common
// static void setup_link_open_pda_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pda_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pda_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pda_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pda_2_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_2_1
// static void setup_link_open_pda_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pea_1_common
// static void setup_link_open_pda_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pda_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pda_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pda_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pda_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pda_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_1_1
// static void setup_link_open_pda_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pea_2_common
// static void setup_link_open_pda_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pda_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pda_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pda_3_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pd6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
static int test_link_open_pd6_0_1(void) {
  int r = open("__f2", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_link_open_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_0_common
// static void setup_link_open_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pd6_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pd6_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
static int test_link_open_pd6_1_1(void) {
  int r = open("__f1", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_link_open_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_1_common
// static void setup_link_open_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pd6_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pd6_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pd6_2_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_1_1
// static void setup_link_open_pd6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_1_common
// static void setup_link_open_pd6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pd6_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pd6_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
static int test_link_open_pd6_3_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_link_open_pd6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_3_common
// static void setup_link_open_pd6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pd6_3_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pd2_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pd2_0_1(void) {
//   int r = open("__f2", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_0_1
// static void setup_link_open_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_0_common
// static void setup_link_open_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pd2_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pd2_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
// static int test_link_open_pd2_1_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_1_1
// static void setup_link_open_pd2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_1_common
// static void setup_link_open_pd2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pd2_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pd2_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pd2_2_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_1_1
// static void setup_link_open_pd2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_1_common
// static void setup_link_open_pd2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pd2_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pd2_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
// static int test_link_open_pd2_3_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_3_1
// static void setup_link_open_pd2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf3_3_common
// static void setup_link_open_pd2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pd2_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pd2_3_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_0
static int test_link_open_pc_0_1(void) {
  int r = open("__f2", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_link_open_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_1_common
// static void setup_link_open_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_0
static int test_link_open_pc_1_1(void) {
  int r = open("__f1", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_link_open_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
static int test_link_open_pbc_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_open_pbc_0_1(void) {
//   int r = open("__f2", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_0_1
static void setup_link_open_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pbc_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pbc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_1_1
// static void setup_link_open_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_pbc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pb78_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pb78_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_0_1
static void setup_link_open_pb78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pb78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb78_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pb78_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pb78_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pb78_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_3_1
static void setup_link_open_pb78_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pb78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb78_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pb78_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pb58_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pb58_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_0_1
// static void setup_link_open_pb58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pb78_0_common
// static void setup_link_open_pb58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pb58_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pb58_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pb58_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_3_1
// static void setup_link_open_pb58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pb78_1_common
// static void setup_link_open_pb58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb58_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pb58_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pb38_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pb38_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
static void setup_link_open_pb38_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pb38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb38_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_open_pee_0_final
// static void setup_link_open_pb38_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pb38_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pb38_1_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
// static void setup_link_open_pb38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pbc_0_common
// static void setup_link_open_pb38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb38_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pb38_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pb38_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pb38_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_3_1
// static void setup_link_open_pb38_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_pb38_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb38_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb38_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pb38_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pb18_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pb18_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
// static void setup_link_open_pb18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pb38_0_common
// static void setup_link_open_pb18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb18_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_open_pee_0_final
// static void setup_link_open_pb18_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pb18_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pb18_1_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
// static void setup_link_open_pb18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pbc_0_common
// static void setup_link_open_pb18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pb18_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pb18_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pb18_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_3_1
// static void setup_link_open_pb18_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_pb18_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb18_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pb18_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pb18_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pae_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pae_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_0_1
static void setup_link_open_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_pae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pae_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_paa_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_paa_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_0_1
// static void setup_link_open_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pae_0_common
// static void setup_link_open_paa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_paa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_paa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_paa_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pa6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pa6_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
// static void setup_link_open_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pae_0_common
// static void setup_link_open_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_pa2_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_pa2_0_1(void) {
//   int r = open("__f2", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_0_1
// static void setup_link_open_pa2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pae_0_common
// static void setup_link_open_pa2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pa2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_pa2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_pa2_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p9f0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_p9f0_0_1(void) {
//   int r = open("__f2", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_0_1
// static void setup_link_open_p9f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pb78_0_common
// static void setup_link_open_p9f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p9f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p9f0_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p9f0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_p9f0_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_1_1
// static void setup_link_open_p9f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_p9f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p9f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p9f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p9f0_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p9b0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_p9b0_0_1(void) {
//   int r = open("__f2", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_0_1
// static void setup_link_open_p9b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pb78_0_common
// static void setup_link_open_p9b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p9b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p9b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p9b0_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p9b0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_p9b0_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_1_1
// static void setup_link_open_p9b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_p9b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p9b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p9b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p9b0_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p970_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_p970_0_1(void) {
//   int r = open("__f2", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_0_1
// static void setup_link_open_p970_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pb38_0_common
// static void setup_link_open_p970_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p970_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p970_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_open_pee_0_final
// static void setup_link_open_p970_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p970_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_p970_1_1(void) {
//   int r = open("__f2", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_0_1
// static void setup_link_open_p970_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pbc_0_common
// static void setup_link_open_p970_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p970_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p970_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p970_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p970_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_p970_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_3_1
// static void setup_link_open_p970_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_p970_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p970_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p970_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p970_2_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p930_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_p930_0_1(void) {
//   int r = open("__f2", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_0_1
// static void setup_link_open_p930_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pb38_0_common
// static void setup_link_open_p930_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p930_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p930_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_open_pee_0_final
// static void setup_link_open_p930_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p930_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_p930_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_3_1
// static void setup_link_open_p930_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_p930_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p930_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p930_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p930_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p80_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_open_pbc_0_0
// static int test_link_open_p80_0_1(void) {
//   int r = open("__f2", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_pc_0_1
// static void setup_link_open_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_pf8_3_common
// static void setup_link_open_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p80_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
static int test_link_open_p7_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_open_p7_0_1(void) {
//   int r = open("__f1", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_open_pf8_2_1
static void setup_link_open_p7_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p7_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p6e_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p6e_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_1_1
static void setup_link_open_p6e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_p6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p6e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p6e_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p6a_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p6a_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_1_1
// static void setup_link_open_p6a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_p7_0_common
// static void setup_link_open_p6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p6a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p6a_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p66_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p66_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_1_1
static void setup_link_open_p66_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_p66_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p66_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p66_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p66_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p62_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p62_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_1_1
// static void setup_link_open_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_p66_0_common
// static void setup_link_open_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p62_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p5a_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p5a_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_1_1
static void setup_link_open_p5a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_open_p5a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p5a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p5a_0_final(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal
// static void setup_link_open_p5a_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p52_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p52_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf70_1_1
// static void setup_link_open_p52_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_open_p5a_0_common
// static void setup_link_open_p52_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p52_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p52_0_final(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal
// static void setup_link_open_p52_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p4a_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p4a_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_1_1
// static void setup_link_open_p4a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_open_p5a_0_common
// static void setup_link_open_p4a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p4a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p4a_0_final(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal
// static void setup_link_open_p4a_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p42_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p42_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pf3_1_1
// static void setup_link_open_p42_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_open_p5a_0_common
// static void setup_link_open_p42_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p42_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p42_0_final(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal
// static void setup_link_open_p42_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p3c_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p3c_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_2_1
// static void setup_link_open_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_p6e_0_common
// static void setup_link_open_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p3c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p3c_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p34_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p34_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pde_2_1
static void setup_link_open_p34_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_open_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p34_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p2c_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p2c_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_1_1
// static void setup_link_open_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_p66_0_common
// static void setup_link_open_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p24_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p24_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_link_open_pd6_1_1
// static void setup_link_open_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_open_p66_0_common
// static void setup_link_open_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_open_pf8_0_final
// static void setup_link_open_p24_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
// static int test_link_open_p0_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_pc_1_1
// static void setup_link_open_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_open_p5a_0_common
// static void setup_link_open_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p0_0_final(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal
// static void setup_link_open_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal

/*
 * calls: link open
 */
// static int test_link_open_p0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_open_p7_0_0
static int test_link_open_p0_1_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_link_open_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_open_p5a_0_common
// static void setup_link_open_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_open_pf8_0_proc1
// static void setup_link_open_p0_1_final(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal
// static void setup_link_open_p0_1_procfinal(void) {
//   
// }
// ^ See setup_link_open_pf8_0_procfinal


/*
 * calls: link pipe
 */
static int test_link_pipe_pf8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_pipe_pf8_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_pipe_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_pipe_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_pipe_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_pipe_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_link_pipe_pf8_0_procfinal(void) {
  
}

/*
 * calls: link pipe
 */
static int test_link_pipe_pf8_1_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_pipe_pf8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pipe_pf8_0_1
static void setup_link_pipe_pf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pipe_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pipe_pf8_0_final
// static void setup_link_pipe_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_link_pipe_pf8_0_procfinal

/*
 * calls: link pipe
 */
// static int test_link_pipe_pd8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pipe_pf8_0_0
// static int test_link_pipe_pd8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pipe_pf8_0_1
// static void setup_link_pipe_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pipe_pf8_0_common
// static void setup_link_pipe_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pipe_pf8_0_final
// static void setup_link_pipe_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_link_pipe_pf8_0_procfinal

/*
 * calls: link pipe
 */
// static int test_link_pipe_pd8_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pipe_pf8_1_0
// static int test_link_pipe_pd8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pipe_pf8_0_1
// static void setup_link_pipe_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pipe_pf8_1_common
// static void setup_link_pipe_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_pd8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pipe_pf8_0_final
// static void setup_link_pipe_pd8_1_procfinal(void) {
//   
// }
// ^ See setup_link_pipe_pf8_0_procfinal

/*
 * calls: link pipe
 */
static int test_link_pipe_pb8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_pipe_pb8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pipe_pf8_0_1
static void setup_link_pipe_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pipe_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pipe_pf8_0_final
// static void setup_link_pipe_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_link_pipe_pf8_0_procfinal

/*
 * calls: link pipe
 */
// static int test_link_pipe_p98_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pipe_pb8_0_0
// static int test_link_pipe_p98_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pipe_pf8_0_1
// static void setup_link_pipe_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pipe_pb8_0_common
// static void setup_link_pipe_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pipe_pf8_0_final
// static void setup_link_pipe_p98_0_procfinal(void) {
//   
// }
// ^ See setup_link_pipe_pf8_0_procfinal

/*
 * calls: link pipe
 */
static int test_link_pipe_p70_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_pipe_p70_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pipe_pf8_0_1
static void setup_link_pipe_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_pipe_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_p70_0_final(void) {
//   
// }
// ^ See setup_link_pipe_pf8_0_procfinal
// static void setup_link_pipe_p70_0_procfinal(void) {
//   
// }
// ^ See setup_link_pipe_pf8_0_procfinal

/*
 * calls: link pipe
 */
// static int test_link_pipe_p30_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pipe_p70_0_0
// static int test_link_pipe_p30_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pipe_pf8_0_1
// static void setup_link_pipe_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_pipe_p70_0_common
// static void setup_link_pipe_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pipe_pf8_0_proc1
// static void setup_link_pipe_p30_0_final(void) {
//   
// }
// ^ See setup_link_pipe_pf8_0_procfinal
// static void setup_link_pipe_p30_0_procfinal(void) {
//   
// }
// ^ See setup_link_pipe_pf8_0_procfinal


/*
 * calls: link pread
 */
static int test_link_pread_pf8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_pread_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_link_pread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_pread_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_pread_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_pread_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_link_pread_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: link pread
 */
// static int test_link_pread_pf8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
// static int test_link_pread_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf8_0_common
static void setup_link_pread_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_link_pread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
static int test_link_pread_pf8_2_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_pread_pf8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
static void setup_link_pread_pf8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pread_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc0
// static void setup_link_pread_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pf8_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pf8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf8_2_common
// static void setup_link_pread_pf8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_1_proc0
// static void setup_link_pread_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pf4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
static int test_link_pread_pf4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_link_pread_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_pread_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_link_pread_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_pread_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_link_pread_pf4_0_procfinal(void) {
  
}

/*
 * calls: link pread
 */
// static int test_link_pread_pf4_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
// static int test_link_pread_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_0_common
static void setup_link_pread_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pread_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pf4_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pf4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
static void setup_link_pread_pf4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pread_pf4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pf4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pf4_2_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pf4_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pf4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_2_common
// static void setup_link_pread_pf4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pf4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pf4_3_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pf0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
static int test_link_pread_pf0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_link_pread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_pread_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pf0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
static void setup_link_pread_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pread_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pf0_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
// static int test_link_pread_pf0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf0_0_common
// static void setup_link_pread_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pf0_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pf0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf0_1_common
// static void setup_link_pread_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pe_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
static int test_link_pread_pe_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_link_pread_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_0_common
// static void setup_link_pread_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pe_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pe_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pe_0_1
// static void setup_link_pread_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_2_common
// static void setup_link_pread_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pe_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
// static int test_link_pread_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf8_0_common
// static void setup_link_pread_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc0
// static void setup_link_pread_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
// static int test_link_pread_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf8_0_common
// static void setup_link_pread_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_1_proc0
// static void setup_link_pread_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd8_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pd8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf8_2_common
// static void setup_link_pread_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc0
// static void setup_link_pread_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd8_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pd8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf8_2_common
// static void setup_link_pread_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_1_proc0
// static void setup_link_pread_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
// static int test_link_pread_pd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_0_common
// static void setup_link_pread_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_2_common
// static void setup_link_pread_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd4_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
// static int test_link_pread_pd4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_0_common
// static void setup_link_pread_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pd4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_pd4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pd4_2_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd4_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pd4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_2_common
// static void setup_link_pread_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_pd4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pd4_3_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
// static int test_link_pread_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf0_0_common
// static void setup_link_pread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf0_1_common
// static void setup_link_pread_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd0_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
// static int test_link_pread_pd0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf0_0_common
// static void setup_link_pread_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_pd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pd0_2_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pd0_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pd0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf0_1_common
// static void setup_link_pread_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_pd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pd0_3_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_0_0
// static int test_link_pread_pc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pe_0_1
// static void setup_link_pread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_0_common
// static void setup_link_pread_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pread_pf8_2_0
// static int test_link_pread_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pe_0_1
// static void setup_link_pread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_2_common
// static void setup_link_pread_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
static int test_link_pread_pb8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_pread_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
static void setup_link_pread_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pread_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc0
// static void setup_link_pread_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pb8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pb8_0_common
// static void setup_link_pread_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_1_proc0
// static void setup_link_pread_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pb4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_pb4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
static void setup_link_pread_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pread_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
static void setup_link_pread_pb4_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_link_pread_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pb4_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
static int test_link_pread_pb4_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 5087232);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_link_pread_pb4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_pread_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pread_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pb4_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_pread_pb4_0_final
// static void setup_link_pread_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pb4_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_pb4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_2_common
// static void setup_link_pread_pb4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pb4_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_pb4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5087232);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pb4_1_1
static void setup_link_pread_pb4_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pread_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5087232, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pb4_1_proc0
// static void setup_link_pread_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pb0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
static void setup_link_pread_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_pread_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pb0_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_pread_pb4_0_final
// static void setup_link_pread_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pb0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
static int test_link_pread_pb0_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 8192);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_link_pread_pb0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pread_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pb0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_pread_pb4_0_final
// static void setup_link_pread_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pb0_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_pb0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf0_1_common
static void setup_link_pread_pb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pread_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pb0_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
static int test_link_pread_pb0_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_link_pread_pb0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_pread_pb0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pread_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_pa0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pe_0_1
// static void setup_link_pread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_2_common
// static void setup_link_pread_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p98_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pb8_0_common
// static void setup_link_pread_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc0
// static void setup_link_pread_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p98_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p98_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pb8_0_common
// static void setup_link_pread_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_1_proc0
// static void setup_link_pread_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p94_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p94_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pb4_0_common
// static void setup_link_pread_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_p94_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_pread_pb4_0_final
// static void setup_link_pread_p94_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p94_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p94_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_2_common
// static void setup_link_pread_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p94_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p94_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p94_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5087232);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pb4_1_1
// static void setup_link_pread_p94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pb4_1_common
// static void setup_link_pread_p94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5087232, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pb4_1_proc0
// static void setup_link_pread_p94_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_pread_pb4_0_final
// static void setup_link_pread_p94_2_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p94_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p94_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5087232);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pb4_1_1
// static void setup_link_pread_p94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pb4_3_common
// static void setup_link_pread_p94_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5087232, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pb4_1_proc0
// static void setup_link_pread_p94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p94_3_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p90_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pb0_0_common
// static void setup_link_pread_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
static void setup_link_pread_p90_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pread_p90_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_pread_pb4_0_final
// static void setup_link_pread_p90_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p90_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pb0_1_1
// static void setup_link_pread_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pb0_1_common
// static void setup_link_pread_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_p90_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_link_pread_pb4_0_final
// static void setup_link_pread_p90_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p90_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p90_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf0_1_common
// static void setup_link_pread_p90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
static void setup_link_pread_p90_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pread_p90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p90_2_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p90_3_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p90_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pb0_3_1
// static void setup_link_pread_p90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pb0_3_common
// static void setup_link_pread_p90_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pb0_3_proc0
// static void setup_link_pread_p90_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p90_3_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p80_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pread_pb8_0_0
// static int test_link_pread_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pe_0_1
// static void setup_link_pread_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pread_pf4_2_common
// static void setup_link_pread_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p80_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
static int test_link_pread_p7_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_pread_p7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
static void setup_link_pread_p7_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_pread_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc0
// static void setup_link_pread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p7_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_pread_p7_0_common
// static void setup_link_pread_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_1_proc0
// static void setup_link_pread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p68_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
static void setup_link_pread_p68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_link_pread_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p68_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_pread_p68_0_common
// static void setup_link_pread_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p60_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
static void setup_link_pread_p60_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_link_pread_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p60_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p60_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_pread_p60_0_common
// static void setup_link_pread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p4_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pe_0_1
static void setup_link_pread_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_pread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p4_0_final(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal
// static void setup_link_pread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p3_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p3_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_pread_p7_0_common
// static void setup_link_pread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc0
// static void setup_link_pread_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p3_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p3_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf8_0_1
// static void setup_link_pread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_pread_p7_0_common
// static void setup_link_pread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_0_proc1
// static void setup_link_pread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pread_pf8_1_proc0
// static void setup_link_pread_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_final
// static void setup_link_pread_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pread_pf8_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p28_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_pread_p68_0_common
// static void setup_link_pread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p28_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p28_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf4_0_1
// static void setup_link_pread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_pread_p68_0_common
// static void setup_link_pread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p20_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_pread_p60_0_common
// static void setup_link_pread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_0_proc0
// static void setup_link_pread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p20_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p20_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pf0_0_1
// static void setup_link_pread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_pread_p60_0_common
// static void setup_link_pread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pread_pf4_1_proc0
// static void setup_link_pread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pread_pf4_0_final
// static void setup_link_pread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal

/*
 * calls: link pread
 */
// static int test_link_pread_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pread_p7_0_0
// static int test_link_pread_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_pread_pe_0_1
// static void setup_link_pread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_pread_p4_0_common
// static void setup_link_pread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pread_pf4_0_proc1
// static void setup_link_pread_p0_0_final(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal
// static void setup_link_pread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_pread_pf4_0_procfinal


/*
 * calls: link pwrite
 */
static int test_link_pwrite_pf8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_pwrite_pf8_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_link_pwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_pwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_pwrite_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_pwrite_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_link_pwrite_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pf8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pf8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf8_0_common
static void setup_link_pwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_link_pwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
static int test_link_pwrite_pf8_2_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_pwrite_pf8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
static void setup_link_pwrite_pf8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pwrite_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc0
// static void setup_link_pwrite_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pf8_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pf8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf8_2_common
// static void setup_link_pwrite_pf8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_1_proc0
// static void setup_link_pwrite_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pf4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
static int test_link_pwrite_pf4_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_link_pwrite_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_pwrite_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_link_pwrite_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_pwrite_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_link_pwrite_pf4_0_procfinal(void) {
  
}

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pf4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pf4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
static void setup_link_pwrite_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_pwrite_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pwrite_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pf4_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pf4_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_0_common
static void setup_link_pwrite_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pwrite_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pf4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pf4_2_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pf4_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pf4_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_1_common
// static void setup_link_pwrite_pf4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pf4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pf4_3_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pf0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pf0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
static void setup_link_pwrite_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_pwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pf0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pf0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf0_0_common
// static void setup_link_pwrite_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pf0_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pf0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
static void setup_link_pwrite_pf0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pwrite_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_0_proc0
// static void setup_link_pwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pf0_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pf0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf0_2_common
// static void setup_link_pwrite_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pe_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
static int test_link_pwrite_pe_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_link_pwrite_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_0_common
// static void setup_link_pwrite_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pe_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pe_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pe_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pe_0_1
// static void setup_link_pwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_1_common
// static void setup_link_pwrite_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pe_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pd8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf8_0_common
// static void setup_link_pwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc0
// static void setup_link_pwrite_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pd8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf8_0_common
// static void setup_link_pwrite_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_1_proc0
// static void setup_link_pwrite_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd8_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pd8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf8_2_common
// static void setup_link_pwrite_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc0
// static void setup_link_pwrite_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd8_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pd8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf8_2_common
// static void setup_link_pwrite_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_1_proc0
// static void setup_link_pwrite_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pd4_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_0_common
// static void setup_link_pwrite_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
static void setup_link_pwrite_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pwrite_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pd4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_1_common
// static void setup_link_pwrite_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_1_proc0
// static void setup_link_pwrite_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd4_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pd4_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_0_common
// static void setup_link_pwrite_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pd4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_pd4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pd4_2_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd4_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pd4_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_1_common
// static void setup_link_pwrite_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_pd4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pd4_3_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pd0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf0_0_common
// static void setup_link_pwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
static void setup_link_pwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pwrite_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pd0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf0_0_common
// static void setup_link_pwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd0_2_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pd0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf0_2_common
// static void setup_link_pwrite_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pd4_0_proc1
// static void setup_link_pwrite_pd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pd0_2_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pd0_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pd0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf0_2_common
// static void setup_link_pwrite_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_pd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pd0_3_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_0
// static int test_link_pwrite_pc_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pe_0_1
// static void setup_link_pwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_0_common
// static void setup_link_pwrite_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_2_0
// static int test_link_pwrite_pc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pe_0_1
// static void setup_link_pwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_1_common
// static void setup_link_pwrite_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
static int test_link_pwrite_pb8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_pwrite_pb8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
static void setup_link_pwrite_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pwrite_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc0
// static void setup_link_pwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pb8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_pb8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pb8_0_common
// static void setup_link_pwrite_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_1_proc0
// static void setup_link_pwrite_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pb4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
static int test_link_pwrite_pb4_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_link_pwrite_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_pwrite_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_1_proc0
// static void setup_link_pwrite_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pb4_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
static int test_link_pwrite_pb4_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_link_pwrite_pb4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_pwrite_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pwrite_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pb0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_pb0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf0_2_common
// static void setup_link_pwrite_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_0_proc0
// static void setup_link_pwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pb0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_pb0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb4_0_1
// static void setup_link_pwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pb4_1_common
static void setup_link_pwrite_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_pwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_pa0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_pa0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pe_0_1
// static void setup_link_pwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_1_common
// static void setup_link_pwrite_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p98_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_p98_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pb8_0_common
// static void setup_link_pwrite_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc0
// static void setup_link_pwrite_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p98_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_p98_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pb8_0_common
// static void setup_link_pwrite_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_1_proc0
// static void setup_link_pwrite_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p94_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_p94_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb4_0_1
// static void setup_link_pwrite_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pb4_0_common
// static void setup_link_pwrite_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_1_proc0
// static void setup_link_pwrite_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p94_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p94_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_p94_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb4_1_1
// static void setup_link_pwrite_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pb4_1_common
// static void setup_link_pwrite_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pb4_1_proc0
// static void setup_link_pwrite_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p94_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p90_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_p90_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf0_2_common
// static void setup_link_pwrite_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pd4_0_proc1
// static void setup_link_pwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p90_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_p90_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb4_0_1
// static void setup_link_pwrite_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pb4_1_common
// static void setup_link_pwrite_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pb0_1_proc0
// static void setup_link_pwrite_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p90_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p80_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pb8_0_0
// static int test_link_pwrite_p80_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pe_0_1
// static void setup_link_pwrite_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_pwrite_pf4_1_common
// static void setup_link_pwrite_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p80_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
static int test_link_pwrite_p7_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_pwrite_p7_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
static void setup_link_pwrite_p7_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_pwrite_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc0
// static void setup_link_pwrite_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p7_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p7_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_pwrite_p7_0_common
// static void setup_link_pwrite_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_1_proc0
// static void setup_link_pwrite_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p68_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p68_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
static void setup_link_pwrite_p68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_link_pwrite_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_0_proc0
// static void setup_link_pwrite_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p68_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p68_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p68_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_pwrite_p68_0_common
// static void setup_link_pwrite_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p68_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p60_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p60_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
static void setup_link_pwrite_p60_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_link_pwrite_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf0_0_proc0
// static void setup_link_pwrite_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p60_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p60_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p60_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_pwrite_p60_0_common
// static void setup_link_pwrite_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p60_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p4_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p4_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pe_0_1
static void setup_link_pwrite_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_pwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p4_0_final(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal
// static void setup_link_pwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p3_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p3_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_pwrite_p7_0_common
// static void setup_link_pwrite_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc0
// static void setup_link_pwrite_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p3_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p3_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf8_0_1
// static void setup_link_pwrite_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_pwrite_p7_0_common
// static void setup_link_pwrite_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_0_proc1
// static void setup_link_pwrite_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_pwrite_pf8_1_proc0
// static void setup_link_pwrite_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_final
// static void setup_link_pwrite_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_pwrite_pf8_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p28_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p28_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_pwrite_p68_0_common
// static void setup_link_pwrite_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pd4_0_proc1
// static void setup_link_pwrite_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p28_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p28_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p28_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_pwrite_p68_0_common
// static void setup_link_pwrite_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p28_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p20_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p20_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_pwrite_p60_0_common
// static void setup_link_pwrite_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pd0_0_proc1
// static void setup_link_pwrite_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p20_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p20_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p20_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pf4_0_1
// static void setup_link_pwrite_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_pwrite_p60_0_common
// static void setup_link_pwrite_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_pwrite_pf4_2_proc0
// static void setup_link_pwrite_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_pwrite_pf4_0_final
// static void setup_link_pwrite_p20_1_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal

/*
 * calls: link pwrite
 */
// static int test_link_pwrite_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_p7_0_0
// static int test_link_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_link_pwrite_pe_0_1
// static void setup_link_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_pwrite_p4_0_common
// static void setup_link_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_pwrite_pf4_0_proc1
// static void setup_link_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal
// static void setup_link_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_pwrite_pf4_0_procfinal


/*
 * calls: link read
 */
static int test_link_read_pfc_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_read_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_link_read_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_read_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_read_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_read_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_link_read_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: link read
 */
static int test_link_read_pfc_1_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_read_pfc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
static void setup_link_read_pfc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pfc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc0
// static void setup_link_read_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pfb_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
static int test_link_read_pfb_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_link_read_pfb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_read_pfb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_link_read_pfb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pfb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pfb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pfb_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pfb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfb_0_1
static void setup_link_read_pfb_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pfb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_pfb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pfb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pfb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pfa_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
static int test_link_read_pfa_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_link_read_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_read_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_link_read_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_link_read_pfa_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pfa_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pfa_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pfa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
static void setup_link_read_pfa_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pfa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc0
// static void setup_link_read_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc1
// static void setup_link_read_pfa_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pfa_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pf8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
static int test_link_read_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_link_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pf8_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
static void setup_link_read_pf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pf4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
// static int test_link_read_pf4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
static void setup_link_read_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_read_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_link_read_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_read_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_link_read_pf4_0_procfinal(void) {
  
}

/*
 * calls: link read
 */
// static int test_link_read_pf4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
static void setup_link_read_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pf4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf4_0_proc0
// static void setup_link_read_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pf0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
// static int test_link_read_pf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
static void setup_link_read_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_read_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pf0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
static void setup_link_read_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf0_0_proc0
// static void setup_link_read_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pe_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
// static int test_link_read_pe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf4_0_common
// static void setup_link_read_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pe_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pe_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf4_1_common
// static void setup_link_read_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pe_1_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pdc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
// static int test_link_read_pdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pfc_0_common
// static void setup_link_read_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc0
// static void setup_link_read_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pdc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pdc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pfc_1_common
// static void setup_link_read_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc0
// static void setup_link_read_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pdb_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
// static int test_link_read_pdb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfb_0_1
// static void setup_link_read_pdb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pfb_0_common
// static void setup_link_read_pdb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pdb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_pdb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pdb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pdb_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pdb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfb_0_1
// static void setup_link_read_pdb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pfb_1_common
// static void setup_link_read_pdb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pdb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_pdb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pdb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pda_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
// static int test_link_read_pda_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
// static void setup_link_read_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pfb_0_common
// static void setup_link_read_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc1
// static void setup_link_read_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc0
// static void setup_link_read_pda_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pda_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pda_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pda_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
// static void setup_link_read_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pfb_1_common
// static void setup_link_read_pda_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc1
// static void setup_link_read_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc0
// static void setup_link_read_pda_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pda_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pd8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
// static int test_link_read_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
// static void setup_link_read_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf8_0_common
// static void setup_link_read_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pd8_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
// static void setup_link_read_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf8_1_common
// static void setup_link_read_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pd4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
// static int test_link_read_pd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
// static void setup_link_read_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf4_0_common
// static void setup_link_read_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf4_0_proc0
// static void setup_link_read_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pd4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
// static void setup_link_read_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf4_1_common
// static void setup_link_read_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf4_0_proc0
// static void setup_link_read_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pd0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
// static int test_link_read_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
// static void setup_link_read_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf0_0_common
// static void setup_link_read_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf0_0_proc0
// static void setup_link_read_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pd0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
// static void setup_link_read_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf0_1_common
// static void setup_link_read_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf0_0_proc0
// static void setup_link_read_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_0_0
// static int test_link_read_pc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf4_0_common
// static void setup_link_read_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_read_pfc_1_0
// static int test_link_read_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf4_1_common
// static void setup_link_read_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
static int test_link_read_pbc_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_read_pbc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
static void setup_link_read_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc0
// static void setup_link_read_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pbb0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_pbb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfb_0_1
static void setup_link_read_pbb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pbb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_pbb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pbb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pbb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pba0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_pba0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
static void setup_link_read_pba0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pba0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc0
// static void setup_link_read_pba0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc1
// static void setup_link_read_pba0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pba0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pb8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
static void setup_link_read_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_read_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pb4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_pb4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
static void setup_link_read_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_read_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_read_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
static void setup_link_read_pb4_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_link_read_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pb4_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_pb4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
// static void setup_link_read_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf4_1_common
// static void setup_link_read_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf4_0_proc0
// static void setup_link_read_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pb0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
static void setup_link_read_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_read_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pb0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_read_pb4_0_final
// static void setup_link_read_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pb0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
static void setup_link_read_pb0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_read_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_read_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_pa0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf4_1_common
// static void setup_link_read_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p9c_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_p9c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pbc_0_common
// static void setup_link_read_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc0
// static void setup_link_read_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p9b0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_p9b0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfb_0_1
// static void setup_link_read_p9b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pbb0_0_common
// static void setup_link_read_p9b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_p9b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_p9b0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p9b0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p9a0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_p9a0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
// static void setup_link_read_p9a0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pba0_0_common
// static void setup_link_read_p9a0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc1
// static void setup_link_read_p9a0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc0
// static void setup_link_read_p9a0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p9a0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p98_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
// static void setup_link_read_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pb8_0_common
// static void setup_link_read_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p94_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_p94_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
// static void setup_link_read_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pb4_0_common
// static void setup_link_read_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pb4_0_proc0
// static void setup_link_read_p94_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_read_pb4_0_final
// static void setup_link_read_p94_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p94_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_p94_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
// static void setup_link_read_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf4_1_common
// static void setup_link_read_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf4_0_proc0
// static void setup_link_read_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_p94_1_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p90_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
// static void setup_link_read_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pb0_0_common
// static void setup_link_read_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pb0_0_proc0
// static void setup_link_read_p90_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_link_read_pb4_0_final
// static void setup_link_read_p90_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p90_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
// static void setup_link_read_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pb0_1_common
// static void setup_link_read_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pb0_1_proc0
// static void setup_link_read_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_p90_1_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p80_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_read_pbc_0_0
// static int test_link_read_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_read_pf4_1_common
// static void setup_link_read_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_p80_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
static int test_link_read_p78_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_read_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
static void setup_link_read_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_read_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc0
// static void setup_link_read_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p76_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfb_0_1
static void setup_link_read_p76_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_read_p76_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p74_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
// static void setup_link_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_read_p76_0_common
// static void setup_link_read_p74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc0
// static void setup_link_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc1
// static void setup_link_read_p74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p70_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
static void setup_link_read_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_read_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p68_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
static void setup_link_read_p68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_link_read_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf4_0_proc0
// static void setup_link_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p60_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
static void setup_link_read_p60_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_link_read_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf0_0_proc0
// static void setup_link_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_p60_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p4_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
static void setup_link_read_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_read_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p4_0_final(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal
// static void setup_link_read_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p38_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_read_p78_0_common
// static void setup_link_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc0
// static void setup_link_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p36_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfb_0_1
// static void setup_link_read_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_read_p76_0_common
// static void setup_link_read_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p34_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
static void setup_link_read_p34_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc1
// static void setup_link_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfa_0_proc0
// static void setup_link_read_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p30_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
// static void setup_link_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_read_p70_0_common
// static void setup_link_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfc_0_proc1
// static void setup_link_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_read_pfb_0_proc0
// static void setup_link_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_final
// static void setup_link_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_read_pfc_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p28_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfa_0_1
// static void setup_link_read_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_read_p68_0_common
// static void setup_link_read_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf4_0_proc0
// static void setup_link_read_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_p28_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p20_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pf8_0_1
// static void setup_link_read_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_read_p60_0_common
// static void setup_link_read_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_read_pf0_0_proc0
// static void setup_link_read_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_read_pf4_0_final
// static void setup_link_read_p20_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal

/*
 * calls: link read
 */
// static int test_link_read_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_read_p78_0_0
// static int test_link_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_link_read_pfc_0_1
// static void setup_link_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_read_p4_0_common
// static void setup_link_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_read_pf4_0_proc1
// static void setup_link_read_p0_0_final(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal
// static void setup_link_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_read_pf4_0_procfinal


/*
 * calls: link rename
 */
static int test_link_rename_pf_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_rename_pf_0_1(void) {
  int r = rename("__f2", "__f2");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_rename_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
static void setup_link_rename_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_rename_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_rename_pf_0_final(void) {
  unlink("__i0");
}
static void setup_link_rename_pf_0_procfinal(void) {
  
}

/*
 * calls: link rename
 */
// static int test_link_rename_pf_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_0_0
static int test_link_rename_pf_1_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_rename_pf_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_rename_pf_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pf_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pf_1_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
static int test_link_rename_pf_2_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_rename_pf_2_1(void) {
  int r = rename("__f1", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_link_rename_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pf_1_common
// static void setup_link_rename_pf_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pf_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pf_2_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pf_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_2_0
// static int test_link_rename_pf_3_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_1_1
static void setup_link_rename_pf_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_rename_pf_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pf_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pf_3_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pee_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_0_0
static int test_link_rename_pee_0_1(void) {
  int r = rename("__f2", "__f3");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_rename_pee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f3");
  if (r < 0) setup_error("link");
}
// static void setup_link_rename_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pee_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pee_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pee_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_2_0
static int test_link_rename_pee_1_1(void) {
  int r = rename("__f1", "__f2");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_link_rename_pee_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pf_0_common
// static void setup_link_rename_pee_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pee_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pee_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pee_1_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pee_2_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_0_0
static int test_link_rename_pee_2_1(void) {
  int r = rename("__f2", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_link_rename_pee_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pf_0_common
// static void setup_link_rename_pee_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pee_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pee_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pee_2_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pee_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_2_0
static int test_link_rename_pee_3_1(void) {
  int r = rename("__f1", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_link_rename_pee_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pf_1_common
// static void setup_link_rename_pee_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pee_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pee_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pee_3_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pe6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_0_0
// static int test_link_rename_pe6_0_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pee_0_1
// static void setup_link_rename_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pf_0_common
// static void setup_link_rename_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pe6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pe6_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pe6_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_2_0
// static int test_link_rename_pe6_1_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pee_1_1
// static void setup_link_rename_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pf_1_common
// static void setup_link_rename_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pe6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pe6_1_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_0_0
static int test_link_rename_pc_0_1(void) {
  int r = rename("__f2", "__f2");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_link_rename_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pf_1_common
// static void setup_link_rename_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_2_0
static int test_link_rename_pc_1_1(void) {
  int r = rename("__f1", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_link_rename_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pf_3_common
// static void setup_link_rename_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
static int test_link_rename_pb8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_rename_pb8_0_1(void) {
//   int r = rename("__f2", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_0_1
static void setup_link_rename_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_rename_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pb8_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pb8_0_0
// static int test_link_rename_pb8_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_1_1
// static void setup_link_rename_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pf_3_common
// static void setup_link_rename_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_paf0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pb8_0_0
// static int test_link_rename_paf0_0_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pee_0_1
static void setup_link_rename_paf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f3");
  if (r < 0) setup_error("link");
}
// static void setup_link_rename_paf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_paf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
static void setup_link_rename_paf0_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_link_rename_paf0_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_paf0_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pb8_0_0
// static int test_link_rename_paf0_1_1(void) {
//   int r = rename("__f2", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pee_2_1
static void setup_link_rename_paf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_rename_paf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_paf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_paf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_paf0_1_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_pa6_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pb8_0_0
// static int test_link_rename_pa6_0_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pee_0_1
// static void setup_link_rename_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pb8_0_common
// static void setup_link_rename_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_p8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pb8_0_0
// static int test_link_rename_p8_0_1(void) {
//   int r = rename("__f2", "__f2");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_rename_pc_0_1
// static void setup_link_rename_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_pf_3_common
// static void setup_link_rename_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_p8_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
static int test_link_rename_p6_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_rename_p6_0_1(void) {
//   int r = rename("__f1", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pf_2_1
static void setup_link_rename_p6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
static int test_link_rename_p50_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static int test_link_rename_p50_0_1(void) {
  int r = rename("__f2", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_rename_p50_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_p50_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_rename_p50_0_0
// static int test_link_rename_p50_1_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pee_0_1
static void setup_link_rename_p50_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f3");
  if (r < 0) setup_error("link");
}
// static void setup_link_rename_p50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_p50_1_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_p40_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_rename_p50_0_0
// static int test_link_rename_p40_0_1(void) {
//   int r = rename("__f2", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_p50_0_1
static void setup_link_rename_p40_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_rename_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_p40_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_p40_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_rename_p50_0_0
// static int test_link_rename_p40_1_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_rename_pee_0_1
// static void setup_link_rename_p40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_rename_p50_0_common
// static void setup_link_rename_p40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_rename_pf_0_final
// static void setup_link_rename_p40_1_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_rename_p6_0_0
// static int test_link_rename_p0_0_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_rename_pc_1_1
static void setup_link_rename_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p0_0_final(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal
// static void setup_link_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal

/*
 * calls: link rename
 */
// static int test_link_rename_p0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_rename_p6_0_0
static int test_link_rename_p0_1_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_link_rename_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_rename_p0_0_common
// static void setup_link_rename_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_rename_pf_0_proc1
// static void setup_link_rename_p0_1_final(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal
// static void setup_link_rename_p0_1_procfinal(void) {
//   
// }
// ^ See setup_link_rename_pf_0_procfinal


/*
 * calls: link stat
 */
static int test_link_stat_pe_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f2", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_link_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
static void setup_link_stat_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_stat_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_stat_pe_0_final(void) {
  unlink("__i0");
}
static void setup_link_stat_pe_0_procfinal(void) {
  
}

/*
 * calls: link stat
 */
// static int test_link_stat_pe_1_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_stat_pe_0_0
static int test_link_stat_pe_1_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_link_stat_pe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_stat_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_stat_pe_0_final
// static void setup_link_stat_pe_1_procfinal(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal

/*
 * calls: link stat
 */
static int test_link_stat_pe_2_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_stat_pe_2_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_link_stat_pe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_stat_pe_1_common
// static void setup_link_stat_pe_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pe_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_stat_pe_0_final
// static void setup_link_stat_pe_2_procfinal(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal

/*
 * calls: link stat
 */
// static int test_link_stat_pe_3_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_stat_pe_2_0
// static int test_link_stat_pe_3_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_link_stat_pe_1_1
static void setup_link_stat_pe_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_stat_pe_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pe_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_stat_pe_0_final
// static void setup_link_stat_pe_3_procfinal(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal

/*
 * calls: link stat
 */
// static int test_link_stat_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_stat_pe_0_0
static int test_link_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f2", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_link_stat_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_stat_pe_1_common
// static void setup_link_stat_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_stat_pe_0_final
// static void setup_link_stat_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal

/*
 * calls: link stat
 */
// static int test_link_stat_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_stat_pe_2_0
static int test_link_stat_pc_1_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_link_stat_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_stat_pe_3_common
// static void setup_link_stat_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_stat_pe_0_final
// static void setup_link_stat_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal

/*
 * calls: link stat
 */
static int test_link_stat_pb8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_link_stat_pb8_0_1(void) {
  struct stat st;
  int r = stat("__f2", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_link_stat_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_stat_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
static void setup_link_stat_pb8_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_link_stat_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal

/*
 * calls: link stat
 */
// static int test_link_stat_p8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_stat_pb8_0_0
// static int test_link_stat_p8_0_1(void) {
//   struct stat st;
//   int r = stat("__f2", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_link_stat_pc_0_1
// static void setup_link_stat_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_stat_pe_3_common
// static void setup_link_stat_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_stat_pe_0_final
// static void setup_link_stat_p8_0_procfinal(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal

/*
 * calls: link stat
 */
static int test_link_stat_p4_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_link_stat_pe_2_1
static void setup_link_stat_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_stat_pe_0_final
// static void setup_link_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal

/*
 * calls: link stat
 */
// static int test_link_stat_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_stat_p4_0_0
// static int test_link_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_link_stat_pc_1_1
static void setup_link_stat_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_p0_0_final(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal
// static void setup_link_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal

/*
 * calls: link stat
 */
// static int test_link_stat_p0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_stat_p4_0_0
static int test_link_stat_p0_1_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_link_stat_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_stat_p0_0_common
// static void setup_link_stat_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_stat_pe_0_proc1
// static void setup_link_stat_p0_1_final(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal
// static void setup_link_stat_p0_1_procfinal(void) {
//   
// }
// ^ See setup_link_stat_pe_0_procfinal


/*
 * calls: link unlink
 */
static int test_link_unlink_pf8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_unlink_pf8_0_1(void) {
  int r = unlink("__f2");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_unlink_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
static void setup_link_unlink_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_unlink_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_unlink_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_link_unlink_pf8_0_procfinal(void) {
  
}

/*
 * calls: link unlink
 */
static int test_link_unlink_pf8_1_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_unlink_pf8_1_1(void) {
  int r = unlink("__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_link_unlink_pf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_unlink_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_unlink_pf8_0_final
// static void setup_link_unlink_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_link_unlink_pf8_0_procfinal

/*
 * calls: link unlink
 */
// static int test_link_unlink_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_unlink_pf8_0_0
static int test_link_unlink_pc_0_1(void) {
  int r = unlink("__f2");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_link_unlink_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_unlink_pf8_1_common
// static void setup_link_unlink_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_unlink_pf8_0_final
// static void setup_link_unlink_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_unlink_pf8_0_procfinal

/*
 * calls: link unlink
 */
// static int test_link_unlink_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_unlink_pf8_1_0
static int test_link_unlink_pc_1_1(void) {
  int r = unlink("__f1");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_link_unlink_pc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_unlink_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_unlink_pf8_0_final
// static void setup_link_unlink_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_unlink_pf8_0_procfinal

/*
 * calls: link unlink
 */
static int test_link_unlink_pb8_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_unlink_pb8_0_1(void) {
//   int r = unlink("__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_unlink_pf8_0_1
static void setup_link_unlink_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_link_unlink_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_unlink_pf8_0_final
// static void setup_link_unlink_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_link_unlink_pf8_0_procfinal

/*
 * calls: link unlink
 */
// static int test_link_unlink_p8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_unlink_pb8_0_0
// static int test_link_unlink_p8_0_1(void) {
//   int r = unlink("__f2");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_unlink_pc_0_1
// static void setup_link_unlink_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_unlink_pc_1_common
// static void setup_link_unlink_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_unlink_pf8_0_final
// static void setup_link_unlink_p8_0_procfinal(void) {
//   
// }
// ^ See setup_link_unlink_pf8_0_procfinal

/*
 * calls: link unlink
 */
static int test_link_unlink_p4_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_unlink_p4_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_unlink_pf8_1_1
static void setup_link_unlink_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_unlink_pf8_0_final
// static void setup_link_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_unlink_pf8_0_procfinal

/*
 * calls: link unlink
 */
// static int test_link_unlink_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_unlink_p4_0_0
// static int test_link_unlink_p0_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_unlink_pc_1_1
static void setup_link_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_link_unlink_pf8_0_procfinal
// static void setup_link_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_unlink_pf8_0_procfinal

/*
 * calls: link unlink
 */
// static int test_link_unlink_p0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_unlink_p4_0_0
static int test_link_unlink_p0_1_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_link_unlink_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_unlink_p0_0_common
// static void setup_link_unlink_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_unlink_pf8_0_proc1
// static void setup_link_unlink_p0_1_final(void) {
//   
// }
// ^ See setup_link_unlink_pf8_0_procfinal
// static void setup_link_unlink_p0_1_procfinal(void) {
//   
// }
// ^ See setup_link_unlink_pf8_0_procfinal


/*
 * calls: link write
 */
static int test_link_write_pfe_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_link_write_pfe_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_link_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_write_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_link_write_pfe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: link write
 */
static int test_link_write_pfe_1_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
// static int test_link_write_pfe_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfe_0_1
static void setup_link_write_pfe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_write_pfe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc0
// static void setup_link_write_pfe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc1
// static void setup_link_write_pfe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pfe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pfc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
static int test_link_write_pfc_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_link_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_link_write_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_link_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pfc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pfc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_pfc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_write_pfc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc0
// static void setup_link_write_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pf8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
static int test_link_write_pf8_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_link_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_link_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pf8_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pf8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
static void setup_link_write_pf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_write_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pf8_0_proc0
// static void setup_link_write_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pf4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
// static int test_link_write_pf4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_link_write_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_link_write_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_link_write_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_link_write_pf4_0_procfinal(void) {
  
}

/*
 * calls: link write
 */
// static int test_link_write_pf4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pf4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_write_pf4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pf0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
// static int test_link_write_pf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_link_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pf0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pf0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_write_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pe_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
// static int test_link_write_pe_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf4_0_common
// static void setup_link_write_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pe_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pe_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pe_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf4_1_common
// static void setup_link_write_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pe_1_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pde_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
// static int test_link_write_pde_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfe_0_1
// static void setup_link_write_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pfe_0_common
// static void setup_link_write_pde_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc1
// static void setup_link_write_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc0
// static void setup_link_write_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pde_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pde_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfe_0_1
// static void setup_link_write_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pfe_1_common
// static void setup_link_write_pde_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc1
// static void setup_link_write_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc0
// static void setup_link_write_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pde_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pdc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
// static int test_link_write_pdc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pfc_0_common
// static void setup_link_write_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc0
// static void setup_link_write_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pdc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pdc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pfc_1_common
// static void setup_link_write_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc0
// static void setup_link_write_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pd8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
// static int test_link_write_pd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf8_0_common
// static void setup_link_write_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pf8_0_proc0
// static void setup_link_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pd8_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pd8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf8_1_common
// static void setup_link_write_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pf8_0_proc0
// static void setup_link_write_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pd4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
// static int test_link_write_pd4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf4_0_common
// static void setup_link_write_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pd4_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pd4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf4_1_common
// static void setup_link_write_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pd0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
// static int test_link_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf0_0_common
// static void setup_link_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pd0_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pd0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf0_1_common
// static void setup_link_write_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_0_0
// static int test_link_write_pc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf4_0_common
// static void setup_link_write_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pc_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pc_1_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_link_write_pfe_1_0
// static int test_link_write_pc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf4_1_common
// static void setup_link_write_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pc_1_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
static int test_link_write_pbe_0_0(void) {
  int r = link("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_link_write_pbe_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfe_0_1
static void setup_link_write_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_write_pbe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc0
// static void setup_link_write_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc1
// static void setup_link_write_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pbc_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_pbc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_write_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc0
// static void setup_link_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pb8_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_pb8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pbc_0_common
// static void setup_link_write_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pf8_0_proc0
// static void setup_link_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pb4_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_pb4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_link_write_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_link_write_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pb0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_link_write_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pb4_0_proc0
// static void setup_link_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_pa0_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf4_1_common
// static void setup_link_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p9e_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_p9e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfe_0_1
// static void setup_link_write_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pbe_0_common
// static void setup_link_write_p9e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc1
// static void setup_link_write_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc0
// static void setup_link_write_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p9c_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_p9c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pbc_0_common
// static void setup_link_write_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc0
// static void setup_link_write_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p98_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_p98_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pbc_0_common
// static void setup_link_write_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pf8_0_proc0
// static void setup_link_write_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p94_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_p94_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pb4_0_common
// static void setup_link_write_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pb4_0_proc0
// static void setup_link_write_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_p94_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p90_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_p90_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pb0_0_common
// static void setup_link_write_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pb4_0_proc0
// static void setup_link_write_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_p90_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p80_0_0(void) {
//   int r = link("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_link_write_pbe_0_0
// static int test_link_write_p80_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_link_write_pf4_1_common
// static void setup_link_write_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_p80_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
static int test_link_write_p7c_0_0(void) {
  int r = link("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_link_write_p7c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfe_0_1
static void setup_link_write_p7c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_write_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc0
// static void setup_link_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc1
// static void setup_link_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p78_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_write_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc0
// static void setup_link_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p70_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
static void setup_link_write_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_link_write_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pf8_0_proc0
// static void setup_link_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p68_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p68_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_p68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_link_write_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p60_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p60_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
static void setup_link_write_p60_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_link_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p4_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
static void setup_link_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_link_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p4_0_final(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal
// static void setup_link_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p3c_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfe_0_1
// static void setup_link_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_write_p7c_0_common
// static void setup_link_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc1
// static void setup_link_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfe_0_proc0
// static void setup_link_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p38_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_write_p78_0_common
// static void setup_link_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc0
// static void setup_link_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p30_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_link_write_p70_0_common
// static void setup_link_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pfc_0_proc1
// static void setup_link_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_link_write_pf8_0_proc0
// static void setup_link_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_final
// static void setup_link_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_link_write_pfe_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p28_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_link_write_p68_0_common
// static void setup_link_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p20_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pfc_0_1
// static void setup_link_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_link_write_p60_0_common
// static void setup_link_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_link_write_pf4_0_proc0
// static void setup_link_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_link_write_pf4_0_final
// static void setup_link_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal

/*
 * calls: link write
 */
// static int test_link_write_p0_0_0(void) {
//   int r = link("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_link_write_p7c_0_0
// static int test_link_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_link_write_pf8_0_1
// static void setup_link_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_link_write_p4_0_common
// static void setup_link_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_link_write_pf4_0_proc1
// static void setup_link_write_p0_0_final(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal
// static void setup_link_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_link_write_pf4_0_procfinal


/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_pf8_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_lseek_pf8_0_1(void) {
  int r = lseek(11, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_lseek_lseek_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_lseek_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_lseek_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_lseek_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_lseek_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf8_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
static void setup_lseek_lseek_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf8_2_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
static void setup_lseek_lseek_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf8_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf8_3_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
static void setup_lseek_lseek_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf8_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf8_4_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
static void setup_lseek_lseek_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf8_5_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf8_5_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pf8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
static void setup_lseek_lseek_pf8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf6_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pf6_0_1(void) {
  int r = lseek(11, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_lseek_lseek_pf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_lseek_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf6_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf6_1_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf6_0_common
static void setup_lseek_lseek_pf6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pf4_0_1(void) {
  int r = lseek(11, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_lseek_lseek_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_lseek_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf4_1_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
static void setup_lseek_lseek_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf4_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf4_2_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
static void setup_lseek_lseek_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf4_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf4_3_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
static void setup_lseek_lseek_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf3_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pf3_0_1(void) {
  int r = lseek(11, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_pf3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pf3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_2_proc0
// static void setup_lseek_lseek_pf3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf3_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf3_1_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf3_0_1
// static void setup_lseek_lseek_pf3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pf3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_3_proc0
// static void setup_lseek_lseek_pf3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf2_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pf2_0_1(void) {
  int r = lseek(11, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_lseek_lseek_pf2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pf2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_2_proc0
// static void setup_lseek_lseek_pf2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf2_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf2_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf2_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf2_1_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf2_0_1
// static void setup_lseek_lseek_pf2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pf2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_3_proc0
// static void setup_lseek_lseek_pf2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf18_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pf18_0_1(void) {
  int r = lseek(11, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_lseek_lseek_pf18_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_lseek_pf18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_0_proc0
// static void setup_lseek_lseek_pf18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf18_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf18_1_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf18_0_1
// static void setup_lseek_lseek_pf18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_pf18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_1_proc0
// static void setup_lseek_lseek_pf18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf10_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pf10_0_1(void) {
  int r = lseek(11, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_lseek_lseek_pf10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_pf10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_0_proc0
// static void setup_lseek_lseek_pf10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf10_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf10_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf10_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf10_1_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf10_0_1
// static void setup_lseek_lseek_pf10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_pf10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_1_proc0
// static void setup_lseek_lseek_pf10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf10_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf10_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf10_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pf10_2_1(void) {
  int r = lseek(11, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static void setup_lseek_lseek_pf10_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pf10_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_2_proc0
// static void setup_lseek_lseek_pf10_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf10_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf10_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf10_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf10_3_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf10_2_1
// static void setup_lseek_lseek_pf10_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pf10_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_3_proc0
// static void setup_lseek_lseek_pf10_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf10_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf10_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf0_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_2_proc0
// static void setup_lseek_lseek_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pf0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pf0_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf4_3_proc0
// static void setup_lseek_lseek_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pe_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pe_0_1(void) {
  int r = lseek(11, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_lseek_lseek_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pe_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
// static void setup_lseek_lseek_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd8_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd8_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd8_2_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd8_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd8_3_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd6_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pd6_0_1(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf6_0_common
// static void setup_lseek_lseek_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
static void setup_lseek_lseek_pd6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd6_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd6_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf6_0_common
// static void setup_lseek_lseek_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd6_0_proc1
// static void setup_lseek_lseek_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pd4_0_1(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_lseek_lseek_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
static void setup_lseek_lseek_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd4_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd4_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd4_2_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
static void setup_lseek_lseek_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd4_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd4_3_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd3_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pd3_0_1(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_pd3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pd3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pd3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pd3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd3_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd3_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_pd3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pd3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pd3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd2_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pd2_0_1(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_lseek_lseek_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pd2_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd2_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd2_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd2_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_pd2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pd2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pd2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd18_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pd18_0_1(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_pd18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_pd18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pd18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_pd18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd18_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd18_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_pd18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_pd18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_pd18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd10_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pd10_0_1(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_lseek_lseek_pd10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_pd10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pd10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_pd10_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd10_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd10_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd10_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_pd10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_pd10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_pd10_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd10_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd10_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pd10_2_1(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static void setup_lseek_lseek_pd10_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pd10_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pd10_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pd10_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd10_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd10_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd10_3_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static void setup_lseek_lseek_pd10_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pd10_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd10_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pd10_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd10_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pd0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pd0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
static int test_lseek_lseek_pc_0_1(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_lseek_lseek_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_pc_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbe_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbe_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf6_0_common
static void setup_lseek_lseek_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbe_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbe_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf6_0_common
static void setup_lseek_lseek_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbd8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbd8_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
static void setup_lseek_lseek_pbd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_lseek_pbd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_lseek_pbd8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_lseek_pbd8_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_lseek_pbd8_0_procfinal(void) {
  
}

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbd8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbd8_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_pbd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_pbd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_pbd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbd8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbd8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbd0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbd0_0_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_pbd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_pbd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_pbd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbd0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbd0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbd0_1_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_pbd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_pbd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_pbd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbd0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbd0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbd0_2_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pbd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_pbd0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_pbd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbd0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbd0_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbd0_3_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pbd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_pbd0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_pbd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbd0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbcc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbcc_0_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf3_0_1
// static void setup_lseek_lseek_pbcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pbcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_pbcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbcc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbcc_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbcc_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_pbcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pbcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pbcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbcc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbcc_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbc8_0_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf2_0_1
// static void setup_lseek_lseek_pbc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pbc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_pbc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbc8_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_pbc8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pbc8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pbc8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc8_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
static int test_lseek_lseek_pbc8_2_1(void) {
  int r = lseek(11, -4096, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_lseek_lseek_pbc8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_pbc8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_pbc8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc8_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
static int test_lseek_lseek_pbc8_3_1(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_lseek_lseek_pbc8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_pbc8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_pbc8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc8_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbc6_0_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf18_0_1
static void setup_lseek_lseek_pbc6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_lseek_lseek_pbc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_pbc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbc6_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_pbc6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
static void setup_lseek_lseek_pbc6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_pbc6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbc4_0_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf10_0_1
// static void setup_lseek_lseek_pbc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pbc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_pbc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbc4_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_pbc4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pbc4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pbc4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
static int test_lseek_lseek_pbc4_2_1(void) {
  int r = lseek(11, -4096, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_lseek_lseek_pbc4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_lseek_pbc4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_pbc4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc4_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbc4_3_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static void setup_lseek_lseek_pbc4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pbc4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pbc4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc4_4_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
static int test_lseek_lseek_pbc4_4_1(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_lseek_lseek_pbc4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_pbc4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pbc4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc4_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbc0_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pbc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pbc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_proc0
// static void setup_lseek_lseek_pbc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pbc0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pbc0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pbc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pbc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_1_proc0
// static void setup_lseek_lseek_pbc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pbc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pbc0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb8_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
// static void setup_lseek_lseek_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_1_proc0
// static void setup_lseek_lseek_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb6_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf6_0_common
static void setup_lseek_lseek_pb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb6_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf6_0_common
// static void setup_lseek_lseek_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pb6_0_proc0
// static void setup_lseek_lseek_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb58_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb58_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_pb58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pb58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_1_proc0
static void setup_lseek_lseek_pb58_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_pb58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb58_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb58_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb58_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
static void setup_lseek_lseek_pb58_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_lseek_pb58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb58_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb58_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb50_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb50_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pb50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pb50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pb50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pb50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb50_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb50_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb50_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pb50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pb50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb50_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb4c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb4c_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_pb4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pb4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb4c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb4c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb48_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb48_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_pb48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pb48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb48_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb48_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb48_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static void setup_lseek_lseek_pb48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pb48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_pb48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_pb48_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb48_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb46_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb46_0_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_pb46_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pb46_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pb46_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pb46_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb46_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb44_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb44_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_pb44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pb44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pb44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pb44_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb44_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb44_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb44_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc4_4_1
// static void setup_lseek_lseek_pb44_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_pb44_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb44_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb44_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb44_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb40_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb40_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pb40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pb40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_1_proc0
// static void setup_lseek_lseek_pb40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_0_proc1
// static void setup_lseek_lseek_pb40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb40_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb40_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pb40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_pb40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pb40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb40_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static int test_lseek_lseek_pb0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_1_proc0
// static void setup_lseek_lseek_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pae_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pae_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
static void setup_lseek_lseek_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pae_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pae_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
static void setup_lseek_lseek_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pae_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pae_2_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pae_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
static void setup_lseek_lseek_pae_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pae_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pae_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pae_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pae_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pae_3_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pae_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
static void setup_lseek_lseek_pae_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_pae_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_pae_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pae_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pad8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pad8_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_pad8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pad8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_pad8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pad8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pad8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pad8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pad8_1_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_pad8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pad8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_pad8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pad8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pad8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pad8_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pad8_2_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_pad8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pad8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pad8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pad8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pad8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pad8_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pad8_3_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_pad8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pad8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pad8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pad8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pad8_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pad0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pad0_0_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_pad0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pad0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pad0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pad0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pad0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pad0_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pad0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pad0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pad0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pad0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pad0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pad0_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pad0_2_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_pad0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pad0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_pad0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pad0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pad0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pad0_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pad0_3_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pad0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pad0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pad0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pad0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pad0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pace_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pace_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_pace_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pace_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pace_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pace_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pace_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac90_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac90_0_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf2_0_1
// static void setup_lseek_lseek_pac90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pac90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_pac90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac90_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac90_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_pac90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_pac90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pac90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac90_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac6_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac6_0_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf18_0_1
// static void setup_lseek_lseek_pac6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pac6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_pac6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac6_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
static int test_lseek_lseek_pac6_1_1(void) {
  int r = lseek(11, -12288, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_pac6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pac6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_pac6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac6_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac6_2_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_pac6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pac6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pac6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac6_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac6_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
static int test_lseek_lseek_pac6_3_1(void) {
  int r = lseek(10, -12288, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_pac6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pac6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pac6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac6_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac4_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac4_0_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf10_0_1
// static void setup_lseek_lseek_pac4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pac4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_pac4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac4_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac4_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_pac4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pac4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pac4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_pac4_2_0(void) {
  int r = lseek(10, 31617024, SEEK_SET);
  expect_result("r", r, 31617024);
  return xerrno(r);
}
// static int test_lseek_lseek_pac4_2_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf10_0_1
// static void setup_lseek_lseek_pac4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
static void setup_lseek_lseek_pac4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_pac4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac4_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac4_3_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf10_2_1
// static void setup_lseek_lseek_pac4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pac4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_pac4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac4_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac4_4_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc4_4_1
// static void setup_lseek_lseek_pac4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_pac4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pac4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac4_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac4_5_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac4_5_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_pac4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pac4_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pac4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac4_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac0_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_pac0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pac0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_pac0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pac0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pac0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pac0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pac0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pac0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pac0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pac0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa8_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
// static void setup_lseek_lseek_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa8_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
// static void setup_lseek_lseek_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa6_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa6_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pa6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pa6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa6_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa6_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pa6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pa6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa6_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa6_2_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pa6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pa6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pa6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_pa6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pa6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa6_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa6_3_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pa6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_pa6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_pa6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_pa6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_pa6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa58_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa58_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_pa58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa58_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa58_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa58_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_pa58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa58_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa58_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa50_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa50_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pa50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa50_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa50_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa50_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_pa50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa50_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa4c_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa4c_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_pa4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa4c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa4c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa48_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa48_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_pa48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa48_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa46_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa46_0_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_pa46_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pa46_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa46_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa46_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa46_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa46_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa46_1_1(void) {
//   int r = lseek(10, -12288, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pac6_3_1
// static void setup_lseek_lseek_pa46_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa46_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa46_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa46_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa46_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa44_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa44_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_pa44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_pa44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa44_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa44_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa44_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa44_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static void setup_lseek_lseek_pa44_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa44_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa44_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa44_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa44_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa40_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa40_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pa40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa40_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa40_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_pa40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa40_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_pa0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static int test_lseek_lseek_pa0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9f_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9f_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p9f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p9f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_2_proc0
// static void setup_lseek_lseek_p9f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p9f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p9f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9f_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9f_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p9f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p9f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_3_proc0
// static void setup_lseek_lseek_p9f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p9f_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p9f_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9ec_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9ec_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_p9ec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9ec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p9ec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9ec_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9ec_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9ec_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9ec_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p9ec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9ec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9ec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9ec_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9ec_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9ea_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9ea_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p9ea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9ea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9ea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9ea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9ea_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
static int test_lseek_lseek_p9e6_0_1(void) {
  int r = lseek(11, -5066752, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_p9e6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_p9e6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p9e6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_p9e6_1_0(void) {
  int r = lseek(10, -8192, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_lseek_p9e6_1_1(void) {
  int r = lseek(11, -8192, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_p9e6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
static void setup_lseek_lseek_p9e6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p9e6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e6_2_0(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e6_1_0
// static int test_lseek_lseek_p9e6_2_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf3_0_1
// static void setup_lseek_lseek_p9e6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p9e6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p9e6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e6_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e6_3_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9e6_3_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf3_0_1
// static void setup_lseek_lseek_p9e6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9e6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p9e6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e6_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e6_4_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9e6_4_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p9e6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9e6_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9e6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e6_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e6_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e5_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9e5_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_p9e5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9e5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9e5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e5_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e5_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9e5_1_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_2_1
// static void setup_lseek_lseek_p9e5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_p9e5_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p9e5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e5_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e3_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
static int test_lseek_lseek_p9e3_0_1(void) {
  int r = lseek(11, -32768, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_lseek_lseek_p9e3_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_lseek_p9e3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p9e3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e3_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_p9e3_1_0(void) {
  int r = lseek(10, -28672, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_lseek_p9e3_1_1(void) {
  int r = lseek(11, -28672, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_lseek_lseek_p9e3_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_lseek_p9e3_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p9e3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e3_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e3_2_0(void) {
//   int r = lseek(10, -28672, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e3_1_0
static int test_lseek_lseek_p9e3_2_1(void) {
  int r = lseek(10, -28672, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_p9e3_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_1_common
static void setup_lseek_lseek_p9e3_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p9e3_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e3_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e3_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e28_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
static int test_lseek_lseek_p9e28_0_1(void) {
  int r = lseek(10, -8192, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_lseek_lseek_p9e28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9e28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9e28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e28_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e28_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9e28_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc4_4_1
// static void setup_lseek_lseek_p9e28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_p9e28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9e28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e28_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9e0_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p9e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9e0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p9e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9e0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9e0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p9e0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9e0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9e0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9e0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9e0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9c_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
// static void setup_lseek_lseek_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9b_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9b_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p9b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p9b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_p9b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_p9b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p9b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9b_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9b_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p9b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p9b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_p9b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_p9b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p9b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9ac_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9ac_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p9ac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9ac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9ac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9ac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9ac_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9a8_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p9a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
static int test_lseek_lseek_p9a6_0_1(void) {
  int r = lseek(10, -5066752, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_p9a6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p9a6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_0_proc1
// static void setup_lseek_lseek_p9a6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a6_1_0(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e6_1_0
// static int test_lseek_lseek_p9a6_1_1(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e6_1_0
// static void setup_lseek_lseek_p9a6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p9a6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p9a6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a6_2_0(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e6_1_0
// static int test_lseek_lseek_p9a6_2_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p9a6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p9a6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a6_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a6_3_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9a6_3_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p9a6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p9a6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a6_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
static int test_lseek_lseek_p9a4_0_1(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 31617024);
  return xerrno(r);
}
// static void setup_lseek_lseek_p9a4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p9a4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
static void setup_lseek_lseek_p9a4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p9a4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9a4_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static void setup_lseek_lseek_p9a4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p9a4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p9a4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9a4_2_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_p9a4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p9a4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a3_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
static int test_lseek_lseek_p9a3_0_1(void) {
  int r = lseek(10, -32768, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_p9a3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_0_common
// static void setup_lseek_lseek_p9a3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a3_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a3_1_0(void) {
//   int r = lseek(10, -28672, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e3_1_0
// static int test_lseek_lseek_p9a3_1_1(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e3_2_1
// static void setup_lseek_lseek_p9a3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_1_common
// static void setup_lseek_lseek_p9a3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_2_proc0
// static void setup_lseek_lseek_p9a3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_2_proc0
// static void setup_lseek_lseek_p9a3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a3_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a2_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
static int test_lseek_lseek_p9a2_0_1(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 24576);
  return xerrno(r);
}
// static void setup_lseek_lseek_p9a2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_1_common
// static void setup_lseek_lseek_p9a2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a2_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a2_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9a2_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc4_4_1
// static void setup_lseek_lseek_p9a2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_p9a2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a2_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9a0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p9a0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p9a0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9a0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9a0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9a0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static int test_lseek_lseek_p98_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p97_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p97_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p97_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p97_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_2_proc0
// static void setup_lseek_lseek_p97_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p97_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p97_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p97_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p97_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p97_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p97_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_3_proc0
// static void setup_lseek_lseek_p97_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p97_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p97_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p96c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p96c_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_p96c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p96c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p96c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p96c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p96c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_p96c_1_0(void) {
  int r = lseek(10, -8192, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_lseek_p96c_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p96c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p96c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p96c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p96c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p96c_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p96c_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static int test_lseek_lseek_p96c_2_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_p96c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p96c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_2_proc0
// static void setup_lseek_lseek_p96c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p96c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p96c_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p96c_3_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p96c_3_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p96c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p96c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p96c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p96c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p96c_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p96c_4_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static int test_lseek_lseek_p96c_4_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p96c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p96c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p96c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p96c_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p96c_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9690_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p9690_0_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_p9690_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9690_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p9690_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9690_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9690_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9690_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p9690_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p9690_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9690_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9690_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9690_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9690_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p967_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p967_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p967_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p967_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p967_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p967_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p967_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p967_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static int test_lseek_lseek_p967_1_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf3_0_1
// static void setup_lseek_lseek_p967_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p967_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e6_1_proc0
// static void setup_lseek_lseek_p967_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p967_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p967_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p964c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p964c_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_p964c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p964c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p964c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p964c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p964c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p963_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p963_0_1(void) {
//   int r = lseek(11, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e3_1_1
// static void setup_lseek_lseek_p963_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_1_common
// static void setup_lseek_lseek_p963_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p963_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p963_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p963_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p963_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static int test_lseek_lseek_p963_1_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf18_0_1
// static void setup_lseek_lseek_p963_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p963_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_2_proc0
// static void setup_lseek_lseek_p963_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p963_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p963_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p963_2_0(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p96c_1_0
// static int test_lseek_lseek_p963_2_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p963_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p963_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p963_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p963_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p963_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p963_3_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static int test_lseek_lseek_p963_3_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p963_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p963_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p963_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p963_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p963_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p963_4_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p963_4_1(void) {
//   int r = lseek(10, -12288, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pac6_3_1
// static void setup_lseek_lseek_p963_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p963_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p963_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p963_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p963_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_p9624_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 9981952);
  return xerrno(r);
}
static int test_lseek_lseek_p9624_0_1(void) {
  int r = lseek(10, 9981952, SEEK_END);
  expect_result("r", r, 9981952);
  return xerrno(r);
}
// static void setup_lseek_lseek_p9624_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
static void setup_lseek_lseek_p9624_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p9624_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9624_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9624_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_p9624_1_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_lseek_p9624_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static void setup_lseek_lseek_p9624_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p9624_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p9624_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9624_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9624_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p9624_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p9624_2_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_p9624_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p9624_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p9624_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p9624_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p9624_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p960_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p960_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p960_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p960_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p960_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p960_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p960_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p960_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p960_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p960_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p960_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p960_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p960_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p960_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p94_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p94_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
// static void setup_lseek_lseek_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p93_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p93_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p93_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p93_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_p93_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_p93_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p93_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p93_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p93_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p93_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p93_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_p93_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_p93_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p93_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p92c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p92c_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p92c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p92c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p92c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p92c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p92c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p92c_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static int test_lseek_lseek_p92c_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p92c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p92c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p92c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p92c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p92c_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p928_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p928_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p928_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p928_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p928_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p928_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p926_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
static int test_lseek_lseek_p926_0_1(void) {
  int r = lseek(10, -31621120, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_p926_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p926_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p926_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p926_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p926_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p926_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static int test_lseek_lseek_p926_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p926_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p926_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p926_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p926_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p926_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_p926_2_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_lseek_p926_2_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p926_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p926_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p926_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p926_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p926_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p926_3_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p926_3_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p926_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p926_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p926_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p926_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p926_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p924_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
static int test_lseek_lseek_p924_0_1(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 155648);
  return xerrno(r);
}
// static void setup_lseek_lseek_p924_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p924_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
static void setup_lseek_lseek_p924_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p924_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p924_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p924_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p924_0_1
// static int test_lseek_lseek_p924_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_p924_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p924_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p924_0_proc1
// static void setup_lseek_lseek_p924_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p924_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p924_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p924_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p924_2_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_p924_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p924_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p924_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p924_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p924_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p923_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p923_0_1(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e3_2_1
// static void setup_lseek_lseek_p923_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_1_common
// static void setup_lseek_lseek_p923_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p923_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p923_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p923_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p923_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static int test_lseek_lseek_p923_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p923_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p923_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p923_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p923_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p923_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p922_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p922_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static void setup_lseek_lseek_p922_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p922_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p922_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p922_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p922_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p920_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p920_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p920_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p920_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p920_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p920_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p920_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static int test_lseek_lseek_p90_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f8_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p8f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_p8f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_0_proc0
// static void setup_lseek_lseek_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p8f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p8f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f8_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p8f8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_p8f8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_1_proc0
// static void setup_lseek_lseek_p8f8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p8f8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p8f8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f6_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_p8f6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p8f6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f6_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p8f6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_1_proc0
// static void setup_lseek_lseek_p8f6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f4_0_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_p8f4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p8f4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
static int test_lseek_lseek_p8f4_1_1(void) {
  int r = lseek(11, 9981952, SEEK_SET);
  expect_result("r", r, 9981952);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8f4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
static void setup_lseek_lseek_p8f4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8f4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f4_2_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p8f4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8f4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f4_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f4_3_1(void) {
//   int r = lseek(10, 31617024, SEEK_SET);
//   expect_result("r", r, 31617024);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pac4_2_0
// static void setup_lseek_lseek_p8f4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p8f4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f3_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f3_0_1(void) {
//   int r = lseek(11, -5066752, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e6_0_1
// static void setup_lseek_lseek_p8f3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
static void setup_lseek_lseek_p8f3_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8f3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f3_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f3_1_0(void) {
//   int r = lseek(10, -12288, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pac6_3_1
static int test_lseek_lseek_p8f3_1_1(void) {
  int r = lseek(11, -12288, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8f3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_p8f3_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8f3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f3_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f3_2_0(void) {
//   int r = lseek(10, -32768, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a3_0_1
static int test_lseek_lseek_p8f3_2_1(void) {
  int r = lseek(11, -32768, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8f3_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_1_common
static void setup_lseek_lseek_p8f3_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8f3_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f3_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f3_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f3_3_0(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e3_2_1
// static int test_lseek_lseek_p8f3_3_1(void) {
//   int r = lseek(10, -28672, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e3_1_0
// static void setup_lseek_lseek_p8f3_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_1_common
// static void setup_lseek_lseek_p8f3_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_2_proc0
// static void setup_lseek_lseek_p8f3_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f3_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f3_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f2_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
static int test_lseek_lseek_p8f2_0_1(void) {
  int r = lseek(11, 0, SEEK_CUR);
  expect_result("r", r, 31617024);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8f2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pac4_2_proc0
// static void setup_lseek_lseek_p8f2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f2_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f2_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f2_1_1(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p96c_1_0
// static void setup_lseek_lseek_p8f2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8f2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f2_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f2_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f2_2_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_2_1
// static void setup_lseek_lseek_p8f2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
static void setup_lseek_lseek_p8f2_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8f2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f2_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f2_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f2_3_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_2_1
// static void setup_lseek_lseek_p8f2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_2_proc0
// static void setup_lseek_lseek_p8f2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f2_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f2_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f2_4_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f2_4_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static void setup_lseek_lseek_p8f2_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f2_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p8f2_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f2_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f2_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f18_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f18_0_1(void) {
//   int r = lseek(11, -32768, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e3_0_1
static void setup_lseek_lseek_p8f18_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_lseek_p8f18_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8f18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
static void setup_lseek_lseek_p8f18_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_lseek_lseek_p8f18_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f18_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f18_1_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf18_0_1
// static void setup_lseek_lseek_p8f18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p8f18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f18_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f18_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f18_2_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p8f18_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f18_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8f18_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f18_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f18_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f10_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
static int test_lseek_lseek_p8f10_0_1(void) {
  int r = lseek(11, 0, SEEK_END);
  expect_result("r", r, 24576);
  return xerrno(r);
}
static void setup_lseek_lseek_p8f10_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_lseek_p8f10_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8f10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f10_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8f10_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f10_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f10_1_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf10_0_1
// static void setup_lseek_lseek_p8f10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p8f10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f10_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f10_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
static int test_lseek_lseek_p8f10_2_1(void) {
  int r = lseek(11, 5062656, SEEK_END);
  expect_result("r", r, 5066752);
  return xerrno(r);
}
static void setup_lseek_lseek_p8f10_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_lseek_p8f10_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8f10_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f10_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8f10_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f10_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
static int test_lseek_lseek_p8f10_3_1(void) {
  int r = lseek(11, 31617024, SEEK_END);
  expect_result("r", r, 31617024);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8f10_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f10_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pac4_2_proc0
// static void setup_lseek_lseek_p8f10_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f10_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f10_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f10_4_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f10_4_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_p8f10_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f10_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8f10_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f10_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f10_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f10_5_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
static int test_lseek_lseek_p8f10_5_1(void) {
  int r = lseek(10, 5062656, SEEK_END);
  expect_result("r", r, 5062656);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8f10_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f10_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_0_proc1
// static void setup_lseek_lseek_p8f10_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f10_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f10_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f0_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p8f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8f0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8f0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p8f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_1_proc0
// static void setup_lseek_lseek_p8f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8f0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8e_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8e_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
// static void setup_lseek_lseek_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d8_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_p8d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p8d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d8_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p8d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_p8d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_p8d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_p8d8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p8d8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d6_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p8d6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d4_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p8d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d4_1_1(void) {
//   int r = lseek(10, 31617024, SEEK_SET);
//   expect_result("r", r, 31617024);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pac4_2_0
// static void setup_lseek_lseek_p8d4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p8d4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p8d4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d3_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d3_0_1(void) {
//   int r = lseek(10, -5066752, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a6_0_1
// static void setup_lseek_lseek_p8d3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_0_proc1
// static void setup_lseek_lseek_p8d3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_0_proc1
// static void setup_lseek_lseek_p8d3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d3_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d3_1_0(void) {
//   int r = lseek(10, -12288, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pac6_3_1
static int test_lseek_lseek_p8d3_1_1(void) {
  int r = lseek(10, -12288, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8d3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p8d3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p8d3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d3_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d3_2_0(void) {
//   int r = lseek(10, -32768, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a3_0_1
static int test_lseek_lseek_p8d3_2_1(void) {
  int r = lseek(10, -32768, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8d3_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_0_common
static void setup_lseek_lseek_p8d3_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_lseek_p8d3_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8d3_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d3_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d2_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d2_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 31617024);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a4_0_1
// static void setup_lseek_lseek_p8d2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p8d2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p8d2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d2_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d2_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
static int test_lseek_lseek_p8d2_1_1(void) {
  int r = lseek(10, 5062656, SEEK_CUR);
  expect_result("r", r, 36679680);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8d2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_0_proc1
// static void setup_lseek_lseek_p8d2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p8d2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d2_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d2_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d2_2_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static void setup_lseek_lseek_p8d2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p924_0_proc1
// static void setup_lseek_lseek_p8d2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p8d2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d2_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d2_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d2_3_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc8_3_1
// static void setup_lseek_lseek_p8d2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p8d2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_3_proc0
// static void setup_lseek_lseek_p8d2_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d2_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d18_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d18_0_1(void) {
//   int r = lseek(10, -32768, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a3_0_1
// static void setup_lseek_lseek_p8d18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p8f18_0_common
static void setup_lseek_lseek_p8d18_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_lseek_p8d18_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8d18_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8d18_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d18_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d18_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p8d18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d18_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d10_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d10_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 24576);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a2_0_1
// static void setup_lseek_lseek_p8d10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p8f10_0_common
// static void setup_lseek_lseek_p8d10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
static void setup_lseek_lseek_p8d10_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8d10_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8d10_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d10_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d10_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_p8d10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d10_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d10_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
static int test_lseek_lseek_p8d10_2_1(void) {
  int r = lseek(10, 5062656, SEEK_END);
  expect_result("r", r, 5066752);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8d10_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p8f10_2_common
// static void setup_lseek_lseek_p8d10_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_0_proc1
static void setup_lseek_lseek_p8d10_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8d10_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8d10_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d10_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
static int test_lseek_lseek_p8d10_3_1(void) {
  int r = lseek(10, 31617024, SEEK_END);
  expect_result("r", r, 31617024);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8d10_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d10_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p8d10_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p8d10_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d10_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8d0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8d0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8d0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8d0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static int test_lseek_lseek_p8c_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b8_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b8_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p8b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_p8b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_0_proc0
// static void setup_lseek_lseek_p8b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p8b8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p8b8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b8_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b8_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p8b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_p8b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_1_proc0
// static void setup_lseek_lseek_p8b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p8b8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p8b8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b8_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p8b8_2_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p8b8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p8b8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_2_proc0
// static void setup_lseek_lseek_p8b8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p8b8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p8b8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b8_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p8b8_3_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p8b8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p8b8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_3_proc0
// static void setup_lseek_lseek_p8b8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p8b8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p8b8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b6_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b6_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_p8b6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p8b6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b6_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b6_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p8b6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8b6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b6_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p8b6_2_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_p8b6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p8b6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p8b6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b6_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b6_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p8b6_3_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p8b6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p8b6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8b6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b6_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b6_4_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc4_4_1
// static int test_lseek_lseek_p8b6_4_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_p8b6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_p8b6_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p8b6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b6_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b6_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b6_5_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc4_4_1
// static int test_lseek_lseek_p8b6_5_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p8b6_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_p8b6_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8b6_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b6_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b6_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b4_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b4_0_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_p8b4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p8b4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b4_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b4_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p8b4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8b4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b4_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b4_2_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_p8b4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p8b4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b4_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b4_3_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p8b4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8b4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b38_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b38_0_1(void) {
//   int r = lseek(11, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e6_1_1
// static void setup_lseek_lseek_p8b38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc8_2_proc0
// static void setup_lseek_lseek_p8b38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b38_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b38_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_p8b38_1_0(void) {
  int r = lseek(10, -16384, SEEK_END);
  expect_result("r", r, 16384);
  return xerrno(r);
}
static int test_lseek_lseek_p8b38_1_1(void) {
  int r = lseek(10, -20480, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_lseek_lseek_p8b38_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_lseek_p8b38_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8b38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b38_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b38_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b38_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b38_2_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p8b38_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b38_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8b38_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b38_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b38_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b38_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc4_4_1
// static int test_lseek_lseek_p8b38_3_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p8b38_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_p8b38_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8b38_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b38_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b38_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b24_0_0(void) {
//   int r = lseek(10, 9981952, SEEK_END);
//   expect_result("r", r, 9981952);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9624_0_1
// static int test_lseek_lseek_p8b24_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 9981952);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9624_0_0
// static void setup_lseek_lseek_p8b24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9624_0_proc0
// static void setup_lseek_lseek_p8b24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b24_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b24_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p8b24_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9624_1_0
// static void setup_lseek_lseek_p8b24_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p8b24_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8b24_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b24_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b24_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b24_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b24_2_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_p8b24_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b24_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8b24_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b24_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b24_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b18_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b18_0_1(void) {
//   int r = lseek(11, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e3_1_1
// static void setup_lseek_lseek_p8b18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p8f10_0_common
// static void setup_lseek_lseek_p8b18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p8f10_0_proc0
// static void setup_lseek_lseek_p8b18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b18_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8b18_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b18_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b18_1_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf18_0_1
// static void setup_lseek_lseek_p8b18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p8b18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b18_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b18_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p8b18_2_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf18_0_1
static void setup_lseek_lseek_p8b18_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_lseek_p8b18_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8b18_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b18_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8b18_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b18_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b18_3_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p8b18_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b18_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8b18_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b18_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b18_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b18_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b18_4_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf18_0_1
// static void setup_lseek_lseek_p8b18_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b18_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p8b18_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b18_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b18_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b18_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b18_5_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p8b18_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b18_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8b18_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b18_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b18_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b10_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b10_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_p8b10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8b10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b10_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_p8b10_1_0(void) {
  int r = lseek(10, 131072, SEEK_END);
  expect_result("r", r, 155648);
  return xerrno(r);
}
static int test_lseek_lseek_p8b10_1_1(void) {
  int r = lseek(10, 131072, SEEK_END);
  expect_result("r", r, 155648);
  return xerrno(r);
}
// static void setup_lseek_lseek_p8b10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_1_common
static void setup_lseek_lseek_p8b10_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 131072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8b10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b10_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b0_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b0_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p8b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8b0_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8b0_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p8b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8b0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8a_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8a_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
// static void setup_lseek_lseek_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8a_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p8a_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
// static void setup_lseek_lseek_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p898_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p898_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p898_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_p898_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_p898_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_p898_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p898_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p898_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p898_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p898_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf18_0_common
// static void setup_lseek_lseek_p898_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_0_proc1
// static void setup_lseek_lseek_p898_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_p898_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p898_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p898_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p898_2_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p898_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p898_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_p898_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_p898_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p898_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p898_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p898_3_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p898_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf4_0_common
// static void setup_lseek_lseek_p898_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_p898_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_p898_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p898_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p896_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p896_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p896_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p896_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p896_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p896_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p896_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p896_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p896_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p896_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p896_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p896_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p896_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p896_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p896_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc4_4_1
// static int test_lseek_lseek_p896_2_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p896_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_p896_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p896_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p896_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p896_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p894_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p894_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p894_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p894_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p894_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p894_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p894_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p894_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p894_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p894_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p894_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p894_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p894_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p894_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p893_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p893_0_1(void) {
//   int r = lseek(10, -31621120, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p926_0_1
// static void setup_lseek_lseek_p893_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p893_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p893_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p893_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p893_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p893_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p893_1_1(void) {
//   int r = lseek(10, -31621120, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p926_0_1
// static void setup_lseek_lseek_p893_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p893_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p893_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p893_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p893_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p893_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc4_4_1
// static int test_lseek_lseek_p893_2_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p893_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_p893_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p893_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p893_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p893_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p893_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pbc4_4_1
// static int test_lseek_lseek_p893_3_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p893_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc4_2_common
// static void setup_lseek_lseek_p893_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p893_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p893_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p893_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p893_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 24576);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a2_0_1
// static int test_lseek_lseek_p893_4_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p893_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_1_common
// static void setup_lseek_lseek_p893_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p893_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p893_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p893_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p892_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p892_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p924_0_1
// static void setup_lseek_lseek_p892_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p892_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p924_0_proc1
// static void setup_lseek_lseek_p892_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p924_0_proc1
// static void setup_lseek_lseek_p892_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p892_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p892_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p892_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 31617024);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a4_0_1
// static void setup_lseek_lseek_p892_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p892_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p892_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9a4_0_proc1
// static void setup_lseek_lseek_p892_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p892_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p892_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p892_2_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_p892_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p892_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p892_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p892_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p892_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8918_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8918_0_1(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9e3_2_1
// static void setup_lseek_lseek_p8918_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p8f10_0_common
// static void setup_lseek_lseek_p8918_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8918_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p8d10_0_proc1
// static void setup_lseek_lseek_p8918_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8918_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
static int test_lseek_lseek_p8918_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 28672);
  return xerrno(r);
}
static int test_lseek_lseek_p8918_1_1(void) {
  int r = lseek(10, -36864, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static void setup_lseek_lseek_p8918_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_lseek_p8918_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
static void setup_lseek_lseek_p8918_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p8918_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8918_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8918_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8918_2_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p8918_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8918_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8918_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8918_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8918_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8918_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8918_3_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p8918_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8918_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8918_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8918_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8918_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8910_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8910_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
static void setup_lseek_lseek_p8910_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_lseek_p8910_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8910_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p8d10_0_proc1
// static void setup_lseek_lseek_p8910_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8910_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8910_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p8910_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_p8910_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p8910_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8910_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p8910_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8910_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8910_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p8910_2_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 24576);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a2_0_1
static void setup_lseek_lseek_p8910_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_lseek_p8910_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8910_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p8918_1_proc1
// static void setup_lseek_lseek_p8910_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_lseek_p8f18_0_final
// static void setup_lseek_lseek_p8910_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p8910_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 24576);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a2_0_1
// static int test_lseek_lseek_p8910_3_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 24576);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_p9a2_0_1
// static void setup_lseek_lseek_p8910_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_p9e3_1_common
// static void setup_lseek_lseek_p8910_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8910_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p8910_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p8910_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p890_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p890_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p890_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p890_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p890_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p890_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p890_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p890_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static int test_lseek_lseek_p88_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p88_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static int test_lseek_lseek_p88_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p88_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p87_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p87_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p87_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_p87_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_2_proc0
// static void setup_lseek_lseek_p87_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p87_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p87_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p87_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p87_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p87_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_p87_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pae_3_proc0
// static void setup_lseek_lseek_p87_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p87_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p87_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p86c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p86c_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_p86c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p86c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_proc0
// static void setup_lseek_lseek_p86c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p86c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p86c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p86c_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p86c_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p86c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p86c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_1_proc0
// static void setup_lseek_lseek_p86c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p86c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p86c_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p868_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p868_0_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_p868_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p868_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p868_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p868_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p868_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p868_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p868_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p868_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p868_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p868_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p868_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p868_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p866_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p866_0_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf3_0_1
// static void setup_lseek_lseek_p866_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p866_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p866_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p866_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p866_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p866_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p866_1_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p866_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p866_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p866_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p866_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p866_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p864_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p864_0_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf2_0_1
// static void setup_lseek_lseek_p864_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p864_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p864_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p864_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p864_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p864_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p864_1_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_p864_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p864_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p864_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p864_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p864_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p863_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p863_0_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf18_0_1
// static void setup_lseek_lseek_p863_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p863_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p863_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p863_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p863_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p863_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p863_1_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p863_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p863_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_1_proc0
// static void setup_lseek_lseek_p863_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p863_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p863_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p862_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p862_0_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf10_0_1
// static void setup_lseek_lseek_p862_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p862_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_0_proc0
// static void setup_lseek_lseek_p862_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p862_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p862_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p862_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p862_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_p862_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p862_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p862_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p862_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p862_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p860_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p860_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p860_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p860_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_1_proc0
// static void setup_lseek_lseek_p860_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p860_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p860_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p860_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p860_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p860_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p860_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p860_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p860_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p860_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p84_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
// static void setup_lseek_lseek_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p83_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p83_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p83_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_p83_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_p83_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_p83_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p83_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p83_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p83_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p83_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_p83_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pd4_2_proc1
// static void setup_lseek_lseek_p83_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_p83_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p83_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p82c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p82c_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p82c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p82c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_1_proc0
// static void setup_lseek_lseek_p82c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_0_proc1
// static void setup_lseek_lseek_p82c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p82c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p82c_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p82c_1_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p82c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_1_common
// static void setup_lseek_lseek_p82c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p82c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p82c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p82c_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p828_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p828_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p828_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p828_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p828_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p828_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p828_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p828_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p828_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p828_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p828_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p828_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p828_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p828_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p826_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p826_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p826_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p826_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p826_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p826_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p826_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p824_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p824_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_p824_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p824_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p824_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p824_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p824_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p823_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p823_0_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p823_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p823_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p823_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p823_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p823_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p822_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p822_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_p822_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p822_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p822_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p822_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p822_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p822_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p822_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static void setup_lseek_lseek_p822_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p822_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p822_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p822_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p822_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p820_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p820_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p820_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p820_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p820_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p820_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p820_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static int test_lseek_lseek_p80_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p7_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p7_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
static void setup_lseek_lseek_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p7_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p7_1_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
static void setup_lseek_lseek_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_lseek_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p6c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p6c_0_1(void) {
//   int r = lseek(11, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf6_0_1
// static void setup_lseek_lseek_p6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_p6c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p6c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p6c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p68_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p68_0_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p68_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p68_1_1(void) {
//   int r = lseek(11, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf4_0_1
// static void setup_lseek_lseek_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
static void setup_lseek_lseek_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_lseek_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p68_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p66_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p66_0_1(void) {
//   int r = lseek(11, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf3_0_1
// static void setup_lseek_lseek_p66_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p66_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p68_1_proc0
// static void setup_lseek_lseek_p66_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p66_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p66_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p64_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p64_0_1(void) {
//   int r = lseek(11, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf2_0_1
// static void setup_lseek_lseek_p64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p68_1_proc0
// static void setup_lseek_lseek_p64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p64_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p64_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p63_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p63_0_1(void) {
//   int r = lseek(11, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf18_0_1
// static void setup_lseek_lseek_p63_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p63_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p68_0_proc0
// static void setup_lseek_lseek_p63_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p63_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p63_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p62_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p62_0_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf10_0_1
// static void setup_lseek_lseek_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p68_0_proc0
// static void setup_lseek_lseek_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p62_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p62_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p62_1_1(void) {
//   int r = lseek(11, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf10_2_1
// static void setup_lseek_lseek_p62_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p62_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p68_1_proc0
// static void setup_lseek_lseek_p62_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p62_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p62_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p60_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p60_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_1
// static void setup_lseek_lseek_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_p68_1_proc0
// static void setup_lseek_lseek_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p60_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p4_0_1(void) {
//   int r = lseek(11, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pe_0_1
static void setup_lseek_lseek_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_lseek_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p4_0_final(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal
// static void setup_lseek_lseek_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p4_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_lseek_p4_0_common
// static void setup_lseek_lseek_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p4_1_final(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal
// static void setup_lseek_lseek_p4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p3_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p3_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_3_proc0
// static void setup_lseek_lseek_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p3_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p3_1_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_lseek_pf8_0_common
// static void setup_lseek_lseek_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_0_proc1
// static void setup_lseek_lseek_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_lseek_pf8_5_proc0
// static void setup_lseek_lseek_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_final
// static void setup_lseek_lseek_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_lseek_pf8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p2c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p2c_0_1(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd6_0_1
// static void setup_lseek_lseek_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pb58_0_proc1
// static void setup_lseek_lseek_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p28_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p28_0_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p28_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p28_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p28_1_1(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd4_0_1
// static void setup_lseek_lseek_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p28_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p26_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p26_0_1(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd3_0_1
// static void setup_lseek_lseek_p26_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p26_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p26_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p26_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p26_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p24_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p24_0_1(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd2_0_1
// static void setup_lseek_lseek_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p24_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p23_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p23_0_1(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd18_0_1
// static void setup_lseek_lseek_p23_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p23_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p23_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p23_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p23_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p22_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p22_0_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_0_1
// static void setup_lseek_lseek_p22_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p22_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p22_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_2_proc0
// static void setup_lseek_lseek_p22_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p22_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p22_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p22_1_1(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pd10_2_1
// static void setup_lseek_lseek_p22_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd8_0_common
// static void setup_lseek_lseek_p22_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p22_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p22_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p22_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p20_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p20_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pf8_0_0
// static void setup_lseek_lseek_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbc6_0_common
// static void setup_lseek_lseek_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_lseek_pbd0_3_proc0
// static void setup_lseek_lseek_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_lseek_pbd8_0_final
// static void setup_lseek_lseek_p20_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal

/*
 * calls: lseek lseek
 */
// static int test_lseek_lseek_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static int test_lseek_lseek_p0_0_1(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_lseek_pc_0_1
// static void setup_lseek_lseek_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_lseek_p4_0_common
// static void setup_lseek_lseek_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_lseek_pbd8_0_proc1
// static void setup_lseek_lseek_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal
// static void setup_lseek_lseek_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_lseek_pbd8_0_procfinal


/*
 * calls: lseek memread
 */
static int test_lseek_memread_pf8_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_memread_pf8_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static void setup_lseek_memread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_memread_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_lseek_memread_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_memread_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_memread_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pf8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
static void setup_lseek_memread_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pf8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
static void setup_lseek_memread_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memread_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf8_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pf8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
static void setup_lseek_memread_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memread_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
static int test_lseek_memread_pf4_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
static void setup_lseek_memread_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_memread_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memread_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pf4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf4_0_common
static void setup_lseek_memread_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memread_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf4_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pf4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf4_0_common
static void setup_lseek_memread_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memread_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf4_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pf4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf4_0_common
static void setup_lseek_memread_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memread_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pf0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
static void setup_lseek_memread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_memread_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pf4_0_proc0
// static void setup_lseek_memread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pf0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf0_0_common
// static void setup_lseek_memread_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pf4_1_proc0
// static void setup_lseek_memread_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf0_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pf0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf0_0_common
// static void setup_lseek_memread_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pf4_2_proc0
// static void setup_lseek_memread_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pf0_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pf0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf0_0_common
// static void setup_lseek_memread_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pf4_3_proc0
// static void setup_lseek_memread_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pe_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
static int test_lseek_memread_pe_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_lseek_memread_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
static void setup_lseek_memread_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_memread_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pe_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
static void setup_lseek_memread_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_memread_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
// static void setup_lseek_memread_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_0_proc0
static void setup_lseek_memread_pd8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memread_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
// static void setup_lseek_memread_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_1_proc0
// static void setup_lseek_memread_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pd8_0_proc1
// static void setup_lseek_memread_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
// static void setup_lseek_memread_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_0_proc0
static void setup_lseek_memread_pd8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memread_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd8_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
// static void setup_lseek_memread_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_1_proc0
// static void setup_lseek_memread_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pd8_2_proc1
// static void setup_lseek_memread_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf4_0_common
// static void setup_lseek_memread_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_0_proc0
static void setup_lseek_memread_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memread_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf4_0_common
// static void setup_lseek_memread_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_1_proc0
// static void setup_lseek_memread_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pd4_0_proc1
// static void setup_lseek_memread_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd4_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf4_0_common
// static void setup_lseek_memread_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_0_proc0
static void setup_lseek_memread_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memread_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd4_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf4_0_common
// static void setup_lseek_memread_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_1_proc0
// static void setup_lseek_memread_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pd4_2_proc1
// static void setup_lseek_memread_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf0_0_common
// static void setup_lseek_memread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_0_proc0
// static void setup_lseek_memread_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pd4_0_proc1
// static void setup_lseek_memread_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf0_0_common
// static void setup_lseek_memread_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_1_proc0
// static void setup_lseek_memread_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pd4_0_proc1
// static void setup_lseek_memread_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd0_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf0_0_common
// static void setup_lseek_memread_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_0_proc0
// static void setup_lseek_memread_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pd4_2_proc1
// static void setup_lseek_memread_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pd0_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pd0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf0_0_common
// static void setup_lseek_memread_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_1_proc0
// static void setup_lseek_memread_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pd4_2_proc1
// static void setup_lseek_memread_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
// static void setup_lseek_memread_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_0_proc0
// static void setup_lseek_memread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_pc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memread_pf8_0_common
// static void setup_lseek_memread_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pe_1_proc0
// static void setup_lseek_memread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memread_pf8_0_proc1
// static void setup_lseek_memread_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_final
// static void setup_lseek_memread_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memread_pf8_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_pbe_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_memread_pbe_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
static void setup_lseek_memread_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memread_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_lseek_memread_pbe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_memread_pbe_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_memread_pbe_0_procfinal(void) {
  
}

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pbe_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pbe_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
static void setup_lseek_memread_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memread_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pbe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pbe_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pbd_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pbd_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
static void setup_lseek_memread_pbd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_memread_pbd_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memread_pbd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pbd_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pbd_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pbd_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pbd_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pbd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_pbd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memread_pbd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pbd_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pbd_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pbd_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pbd_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pbd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_pbd_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memread_pbd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pbd_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pbd_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pbd_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pbd_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pbd_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_pbd_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memread_pbd_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pbd_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pbd_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pbc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pbc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
static void setup_lseek_memread_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_memread_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_0_proc0
// static void setup_lseek_memread_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pbc_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pbc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pbc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pbc_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pbc_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pbc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_2_proc0
// static void setup_lseek_memread_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pbc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pbc_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pbc_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pbc_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pbc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pbc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pbc_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
static void setup_lseek_memread_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memread_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb6_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb8_0_proc0
static void setup_lseek_memread_pb6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memread_pb6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb6_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb8_0_proc0
static void setup_lseek_memread_pb6_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memread_pb6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb5_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb5_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pb5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_pb5_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_memread_pb5_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memread_pb5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb5_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb5_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb5_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pb5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_pb5_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memread_pb5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_pb5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb5_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb5_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb5_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pb5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pb5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
static void setup_lseek_memread_pb5_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memread_pb5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb5_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb5_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb5_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pb5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pb5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pb5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_pb5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb5_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pb4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb4_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pbe_0_0
// static int test_lseek_memread_pb0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb8_0_proc0
// static void setup_lseek_memread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_pae_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_memread_pae_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memread_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pae_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pae_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pae_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memread_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pae_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pae_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pad_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pad_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pad_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pad_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_0_proc0
// static void setup_lseek_memread_pad_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pad_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pad_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pad_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pad_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pad_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pad_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_2_proc0
// static void setup_lseek_memread_pad_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pad_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pad_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pad_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pad_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
static void setup_lseek_memread_pad_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memread_pad_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
// static void setup_lseek_memread_pad_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pad_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pad_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pad_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pad_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pad_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_pad_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_lseek_memread_pad_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pad_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pad_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pad_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pad_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pad_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pad_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_pad_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pad_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pad_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pad_5_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pad_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pad_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pad_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_pad_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pad_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pad_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pac_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pac_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_0_proc0
// static void setup_lseek_memread_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pac_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pac_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pac_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_2_proc0
// static void setup_lseek_memread_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pac_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pac_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pac_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
static void setup_lseek_memread_pac_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_lseek_memread_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pac_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pac_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pac_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pac_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_pac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_lseek_memread_pad_3_proc0
// static void setup_lseek_memread_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pac_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pac_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pac_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pac_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pac_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pac_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_pac_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pac_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pac_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pac_5_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pac_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pac_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pac_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_pac_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pac_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pac_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa6_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa6_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pb6_0_proc1
// static void setup_lseek_memread_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa6_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa6_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pb6_1_proc1
// static void setup_lseek_memread_pa6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa5_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa5_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pa5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pa5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_pa5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_pa5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa5_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa5_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa5_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pa5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pa5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_pa5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_pa5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa5_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa5_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa5_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pa5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_pa5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
static void setup_lseek_memread_pa5_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
// static void setup_lseek_memread_pa5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa5_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_pa5_3_0(void) {
  int r = lseek(10, 4096, SEEK_SET);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_memread_pa5_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pa5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_pa5_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memread_pa5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_pa5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa5_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa5_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa5_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pa5_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pa5_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pa5_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_pa5_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa5_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa5_5_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa5_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_pa5_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pa5_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pa5_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_pa5_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa5_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa4_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_pa4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa4_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pa4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pa4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_pa4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_pa4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa4_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pa4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_pa4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
static void setup_lseek_memread_pa4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_lseek_memread_pa4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_pa4_3_0(void) {
  int r = lseek(10, 28672, SEEK_SET);
  expect_result("r", r, 28672);
  return xerrno(r);
}
// static int test_lseek_memread_pa4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pa4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
static void setup_lseek_memread_pa4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_memread_pa4_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_lseek_memread_pa4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa4_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa4_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pa4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pa4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pa4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_pa4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa4_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa4_5_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa4_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_pa4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_pa4_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pa4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_pa4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa4_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pae_0_0
// static int test_lseek_memread_pa0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p9f_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_memread_p9f_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p9f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_p9f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pae_0_proc0
// static void setup_lseek_memread_p9f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p9f_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9f_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9f_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9f_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p9f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_p9f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pae_1_proc0
// static void setup_lseek_memread_p9f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p9f_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9f_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9e8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9e8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p9e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
static void setup_lseek_memread_p9e8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_lseek_memread_p9e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p9e8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9e8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9e8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9e8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p9e8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p9e8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_p9e8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p9e8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9e8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9e8_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9e8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p9e8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p9e8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_p9e8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p9e8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9e8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9e0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9e0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
static void setup_lseek_memread_p9e0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memread_p9e0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_lseek_memread_p9e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p9e0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9e0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9e0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9e0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p9e0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p9e0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_p9e0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p9e0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9e0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9e0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9e0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p9e0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p9e0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_p9e0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p9e0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9e0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9c_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9b_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9b_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p9b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_p9b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p9b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pb6_0_proc1
// static void setup_lseek_memread_p9b_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9b_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9b_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9b_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p9b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_p9b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p9b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pb6_1_proc1
// static void setup_lseek_memread_p9b_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9b_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9a8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9a8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p9a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_p9a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
static void setup_lseek_memread_p9a8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_lseek_memread_p9a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9a8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9a8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9a8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p9a8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p9a8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p9a8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p9a8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9a8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9a8_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9a8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p9a8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p9a8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p9a8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p9a8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9a8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9a0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9a0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p9a0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p9e0_0_common
// static void setup_lseek_memread_p9a0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
static void setup_lseek_memread_p9a0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_lseek_memread_p9a0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9a0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9a0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9a0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p9a0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p9a0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p9a0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p9a0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9a0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p9a0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p9a0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p9a0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p9a0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p9a0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p9a0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p9a0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p9f_0_0
// static int test_lseek_memread_p98_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p97_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_memread_p97_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p97_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p97_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pae_0_proc0
// static void setup_lseek_memread_p97_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p97_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p97_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p97_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p97_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p97_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p97_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pae_1_proc0
// static void setup_lseek_memread_p97_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p97_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p97_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p968_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p968_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
static void setup_lseek_memread_p968_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memread_p968_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_lseek_memread_p968_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p968_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p968_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p968_1_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_memread_p968_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p968_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p968_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memread_p968_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p968_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p968_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p968_2_0(void) {
  int r = lseek(10, 4096, SEEK_CUR);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_memread_p968_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p968_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p968_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_lseek_memread_p968_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p968_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p968_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p968_3_0(void) {
//   int r = lseek(10, 4096, SEEK_CUR);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p968_2_0
// static int test_lseek_memread_p968_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p968_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p968_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_lseek_memread_pad_3_proc0
// static void setup_lseek_memread_p968_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p968_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p968_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p968_4_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p968_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p968_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p968_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_p968_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p968_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p968_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p968_5_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p968_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p968_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p968_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_lseek_memread_pad_3_proc0
// static void setup_lseek_memread_p968_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p968_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p968_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p968_6_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p968_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p968_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p968_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_p968_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p968_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p968_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p960_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p960_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p960_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_p960_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x6000);
// }
// ^ See setup_lseek_memread_pac_2_proc0
// static void setup_lseek_memread_p960_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p960_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p960_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p960_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p968_1_0
// static int test_lseek_memread_p960_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p960_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p960_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_p968_1_proc0
// static void setup_lseek_memread_p960_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p960_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p960_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p960_2_0(void) {
//   int r = lseek(10, 4096, SEEK_CUR);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p968_2_0
// static int test_lseek_memread_p960_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p960_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_p960_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_lseek_memread_p968_2_proc0
// static void setup_lseek_memread_p960_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p960_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p960_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p960_3_0(void) {
//   int r = lseek(10, 4096, SEEK_CUR);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p968_2_0
// static int test_lseek_memread_p960_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p960_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_p960_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_lseek_memread_pad_3_proc0
// static void setup_lseek_memread_p960_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p960_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p960_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p960_4_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p960_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p960_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p960_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_p960_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p960_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p960_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p960_5_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p960_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p960_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_p960_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_lseek_memread_pad_3_proc0
// static void setup_lseek_memread_p960_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p960_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p960_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p960_6_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p960_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p960_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p960_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_p960_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p960_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p960_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p94_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p94_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p93_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p93_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p93_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p93_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p93_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pb6_0_proc1
// static void setup_lseek_memread_p93_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p93_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p93_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p93_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p93_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p93_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p93_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pb6_1_proc1
// static void setup_lseek_memread_p93_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p93_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p928_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p928_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p928_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p968_0_common
// static void setup_lseek_memread_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
static void setup_lseek_memread_p928_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_lseek_memread_p928_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p928_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p928_1_0(void) {
  int r = lseek(10, 9981952, SEEK_CUR);
  expect_result("r", r, 9981952);
  return xerrno(r);
}
// static int test_lseek_memread_p928_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p928_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p9e0_0_common
// static void setup_lseek_memread_p928_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
static void setup_lseek_memread_p928_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_lseek_memread_p928_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p928_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p928_2_0(void) {
//   int r = lseek(10, 4096, SEEK_CUR);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p968_2_0
// static int test_lseek_memread_p928_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p928_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p928_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p928_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p928_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p928_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p928_3_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p928_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p928_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p928_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p928_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p928_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p928_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p928_4_0(void) {
  int r = lseek(10, 4096, SEEK_CUR);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_memread_p928_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p928_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p928_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa5_3_proc0
// static void setup_lseek_memread_p928_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p928_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p928_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p928_5_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p928_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p928_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p928_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p928_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p928_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p928_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p920_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p920_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p920_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_p920_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p920_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x6000);
// }
// ^ See setup_lseek_memread_pa4_2_proc1
// static void setup_lseek_memread_p920_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p920_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p920_1_0(void) {
  int r = lseek(10, 28672, SEEK_CUR);
  expect_result("r", r, 28672);
  return xerrno(r);
}
// static int test_lseek_memread_p920_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p920_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_p920_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p920_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_lseek_memread_pa4_3_proc1
// static void setup_lseek_memread_p920_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p920_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p920_2_0(void) {
//   int r = lseek(10, 4096, SEEK_CUR);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p968_2_0
// static int test_lseek_memread_p920_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p920_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p920_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p920_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p920_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p920_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p920_3_0(void) {
//   int r = lseek(10, 4096, SEEK_CUR);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p968_2_0
// static int test_lseek_memread_p920_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p920_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_p920_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
static void setup_lseek_memread_p920_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_lseek_memread_p920_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p920_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p920_4_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p920_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p920_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p920_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p920_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p920_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p920_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p920_5_0(void) {
  int r = lseek(10, 32768, SEEK_CUR);
  expect_result("r", r, 65536);
  return xerrno(r);
}
// static int test_lseek_memread_p920_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p920_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
static void setup_lseek_memread_p920_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memread_p920_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_lseek_memread_pa4_3_proc1
// static void setup_lseek_memread_p920_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p920_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p920_6_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p920_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p920_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p920_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p920_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p920_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p920_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p97_0_0
// static int test_lseek_memread_p90_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p8f8_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_memread_p8f8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p8f8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memread_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8f8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8f8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8f8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8f8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p8f8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memread_p8f8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8f8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8f4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8f4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
static void setup_lseek_memread_p8f4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memread_p8f4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x1e27000);
}
// static void setup_lseek_memread_p8f4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
static void setup_lseek_memread_p8f4_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_lseek_memread_p8f4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8f4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8f4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8f4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f4_0_common
static void setup_lseek_memread_p8f4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x1e27000);
}
// static void setup_lseek_memread_p8f4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f4_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8f4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8f4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8f4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8f4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p8f4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_lseek_memread_p8f4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8f4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8f4_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8f4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8f4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p8f4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_lseek_memread_p8f4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8f4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8f4_4_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8f4_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8f4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p8f4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_lseek_memread_p8f4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8f4_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8f0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
static void setup_lseek_memread_p8f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memread_p8f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x7000);
}
// static void setup_lseek_memread_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8f0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8f0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f0_0_common
static void setup_lseek_memread_p8f0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
// static void setup_lseek_memread_p8f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f0_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8f0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p8f0_2_0(void) {
  int r = lseek(10, -8192, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_memread_p8f0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
static void setup_lseek_memread_p8f0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memread_p8f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8f0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8f0_3_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f0_2_0
// static int test_lseek_memread_p8f0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8f0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8f0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_p8f0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8f0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8f0_4_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f0_2_0
// static int test_lseek_memread_p8f0_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8f0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8f0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_p8f0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8f0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8f0_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8e_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8e_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p8e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memread_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8d8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_p8e_0_proc0
// static void setup_lseek_memread_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pb6_0_proc1
// static void setup_lseek_memread_p8d8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8d8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8d8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_p8e_0_proc0
// static void setup_lseek_memread_p8d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pb6_1_proc1
// static void setup_lseek_memread_p8d8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8d8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8d4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f4_0_common
// static void setup_lseek_memread_p8d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa5_3_proc0
static void setup_lseek_memread_p8d4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x1e27000);
}
// static void setup_lseek_memread_p8d4_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8d4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8d4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8d4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f4_0_common
// static void setup_lseek_memread_p8d4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa5_3_proc0
static void setup_lseek_memread_p8d4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x1e27000);
}
// static void setup_lseek_memread_p8d4_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8d4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8d4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8d4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8d4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_p8d4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_lseek_memread_p9a8_0_proc1
// static void setup_lseek_memread_p8d4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8d4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d4_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8d4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8d4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p8d4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memread_p8d4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_lseek_memread_p9a8_0_proc1
// static void setup_lseek_memread_p8d4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8d4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d4_4_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8d4_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8d4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8d4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_p8d4_3_proc0
static void setup_lseek_memread_p8d4_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_lseek_memread_p8d4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8d4_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8d0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f0_0_common
// static void setup_lseek_memread_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa5_3_proc0
static void setup_lseek_memread_p8d0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x7000);
}
// static void setup_lseek_memread_p8d0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8d0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8d0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f0_0_common
// static void setup_lseek_memread_p8d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa5_3_proc0
static void setup_lseek_memread_p8d0_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
// static void setup_lseek_memread_p8d0_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8d0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d0_2_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f0_2_0
// static int test_lseek_memread_p8d0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8d0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8d0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa5_3_proc0
// static void setup_lseek_memread_p8d0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p8d0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8d0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d0_3_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f0_2_0
// static int test_lseek_memread_p8d0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8d0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8d0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p8d0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p8d0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8d0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8d0_4_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f0_2_0
// static int test_lseek_memread_p8d0_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8d0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8d0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p8d0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p8d0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8d0_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8f8_0_0
// static int test_lseek_memread_p8c_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_p8e_0_proc0
// static void setup_lseek_memread_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p8b8_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_memread_p8b8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pae_0_proc0
// static void setup_lseek_memread_p8b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b8_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8b8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pae_1_proc0
// static void setup_lseek_memread_p8b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b4_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8b4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
static void setup_lseek_memread_p8b4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memread_p8b4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_lseek_memread_p8b4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8b4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b4_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8b4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8b4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8b4_0_common
static void setup_lseek_memread_p8b4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_lseek_memread_p8b4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8b4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p8b4_2_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 28672);
  return xerrno(r);
}
// static int test_lseek_memread_p8b4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
static void setup_lseek_memread_p8b4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memread_p8b4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2297000);
}
// static void setup_lseek_memread_p8b4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8b4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b4_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8b4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8b4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p8b4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_lseek_memread_p8b4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p8b4_4_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_memread_p8b4_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
static void setup_lseek_memread_p8b4_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memread_p8b4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x1000);
}
// static void setup_lseek_memread_p8b4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8b4_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p8b4_5_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_memread_p8b4_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8b4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8b4_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_lseek_memread_p968_2_proc0
// static void setup_lseek_memread_p8b4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b4_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b4_6_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_5_0
// static int test_lseek_memread_p8b4_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8b4_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8b4_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_lseek_memread_pad_3_proc0
// static void setup_lseek_memread_p8b4_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b4_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b4_7_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8b4_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8b4_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p8b4_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memread_p8b4_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b4_7_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b4_8_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8b4_8_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8b4_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8b4_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_p8b4_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b4_8_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b4_9_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8b4_9_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8b4_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8b4_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_2_proc0
// static void setup_lseek_memread_p8b4_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b4_9_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b4_10_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8b4_10_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p8b4_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8b4_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_p8b4_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b4_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b4_10_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b0_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8b0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f4_0_common
static void setup_lseek_memread_p8b0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x6000);
}
// static void setup_lseek_memread_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b0_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8b0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f4_0_common
static void setup_lseek_memread_p8b0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
}
// static void setup_lseek_memread_p8b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8b0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b0_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_4_0
// static int test_lseek_memread_p8b0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
static void setup_lseek_memread_p8b0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memread_p8b0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x7000);
}
// static void setup_lseek_memread_p8b0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8b0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b0_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_4_0
// static int test_lseek_memread_p8b0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8b0_2_common
static void setup_lseek_memread_p8b0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
// static void setup_lseek_memread_p8b0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p8b0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b0_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_5_0
// static int test_lseek_memread_p8b0_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8b0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_0_proc0
// static void setup_lseek_memread_p8b0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b0_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b0_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 28672);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_2_0
// static int test_lseek_memread_p8b0_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_p8b0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x6000);
// }
// ^ See setup_lseek_memread_pac_2_proc0
// static void setup_lseek_memread_p8b0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b0_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p8b0_6_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_memread_p8b0_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8b0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_2_proc0
// static void setup_lseek_memread_p8b0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b0_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b0_7_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_4_0
// static int test_lseek_memread_p8b0_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbe_0_common
// static void setup_lseek_memread_p8b0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_lseek_memread_pad_3_proc0
// static void setup_lseek_memread_p8b0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b0_7_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b0_8_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_5_0
// static int test_lseek_memread_p8b0_8_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8b0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_p8b0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b0_8_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b0_9_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_5_0
// static int test_lseek_memread_p8b0_9_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
static void setup_lseek_memread_p8b0_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memread_p8b0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b0_9_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8b0_10_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_5_0
// static int test_lseek_memread_p8b0_10_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p8b0_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p8b0_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_p8b0_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8b0_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8b0_10_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p8a_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p8a_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p898_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p898_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p898_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p898_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p898_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pb6_0_proc1
// static void setup_lseek_memread_p898_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p898_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p898_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p898_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p898_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p898_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p898_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pb6_1_proc1
// static void setup_lseek_memread_p898_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p898_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p894_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p894_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8b4_0_common
// static void setup_lseek_memread_p894_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa5_3_proc0
static void setup_lseek_memread_p894_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_lseek_memread_p894_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p894_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p894_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p894_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8b4_0_common
// static void setup_lseek_memread_p894_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa5_3_proc0
static void setup_lseek_memread_p894_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_lseek_memread_p894_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p894_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p894_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 28672);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_2_0
// static int test_lseek_memread_p894_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8b4_2_common
// static void setup_lseek_memread_p894_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
static void setup_lseek_memread_p894_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x2297000);
}
// static void setup_lseek_memread_p894_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p894_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p894_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p894_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p894_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_p894_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x985000);
// }
// ^ See setup_lseek_memread_p928_1_proc1
// static void setup_lseek_memread_p894_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p894_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p894_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_5_0
// static int test_lseek_memread_p894_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p894_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p894_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_lseek_memread_p920_3_proc1
// static void setup_lseek_memread_p894_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p894_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p894_5_0(void) {
  int r = lseek(10, 5066752, SEEK_END);
  expect_result("r", r, 5066752);
  return xerrno(r);
}
// static int test_lseek_memread_p894_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f4_0_common
static void setup_lseek_memread_p894_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5066752, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_memread_p894_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x4d4000);
}
// static void setup_lseek_memread_p894_5_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p894_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p894_6_0(void) {
  int r = lseek(10, 159744, SEEK_END);
  expect_result("r", r, 159744);
  return xerrno(r);
}
// static int test_lseek_memread_p894_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p894_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 159744, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_memread_p894_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_lseek_memread_p894_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p894_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p894_7_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p894_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
static void setup_lseek_memread_p894_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memread_p894_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p894_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p894_7_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p894_8_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p894_8_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p894_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p894_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p894_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p894_8_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p894_9_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p894_9_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p894_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_p894_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p894_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p894_9_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p894_10_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p894_10_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p894_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p894_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p894_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p894_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p894_10_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p890_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p890_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f4_0_common
// static void setup_lseek_memread_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa5_3_proc0
static void setup_lseek_memread_p890_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x6000);
}
// static void setup_lseek_memread_p890_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p890_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p890_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p890_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f4_0_common
// static void setup_lseek_memread_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa5_3_proc0
static void setup_lseek_memread_p890_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
}
// static void setup_lseek_memread_p890_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p890_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p890_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_5_0
// static int test_lseek_memread_p890_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p890_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p890_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_p890_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p890_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p890_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p890_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_5_0
// static int test_lseek_memread_p890_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p890_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p890_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_p890_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p890_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p890_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p890_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_4_0
// static int test_lseek_memread_p890_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p890_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8b0_2_common
// static void setup_lseek_memread_p890_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p890_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x7000);
// }
// ^ See setup_lseek_memread_p8d0_0_proc1
// static void setup_lseek_memread_p890_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p890_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p890_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 28672);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_2_0
// static int test_lseek_memread_p890_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p890_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pad_2_common
// static void setup_lseek_memread_p890_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p890_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x6000);
// }
// ^ See setup_lseek_memread_pa4_2_proc1
// static void setup_lseek_memread_p890_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p890_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p890_6_0(void) {
  int r = lseek(10, 32768, SEEK_END);
  expect_result("r", r, 32768);
  return xerrno(r);
}
// static int test_lseek_memread_p890_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p890_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p8f0_0_common
// static void setup_lseek_memread_p890_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_p920_5_proc0
// static void setup_lseek_memread_p890_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x7000);
// }
// ^ See setup_lseek_memread_p8d0_1_proc1
// static void setup_lseek_memread_p890_6_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memread_p8f4_0_final
// static void setup_lseek_memread_p890_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p890_7_0(void) {
  int r = lseek(10, 28672, SEEK_END);
  expect_result("r", r, 61440);
  return xerrno(r);
}
// static int test_lseek_memread_p890_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p890_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p9e0_0_common
// static void setup_lseek_memread_p890_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pa4_3_proc0
// static void setup_lseek_memread_p890_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x7000);
// }
// ^ See setup_lseek_memread_p9a0_0_proc1
// static void setup_lseek_memread_p890_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p890_7_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p890_8_0(void) {
  int r = lseek(10, 24576, SEEK_END);
  expect_result("r", r, 57344);
  return xerrno(r);
}
// static int test_lseek_memread_p890_8_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p890_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_p9e0_0_common
static void setup_lseek_memread_p890_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_memread_p890_8_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_lseek_memread_p890_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p890_8_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p890_9_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b4_5_0
// static int test_lseek_memread_p890_9_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p890_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p890_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p890_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p890_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p890_9_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p8b8_0_0
// static int test_lseek_memread_p88_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p87_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p87_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p87_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p87_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pae_0_proc0
// static void setup_lseek_memread_p87_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p87_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p87_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p87_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p87_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p87_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p87_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pae_1_proc0
// static void setup_lseek_memread_p87_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p87_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p87_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p868_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p868_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p868_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p868_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_0_proc0
// static void setup_lseek_memread_p868_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p868_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p868_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p868_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p868_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p868_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p868_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_2_proc0
// static void setup_lseek_memread_p868_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p868_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p868_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p868_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p868_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p868_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p868_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_p868_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p868_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p868_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p868_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p868_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p868_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p868_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_p868_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p868_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p868_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p860_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p860_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p860_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p860_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_0_proc0
// static void setup_lseek_memread_p860_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p860_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p860_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p860_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p860_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p860_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p860_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_2_proc0
// static void setup_lseek_memread_p860_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p860_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p860_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p860_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p860_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p860_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p860_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_1_proc0
// static void setup_lseek_memread_p860_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p860_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p860_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p860_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p860_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p860_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p860_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pbd_3_proc0
// static void setup_lseek_memread_p860_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p860_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p860_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p84_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p83_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p83_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p83_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p83_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p83_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pb6_0_proc1
// static void setup_lseek_memread_p83_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p83_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p83_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p83_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p83_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p83_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p83_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pb6_1_proc1
// static void setup_lseek_memread_p83_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p83_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p828_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p828_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p828_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p828_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_p828_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p828_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p828_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p828_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p828_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p828_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p828_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_p828_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p828_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p828_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p828_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p828_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p828_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p828_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p828_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p828_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p828_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p828_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p828_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p828_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p828_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p828_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p828_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p828_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p820_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p820_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p820_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p820_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_p820_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p820_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p820_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p820_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p820_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p820_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p820_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_0_proc0
// static void setup_lseek_memread_p820_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p820_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p820_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p820_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p820_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p820_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p820_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p820_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p820_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p820_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p820_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p820_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p820_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p820_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p820_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p820_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p820_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_pf8_0_0
// static int test_lseek_memread_p80_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memread_pb5_1_proc0
// static void setup_lseek_memread_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
static int test_lseek_memread_p7_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_memread_p7_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
static void setup_lseek_memread_p7_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_memread_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pb6_0_proc1
// static void setup_lseek_memread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p7_0_final(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal
// static void setup_lseek_memread_p7_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p7_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p7_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_memread_p7_0_common
// static void setup_lseek_memread_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pb6_1_proc1
// static void setup_lseek_memread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p7_1_final(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal
// static void setup_lseek_memread_p7_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p68_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p68_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p68_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p68_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p60_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p60_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p60_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p60_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_memread_p7_0_common
// static void setup_lseek_memread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p4_0_final(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal
// static void setup_lseek_memread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p3_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p3_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_memread_p7_0_common
// static void setup_lseek_memread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memread_pb6_0_proc1
// static void setup_lseek_memread_p3_0_final(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal
// static void setup_lseek_memread_p3_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p3_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p3_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_memread_p7_0_common
// static void setup_lseek_memread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memread_pb6_1_proc1
// static void setup_lseek_memread_p3_1_final(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal
// static void setup_lseek_memread_p3_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p28_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p28_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p28_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p28_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pf4_0_1
// static void setup_lseek_memread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memread_pbd_0_common
// static void setup_lseek_memread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p20_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p20_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_0_proc1
// static void setup_lseek_memread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p20_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p20_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_lseek_memread_pf8_0_1
// static void setup_lseek_memread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memread_pbc_0_common
// static void setup_lseek_memread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memread_pb5_2_proc1
// static void setup_lseek_memread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memread_pbe_0_final
// static void setup_lseek_memread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal

/*
 * calls: lseek memread
 */
// static int test_lseek_memread_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memread_p7_0_0
// static int test_lseek_memread_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memread_pe_0_1
// static void setup_lseek_memread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_memread_p7_0_common
// static void setup_lseek_memread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memread_pbe_0_proc1
// static void setup_lseek_memread_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal
// static void setup_lseek_memread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memread_pbe_0_procfinal


/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_pfc_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_memwrite_pfc_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static void setup_lseek_memwrite_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_memwrite_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_lseek_memwrite_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_memwrite_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_memwrite_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pfc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pfc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
static void setup_lseek_memwrite_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memwrite_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pfa_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
static int test_lseek_memwrite_pfa_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
static void setup_lseek_memwrite_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_memwrite_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_lseek_memwrite_pfa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pfa_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pfa_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pfa_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pfa_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pfa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfa_0_common
static void setup_lseek_memwrite_pfa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_lseek_memwrite_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pfa_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pfa_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pf8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pf8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
static void setup_lseek_memwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_memwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pf8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pf8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pf8_0_common
static void setup_lseek_memwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pf0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
static int test_lseek_memwrite_pf0_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_lseek_memwrite_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
static void setup_lseek_memwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pf0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pf0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
static void setup_lseek_memwrite_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pf0_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pf0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
static void setup_lseek_memwrite_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pf0_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pf0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
static void setup_lseek_memwrite_pf0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pe_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pe_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
static void setup_lseek_memwrite_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_memwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pe_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
static void setup_lseek_memwrite_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_memwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pdc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pdc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
// static void setup_lseek_memwrite_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_0_proc0
static void setup_lseek_memwrite_pdc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memwrite_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pdc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pdc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
// static void setup_lseek_memwrite_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_1_proc0
// static void setup_lseek_memwrite_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_pdc_0_proc1
// static void setup_lseek_memwrite_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pda_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pda_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
static void setup_lseek_memwrite_pda_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_memwrite_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_0_proc0
static void setup_lseek_memwrite_pda_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pda_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pda_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pda_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pda_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pda_0_common
// static void setup_lseek_memwrite_pda_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_1_proc0
// static void setup_lseek_memwrite_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pda_0_proc1
// static void setup_lseek_memwrite_pda_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pda_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pd8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pd8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pf8_0_common
// static void setup_lseek_memwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_0_proc0
// static void setup_lseek_memwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pda_0_proc1
// static void setup_lseek_memwrite_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pd8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pd8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pf8_0_common
// static void setup_lseek_memwrite_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_1_proc0
// static void setup_lseek_memwrite_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pda_0_proc1
// static void setup_lseek_memwrite_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pd0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pd0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
// static void setup_lseek_memwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_0_proc0
static void setup_lseek_memwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pd0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pd0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
// static void setup_lseek_memwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_1_proc0
// static void setup_lseek_memwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pd0_0_proc1
// static void setup_lseek_memwrite_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pd0_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pd0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
// static void setup_lseek_memwrite_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_0_proc0
static void setup_lseek_memwrite_pd0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memwrite_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pd0_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pd0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
// static void setup_lseek_memwrite_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_1_proc0
// static void setup_lseek_memwrite_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pd0_2_proc1
// static void setup_lseek_memwrite_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
// static void setup_lseek_memwrite_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_0_proc0
// static void setup_lseek_memwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_pc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_memwrite_pfc_0_common
// static void setup_lseek_memwrite_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pe_1_proc0
// static void setup_lseek_memwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_memwrite_pfc_0_proc1
// static void setup_lseek_memwrite_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_final
// static void setup_lseek_memwrite_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_memwrite_pfc_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_pbf_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_memwrite_pbf_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
static void setup_lseek_memwrite_pbf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memwrite_pbf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_lseek_memwrite_pbf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_memwrite_pbf_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_memwrite_pbf_0_procfinal(void) {
  
}

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pbe8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pbe8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
static void setup_lseek_memwrite_pbe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_memwrite_pbe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_lseek_memwrite_pbe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pbe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pbe8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pbe8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pbe8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pbe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_pbe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x985000);
}
// static void setup_lseek_memwrite_pbe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pbe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pbe8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pbe0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pbe0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
static void setup_lseek_memwrite_pbe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memwrite_pbe0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pbe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pbe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pbe0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pbe0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pbe0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pbe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
static void setup_lseek_memwrite_pbe0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pbe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pbe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pbe0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pbc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pbc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
static void setup_lseek_memwrite_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_lseek_memwrite_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pbc_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pbc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
static void setup_lseek_memwrite_pbc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memwrite_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pbc_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pbc_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
static void setup_lseek_memwrite_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memwrite_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pbc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pbc_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pb8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
static void setup_lseek_memwrite_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pb7_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pb7_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pb7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
// static void setup_lseek_memwrite_pb7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb8_0_proc0
static void setup_lseek_memwrite_pb7_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memwrite_pb7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pb7_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pb68_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pb68_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pb68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_pb68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_memwrite_pb68_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pb68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pb68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pb68_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pb68_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pb68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_pb68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memwrite_pb68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_pb68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pb68_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pb60_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pb60_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pb60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_pb60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc0
// static void setup_lseek_memwrite_pb60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_pb60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pb60_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pb60_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pb60_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pb60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_pb60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_pb60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_pb60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pb60_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pb4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pb4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
// static void setup_lseek_memwrite_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb8_0_proc0
static void setup_lseek_memwrite_pb4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_lseek_memwrite_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pb4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pb4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbc_1_common
// static void setup_lseek_memwrite_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
static void setup_lseek_memwrite_pb4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_memwrite_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pb4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pb4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
// static void setup_lseek_memwrite_pb4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb8_0_proc0
static void setup_lseek_memwrite_pb4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memwrite_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pbf_0_0
// static int test_lseek_memwrite_pb0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
// static void setup_lseek_memwrite_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb8_0_proc0
// static void setup_lseek_memwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_paf_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_memwrite_paf_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_paf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_paf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memwrite_paf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_paf_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_paf_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pae8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pae8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pae8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_pae8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_lseek_memwrite_pbe8_0_proc0
// static void setup_lseek_memwrite_pae8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pae8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pae8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pae8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pae8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pae8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_pae8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_lseek_memwrite_pae8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pae8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pae8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pae8_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pae8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pae8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_pae8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_lseek_memwrite_pae8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pae8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pae8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pae8_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pae8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pae8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_pae8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_1_proc0
// static void setup_lseek_memwrite_pae8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pae8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pae8_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pae0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pae0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pae0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_pae0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_0_proc0
// static void setup_lseek_memwrite_pae0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pae0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pae0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pae0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pae0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
static void setup_lseek_memwrite_pae0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memwrite_pae0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_lseek_memwrite_pae0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pae0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pae0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pae0_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pae0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pae0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_pae0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_1_proc0
// static void setup_lseek_memwrite_pae0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pae0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pae0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pac_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pac_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbc_1_proc0
// static void setup_lseek_memwrite_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pac_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pac_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pac_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_pac_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memwrite_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pac_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa7_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa7_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pa7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_pa7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_pa7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_pb7_0_proc1
// static void setup_lseek_memwrite_pa7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa7_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa68_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa68_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pa68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_pa68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc0
// static void setup_lseek_memwrite_pa68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_pa68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa68_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa68_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pa68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbc_1_common
// static void setup_lseek_memwrite_pa68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
static void setup_lseek_memwrite_pa68_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_lseek_memwrite_pa68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa68_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa68_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa68_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_pa68_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_pa68_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_pa68_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_pa68_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa68_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa60_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa60_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pa60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_pa60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc0
// static void setup_lseek_memwrite_pa60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_pa60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa60_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa60_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa60_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pa60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_pa60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
static void setup_lseek_memwrite_pa60_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_lseek_memwrite_pa60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa60_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa60_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa60_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_pa60_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_pa60_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_pa60_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_pa60_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa60_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa4_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb4_1_proc1
// static void setup_lseek_memwrite_pa4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa4_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pa4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_pa4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_pa4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pb4_2_proc1
// static void setup_lseek_memwrite_pa4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_paf_0_0
// static int test_lseek_memwrite_pa0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_p9f8_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_memwrite_p9f8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p9f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_p9f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_paf_0_proc0
// static void setup_lseek_memwrite_p9f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p9f8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9f8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9f4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9f4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p9f4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p9f4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_lseek_memwrite_p9f4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p9f4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9f4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9f4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9f4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p9f4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p9f4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_1_proc0
// static void setup_lseek_memwrite_p9f4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p9f4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9f4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9f0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
static void setup_lseek_memwrite_p9f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memwrite_p9f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_lseek_memwrite_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p9f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9f0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9f0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p9f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p9f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_1_proc0
// static void setup_lseek_memwrite_p9f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p9f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9f0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9e_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9e_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
static void setup_lseek_memwrite_p9e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_lseek_memwrite_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p9e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9e_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9e_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
// static void setup_lseek_memwrite_p9e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbc_1_proc0
// static void setup_lseek_memwrite_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p9e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9e_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9e_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9e_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p9e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
// static void setup_lseek_memwrite_p9e_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pac_1_proc0
// static void setup_lseek_memwrite_p9e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p9e_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9e_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9c_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9b8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9b8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p9b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_p9b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p9b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_pb7_0_proc1
// static void setup_lseek_memwrite_p9b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9b8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9b4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9b4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p9b4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_p9b4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
static void setup_lseek_memwrite_p9b4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_lseek_memwrite_p9b4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9b4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9b4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9b4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p9b4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p9b4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p9b4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p9b4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9b4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9b0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9b0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p9b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p9f0_0_common
// static void setup_lseek_memwrite_p9b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
static void setup_lseek_memwrite_p9b0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_lseek_memwrite_p9b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9b0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9b0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9b0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p9b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p9b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p9b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p9b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9b0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9a_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9a_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
static void setup_lseek_memwrite_p9a_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_lseek_memwrite_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9a_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9a_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
// static void setup_lseek_memwrite_p9a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb4_1_proc1
// static void setup_lseek_memwrite_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p9a_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p9a_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p9a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbf_0_common
// static void setup_lseek_memwrite_p9a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pb4_2_proc1
// static void setup_lseek_memwrite_p9a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p9f8_0_0
// static int test_lseek_memwrite_p98_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_p978_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_memwrite_p978_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p978_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p978_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_paf_0_proc0
// static void setup_lseek_memwrite_p978_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p978_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p978_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p974_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p974_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p974_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p974_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_lseek_memwrite_p974_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p974_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p974_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_p974_1_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 155648);
  return xerrno(r);
}
// static int test_lseek_memwrite_p974_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p974_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p974_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_memwrite_p974_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p974_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p974_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p974_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p974_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p974_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p974_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_1_proc0
// static void setup_lseek_memwrite_p974_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p974_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p974_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p970_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p970_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p970_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_p970_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_lseek_memwrite_pae0_1_proc0
// static void setup_lseek_memwrite_p970_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p970_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p970_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p970_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p974_1_0
// static int test_lseek_memwrite_p970_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p970_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p970_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_p974_1_proc0
// static void setup_lseek_memwrite_p970_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p970_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p970_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p970_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p970_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p970_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p970_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_1_proc0
// static void setup_lseek_memwrite_p970_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p970_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p970_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p96_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p96_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbc_1_proc0
// static void setup_lseek_memwrite_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p96_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p96_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p96_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p96_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p96_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p96_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pac_1_proc0
// static void setup_lseek_memwrite_p96_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p96_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p96_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p94_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p94_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p938_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p938_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p938_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p938_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p938_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_pb7_0_proc1
// static void setup_lseek_memwrite_p938_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p938_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p934_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p934_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p934_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbc_1_common
// static void setup_lseek_memwrite_p934_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p934_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_lseek_memwrite_pa68_1_proc1
// static void setup_lseek_memwrite_p934_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p934_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p934_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p974_1_0
// static int test_lseek_memwrite_p934_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p934_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p934_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memwrite_p934_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p934_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p934_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p934_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p934_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p934_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p934_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p934_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p934_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p934_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p930_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p930_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p930_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_p930_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p930_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_lseek_memwrite_pa60_1_proc1
// static void setup_lseek_memwrite_p930_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p930_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p930_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p974_1_0
// static int test_lseek_memwrite_p930_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p930_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p930_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p934_1_proc0
// static void setup_lseek_memwrite_p930_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p930_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p930_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p930_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p930_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p930_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p930_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p930_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p930_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p930_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p92_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p92_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p92_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p92_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p92_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb4_1_proc1
// static void setup_lseek_memwrite_p92_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p92_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p92_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p92_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p92_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p92_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p92_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pb4_2_proc1
// static void setup_lseek_memwrite_p92_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p92_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p978_0_0
// static int test_lseek_memwrite_p90_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_p8fc_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_memwrite_p8fc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8fc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p8fc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_memwrite_p8fc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8fc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8fc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8fa_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8fa_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
static void setup_lseek_memwrite_p8fa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_memwrite_p8fa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x1e27000);
}
// static void setup_lseek_memwrite_p8fa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
static void setup_lseek_memwrite_p8fa_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_lseek_memwrite_p8fa_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8fa_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8fa_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p8fa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p8fa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_lseek_memwrite_p8fa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8fa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8fa_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8fa_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8fa_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p8fa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p8fa_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_lseek_memwrite_p8fa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8fa_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8fa_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8f8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8f8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
static void setup_lseek_memwrite_p8f8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memwrite_p8f8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
// static void setup_lseek_memwrite_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8f8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p8f8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_p8f8_1_0(void) {
  int r = lseek(10, -8192, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_memwrite_p8f8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8f8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p8f8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_1_proc0
// static void setup_lseek_memwrite_p8f8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8f8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8f8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8f0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p8f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_lseek_memwrite_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8f0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8f0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p8f0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
// static void setup_lseek_memwrite_p8f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8f0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8f0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8f0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p8f0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_memwrite_p8f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8f0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8f0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8e_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8e_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p8e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memwrite_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8dc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8dc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8e_0_proc0
// static void setup_lseek_memwrite_p8dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_pb7_0_proc1
// static void setup_lseek_memwrite_p8dc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8dc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8da_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8da_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
static void setup_lseek_memwrite_p8da_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memwrite_p8da_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_memwrite_p8da_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x1e27000);
}
// static void setup_lseek_memwrite_p8da_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p8da_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8da_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8da_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p8da_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8da_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc0
// static void setup_lseek_memwrite_p8da_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_lseek_memwrite_p9b4_0_proc1
// static void setup_lseek_memwrite_p8da_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8da_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8da_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8da_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p8da_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p8da_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_memwrite_p8da_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_lseek_memwrite_p9b4_0_proc1
// static void setup_lseek_memwrite_p8da_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8da_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8d8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8d8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8f8_0_common
// static void setup_lseek_memwrite_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8da_0_proc0
static void setup_lseek_memwrite_p8d8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
// static void setup_lseek_memwrite_p8d8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p8d8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8d8_1_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8f8_1_0
// static int test_lseek_memwrite_p8d8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p8d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8da_0_proc0
// static void setup_lseek_memwrite_p8d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p8d8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8d8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8d8_2_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8f8_1_0
// static int test_lseek_memwrite_p8d8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8d8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p8d8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p8d8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p8d8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8d8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8d0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8d0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8e_0_proc0
static void setup_lseek_memwrite_p8d0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
// static void setup_lseek_memwrite_p8d0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8d0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8d0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8d0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p8d0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_memwrite_p8d0_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
// static void setup_lseek_memwrite_p8d0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8d0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8d0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8d0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8d0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8d0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8e_0_proc0
// static void setup_lseek_memwrite_p8d0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pb4_2_proc1
// static void setup_lseek_memwrite_p8d0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8d0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8fc_0_0
// static int test_lseek_memwrite_p8c_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8e_0_proc0
// static void setup_lseek_memwrite_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_p8bc_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_memwrite_p8bc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8bc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8bc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_paf_0_proc0
// static void setup_lseek_memwrite_p8bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8bc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8bc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8ba_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p8ba_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p8ba_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8fa_0_common
static void setup_lseek_memwrite_p8ba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_lseek_memwrite_p8ba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8ba_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p8ba_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_p8ba_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_memwrite_p8ba_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
static void setup_lseek_memwrite_p8ba_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_memwrite_p8ba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x1e27000);
}
// static void setup_lseek_memwrite_p8ba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8ba_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p8ba_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8ba_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p8ba_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p8ba_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
static void setup_lseek_memwrite_p8ba_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_lseek_memwrite_p8ba_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8ba_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8ba_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_p8ba_3_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_memwrite_p8ba_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p8ba_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p8ba_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_lseek_memwrite_pae8_2_proc0
// static void setup_lseek_memwrite_p8ba_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8ba_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8ba_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8ba_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p8ba_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p8ba_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8ba_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_p974_1_proc0
// static void setup_lseek_memwrite_p8ba_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8ba_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8ba_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8ba_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p8ba_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p8ba_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8ba_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_1_proc0
// static void setup_lseek_memwrite_p8ba_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8ba_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8ba_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8b8_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p8b8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8da_0_common
static void setup_lseek_memwrite_p8b8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
}
// static void setup_lseek_memwrite_p8b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8b8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p8b8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8b8_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8ba_1_0
// static int test_lseek_memwrite_p8b8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
static void setup_lseek_memwrite_p8b8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_memwrite_p8b8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
// static void setup_lseek_memwrite_p8b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8b8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p8b8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8b8_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8ba_3_0
// static int test_lseek_memwrite_p8b8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8b8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p8b8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_0_proc0
// static void setup_lseek_memwrite_p8b8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8b8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8b8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_p8b8_3_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 28672);
  return xerrno(r);
}
// static int test_lseek_memwrite_p8b8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8b8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_p8b8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_lseek_memwrite_pae0_1_proc0
// static void setup_lseek_memwrite_p8b8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8b8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8b8_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8b8_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8ba_3_0
// static int test_lseek_memwrite_p8b8_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p8b8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p8b8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_1_proc0
// static void setup_lseek_memwrite_p8b8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8b8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8b8_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8b0_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p8b0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbc_1_proc0
// static void setup_lseek_memwrite_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8b0_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p8b0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pac_1_proc0
// static void setup_lseek_memwrite_p8b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8b0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p8a_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p8a_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p89c_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p89c_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p89c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p89c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p89c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_pb7_0_proc1
// static void setup_lseek_memwrite_p89c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p89c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p89a_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p89a_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
static void setup_lseek_memwrite_p89a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_memwrite_p89a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8da_0_proc0
static void setup_lseek_memwrite_p89a_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_lseek_memwrite_p89a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p89a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p89a_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p89a_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p89a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p89a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc0
static void setup_lseek_memwrite_p89a_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x985000);
}
// static void setup_lseek_memwrite_p89a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p89a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p89a_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8ba_1_0
// static int test_lseek_memwrite_p89a_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
static void setup_lseek_memwrite_p89a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_memwrite_p89a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
static void setup_lseek_memwrite_p89a_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x1000);
}
// static void setup_lseek_memwrite_p89a_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p89a_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p89a_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8ba_3_0
// static int test_lseek_memwrite_p89a_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p89a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p89a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
static void setup_lseek_memwrite_p89a_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_lseek_memwrite_p89a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p89a_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p89a_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p89a_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p89a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p89a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p934_1_proc0
// static void setup_lseek_memwrite_p89a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p89a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p89a_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p89a_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p89a_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p89a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p89a_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p89a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p89a_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p89a_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p898_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p898_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p898_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8da_0_common
// static void setup_lseek_memwrite_p898_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8da_0_proc0
static void setup_lseek_memwrite_p898_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
}
// static void setup_lseek_memwrite_p898_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p898_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p898_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8ba_1_0
// static int test_lseek_memwrite_p898_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p898_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_p8b8_1_common
// static void setup_lseek_memwrite_p898_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p898_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x7000);
// }
// ^ See setup_lseek_memwrite_p8d8_0_proc1
// static void setup_lseek_memwrite_p898_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_memwrite_p8fa_0_final
// static void setup_lseek_memwrite_p898_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p898_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8ba_3_0
// static int test_lseek_memwrite_p898_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p898_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p898_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc0
// static void setup_lseek_memwrite_p898_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p898_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p898_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p898_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 28672);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8b8_3_0
// static int test_lseek_memwrite_p898_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p898_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pae0_1_common
// static void setup_lseek_memwrite_p898_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p898_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_lseek_memwrite_pa60_1_proc1
// static void setup_lseek_memwrite_p898_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p898_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p898_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8ba_3_0
// static int test_lseek_memwrite_p898_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p898_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p898_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p898_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p898_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p898_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p890_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p890_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb4_1_proc1
// static void setup_lseek_memwrite_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p890_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p890_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p890_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p890_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pb4_2_proc1
// static void setup_lseek_memwrite_p890_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p890_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p8bc_0_0
// static int test_lseek_memwrite_p88_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p878_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p878_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p878_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p878_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_paf_0_proc0
// static void setup_lseek_memwrite_p878_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p878_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p878_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p874_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p874_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p874_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p874_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_lseek_memwrite_pbe8_0_proc0
// static void setup_lseek_memwrite_p874_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p874_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p874_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p874_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p874_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p874_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p874_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_lseek_memwrite_p8fa_2_proc0
// static void setup_lseek_memwrite_p874_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p874_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p874_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p870_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p870_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p870_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p870_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_0_proc0
// static void setup_lseek_memwrite_p870_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p870_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p870_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p870_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p870_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p870_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p870_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbe0_1_proc0
// static void setup_lseek_memwrite_p870_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p870_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p870_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p86_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p86_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p86_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p86_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pbc_1_proc0
// static void setup_lseek_memwrite_p86_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p86_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p86_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p86_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p86_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p86_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p86_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pac_1_proc0
// static void setup_lseek_memwrite_p86_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p86_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p86_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p84_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p838_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p838_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p838_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p838_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p838_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_pb7_0_proc1
// static void setup_lseek_memwrite_p838_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p838_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p834_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p834_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p834_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p834_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc0
// static void setup_lseek_memwrite_p834_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p834_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p834_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p834_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p834_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p834_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p834_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p834_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p834_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p834_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p830_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p830_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p830_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p830_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc0
// static void setup_lseek_memwrite_p830_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p830_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p830_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p830_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p830_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p830_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p830_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p830_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p830_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p830_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p82_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p82_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p82_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p82_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p82_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb4_1_proc1
// static void setup_lseek_memwrite_p82_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p82_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p82_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p82_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p82_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p82_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p82_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pb4_2_proc1
// static void setup_lseek_memwrite_p82_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p82_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_pfc_0_0
// static int test_lseek_memwrite_p80_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pb68_1_proc0
// static void setup_lseek_memwrite_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
static int test_lseek_memwrite_p78_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_memwrite_p78_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
static void setup_lseek_memwrite_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_memwrite_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_pb7_0_proc1
// static void setup_lseek_memwrite_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p78_0_final(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal
// static void setup_lseek_memwrite_p78_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p74_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p74_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_lseek_memwrite_pa68_1_proc1
// static void setup_lseek_memwrite_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p74_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p74_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p70_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p70_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p70_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p6_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p6_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb4_1_proc1
// static void setup_lseek_memwrite_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p6_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p6_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_p78_0_common
// static void setup_lseek_memwrite_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pb4_2_proc1
// static void setup_lseek_memwrite_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p6_1_final(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal
// static void setup_lseek_memwrite_p6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_p78_0_common
// static void setup_lseek_memwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p4_0_final(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal
// static void setup_lseek_memwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p38_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p38_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_p78_0_common
// static void setup_lseek_memwrite_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_memwrite_pb7_0_proc1
// static void setup_lseek_memwrite_p38_0_final(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal
// static void setup_lseek_memwrite_p38_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p34_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p34_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pfa_0_1
// static void setup_lseek_memwrite_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p34_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p30_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p30_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_lseek_memwrite_pfc_0_1
// static void setup_lseek_memwrite_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe0_0_common
// static void setup_lseek_memwrite_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb68_0_proc1
// static void setup_lseek_memwrite_p30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p30_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p2_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p2_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_memwrite_pbe8_0_common
// static void setup_lseek_memwrite_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_memwrite_pb4_1_proc1
// static void setup_lseek_memwrite_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_memwrite_pbf_0_final
// static void setup_lseek_memwrite_p2_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p2_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p2_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_p78_0_common
// static void setup_lseek_memwrite_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_memwrite_pb4_2_proc1
// static void setup_lseek_memwrite_p2_1_final(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal
// static void setup_lseek_memwrite_p2_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal

/*
 * calls: lseek memwrite
 */
// static int test_lseek_memwrite_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_memwrite_p78_0_0
// static int test_lseek_memwrite_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_lseek_memwrite_pf0_0_1
// static void setup_lseek_memwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_p78_0_common
// static void setup_lseek_memwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_memwrite_pbf_0_proc1
// static void setup_lseek_memwrite_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal
// static void setup_lseek_memwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_memwrite_pbf_0_procfinal


/*
 * calls: lseek mmap
 */
static int test_lseek_mmap_pf8_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_mmap_pf8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_lseek_mmap_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_mmap_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_mmap_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_mmap_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_mmap_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pf8_1_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_lseek_mmap_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pf8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
static void setup_lseek_mmap_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf8_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pf8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pf8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf6_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pf6_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_lseek_mmap_pf6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
static void setup_lseek_mmap_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pf6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf6_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pf6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
static void setup_lseek_mmap_pf6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf6_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pf6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_pf6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
static void setup_lseek_mmap_pf6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pf6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf6_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pf6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_pf6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
static void setup_lseek_mmap_pf6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pf6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf6_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pf6_4_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_lseek_mmap_pf6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pf6_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pf6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf6_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf6_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf6_5_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pf6_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pf6_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pf6_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pf6_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf6_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf6_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pf4_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_lseek_mmap_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_mmap_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pf4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf4_0_1
// static void setup_lseek_mmap_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
static void setup_lseek_mmap_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pf0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_lseek_mmap_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pf0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pf0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pec_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pec_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pec_2_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_pec_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pec_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pec_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pec_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pec_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pec_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pec_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pec_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pec_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pec_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_5_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pec_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pec_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pec_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf6_1_proc0
// static void setup_lseek_mmap_pec_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_6_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pec_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pec_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
static void setup_lseek_mmap_pec_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pec_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_7_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pec_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pec_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pec_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf6_0_proc0
// static void setup_lseek_mmap_pec_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_8_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pec_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pec_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
static void setup_lseek_mmap_pec_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pec_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_9_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pec_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pec_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pec_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf6_1_proc0
// static void setup_lseek_mmap_pec_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pec_10_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pec_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pec_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pec_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pec_6_proc0
// static void setup_lseek_mmap_pec_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pec_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pec_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe6_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pe6_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_lseek_mmap_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf6_0_proc0
// static void setup_lseek_mmap_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe6_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf6_1_proc0
// static void setup_lseek_mmap_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe6_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_pe6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pe6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf6_3_proc0
// static void setup_lseek_mmap_pe6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe6_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pe6_3_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_lseek_mmap_pe6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pe6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pe6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe6_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe6_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_pe6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pe6_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf6_2_proc0
// static void setup_lseek_mmap_pe6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe6_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe6_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe6_5_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe6_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pe6_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pe6_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pe6_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe6_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe6_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe5_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pe5_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_pe5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pe5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf4_0_proc0
// static void setup_lseek_mmap_pe5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe5_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe5_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe5_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pe5_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_pe5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pe5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf4_0_proc0
// static void setup_lseek_mmap_pe5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe5_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe5_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe5_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_pe5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pe5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pec_8_proc0
// static void setup_lseek_mmap_pe5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe5_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe5_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe5_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_pe5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pe5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pec_8_proc0
// static void setup_lseek_mmap_pe5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe5_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe5_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe5_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe5_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_pe5_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pe5_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf4_1_proc0
// static void setup_lseek_mmap_pe5_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe5_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe5_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe5_5_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe5_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_pe5_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pe5_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pec_6_proc0
// static void setup_lseek_mmap_pe5_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe5_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe5_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe5_6_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe5_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_pe5_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pe5_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf4_1_proc0
// static void setup_lseek_mmap_pe5_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe5_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe5_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe5_7_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe5_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_pe5_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pe5_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pec_6_proc0
// static void setup_lseek_mmap_pe5_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe5_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe5_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pe0_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_lseek_mmap_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pe0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pe0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pd8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pd8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pd8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pd8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pd6_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pd6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pd6_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pd6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pd6_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pd6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pd6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pd6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pd6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pd6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pd6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pd6_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pd6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pd6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pd6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pd6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pd6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pd6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pd4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pd4_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_lseek_mmap_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
static void setup_lseek_mmap_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pd4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pd4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pd0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pd0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_lseek_mmap_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pd0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pd0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pcc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pcc_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pcc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pcc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pcc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pcc_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_pcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pcc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pcc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pcc_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pcc_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_pcc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pcc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pcc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pcc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pcc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pcc_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pcc_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_pcc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pcc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pcc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pcc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pcc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc6_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pc6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc6_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pc6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pc6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pc6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pc6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc6_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pc6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pc6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pc6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pc6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc6_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pc6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pc6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pc6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pc6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc5_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pc5_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_pc5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pc5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pc5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_pc5_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc5_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc5_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pc5_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_pc5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pc5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pc5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_pc5_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc5_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc5_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_pc5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pc5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pc5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_pc5_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc5_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc5_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_pc5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pc5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pc5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_pc5_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc5_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc5_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc5_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_pc5_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pc5_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
static void setup_lseek_mmap_pc5_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pc5_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc5_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc5_5_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc5_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_pc5_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pc5_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pc5_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_pc5_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc5_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc5_6_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc5_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_pc5_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pc5_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pc5_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_pc5_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc5_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc5_7_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc5_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_pc5_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pc5_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pc5_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_pc5_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc5_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
static int test_lseek_mmap_pc0_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_lseek_mmap_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pc0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_pc0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_pc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_pc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pc0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pc0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
static int test_lseek_mmap_pbe_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_mmap_pbe_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
static void setup_lseek_mmap_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_mmap_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_mmap_pbe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_mmap_pbe_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_mmap_pbe_0_procfinal(void) {
  
}

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbe_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbe_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
static void setup_lseek_mmap_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pbe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pbe_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbe_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbe_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
static void setup_lseek_mmap_pbe_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_mmap_pbe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pbe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pbe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pbe_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbd8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbd8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_pbd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pbe_2_common
// static void setup_lseek_mmap_pbd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pbe_2_proc0
// static void setup_lseek_mmap_pbd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pbd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pbd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbd8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbd8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_pbd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pbe_2_common
static void setup_lseek_mmap_pbd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pbd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pbd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pbd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbd0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbd0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf4_0_1
// static void setup_lseek_mmap_pbd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
static void setup_lseek_mmap_pbd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_pbd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pbd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pbd0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbd0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbd0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_pbd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pbd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_1_proc0
// static void setup_lseek_mmap_pbd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pbd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pbd0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_1_proc0
// static void setup_lseek_mmap_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbb0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pbb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pbb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_proc0
// static void setup_lseek_mmap_pbb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pbb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pbb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbb0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbb0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pbb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pbb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_1_proc0
// static void setup_lseek_mmap_pbb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pbb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pbb0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbb0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbb0_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pbb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pbb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_1_proc0
// static void setup_lseek_mmap_pbb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pbb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pbb0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbb0_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbb0_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pbb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pbe_2_common
// static void setup_lseek_mmap_pbb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pbe_2_proc0
// static void setup_lseek_mmap_pbb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pbb0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pbb0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbb0_4_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbb0_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pbb0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pbb0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_proc0
// static void setup_lseek_mmap_pbb0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pbb0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pbb0_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pbb0_5_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pbb0_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pbb0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pbe_2_common
// static void setup_lseek_mmap_pbb0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pbe_2_proc0
// static void setup_lseek_mmap_pbb0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pbb0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pbb0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb98_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_pb98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pbe_2_common
// static void setup_lseek_mmap_pb98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pbe_2_proc0
// static void setup_lseek_mmap_pb98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pb98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pb98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb98_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb98_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_pb98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pbe_2_common
// static void setup_lseek_mmap_pb98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pbd8_1_proc0
// static void setup_lseek_mmap_pb98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pb98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pb98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb94_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb94_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_pb94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_pb94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb94_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb94_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_pb94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
static void setup_lseek_mmap_pb94_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_pb94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb94_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb94_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb94_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_pb94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_pb94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb94_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb94_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb94_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb94_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_pb94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
static void setup_lseek_mmap_pb94_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_pb94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb94_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb94_4_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb94_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_pb94_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
static void setup_lseek_mmap_pb94_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_pb94_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb94_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb94_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb94_5_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb94_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_pb94_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb94_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pb94_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb94_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb94_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb94_6_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb94_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_pb94_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb94_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pb94_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb94_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb94_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb8_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_1_proc0
// static void setup_lseek_mmap_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_1_proc0
// static void setup_lseek_mmap_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb58_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb58_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pb58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pbe_2_common
static void setup_lseek_mmap_pb58_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pb58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pb58_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pb58_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb58_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb58_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pb58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pbe_2_common
// static void setup_lseek_mmap_pb58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pb58_0_proc0
// static void setup_lseek_mmap_pb58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pb58_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pb58_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb50_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb50_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_pb50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pb50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pb50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb50_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_1_proc0
// static void setup_lseek_mmap_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb30_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb30_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_pb30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_1_proc0
// static void setup_lseek_mmap_pb30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb30_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb30_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb30_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_pb30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_1_proc0
// static void setup_lseek_mmap_pb30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb30_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb30_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb18_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pb18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pbe_2_common
// static void setup_lseek_mmap_pb18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pb58_0_proc0
// static void setup_lseek_mmap_pb18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pb18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pb18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb18_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pb18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pbe_2_common
// static void setup_lseek_mmap_pb18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pb58_0_proc0
// static void setup_lseek_mmap_pb18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pb18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pb18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb14_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb14_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_pb14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pb14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pb14_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb14_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb14_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb14_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_pb14_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb14_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pb14_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pb14_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb14_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb14_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb14_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_pb14_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb14_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pb14_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pb14_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb14_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb14_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb14_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_pb14_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb14_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pb14_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pb14_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb14_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pbe_0_0
// static int test_lseek_mmap_pb0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_1_proc0
// static void setup_lseek_mmap_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
static int test_lseek_mmap_pae_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_mmap_pae_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
static void setup_lseek_mmap_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_lseek_mmap_pae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pae_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pae_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pae_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pae_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pae_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pae_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pae_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pae_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_pae_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
static void setup_lseek_mmap_pae_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pae_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pae_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pae_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pae_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pae_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_pae_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pae_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pae_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pae_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pae_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pae_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pae_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_pae_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
static void setup_lseek_mmap_pae_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pae_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pae_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pae_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pad8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pad8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_pad8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pad8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_pad8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pad8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pad8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pad8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pad8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_pad8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
static void setup_lseek_mmap_pad8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pad8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pad8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pad8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pad8_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pad8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_pad8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pad8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_pad8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pad8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pad8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pad8_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pad8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_pad8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
static void setup_lseek_mmap_pad8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_pad8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pad8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pad8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pad0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pad0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf4_0_1
// static void setup_lseek_mmap_pad0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pad0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pad0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pad0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pad0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pad0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf4_0_1
// static void setup_lseek_mmap_pad0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pad0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_pad0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pad0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pad0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pad0_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pad0_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_pad0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_pad0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pad0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pad0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pad0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pac_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pac_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pac_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pac_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pac_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pac_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pab0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pab0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pab0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_pab0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_pab0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pab0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pab0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pab0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pab0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pab0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pab0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pab0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pab0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pab0_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pab0_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pab0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pab0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pab0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pab0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pab0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pab0_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pab0_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pab0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pab0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pab0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pab0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pab0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pab0_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pab0_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pab0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pab0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_pab0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pab0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pab0_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pab0_5_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pab0_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pab0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pab0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pab0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pab0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pab0_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pab0_6_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pab0_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pab0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pab0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_pab0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pab0_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pab0_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pab0_7_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pab0_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_pab0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pab0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_pab0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pab0_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pab0_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pab0_8_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pab0_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pab0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pab0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_pab0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pab0_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pab0_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pab0_9_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pab0_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_pab0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pab0_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_pab0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pab0_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pab0_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa98_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa98_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_pa98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_pa98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pa98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa98_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa98_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_pa98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_1_proc0
// static void setup_lseek_mmap_pa98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pa98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa98_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa98_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_pa98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa98_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_pa98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pa98_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa98_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa98_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa98_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_pa98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_3_proc0
// static void setup_lseek_mmap_pa98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_pa98_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa98_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa94_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa94_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_pa94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_pa94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa94_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa94_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_pa94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_pa94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa94_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa94_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa94_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_pa94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_pa94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa94_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa94_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa94_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa94_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_pa94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_pa94_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa94_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa8_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa8_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa6_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa58_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa58_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pa58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_pa58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pa58_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa58_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa58_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa58_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pa58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_pa58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pa58_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa58_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa58_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa58_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pa58_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa58_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_pa58_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pa58_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa58_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa58_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa58_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_pa58_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa58_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_pa58_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pa58_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa58_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa50_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa50_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_pa50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pa50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pa50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa50_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa50_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa50_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_pa50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa50_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa4_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa4_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_pa4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa30_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa30_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_pa30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_pa30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa30_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa30_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa30_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_pa30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_pa30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa30_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa30_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa18_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pa18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_pa18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pa18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa18_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pa18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_pa18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pa18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa18_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa18_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pa18_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa18_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_pa18_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_pa18_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa18_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa18_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa18_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_pa18_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_pa18_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_pa18_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_pa18_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_pa18_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa14_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa14_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_pa14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pa14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pa14_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa14_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa14_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa14_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_pa14_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa14_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pa14_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pa14_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa14_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa14_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa14_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_pa14_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa14_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa14_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa14_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa14_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa14_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa14_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_pa14_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa14_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa14_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa14_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa14_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_pa0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pae_0_0
// static int test_lseek_mmap_pa0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
static int test_lseek_mmap_p9f0_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_mmap_p9f0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
static void setup_lseek_mmap_p9f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_mmap_p9f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9f0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9f0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p9f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9f0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9f0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9f0_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p9f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p9f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p9f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p9f0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p9f0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9ec_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9ec_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p9ec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p9ec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p9ec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p9ec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p9ec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9ec_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9ec_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p9ec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p9ec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_3_proc0
// static void setup_lseek_mmap_p9ec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p9ec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p9ec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9e8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9e8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf4_0_1
// static void setup_lseek_mmap_p9e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p9e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9e8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9e8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9e8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9e8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p9e8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9e8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9e8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9e8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9e8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9e0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9e0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_p9e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9e0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9e0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9e0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9d8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9d8_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p9d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_p9f0_0_common
// static void setup_lseek_mmap_p9d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p9d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9d8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9d8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9d8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9d8_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p9d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9d8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9d8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9d8_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9d8_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p9d8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9d8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p9d8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9d8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9d8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9d8_3_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9d8_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p9d8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9d8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9d8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9d8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9d8_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9d8_4_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9d8_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p9d8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p9d8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p9d8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p9d8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p9d8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9d8_5_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9d8_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p9d8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p9d8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p9d8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p9d8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p9d8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9cc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9cc_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p9cc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p9cc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p9cc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p9cc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p9cc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9cc_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9cc_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p9cc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p9cc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_3_proc0
// static void setup_lseek_mmap_p9cc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p9cc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p9cc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9ca_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9ca_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_p9ca_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9ca_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p9ca_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9ca_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9ca_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9ca_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9ca_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_p9ca_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9ca_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p9ca_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9ca_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9ca_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9ca_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9ca_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p9ca_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9ca_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9ca_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9ca_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9ca_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9ca_3_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9ca_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p9ca_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9ca_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9ca_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9ca_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9ca_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9c0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9c0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_p9c0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9c0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9c0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9c0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9b0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9b0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_p9b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_p9f0_0_common
// static void setup_lseek_mmap_p9b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9b0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9ac_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9ac_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p9ac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p9ac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p9ac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p9ac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p9ac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9ac_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9ac_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p9ac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p9ac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p9ac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p9ac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p9ac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9a8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9a8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p9a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9a8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p9a0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p9a0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_p9a0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p9a0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p9a0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p9a0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p9a0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p998_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p998_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_p998_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_p9f0_0_common
// static void setup_lseek_mmap_p998_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p998_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p998_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p998_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p998_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p998_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_p998_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p998_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p998_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p998_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p998_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p98c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p98c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p98c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p98c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p98c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p98c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p98c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p98c_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p98c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p98c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p98c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p98c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p98c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p98c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p98a_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p98a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p98a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p98a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p98a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p98a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p98a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p98a_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p98a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p98a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p98a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p98a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p98a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p98a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p980_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p9f0_0_0
// static int test_lseek_mmap_p980_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_p980_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p980_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p980_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p980_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p980_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
static int test_lseek_mmap_p970_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_mmap_p970_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p970_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p970_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p970_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p970_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p970_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p970_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p970_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p970_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p970_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p970_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p970_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p970_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p970_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p970_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p970_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p970_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p970_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p970_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p970_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p96c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p96c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p96c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p96c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p96c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p96c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p96c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p96c_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p96c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p96c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p96c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_3_proc0
// static void setup_lseek_mmap_p96c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p96c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p96c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p968_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p968_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf4_0_1
// static void setup_lseek_mmap_p968_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p968_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p968_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p968_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p968_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p968_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p968_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p968_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p968_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p968_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p968_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p968_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p960_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p960_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_p960_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p960_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p960_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p960_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p960_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p958_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p958_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p958_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p958_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p958_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p958_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p958_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p958_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p958_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p958_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p958_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p958_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p958_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p958_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p958_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p958_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p958_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p958_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p958_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p958_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p958_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p958_3_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p958_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p958_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p958_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p958_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p958_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p958_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p958_4_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p958_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p958_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p958_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p958_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p958_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p958_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p958_5_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p958_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p958_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p958_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p958_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p958_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p958_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p94c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p94c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p94c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p94c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p94c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p94c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p94c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p94c_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p94c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p94c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p94c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_3_proc0
// static void setup_lseek_mmap_p94c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p94c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p94c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p94a_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p94a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_p94a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p94a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p94a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p94a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p94a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p94a_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p94a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_p94a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p94a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p94a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p94a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p94a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p94a_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p94a_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p94a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p94a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p94a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p94a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p94a_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p94a_3_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p94a_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p94a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p94a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p94a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p94a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p94a_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p940_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p940_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_p940_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p940_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p940_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p940_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p940_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p930_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p930_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_p930_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p930_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p930_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p930_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p930_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p92c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p92c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p92c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p92c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p92c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p92c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p92c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p92c_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p92c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p92c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p92c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p92c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p92c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p92c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p928_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p928_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p928_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p928_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p928_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p928_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p920_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p920_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_p920_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p920_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p920_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p920_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p920_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p918_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p918_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_p918_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p918_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p918_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p918_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p918_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p918_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p918_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_p918_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p918_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p918_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p918_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p918_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p90c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p90c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p90c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p90c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p90c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p90c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p90c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p90c_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p90c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p90c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p90c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p90c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p90c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p90c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p90a_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p90a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p90a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p90a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p90a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p90a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p90a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p90a_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p90a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p90a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p90a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p90a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p90a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p90a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p900_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p970_0_0
// static int test_lseek_mmap_p900_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_p900_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p900_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p900_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p900_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p900_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
static int test_lseek_mmap_p8f8_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_mmap_p8f8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p8f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
static void setup_lseek_mmap_p8f8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8f8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8f8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8f8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8f8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p8f8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8f8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8f8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8f8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8f8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8f8_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8f8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
static void setup_lseek_mmap_p8f8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_mmap_p8f8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_p8f8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8f8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8f8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8f6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8f6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p8f6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8f6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_p8f6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8f6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8f6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8f6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8f6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p8f6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8f6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_1_proc0
// static void setup_lseek_mmap_p8f6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8f6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8f6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8f4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8f4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf4_0_1
// static void setup_lseek_mmap_p8f4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8f4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_p8f4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8f4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8f4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8f4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8f4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p8f4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
static void setup_lseek_mmap_p8f4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_p8f4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8f4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8f4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8f0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_p8f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ec_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8ec_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p8ec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8ec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p8f8_0_proc0
// static void setup_lseek_mmap_p8ec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8ec_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8ec_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ec_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8ec_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p8ec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8ec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8ec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8ec_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8ec_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ec_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8ec_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
static void setup_lseek_mmap_p8ec_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_mmap_p8ec_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_p8ec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8ec_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8ec_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ec_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8ec_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p8ec_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8ec_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_p8ec_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8ec_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8ec_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ec_4_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8ec_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p8ec_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8ec_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8ec_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8ec_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8ec_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ec_5_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8ec_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p8ec_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8ec_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_p8ec_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8ec_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8ec_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8e6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p8e6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8e6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_p8e6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8e6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8e6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8e6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p8e6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8e6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_1_proc0
// static void setup_lseek_mmap_p8e6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8e6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8e6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e5_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8e5_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_p8e5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8e5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_p8e5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8e5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8e5_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e5_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
static int test_lseek_mmap_p8e5_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x985000UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_p8e5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
static void setup_lseek_mmap_p8e5_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_p8e5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8e5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8e5_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e5_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8e5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p8e5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
static void setup_lseek_mmap_p8e5_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_p8e5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8e5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8e5_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e5_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
static int test_lseek_mmap_p8e5_3_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x985000UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_p8e5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
static void setup_lseek_mmap_p8e5_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_p8e5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8e5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8e5_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e5_4_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8e5_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_p8e5_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8e5_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_p8e5_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8e5_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8e5_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e5_5_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
static int test_lseek_mmap_p8e5_5_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x985000UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_p8e5_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8e5_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p8e5_1_proc0
// static void setup_lseek_mmap_p8e5_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8e5_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8e5_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e5_6_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8e5_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p8e5_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8e5_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8e5_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8e5_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8e5_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e5_7_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
static int test_lseek_mmap_p8e5_7_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
  
  return xerrno(r);
}
// static void setup_lseek_mmap_p8e5_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
static void setup_lseek_mmap_p8e5_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_p8e5_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8e5_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8e5_7_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8e0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8e0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_p8e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8e0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8e0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8e0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8d8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8d8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p8f4_1_proc0
// static void setup_lseek_mmap_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8d8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8d8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8d6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8d6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p8d6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8d6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_p8d6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p8d6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8d6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8d6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8d6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p8d6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8d6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_p8d6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p8d6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8d6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8d4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8d4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p8d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8d4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8d4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8d0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8d0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8d0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8d0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8cc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8cc_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_p8cc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8cc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p8f4_1_proc0
// static void setup_lseek_mmap_p8cc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8cc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8cc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8cc_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8cc_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_p8cc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8cc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p8f4_1_proc0
// static void setup_lseek_mmap_p8cc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8cc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8cc_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8c6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8c6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p8c6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8c6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_p8c6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p8c6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8c6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8c6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8c6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p8c6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8c6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_p8c6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p8c6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8c6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8c5_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8c5_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p8c5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8c5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8c5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8c5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8c5_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8c5_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8c5_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x985000UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8e5_3_1
// static void setup_lseek_mmap_p8c5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8c5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p8e5_3_proc0
// static void setup_lseek_mmap_p8c5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p8e5_3_proc0
// static void setup_lseek_mmap_p8c5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8c5_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8c5_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8c5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p8c5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8c5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8c5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8c5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8c5_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8c5_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8c5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8e5_7_1
// static void setup_lseek_mmap_p8c5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8c5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p8e5_7_proc0
// static void setup_lseek_mmap_p8c5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p8e5_7_proc0
// static void setup_lseek_mmap_p8c5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8c5_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8c0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8f8_0_0
// static int test_lseek_mmap_p8c0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_p8c0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8c0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8c0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8c0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
static int test_lseek_mmap_p8b8_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_mmap_p8b8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p8b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p8b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8b8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b8_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8b8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p8b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8b8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8b8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b8_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8b8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p8b8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8b8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_p8b8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8b8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8b8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
static int test_lseek_mmap_p8b8_3_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_mmap_p8b8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p8b8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p8b8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p8b8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8b8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8b8_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b8_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8b8_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p8b8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p8b8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p8b8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8b8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8b8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b6_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8b6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p8b6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8b6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_p8b6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8b6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8b6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b6_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8b6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p8b6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8b6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_1_proc0
// static void setup_lseek_mmap_p8b6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8b6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8b6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b6_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8b6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p8b6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p8b6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p8b6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8b6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8b6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b6_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8b6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p8b6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p8b6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_3_proc0
// static void setup_lseek_mmap_p8b6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8b6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8b6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b4_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8b4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf4_0_1
// static void setup_lseek_mmap_p8b4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8b4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_p8b4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8b4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8b4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b4_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8b4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p8b4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8b4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p8b4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8b4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8b4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b0_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8b0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_p8b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8b0_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8b0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_p8b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p8b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p8b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8b0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ac_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8ac_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p8ac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8ac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p8ac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8ac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8ac_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ac_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8ac_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p8ac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8ac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8ac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8ac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8ac_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ac_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8ac_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p8ac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8ac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p8ac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8ac_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8ac_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ac_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8ac_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p8ac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8ac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8ac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8ac_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8ac_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ac_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8ac_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p8ac_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8ac_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_p8ac_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8ac_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8ac_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ac_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8ac_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p8ac_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8ac_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_p8ac_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8ac_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8ac_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ac_6_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8ac_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p8ac_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p8ac_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p8ac_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8ac_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8ac_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ac_7_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8ac_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p8ac_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p8ac_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p8ac_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8ac_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8ac_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ac_8_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8ac_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p8ac_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p8ac_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p8ac_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8ac_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8ac_8_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8ac_9_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8ac_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p8ac_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p8ac_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p8ac_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8ac_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8ac_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a6_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8a6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p8a6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8a6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_2_proc0
// static void setup_lseek_mmap_p8a6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8a6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8a6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a6_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8a6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p8a6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p8a6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_1_proc0
// static void setup_lseek_mmap_p8a6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8a6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8a6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a6_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8a6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p8a6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p8a6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p8a6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8a6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8a6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a6_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8a6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p8a6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p8a6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_3_proc0
// static void setup_lseek_mmap_p8a6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p8a6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p8a6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a5_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8a5_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_p8a5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8a5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_p8a5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8a5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8a5_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a5_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8a5_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_p8a5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8a5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_p8a5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8a5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8a5_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a5_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8a5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_p8a5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p8a5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p8a5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8a5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8a5_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a5_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8a5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_p8a5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p8a5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p8a5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8a5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8a5_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a5_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8a5_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p8a5_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8a5_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p8a5_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8a5_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8a5_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a5_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8a5_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p8a5_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8a5_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p8a5_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8a5_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8a5_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a0_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p8a0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_p8a0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p8a0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p8a0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8a0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8a0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p8a0_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p8a0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_p8a0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p8a0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p8a0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p8a0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p8a0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p898_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p898_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_p898_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p898_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p898_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p898_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p898_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p896_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p896_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p896_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p896_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_p896_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p896_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p896_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p896_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p896_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p896_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p896_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_p896_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p896_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p896_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p896_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p896_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p896_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p896_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p896_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p896_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p896_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p896_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p896_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p896_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p896_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p896_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p896_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p896_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p894_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p894_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p894_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p894_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p894_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p894_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p894_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p894_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p894_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p894_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p894_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p894_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p894_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p894_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p890_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p890_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p890_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p890_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p890_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p890_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p890_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p890_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p88c_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p88c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_p88c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p88c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p88c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p88c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p88c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p88c_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p88c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_p88c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p88c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p88c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p88c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p88c_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p886_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p886_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p886_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p886_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_p886_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p886_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p886_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p886_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p886_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p886_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_p8f8_2_common
// static void setup_lseek_mmap_p886_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pd4_0_proc1
// static void setup_lseek_mmap_p886_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p886_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p886_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p886_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p886_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p886_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p886_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p886_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p886_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p886_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p886_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p886_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p886_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf4_0_common
// static void setup_lseek_mmap_p886_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p886_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p886_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p886_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p885_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p885_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p885_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p885_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p885_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p885_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p885_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p885_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p885_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p885_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p885_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p885_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p885_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p885_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p885_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p885_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p885_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p885_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p885_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p885_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p885_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p885_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p885_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p885_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p885_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p885_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p885_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p885_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p880_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_0_0
// static int test_lseek_mmap_p880_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_p880_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p880_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p880_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p880_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p880_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p880_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p8b8_3_0
// static int test_lseek_mmap_p880_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_p880_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p880_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p880_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p880_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p880_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p870_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p870_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_p870_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p870_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p870_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p870_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p870_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p870_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p870_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p870_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p870_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p870_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p870_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p870_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p86c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p86c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p86c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p86c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p86c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p86c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p86c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p86c_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p86c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p86c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p86c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_3_proc0
// static void setup_lseek_mmap_p86c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p86c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p86c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p868_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p868_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf4_0_1
// static void setup_lseek_mmap_p868_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p868_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_p868_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p868_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p868_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p868_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p868_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p868_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p868_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p868_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p868_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p868_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p860_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p860_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_p860_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p860_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p860_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p860_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p860_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p858_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p858_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_p858_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p858_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p858_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p858_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p858_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p858_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p858_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p858_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p858_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p858_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p858_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p858_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p858_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p858_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_p858_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p858_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p858_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p858_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p858_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p858_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p858_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p858_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p858_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p858_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p858_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p858_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p84c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p84c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p84c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p84c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pae_4_proc0
// static void setup_lseek_mmap_p84c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p84c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p84c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p84c_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p84c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p84c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p84c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pad8_3_proc0
// static void setup_lseek_mmap_p84c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p84c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p84c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p84a_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p84a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_p84a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p84a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_p84a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p84a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p84a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p84a_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p84a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_p84a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p84a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbd0_0_proc0
// static void setup_lseek_mmap_p84a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p84a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p84a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p84a_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p84a_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_p84a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p84a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p84a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p84a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p84a_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p84a_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p84a_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_p84a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p84a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_1_proc0
// static void setup_lseek_mmap_p84a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p84a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p84a_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p84a_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p84a_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p84a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p84a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p84a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p84a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p84a_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p84a_5_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p84a_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p84a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p84a_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p84a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p84a_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p84a_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p840_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p840_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_p840_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p840_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p840_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p840_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p840_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p830_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p830_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_p830_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p830_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p830_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p830_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p830_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p82c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p82c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p82c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p82c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p82c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p82c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p82c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p82c_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p82c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p82c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p82c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p82c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p82c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p82c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p828_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p828_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p828_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p828_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p828_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p828_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p828_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p820_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p820_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_p820_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p820_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p820_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p820_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p820_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p818_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p818_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_p818_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p818_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p818_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p818_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p818_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p818_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p818_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_p818_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p818_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p818_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p818_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p818_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p80c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p80c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p80c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p80c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p80c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p80c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p80c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p80c_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p80c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p80c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p80c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pc5_4_proc1
// static void setup_lseek_mmap_p80c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p80c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p80c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p80a_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p80a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p80a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p80a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p80a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p80a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p80a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p80a_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p80a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p80a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p80a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p80a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p80a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p80a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p80a_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p80a_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p80a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p80a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p80a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p80a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p80a_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p80a_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p80a_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p80a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p80a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p80a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p80a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p80a_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p800_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_0
// static int test_lseek_mmap_p800_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_p800_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p800_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p800_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p800_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p800_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
static int test_lseek_mmap_p70_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_mmap_p70_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
static void setup_lseek_mmap_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_mmap_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p70_0_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p70_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p70_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p70_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_1_1
// static void setup_lseek_mmap_p70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
static void setup_lseek_mmap_p70_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_p70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p70_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p6c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p6c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
static void setup_lseek_mmap_p6c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p6c_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p6c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_0_1
// static void setup_lseek_mmap_p6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
static void setup_lseek_mmap_p6c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mmap_p6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p6c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p6c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p68_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p68_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf4_0_1
// static void setup_lseek_mmap_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
static void setup_lseek_mmap_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mmap_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p60_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p60_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf0_0_1
// static void setup_lseek_mmap_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p60_0_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p60_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p60_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p60_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p60_1_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p60_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p58_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p58_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_p58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p58_0_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p58_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p58_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p58_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_p58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p58_1_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p58_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p58_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p58_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_1_1
// static void setup_lseek_mmap_p58_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p58_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p70_1_proc0
// static void setup_lseek_mmap_p58_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p58_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p58_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p58_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p58_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_2_1
// static void setup_lseek_mmap_p58_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pae_0_common
// static void setup_lseek_mmap_p58_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p70_1_proc0
// static void setup_lseek_mmap_p58_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p58_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p58_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p4c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p4c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_p6c_0_proc0
// static void setup_lseek_mmap_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p4c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p4c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p4c_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p4c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_0_1
// static void setup_lseek_mmap_p4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_p6c_1_proc0
// static void setup_lseek_mmap_p4c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p4c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p4c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p4a_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p4a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_p4a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p4a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p68_0_proc0
// static void setup_lseek_mmap_p4a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p4a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p4a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p4a_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p4a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_p4a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p4a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p68_0_proc0
// static void setup_lseek_mmap_p4a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p4a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p4a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p4a_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p4a_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_0_1
// static void setup_lseek_mmap_p4a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p4a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p70_1_proc0
// static void setup_lseek_mmap_p4a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p4a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p4a_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p4a_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p4a_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe5_1_1
// static void setup_lseek_mmap_p4a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p4a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_p70_1_proc0
// static void setup_lseek_mmap_p4a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p4a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p4a_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p40_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p40_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe0_0_1
// static void setup_lseek_mmap_p40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p40_0_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p40_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p40_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_p40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p40_1_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p40_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p30_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p30_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf8_0_1
// static void setup_lseek_mmap_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p30_0_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p30_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p2c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p2c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p2c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p2c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p2c_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p2c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pf6_4_1
// static void setup_lseek_mmap_p2c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p2c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p2c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p2c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p2c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p28_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p28_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd4_0_1
// static void setup_lseek_mmap_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p28_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p20_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p20_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pd0_0_1
// static void setup_lseek_mmap_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p20_0_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p20_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p18_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pec_0_1
// static void setup_lseek_mmap_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p18_0_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p18_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p18_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pcc_1_1
// static void setup_lseek_mmap_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p18_1_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p18_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p0c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p0c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc0
// static void setup_lseek_mmap_p0c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p0c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p0c_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p0c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pe6_3_1
// static void setup_lseek_mmap_p0c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mmap_pf8_0_common
// static void setup_lseek_mmap_p0c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_0_proc1
// static void setup_lseek_mmap_p0c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mmap_pf8_2_proc0
// static void setup_lseek_mmap_p0c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_final
// static void setup_lseek_mmap_p0c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mmap_pf8_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p0a_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p0a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p0a_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p0a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p0a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p0a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p0a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_3_proc0
// static void setup_lseek_mmap_p0a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p0a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p0a_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p0a_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_0_1
// static void setup_lseek_mmap_p0a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p0a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p0a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p0a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p0a_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p0a_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p0a_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc5_1_1
// static void setup_lseek_mmap_p0a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mmap_pbe_0_common
// static void setup_lseek_mmap_p0a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p0a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mmap_pb94_4_proc0
// static void setup_lseek_mmap_p0a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mmap_pbe_0_final
// static void setup_lseek_mmap_p0a_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal

/*
 * calls: lseek mmap
 */
// static int test_lseek_mmap_p00_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_p70_0_0
// static int test_lseek_mmap_p00_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mmap_pc0_0_1
// static void setup_lseek_mmap_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mmap_p70_0_common
// static void setup_lseek_mmap_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mmap_pbe_0_proc1
// static void setup_lseek_mmap_p00_0_final(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal
// static void setup_lseek_mmap_p00_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mmap_pbe_0_procfinal


/*
 * calls: lseek mprotect
 */
static int test_lseek_mprotect_pf_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_mprotect_pf_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_lseek_mprotect_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_mprotect_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_lseek_mprotect_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_mprotect_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_mprotect_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pf_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pf_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
static void setup_lseek_mprotect_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_mprotect_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pf_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pf_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
static void setup_lseek_mprotect_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_mprotect_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pf_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pf_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
static void setup_lseek_mprotect_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_mprotect_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pf_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pf_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pf_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pf_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pf_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
static void setup_lseek_mprotect_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_mprotect_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pf_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pf_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pf_5_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pf_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
static void setup_lseek_mprotect_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_mprotect_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pf_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pf_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pf_6_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pf_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pf_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
static void setup_lseek_mprotect_pf_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_mprotect_pf_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pf_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pf_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pf_7_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pf_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pf_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
static void setup_lseek_mprotect_pf_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_mprotect_pf_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pf_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pf_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pe_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
static int test_lseek_mprotect_pe_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_lseek_mprotect_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
static void setup_lseek_mprotect_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mprotect_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pe_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
static void setup_lseek_mprotect_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_mprotect_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pd_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pd_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pd_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
// static void setup_lseek_mprotect_pd_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pe_0_proc0
static void setup_lseek_mprotect_pd_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_mprotect_pd_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pd_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pd_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pd_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
// static void setup_lseek_mprotect_pd_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pe_0_proc0
static void setup_lseek_mprotect_pd_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_mprotect_pd_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pd_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pd_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pd_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
// static void setup_lseek_mprotect_pd_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pe_1_proc0
// static void setup_lseek_mprotect_pd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pd_0_proc1
// static void setup_lseek_mprotect_pd_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pd_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pd_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pd_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pd_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
// static void setup_lseek_mprotect_pd_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pe_1_proc0
// static void setup_lseek_mprotect_pd_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pd_1_proc1
// static void setup_lseek_mprotect_pd_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pd_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pd_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pd_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pd_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
// static void setup_lseek_mprotect_pd_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pe_0_proc0
static void setup_lseek_mprotect_pd_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_mprotect_pd_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pd_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pd_5_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pd_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pd_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
// static void setup_lseek_mprotect_pd_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pe_1_proc0
// static void setup_lseek_mprotect_pd_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pd_4_proc1
// static void setup_lseek_mprotect_pd_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pd_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pd_6_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pd_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pd_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
// static void setup_lseek_mprotect_pd_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pe_0_proc0
static void setup_lseek_mprotect_pd_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_mprotect_pd_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pd_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pd_7_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pd_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pd_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
// static void setup_lseek_mprotect_pd_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pe_1_proc0
// static void setup_lseek_mprotect_pd_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pd_6_proc1
// static void setup_lseek_mprotect_pd_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pd_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
// static void setup_lseek_mprotect_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pe_0_proc0
// static void setup_lseek_mprotect_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_pc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_mprotect_pf_0_common
// static void setup_lseek_mprotect_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pe_1_proc0
// static void setup_lseek_mprotect_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_mprotect_pf_0_proc1
// static void setup_lseek_mprotect_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_final
// static void setup_lseek_mprotect_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_mprotect_pf_0_procfinal

/*
 * calls: lseek mprotect
 */
static int test_lseek_mprotect_pbc_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_mprotect_pbc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
static void setup_lseek_mprotect_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_mprotect_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
static void setup_lseek_mprotect_pbc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_mprotect_pbc_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_mprotect_pbc_0_procfinal(void) {
  
}

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pbc_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pbc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
static void setup_lseek_mprotect_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_mprotect_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pbc_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pbc_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
static void setup_lseek_mprotect_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x985000);
}
// static void setup_lseek_mprotect_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pbc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pbc_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pbc_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pbc_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
static void setup_lseek_mprotect_pbc_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_mprotect_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_mprotect_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pbc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pbc_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pbc_4_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pbc_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pbc_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_3_common
static void setup_lseek_mprotect_pbc_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_mprotect_pbc_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pbc_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pbc_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pbc_5_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pbc_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pbc_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
static void setup_lseek_mprotect_pbc_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_mprotect_pbc_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pbc_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pbc_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pb8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
static void setup_lseek_mprotect_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mprotect_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pb4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pb4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb8_0_proc0
static void setup_lseek_mprotect_pb4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_lseek_mprotect_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pb4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pb4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb8_0_proc0
static void setup_lseek_mprotect_pb4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_lseek_mprotect_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pb4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pb4_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_3_common
static void setup_lseek_mprotect_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_mprotect_pb4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_lseek_mprotect_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pb4_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pb4_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb8_0_proc0
static void setup_lseek_mprotect_pb4_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_mprotect_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pb4_4_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pb4_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pb4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_3_common
// static void setup_lseek_mprotect_pb4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
static void setup_lseek_mprotect_pb4_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_lseek_mprotect_pb4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pb4_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pb4_5_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pb4_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pb4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_pb4_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb8_0_proc0
static void setup_lseek_mprotect_pb4_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_mprotect_pb4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pb4_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pbc_0_0
// static int test_lseek_mprotect_pb0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb8_0_proc0
// static void setup_lseek_mprotect_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
static int test_lseek_mprotect_pac_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_mprotect_pac_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
static void setup_lseek_mprotect_pac_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_lseek_mprotect_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pbc_3_proc0
// static void setup_lseek_mprotect_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pac_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pac_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pac_0_0
// static int test_lseek_mprotect_pac_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pbc_4_proc0
// static void setup_lseek_mprotect_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pac_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pac_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pac_0_0
// static int test_lseek_mprotect_pac_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
static void setup_lseek_mprotect_pac_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_mprotect_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pac_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pac_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pac_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pac_0_0
// static int test_lseek_mprotect_pac_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
static void setup_lseek_mprotect_pac_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_mprotect_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pac_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pac_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pac_0_0
// static int test_lseek_mprotect_pa8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pa4_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pac_0_0
// static int test_lseek_mprotect_pa4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc1
// static void setup_lseek_mprotect_pa4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pa4_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pac_0_0
// static int test_lseek_mprotect_pa4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pa4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_pa4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_pa4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pb4_3_proc1
// static void setup_lseek_mprotect_pa4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pa4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pa4_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pac_0_0
// static int test_lseek_mprotect_pa4_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pa4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_pa4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_pa4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_4_proc1
// static void setup_lseek_mprotect_pa4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pa4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pa4_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pac_0_0
// static int test_lseek_mprotect_pa4_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_pa4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_pa4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_pa4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pb4_5_proc1
// static void setup_lseek_mprotect_pa4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pa4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pac_0_0
// static int test_lseek_mprotect_pa0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
static int test_lseek_mprotect_p9e_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_mprotect_p9e_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
static void setup_lseek_mprotect_p9e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_mprotect_p9e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_lseek_mprotect_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p9e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9e_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9e_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_p9e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pbc_3_proc0
// static void setup_lseek_mprotect_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p9e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9e_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9e_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9e_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p9e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_p9e_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pbc_4_proc0
// static void setup_lseek_mprotect_p9e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p9e_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9e_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9e_3_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9e_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p9e_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_p9e_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pac_2_proc0
// static void setup_lseek_mprotect_p9e_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p9e_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9e_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9e_4_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9e_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p9e_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_p9e_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pac_3_proc0
// static void setup_lseek_mprotect_p9e_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p9e_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9e_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_p9e_0_common
// static void setup_lseek_mprotect_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9a_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9a_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_p9e_0_common
// static void setup_lseek_mprotect_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
static void setup_lseek_mprotect_p9a_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_lseek_mprotect_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9a_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9a_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_p9a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc1
// static void setup_lseek_mprotect_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9a_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9a_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p9a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_p9a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pb4_3_proc1
// static void setup_lseek_mprotect_p9a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9a_3_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9a_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p9a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_p9a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
static void setup_lseek_mprotect_p9a_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_lseek_mprotect_p9a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9a_4_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9a_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p9a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_p9a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p9a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_4_proc1
// static void setup_lseek_mprotect_p9a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9a_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p9a_5_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p9a_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p9a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pbc_0_common
// static void setup_lseek_mprotect_p9a_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p9a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pb4_5_proc1
// static void setup_lseek_mprotect_p9a_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p9a_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p9e_0_0
// static int test_lseek_mprotect_p98_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_mprotect_p9e_0_common
// static void setup_lseek_mprotect_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
static int test_lseek_mprotect_p96_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_mprotect_p96_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pbc_3_proc0
// static void setup_lseek_mprotect_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p96_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p96_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p96_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p96_0_0
// static int test_lseek_mprotect_p96_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p96_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p96_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pbc_4_proc0
// static void setup_lseek_mprotect_p96_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p96_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p96_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p96_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p96_0_0
// static int test_lseek_mprotect_p96_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p96_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p96_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pac_2_proc0
// static void setup_lseek_mprotect_p96_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p96_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p96_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p96_3_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p96_0_0
// static int test_lseek_mprotect_p96_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p96_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p96_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pac_3_proc0
// static void setup_lseek_mprotect_p96_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p96_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p96_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p94_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p96_0_0
// static int test_lseek_mprotect_p94_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p92_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p96_0_0
// static int test_lseek_mprotect_p92_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p92_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p92_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p92_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc1
// static void setup_lseek_mprotect_p92_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p92_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p92_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p96_0_0
// static int test_lseek_mprotect_p92_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p92_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p92_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p92_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pb4_3_proc1
// static void setup_lseek_mprotect_p92_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p92_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p92_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p96_0_0
// static int test_lseek_mprotect_p92_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p92_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p92_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p92_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_4_proc1
// static void setup_lseek_mprotect_p92_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p92_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p92_3_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p96_0_0
// static int test_lseek_mprotect_p92_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p92_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p92_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p92_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pb4_5_proc1
// static void setup_lseek_mprotect_p92_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p92_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p96_0_0
// static int test_lseek_mprotect_p90_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
static int test_lseek_mprotect_p8f_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_mprotect_p8f_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
static void setup_lseek_mprotect_p8f_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_lseek_mprotect_p8f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8f_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8f_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8f_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8f_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
static void setup_lseek_mprotect_p8f_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2297000);
}
// static void setup_lseek_mprotect_p8f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8f_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8f_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8f_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8f_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8f_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
static void setup_lseek_mprotect_p8f_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
// static void setup_lseek_mprotect_p8f_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8f_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8f_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8f_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8f_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8f_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
static void setup_lseek_mprotect_p8f_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8ea000);
}
// static void setup_lseek_mprotect_p8f_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8f_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8f_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8f_4_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8f_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8f_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
static void setup_lseek_mprotect_p8f_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_lseek_mprotect_p8f_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8f_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8f_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8f_5_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8f_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8f_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
static void setup_lseek_mprotect_p8f_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_lseek_mprotect_p8f_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8f_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8f_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8e_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8e_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
static void setup_lseek_mprotect_p8e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_mprotect_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8d_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8d_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8d_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8d_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_p8e_0_proc0
static void setup_lseek_mprotect_p8d_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
// static void setup_lseek_mprotect_p8d_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8d_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8d_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8d_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8d_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8d_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_p8e_0_proc0
static void setup_lseek_mprotect_p8d_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
}
// static void setup_lseek_mprotect_p8d_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8d_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8d_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8d_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8d_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
static void setup_lseek_mprotect_p8d_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_mprotect_p8d_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
// static void setup_lseek_mprotect_p8d_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8d_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8d_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8d_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8d_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8d_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9347072, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_p8d_2_proc0
static void setup_lseek_mprotect_p8d_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x8ea000);
}
// static void setup_lseek_mprotect_p8d_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8d_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8d_4_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8d_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8d_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8d_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_p8e_0_proc0
// static void setup_lseek_mprotect_p8d_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pb4_3_proc1
// static void setup_lseek_mprotect_p8d_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8d_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8d_5_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8d_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8d_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8d_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_p8e_0_proc0
// static void setup_lseek_mprotect_p8d_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pb4_5_proc1
// static void setup_lseek_mprotect_p8d_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8d_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8f_0_0
// static int test_lseek_mprotect_p8c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_p8e_0_proc0
// static void setup_lseek_mprotect_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
static int test_lseek_mprotect_p8b_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_mprotect_p8b_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pbc_3_proc0
// static void setup_lseek_mprotect_p8b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8b_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8b_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8b_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8b_0_0
// static int test_lseek_mprotect_p8b_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pac_2_proc0
// static void setup_lseek_mprotect_p8b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8b_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8b_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8b_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8b_0_0
// static int test_lseek_mprotect_p8b_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8b_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8b_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pbc_4_proc0
// static void setup_lseek_mprotect_p8b_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8b_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8b_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8b_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8b_0_0
// static int test_lseek_mprotect_p8b_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p8b_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8b_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pac_3_proc0
// static void setup_lseek_mprotect_p8b_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8b_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8b_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p8a_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8b_0_0
// static int test_lseek_mprotect_p8a_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p89_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8b_0_0
// static int test_lseek_mprotect_p89_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p89_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p89_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p89_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc1
// static void setup_lseek_mprotect_p89_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p89_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p89_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8b_0_0
// static int test_lseek_mprotect_p89_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p89_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p89_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p89_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pb4_3_proc1
// static void setup_lseek_mprotect_p89_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p89_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p89_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8b_0_0
// static int test_lseek_mprotect_p89_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p89_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p89_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p89_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_4_proc1
// static void setup_lseek_mprotect_p89_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p89_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p89_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8b_0_0
// static int test_lseek_mprotect_p89_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p89_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p89_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p89_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pb4_5_proc1
// static void setup_lseek_mprotect_p89_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p89_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p8b_0_0
// static int test_lseek_mprotect_p88_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p86_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_p86_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p86_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p86_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pbc_3_proc0
// static void setup_lseek_mprotect_p86_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p86_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p86_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p86_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_p86_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p86_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p86_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pac_2_proc0
// static void setup_lseek_mprotect_p86_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p86_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p86_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p86_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_p86_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p86_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p86_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pbc_4_proc0
// static void setup_lseek_mprotect_p86_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p86_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p86_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p86_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_p86_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p86_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p86_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pac_3_proc0
// static void setup_lseek_mprotect_p86_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p86_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p86_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_p84_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p82_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_p82_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p82_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p82_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p82_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc1
// static void setup_lseek_mprotect_p82_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p82_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p82_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_p82_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p82_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p82_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p82_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pb4_3_proc1
// static void setup_lseek_mprotect_p82_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p82_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p82_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_p82_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p82_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p82_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p82_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_4_proc1
// static void setup_lseek_mprotect_p82_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p82_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p82_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_p82_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p82_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p82_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p82_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pb4_5_proc1
// static void setup_lseek_mprotect_p82_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p82_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_0
// static int test_lseek_mprotect_p80_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc0
// static void setup_lseek_mprotect_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
static int test_lseek_mprotect_p6_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_mprotect_p6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc1
// static void setup_lseek_mprotect_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p6_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p6_0_0
// static int test_lseek_mprotect_p6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_4_proc1
// static void setup_lseek_mprotect_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p6_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p6_0_0
// static int test_lseek_mprotect_p6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
static void setup_lseek_mprotect_p6_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_mprotect_p6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pb4_3_proc1
// static void setup_lseek_mprotect_p6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p6_2_final(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal
// static void setup_lseek_mprotect_p6_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p6_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p6_0_0
// static int test_lseek_mprotect_p6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_p6_2_common
// static void setup_lseek_mprotect_p6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pb4_5_proc1
// static void setup_lseek_mprotect_p6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p6_3_final(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal
// static void setup_lseek_mprotect_p6_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p6_0_0
// static int test_lseek_mprotect_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_p6_2_common
// static void setup_lseek_mprotect_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p4_0_final(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal
// static void setup_lseek_mprotect_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p2_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p6_0_0
// static int test_lseek_mprotect_p2_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_2_proc1
// static void setup_lseek_mprotect_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p2_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p2_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p6_0_0
// static int test_lseek_mprotect_p2_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_p6_2_common
// static void setup_lseek_mprotect_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_lseek_mprotect_pb4_3_proc1
// static void setup_lseek_mprotect_p2_1_final(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal
// static void setup_lseek_mprotect_p2_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p2_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p6_0_0
// static int test_lseek_mprotect_p2_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_mprotect_pac_0_common
// static void setup_lseek_mprotect_p2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_lseek_mprotect_pb4_4_proc1
// static void setup_lseek_mprotect_p2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_mprotect_pbc_0_final
// static void setup_lseek_mprotect_p2_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p2_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p6_0_0
// static int test_lseek_mprotect_p2_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pf_0_1
// static void setup_lseek_mprotect_p2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_p6_2_common
// static void setup_lseek_mprotect_p2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_lseek_mprotect_pb4_5_proc1
// static void setup_lseek_mprotect_p2_3_final(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal
// static void setup_lseek_mprotect_p2_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal

/*
 * calls: lseek mprotect
 */
// static int test_lseek_mprotect_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_p6_0_0
// static int test_lseek_mprotect_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_lseek_mprotect_pe_0_1
// static void setup_lseek_mprotect_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_p6_2_common
// static void setup_lseek_mprotect_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_mprotect_pbc_0_proc1
// static void setup_lseek_mprotect_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal
// static void setup_lseek_mprotect_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_mprotect_pbc_0_procfinal


/*
 * calls: lseek munmap
 */
static int test_lseek_munmap_pe_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_munmap_pe_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_lseek_munmap_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_munmap_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_munmap_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_munmap_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_munmap_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_0
// static int test_lseek_munmap_pe_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_munmap_pe_0_common
static void setup_lseek_munmap_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_munmap_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_munmap_pe_0_proc1
// static void setup_lseek_munmap_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_munmap_pe_0_final
// static void setup_lseek_munmap_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_munmap_pe_0_procfinal

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_0
// static int test_lseek_munmap_pc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_munmap_pe_0_common
// static void setup_lseek_munmap_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_munmap_pe_0_proc0
// static void setup_lseek_munmap_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_munmap_pe_0_proc1
// static void setup_lseek_munmap_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_munmap_pe_0_final
// static void setup_lseek_munmap_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_munmap_pe_0_procfinal

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_0
// static int test_lseek_munmap_pc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_munmap_pe_0_common
// static void setup_lseek_munmap_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_munmap_pe_1_proc0
// static void setup_lseek_munmap_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_munmap_pe_0_proc1
// static void setup_lseek_munmap_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_munmap_pe_0_final
// static void setup_lseek_munmap_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_munmap_pe_0_procfinal

/*
 * calls: lseek munmap
 */
static int test_lseek_munmap_pb8_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_munmap_pb8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
static void setup_lseek_munmap_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_munmap_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_munmap_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_munmap_pb8_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_munmap_pb8_0_procfinal(void) {
  
}

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pb8_0_0
// static int test_lseek_munmap_pb0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_munmap_pb8_0_common
// static void setup_lseek_munmap_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pb8_0_proc0
// static void setup_lseek_munmap_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
static int test_lseek_munmap_pa8_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_munmap_pa8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
static void setup_lseek_munmap_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_munmap_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_munmap_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pa8_0_0
// static int test_lseek_munmap_pa0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_common
// static void setup_lseek_munmap_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_proc0
// static void setup_lseek_munmap_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
static int test_lseek_munmap_p9c_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_munmap_p9c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
static void setup_lseek_munmap_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_munmap_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_proc0
// static void setup_lseek_munmap_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_p9c_0_0
// static int test_lseek_munmap_p98_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_munmap_p9c_0_common
// static void setup_lseek_munmap_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_proc0
// static void setup_lseek_munmap_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
static int test_lseek_munmap_p94_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_munmap_p94_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_common
// static void setup_lseek_munmap_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_proc0
// static void setup_lseek_munmap_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_p94_0_0
// static int test_lseek_munmap_p90_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_common
// static void setup_lseek_munmap_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_proc0
// static void setup_lseek_munmap_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
static int test_lseek_munmap_p8e_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_munmap_p8e_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_common
static void setup_lseek_munmap_p8e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_munmap_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_p8e_0_0
// static int test_lseek_munmap_p8c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_common
// static void setup_lseek_munmap_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_p8e_0_proc0
// static void setup_lseek_munmap_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
static int test_lseek_munmap_p8a_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_munmap_p8a_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_common
// static void setup_lseek_munmap_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_proc0
// static void setup_lseek_munmap_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_p8a_0_0
// static int test_lseek_munmap_p88_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_common
// static void setup_lseek_munmap_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_proc0
// static void setup_lseek_munmap_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_0
// static int test_lseek_munmap_p84_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_common
// static void setup_lseek_munmap_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_proc0
// static void setup_lseek_munmap_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_0
// static int test_lseek_munmap_p80_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_common
// static void setup_lseek_munmap_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_munmap_pa8_0_proc0
// static void setup_lseek_munmap_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_munmap_pb8_0_final
// static void setup_lseek_munmap_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
static int test_lseek_munmap_p4_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_munmap_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
static void setup_lseek_munmap_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_munmap_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p4_0_final(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal
// static void setup_lseek_munmap_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal

/*
 * calls: lseek munmap
 */
// static int test_lseek_munmap_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_p4_0_0
// static int test_lseek_munmap_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_munmap_pe_0_1
// static void setup_lseek_munmap_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_munmap_p4_0_common
// static void setup_lseek_munmap_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_munmap_pb8_0_proc1
// static void setup_lseek_munmap_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal
// static void setup_lseek_munmap_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_munmap_pb8_0_procfinal


/*
 * calls: lseek open
 */
static int test_lseek_open_pf8_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_open_pf8_0_1(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_lseek_open_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_open_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_open_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_open_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_open_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek open
 */
// static int test_lseek_open_pf8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pf8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_1
// static void setup_lseek_open_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf8_0_common
static void setup_lseek_open_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_open_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pf70_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
static int test_lseek_open_pf70_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_lseek_open_pf70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_pf70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pf70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pf70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pf70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pf70_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pf70_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_pf70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf70_0_common
// static void setup_lseek_open_pf70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pf70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pf70_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pf70_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pf50_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pf50_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_pf50_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_pf50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pf50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pf50_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pf50_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pf50_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pf50_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_pf50_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_pf50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pf50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pf50_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pf50_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pf3_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
static int test_lseek_open_pf3_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_lseek_open_pf3_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_pf3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pf3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pf3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pf3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pf3_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pf3_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pf3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf3_0_common
// static void setup_lseek_open_pf3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pf3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pf3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pf3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pf1_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pf1_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pf1_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf3_0_common
// static void setup_lseek_open_pf1_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pf1_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pf1_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pf1_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pf1_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pf1_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pf1_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf3_0_common
// static void setup_lseek_open_pf1_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pf1_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pf1_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pf1_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pee_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pee_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_pee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_open_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pee_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pee_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_pee_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_open_pee_0_common
// static void setup_lseek_open_pee_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pee_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pee_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pee_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pea_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pea_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_pea_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_open_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pea_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pea_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pea_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pea_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_pea_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_open_pea_0_common
// static void setup_lseek_open_pea_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pea_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pea_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pea_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pe6_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pe6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
static void setup_lseek_open_pe6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_open_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pe6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pe6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pe6_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pe6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_open_pe6_0_common
// static void setup_lseek_open_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pe6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pe6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pe2_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pe2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
static void setup_lseek_open_pe2_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_open_pe2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pe2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pe2_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pe2_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pe2_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pe2_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pe2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_open_pea_0_common
// static void setup_lseek_open_pe2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pe2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pe2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pe2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pde_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
static int test_lseek_open_pde_0_1(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_lseek_open_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf70_0_common
// static void setup_lseek_open_pde_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pde_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pde_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
static void setup_lseek_open_pde_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_pde_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pde_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pda_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pda_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf50_0_common
// static void setup_lseek_open_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pda_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pda_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pda_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pda_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf50_1_common
// static void setup_lseek_open_pda_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pda_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pda_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pd6_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
static int test_lseek_open_pd6_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_lseek_open_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf3_0_common
// static void setup_lseek_open_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pd6_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pd6_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf3_0_common
// static void setup_lseek_open_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pd2_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pd2_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf3_0_common
// static void setup_lseek_open_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pd2_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pd2_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pd2_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pd2_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_pd2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pf3_0_common
// static void setup_lseek_open_pd2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pd2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pd2_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pd2_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
static int test_lseek_open_pc_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_lseek_open_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_open_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc0
// static void setup_lseek_open_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_pc_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pc_0_1
// static void setup_lseek_open_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_open_pc_0_common
// static void setup_lseek_open_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_1_proc0
// static void setup_lseek_open_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_open_pf8_0_proc1
// static void setup_lseek_open_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_final
// static void setup_lseek_open_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_open_pf8_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_pbe_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_open_pbe_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_1
static void setup_lseek_open_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_open_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_open_pbe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_open_pbe_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_open_pbe_0_procfinal(void) {
  
}

/*
 * calls: lseek open
 */
// static int test_lseek_open_pbdc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pbdc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_pbdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
static void setup_lseek_open_pbdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 33169408, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_pbdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pbdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pbdc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pbd4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pbd4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_pbd4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_open_pbd4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_pbd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pbd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pbd4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pbcc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pbcc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
static void setup_lseek_open_pbcc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_open_pbcc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_pbcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pbcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pbcc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pbc4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pbc4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pbc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
static void setup_lseek_open_pbc4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_pbc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pbc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pbc4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pbb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pbb8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_pbb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_open_pbb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_pbb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pbb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pbb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pba8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pba8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_pba8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_open_pba8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_proc0
// static void setup_lseek_open_pba8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pba8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pba8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pb98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pb98_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pb98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
// static void setup_lseek_open_pb98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_proc0
// static void setup_lseek_open_pb98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pb98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pb98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pb88_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pb88_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
static void setup_lseek_open_pb88_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_lseek_open_pb88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_proc0
// static void setup_lseek_open_pb88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pb88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pb88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pb78_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pb78_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
static void setup_lseek_open_pb78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_open_pb78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23973888, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_pb78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pb78_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pb78_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pb68_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pb68_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_pb68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_pb68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9347072, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbd4_0_proc0
// static void setup_lseek_open_pb68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pb68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pb68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pb58_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pb58_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_pb58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbcc_0_common
// static void setup_lseek_open_pb58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbcc_0_proc0
// static void setup_lseek_open_pb58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pb58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pb58_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pb48_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pb48_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_pb48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_pb48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_pb48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pb48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pb48_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pbe_0_0
// static int test_lseek_open_pb0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pc_0_1
// static void setup_lseek_open_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
// static void setup_lseek_open_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbe_0_proc0
// static void setup_lseek_open_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_pae_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_open_pae_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_1
// static void setup_lseek_open_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
static void setup_lseek_open_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pae_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_padc_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_padc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_padc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_padc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pb78_0_proc0
// static void setup_lseek_open_padc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_padc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_padc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_padc_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_padc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_padc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_padc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_padc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_padc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_padc_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pad4_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pad4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_pad4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pb78_0_common
static void setup_lseek_open_pad4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_pad4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pad4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pad4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pad4_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pad4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_pad4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_pad4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_pad4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pad4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pad4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pacc_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pacc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pacc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_pacc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_pacc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pacc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pacc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pacc_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pacc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pacc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pad4_1_common
// static void setup_lseek_open_pacc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_pacc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pacc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pacc_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pac4_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pac4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pac4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_pac4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_pac4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pac4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pac4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pac4_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pac4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pac4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_pac4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_pac4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pac4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pac4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pab8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pab8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_pab8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_open_pb88_0_common
static void setup_lseek_open_pab8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1150976, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_pab8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pab8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pab8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pab8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pab8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_pab8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_pab8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_pab8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pab8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pab8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_paa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_paa8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_paa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
// static void setup_lseek_open_paa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_proc0
// static void setup_lseek_open_paa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_paa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_paa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_paa8_1_0(void) {
  int r = lseek(10, 25735168, SEEK_SET);
  expect_result("r", r, 25735168);
  return xerrno(r);
}
// static int test_lseek_open_paa8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_paa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
static void setup_lseek_open_paa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 25735168, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_paa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_paa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_paa8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa98_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa98_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pa98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_open_pb88_0_common
// static void setup_lseek_open_pa98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbdc_0_proc0
// static void setup_lseek_open_pa98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_pa98_1_0(void) {
  int r = lseek(10, 23973888, SEEK_SET);
  expect_result("r", r, 23973888);
  return xerrno(r);
}
// static int test_lseek_open_pa98_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
static void setup_lseek_open_pa98_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_open_pa98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pb78_0_proc0
// static void setup_lseek_open_pa98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa98_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa88_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa88_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pa88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_open_pb88_0_common
// static void setup_lseek_open_pa88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_proc0
// static void setup_lseek_open_pa88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa88_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa88_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_pa88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_pa88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_pa88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa88_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa78_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa78_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_pa78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pb78_0_common
// static void setup_lseek_open_pa78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pb78_0_proc0
// static void setup_lseek_open_pa78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa78_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa78_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa78_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa78_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_pa78_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_padc_1_common
// static void setup_lseek_open_pa78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_pa78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa78_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa78_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa68_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa68_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_pa68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_pa68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9347072, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbd4_0_proc0
// static void setup_lseek_open_pa68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa68_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa68_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_pa68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pad4_1_common
// static void setup_lseek_open_pa68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_pa68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa68_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa58_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa58_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_pa58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_pa58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_pa58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa58_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa58_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa58_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_pa58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pad4_1_common
// static void setup_lseek_open_pa58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_pa58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa58_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa58_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa48_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa48_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_pa48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_pa48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_pa48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa48_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa48_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa48_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_pa48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_pa48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_pa48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa48_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa48_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pae_0_0
// static int test_lseek_open_pa0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pc_0_1
// static void setup_lseek_open_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_open_pb88_0_common
// static void setup_lseek_open_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p9f_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_open_p9f_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_1
// static void setup_lseek_open_p9f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pad4_1_common
// static void setup_lseek_open_p9f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9f_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9f_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9ee_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9ee_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p9ee_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_padc_1_common
// static void setup_lseek_open_p9ee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9ee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9ee_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9ee_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9ea_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9ea_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p9ea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pad4_1_common
// static void setup_lseek_open_p9ea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9ea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9ea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9ea_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9e6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9e6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p9e6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p9e6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9e6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9e6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9e6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9e2_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9e2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p9e2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p9e2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9e2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9e2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9e2_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9dc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9dc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p9dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_p9dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9dc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9dc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9d4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9d4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p9d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
// static void setup_lseek_open_p9d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9d4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9d4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9cc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9cc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p9cc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_p9cc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9cc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9cc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9cc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9c4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9c4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p9c4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
// static void setup_lseek_open_p9c4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9c4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9c4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9c4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9bc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9bc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p9bc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_padc_1_common
// static void setup_lseek_open_p9bc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9bc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9bc_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9b4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9b4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p9b4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pad4_1_common
// static void setup_lseek_open_p9b4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9b4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9b4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9b4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9ac_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9ac_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p9ac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p9ac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9ac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9ac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9ac_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p9a4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p9a4_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p9a4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p9a4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p9a4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p9a4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p9a4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p9f_0_0
// static int test_lseek_open_p98_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pc_0_1
static void setup_lseek_open_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_open_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p97_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_open_p97_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_1
// static void setup_lseek_open_p97_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p97_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p97_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p97_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p97_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p96e_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p96e_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p96e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p96e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p96e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p96e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p96e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p96a_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p96a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p96a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pad4_1_common
// static void setup_lseek_open_p96a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p96a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p96a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p96a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p966_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p966_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
static void setup_lseek_open_p966_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_p966_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p966_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p966_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p966_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p962_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p962_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p962_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p962_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p962_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p962_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p962_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p95c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p95c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p95c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_p95c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p95c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p95c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p95c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p954_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p954_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p954_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_p954_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p954_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p954_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p954_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p94c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p94c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p94c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_p94c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p94c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p94c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p94c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p944_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 36638720);
  return xerrno(r);
}
// static int test_lseek_open_p944_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p944_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
static void setup_lseek_open_p944_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36638720, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_p944_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p944_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p944_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p944_1_0(void) {
  int r = lseek(10, 25735168, SEEK_CUR);
  expect_result("r", r, 51470336);
  return xerrno(r);
}
// static int test_lseek_open_p944_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p944_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
// static void setup_lseek_open_p944_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 25735168, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_paa8_1_proc0
// static void setup_lseek_open_p944_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p944_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p944_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p93c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p93c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p93c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_padc_1_common
// static void setup_lseek_open_p93c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p93c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p93c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p93c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p934_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p934_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p934_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pad4_1_common
// static void setup_lseek_open_p934_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p934_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p934_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p934_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p92c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p92c_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p92c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pad4_1_common
// static void setup_lseek_open_p92c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p92c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p92c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p92c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p924_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p924_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p924_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p924_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p924_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p924_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p924_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p97_0_0
// static int test_lseek_open_p90_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pc_0_1
// static void setup_lseek_open_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_open_pb88_0_common
// static void setup_lseek_open_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8f8_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_open_p8f8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_1
// static void setup_lseek_open_p8f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbcc_0_proc0
// static void setup_lseek_open_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8f8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8f8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8f70_0_0(void) {
  int r = lseek(10, -8192, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_open_p8f70_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_p8f70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_p8f70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbdc_0_proc0
// static void setup_lseek_open_p8f70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
static void setup_lseek_open_p8f70_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_lseek_open_p8f70_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8f70_1_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f70_0_0
// static int test_lseek_open_p8f70_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_p8f70_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_p8f70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pb78_0_proc0
// static void setup_lseek_open_p8f70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8f70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8f70_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8f50_0_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f70_0_0
// static int test_lseek_open_p8f50_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8f50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_p8f70_0_common
// static void setup_lseek_open_p8f50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbdc_0_proc0
// static void setup_lseek_open_p8f50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8f50_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_open_p8f70_0_final
// static void setup_lseek_open_p8f50_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8f50_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f8_0_0
// static int test_lseek_open_p8f50_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8f50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
static void setup_lseek_open_p8f50_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4677632, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_p8f50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8f50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8f50_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8f3_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f8_0_0
// static int test_lseek_open_p8f3_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8f3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
static void setup_lseek_open_p8f3_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_p8f3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8f3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8f3_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8f1_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f8_0_0
// static int test_lseek_open_p8f1_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8f1_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8f1_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_p8f1_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8f1_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8f1_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8ee_0_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f70_0_0
// static int test_lseek_open_p8ee_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_p8ee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_open_p8ee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p8ee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8ee_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8ee_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8ea_0_0(void) {
  int r = lseek(10, -28672, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_open_p8ea_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_p8ea_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_open_p8ea_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2191360, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_p8ea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8ea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8ea_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8e6_0_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f70_0_0
// static int test_lseek_open_p8e6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8e6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_p8ee_0_common
// static void setup_lseek_open_p8e6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1150976, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pab8_0_proc0
// static void setup_lseek_open_p8e6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8e6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8e6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8e2_0_0(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8ea_0_0
// static int test_lseek_open_p8e2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8e2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_p8ea_0_common
// static void setup_lseek_open_p8e2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 2191360, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8ea_0_proc0
// static void setup_lseek_open_p8e2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8e2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8e2_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8de_0_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f70_0_0
// static int test_lseek_open_p8de_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p8de_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_p8f70_1_common
// static void setup_lseek_open_p8de_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbdc_0_proc0
// static void setup_lseek_open_p8de_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8de_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8de_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8da_0_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f70_0_0
// static int test_lseek_open_p8da_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p8da_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_p8f70_0_common
// static void setup_lseek_open_p8da_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbdc_0_proc0
// static void setup_lseek_open_p8da_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8da_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_open_p8f70_0_final
// static void setup_lseek_open_p8da_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8da_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f8_0_0
// static int test_lseek_open_p8da_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p8da_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8da_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p8da_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8da_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8da_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8d6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f8_0_0
// static int test_lseek_open_p8d6_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p8d6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8d6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 12288, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f3_0_proc0
// static void setup_lseek_open_p8d6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8d6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8d6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8d2_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f8_0_0
// static int test_lseek_open_p8d2_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p8d2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8d2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_p8d2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8d2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8d2_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8f8_0_0
// static int test_lseek_open_p8c_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pc_0_1
// static void setup_lseek_open_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_open_pb88_0_common
// static void setup_lseek_open_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbcc_0_proc0
// static void setup_lseek_open_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8b8_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_open_p8b8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_1
// static void setup_lseek_open_p8b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p8b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8b8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8b6c_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p8b6c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_p8b6c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_p8b6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p8b6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
static void setup_lseek_open_p8b6c_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_lseek_open_p8b6c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8b6c_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p8b6c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8b6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8b6c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p8b6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b6c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8b6c_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8b6c_2_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_open_p8b6c_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_p8b6c_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_p8b6c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p8b6c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b6c_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_lseek_open_p8b6c_0_final
// static void setup_lseek_open_p8b6c_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8b6c_3_0(void) {
  int r = lseek(10, 155648, SEEK_END);
  expect_result("r", r, 155648);
  return xerrno(r);
}
// static int test_lseek_open_p8b6c_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8b6c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
static void setup_lseek_open_p8b6c_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_p8b6c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b6c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8b6c_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8b4c_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p8b4c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_p8b4c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_open_p8b4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p8b4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b4c_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_open_p8f70_0_final
// static void setup_lseek_open_p8b4c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8b4c_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b6c_2_0
// static int test_lseek_open_p8b4c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8b4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_p8f70_0_common
// static void setup_lseek_open_p8b4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p8b4c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b4c_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_open_p8f70_0_final
// static void setup_lseek_open_p8b4c_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8b4c_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p8b4c_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8b4c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8b4c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p8b4c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b4c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8b4c_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8b4c_3_0(void) {
  int r = lseek(10, 36270080, SEEK_END);
  expect_result("r", r, 36270080);
  return xerrno(r);
}
// static int test_lseek_open_p8b4c_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8b4c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8b4c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbe_0_proc0
// static void setup_lseek_open_p8b4c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b4c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8b4c_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8b3_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p8b3_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8b3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
static void setup_lseek_open_p8b3_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_p8b3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8b3_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8b3_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p8b3_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8b3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8b3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p8b3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8b3_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8b1_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p8b1_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8b1_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8b1_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_p8b1_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b1_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8b1_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8b1_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_open_p8b1_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8b1_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p8b1_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p8b1_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8b1_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8b1_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8ae_0_0(void) {
  int r = lseek(10, -8192, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_open_p8ae_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8ae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
// static void setup_lseek_open_p8ae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36638720, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p944_0_proc0
// static void setup_lseek_open_p8ae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8ae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8ae_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8ae_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b6c_2_0
// static int test_lseek_open_p8ae_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8ae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_p8ee_0_common
// static void setup_lseek_open_p8ae_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p8ae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8ae_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8ae_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8aa_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b6c_2_0
// static int test_lseek_open_p8aa_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8aa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_p8ee_0_common
// static void setup_lseek_open_p8aa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1150976, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pab8_0_proc0
// static void setup_lseek_open_p8aa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8aa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8aa_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8aa_1_0(void) {
  int r = lseek(10, 4677632, SEEK_END);
  expect_result("r", r, 4689920);
  return xerrno(r);
}
// static int test_lseek_open_p8aa_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p8aa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_p8aa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p8aa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8aa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8aa_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8a6_0_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8ae_0_0
// static int test_lseek_open_p8a6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8a6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
// static void setup_lseek_open_p8a6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36638720, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p944_0_proc0
// static void setup_lseek_open_p8a6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8a6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8a6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8a6_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b6c_2_0
// static int test_lseek_open_p8a6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8a6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_p8ee_0_common
// static void setup_lseek_open_p8a6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p8a6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8a6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8a6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8a2_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p8a2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8a2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_open_pb88_0_common
// static void setup_lseek_open_p8a2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1150976, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pab8_0_proc0
// static void setup_lseek_open_p8a2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8a2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8a2_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p8a2_1_0(void) {
  int r = lseek(10, 25735168, SEEK_END);
  expect_result("r", r, 25747456);
  return xerrno(r);
}
// static int test_lseek_open_p8a2_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p8a2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_p8a2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 25735168, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_paa8_1_proc0
// static void setup_lseek_open_p8a2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8a2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8a2_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p89d8_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p89d8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p89d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_p8b6c_0_common
// static void setup_lseek_open_p89d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p89d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p89d8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_lseek_open_p8b6c_0_final
// static void setup_lseek_open_p89d8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p89d8_1_0(void) {
  int r = lseek(10, 4096, SEEK_END);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_open_p89d8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p89d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_p8b6c_0_common
static void setup_lseek_open_p89d8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_open_p89d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p89d8_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_lseek_open_p8b6c_0_final
// static void setup_lseek_open_p89d8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p89d8_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p89d8_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p89d8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p89d8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p89d8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p89d8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p89d8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p89d8_3_0(void) {
//   int r = lseek(10, 155648, SEEK_END);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b6c_3_0
// static int test_lseek_open_p89d8_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p89d8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p89d8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8b6c_3_proc0
// static void setup_lseek_open_p89d8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p89d8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p89d8_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8998_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p8998_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p8998_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_p8b4c_0_common
// static void setup_lseek_open_p8998_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p8998_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8998_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_open_p8f70_0_final
// static void setup_lseek_open_p8998_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8998_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b6c_2_0
// static int test_lseek_open_p8998_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p8998_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_p8f70_0_common
// static void setup_lseek_open_p8998_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p8998_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8998_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_open_p8f70_0_final
// static void setup_lseek_open_p8998_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8998_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p8998_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p8998_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8998_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4677632, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8f50_1_proc0
// static void setup_lseek_open_p8998_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8998_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8998_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p8998_3_0(void) {
//   int r = lseek(10, 36270080, SEEK_END);
//   expect_result("r", r, 36270080);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b4c_3_0
// static int test_lseek_open_p8998_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p8998_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p8998_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbe_0_proc0
// static void setup_lseek_open_p8998_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p8998_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p8998_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p896_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p896_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p896_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p896_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_p8b3_0_proc0
// static void setup_lseek_open_p896_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p896_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p896_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p896_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p896_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p896_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p896_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p896_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p896_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p896_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p892_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p892_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p892_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p892_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_p892_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p892_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p892_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p892_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b1_1_0
// static int test_lseek_open_p892_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p892_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p892_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p892_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p892_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p892_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p8b8_0_0
// static int test_lseek_open_p88_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pc_0_1
// static void setup_lseek_open_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_open_pb88_0_common
// static void setup_lseek_open_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p87_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p87_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_1
// static void setup_lseek_open_p87_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p87_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p87_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p87_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p87_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p86e_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p86e_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p86e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p86e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbdc_0_proc0
// static void setup_lseek_open_p86e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p86e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p86e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p86a_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p86a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p86a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pb78_0_common
// static void setup_lseek_open_p86a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pad4_0_proc0
// static void setup_lseek_open_p86a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p86a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p86a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p866_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p866_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p866_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbcc_0_common
// static void setup_lseek_open_p866_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbcc_0_proc0
// static void setup_lseek_open_p866_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p866_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p866_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p862_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p862_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p862_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p862_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_p862_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p862_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p862_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p85c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p85c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p85c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_p85c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_proc0
// static void setup_lseek_open_p85c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p85c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p85c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p854_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p854_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p854_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
// static void setup_lseek_open_p854_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_proc0
// static void setup_lseek_open_p854_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p854_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p854_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p84c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p84c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p84c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_common
// static void setup_lseek_open_p84c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_proc0
// static void setup_lseek_open_p84c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p84c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p84c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p844_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p844_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p844_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_open_pba8_0_common
// static void setup_lseek_open_p844_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbb8_0_proc0
// static void setup_lseek_open_p844_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p844_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p844_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p83c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p83c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p83c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p83c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbdc_0_proc0
// static void setup_lseek_open_p83c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p83c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p83c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p834_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p834_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p834_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p834_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9347072, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbd4_0_proc0
// static void setup_lseek_open_p834_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p834_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p834_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p82c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p82c_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p82c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbcc_0_common
// static void setup_lseek_open_p82c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbcc_0_proc0
// static void setup_lseek_open_p82c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p82c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p82c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p824_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p824_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p824_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p824_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pbc4_0_proc0
// static void setup_lseek_open_p824_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p824_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p824_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_0
// static int test_lseek_open_p80_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pc_0_1
// static void setup_lseek_open_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_open_pb88_0_common
// static void setup_lseek_open_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_open_pae_0_proc0
// static void setup_lseek_open_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
static int test_lseek_open_p7_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_open_p7_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf8_0_1
// static void setup_lseek_open_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p7_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p6d0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p6d0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p6d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pb78_0_common
// static void setup_lseek_open_p6d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p6d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p6d0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p6d0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p6a_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p6a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p6a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pb78_0_common
// static void setup_lseek_open_p6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p6a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p6a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p65_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p65_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p65_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p65_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p65_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p65_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p65_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p62_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p62_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p62_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p5a_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p5a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
static void setup_lseek_open_p5a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_open_p5a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p5a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p5a_0_final(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal
// static void setup_lseek_open_p5a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p54_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p54_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf70_0_1
// static void setup_lseek_open_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_open_p5a_0_common
// static void setup_lseek_open_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p54_0_final(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal
// static void setup_lseek_open_p54_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p4a_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p4a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p4a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_open_p5a_0_common
// static void setup_lseek_open_p4a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p4a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p4a_0_final(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal
// static void setup_lseek_open_p4a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p44_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p44_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pf3_0_1
// static void setup_lseek_open_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_open_p5a_0_common
// static void setup_lseek_open_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p44_0_final(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal
// static void setup_lseek_open_p44_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p3a_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p3a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p3a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pb78_0_common
// static void setup_lseek_open_p3a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p3a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p3a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p3a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p34_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p34_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pde_0_1
// static void setup_lseek_open_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbd4_0_common
// static void setup_lseek_open_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p34_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p2a_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p2a_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p2a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p2a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p2a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p2a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p2a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p24_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p24_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_lseek_open_pd6_0_1
// static void setup_lseek_open_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_open_pbe_0_common
// static void setup_lseek_open_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_open_pbe_0_final
// static void setup_lseek_open_p24_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal

/*
 * calls: lseek open
 */
// static int test_lseek_open_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_open_p7_0_0
// static int test_lseek_open_p0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_open_pc_0_1
// static void setup_lseek_open_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_open_p5a_0_common
// static void setup_lseek_open_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_open_pbe_0_proc1
// static void setup_lseek_open_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal
// static void setup_lseek_open_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_open_pbe_0_procfinal


/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_pf8_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_pipe_pf8_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_lseek_pipe_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pipe_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_pipe_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_pipe_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_pipe_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_pf8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_0
// static int test_lseek_pipe_pf8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pipe_pf8_0_common
static void setup_lseek_pipe_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pipe_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pipe_pf8_0_proc1
// static void setup_lseek_pipe_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pipe_pf8_0_final
// static void setup_lseek_pipe_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pipe_pf8_0_procfinal

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_pd8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_0
// static int test_lseek_pipe_pd8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
static void setup_lseek_pipe_pd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_pipe_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pipe_pf8_0_proc0
// static void setup_lseek_pipe_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pipe_pf8_0_proc1
// static void setup_lseek_pipe_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pipe_pf8_0_final
// static void setup_lseek_pipe_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pipe_pf8_0_procfinal

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_pd8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_0
// static int test_lseek_pipe_pd8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pipe_pd8_0_common
// static void setup_lseek_pipe_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pipe_pf8_1_proc0
// static void setup_lseek_pipe_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pipe_pf8_0_proc1
// static void setup_lseek_pipe_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pipe_pf8_0_final
// static void setup_lseek_pipe_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pipe_pf8_0_procfinal

/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_pbe_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pipe_pbe_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
static void setup_lseek_pipe_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pipe_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pipe_pbe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_pipe_pbe_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_pipe_pbe_0_procfinal(void) {
  
}

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_pb6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pbe_0_0
// static int test_lseek_pipe_pb6_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pipe_pbe_0_common
// static void setup_lseek_pipe_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pipe_pbe_0_proc0
// static void setup_lseek_pipe_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_pb6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_pb6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_pae_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_pipe_pae_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
static void setup_lseek_pipe_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pipe_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pipe_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_pae_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_pae_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pae_0_0
// static int test_lseek_pipe_pae_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pipe_pbe_0_common
static void setup_lseek_pipe_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pipe_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_pae_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_pae_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_pa6_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pae_0_0
// static int test_lseek_pipe_pa6_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
static void setup_lseek_pipe_pa6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pipe_pa6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pipe_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_pa6_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pae_0_0
// static int test_lseek_pipe_pa6_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pipe_pae_0_common
// static void setup_lseek_pipe_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pipe_pae_1_proc0
// static void setup_lseek_pipe_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_pa6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_pa6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_p9f0_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pipe_p9f0_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_p9f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pipe_pae_0_common
// static void setup_lseek_pipe_p9f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pipe_pae_1_proc0
// static void setup_lseek_pipe_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p9f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p9f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_p9b0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_p9f0_0_0
// static int test_lseek_pipe_p9b0_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_p9b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pipe_pae_0_common
// static void setup_lseek_pipe_p9b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pipe_pae_1_proc0
// static void setup_lseek_pipe_p9b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p9b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p9b0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_p970_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 9981952);
  return xerrno(r);
}
// static int test_lseek_pipe_p970_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
static void setup_lseek_pipe_p970_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pipe_p970_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pipe_p970_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p970_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p970_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_p970_1_0(void) {
  int r = lseek(10, 36270080, SEEK_CUR);
  expect_result("r", r, 72540160);
  return xerrno(r);
}
// static int test_lseek_pipe_p970_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
static void setup_lseek_pipe_p970_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pipe_p970_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pipe_p970_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p970_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p970_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_p930_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_pipe_p930_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_p930_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pipe_pae_0_common
// static void setup_lseek_pipe_p930_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pipe_pae_1_proc0
// static void setup_lseek_pipe_p930_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p930_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p930_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_p8f8_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pipe_p8f8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
static void setup_lseek_pipe_p8f8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_pipe_p8f8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23973888, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pipe_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p8f8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p8f8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_p8d8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_p8f8_0_0
// static int test_lseek_pipe_p8d8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pipe_p8f8_0_common
// static void setup_lseek_pipe_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pipe_pae_0_proc0
// static void setup_lseek_pipe_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p8d8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p8d8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_p8b8_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_pipe_p8b8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_p8b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pipe_p8f8_0_common
// static void setup_lseek_pipe_p8b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pipe_pbe_0_proc0
// static void setup_lseek_pipe_p8b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p8b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p8b8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_p8b8_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_pipe_p8b8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_p8b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pipe_p970_0_common
// static void setup_lseek_pipe_p8b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pipe_pae_1_proc0
// static void setup_lseek_pipe_p8b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p8b8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p8b8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_p870_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_0
// static int test_lseek_pipe_p870_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_p870_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pipe_pbe_0_common
// static void setup_lseek_pipe_p870_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pipe_pbe_0_proc0
// static void setup_lseek_pipe_p870_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p870_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p870_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_p830_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_0
// static int test_lseek_pipe_p830_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_p830_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pipe_pa6_0_common
// static void setup_lseek_pipe_p830_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pipe_pa6_0_proc0
// static void setup_lseek_pipe_p830_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p830_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pipe_pbe_0_final
// static void setup_lseek_pipe_p830_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
static int test_lseek_pipe_p58_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_pipe_p58_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
static void setup_lseek_pipe_p58_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_pipe_p58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p58_0_final(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal
// static void setup_lseek_pipe_p58_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal

/*
 * calls: lseek pipe
 */
// static int test_lseek_pipe_p30_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_p58_0_0
// static int test_lseek_pipe_p30_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pipe_pf8_0_1
// static void setup_lseek_pipe_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_pipe_p58_0_common
// static void setup_lseek_pipe_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pipe_pbe_0_proc1
// static void setup_lseek_pipe_p30_0_final(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal
// static void setup_lseek_pipe_p30_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pipe_pbe_0_procfinal


/*
 * calls: lseek pread
 */
static int test_lseek_pread_pf8_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_pread_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_lseek_pread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pread_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_pread_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_pread_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_pread_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
static void setup_lseek_pread_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pf8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
static void setup_lseek_pread_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf8_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
static int test_lseek_pread_pf8_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_pread_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
static void setup_lseek_pread_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf8_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pf8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
static void setup_lseek_pread_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
static int test_lseek_pread_pf4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_lseek_pread_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pread_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
static void setup_lseek_pread_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf4_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pf4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
static void setup_lseek_pread_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf4_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pf4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
static void setup_lseek_pread_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
static int test_lseek_pread_pf0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_lseek_pread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pread_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf0_0_common
static void setup_lseek_pread_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf0_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pf0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
static void setup_lseek_pread_pf0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_pread_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf4_2_proc0
// static void setup_lseek_pread_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pf0_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pf0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf0_2_common
// static void setup_lseek_pread_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf4_3_proc0
// static void setup_lseek_pread_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pe_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
static int test_lseek_pread_pe_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_pread_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
// static void setup_lseek_pread_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pd8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd8_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pd8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
static int test_lseek_pread_pd4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_pread_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
static void setup_lseek_pread_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_0_proc1
// static void setup_lseek_pread_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd4_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pd4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
static void setup_lseek_pread_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd4_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pd4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
static int test_lseek_pread_pd0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_pread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf0_0_common
// static void setup_lseek_pread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
static void setup_lseek_pread_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf0_0_common
// static void setup_lseek_pread_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd0_0_proc1
// static void setup_lseek_pread_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd0_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pd0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf0_2_common
// static void setup_lseek_pread_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pd0_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pd0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
static void setup_lseek_pread_pd0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_pread_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
static int test_lseek_pread_pc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_pread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_pbe_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pread_pbe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
static void setup_lseek_pread_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pread_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pbe_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pbe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pbe_0_common
static void setup_lseek_pread_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pbd_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pbd_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
static void setup_lseek_pread_pbd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_pread_pbd_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pread_pbd_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_pread_pbd_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_pread_pbd_0_procfinal(void) {
  
}

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pbd_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pbd_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_pbd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
static void setup_lseek_pread_pbd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_pbd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pbd_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pbd_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pbd_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pbd_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pbd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
static void setup_lseek_pread_pbd_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_pbd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pbd_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pbd_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pbd_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pbd_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pbd_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
static void setup_lseek_pread_pbd_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_pbd_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pbd_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pbd_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pbc0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pbc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
static void setup_lseek_pread_pbc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pread_pbc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_pbc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pbc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pbc0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pbc0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pbc0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_pbc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_pbc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_pbc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pbc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pbc0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pbc0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pbc0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_pbc0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_pbc0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_pbc0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pbc0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pbc0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pbc0_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pbc0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_pbc0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_pbc0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pbc0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pbc0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pbc0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
static void setup_lseek_pread_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pread_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pb6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pb6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pbe_0_common
static void setup_lseek_pread_pb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pb6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pb6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pbe_0_common
// static void setup_lseek_pread_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pb6_0_proc0
// static void setup_lseek_pread_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pb5_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pb5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pb5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_pb5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_pb5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_pb5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pb5_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pb5_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pb5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pb5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_pb5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pb5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pb5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pb5_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pb40_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pb40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_pb40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
static void setup_lseek_pread_pb40_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pread_pb40_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_pb40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pb40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pb40_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pb40_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_pb40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_pb40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pb40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pb40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pb40_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pbe_0_0
// static int test_lseek_pread_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_proc0
// static void setup_lseek_pread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_pae_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_pread_pae_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
static void setup_lseek_pread_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pread_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pae_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pae_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
static void setup_lseek_pread_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pae_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pae_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_pae_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
static void setup_lseek_pread_pae_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pae_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pae_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pae_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pae_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pae_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_pae_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
static void setup_lseek_pread_pae_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_pae_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_pae_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pae_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pad_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pad_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_pad_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_pad_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_proc0
// static void setup_lseek_pread_pad_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pad_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pad_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pad_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pad_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pad_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_pad_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_pad_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pad_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pad_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pad_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pad_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_pad_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_pad_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_pad_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pad_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pad_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pad_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pad_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pad_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_pad_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pad_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pad_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pad_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pac0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pac0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_pac0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_pac0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_proc0
// static void setup_lseek_pread_pac0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pac0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pac0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pac0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pac0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_pac0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_pac0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_pac0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pac0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pac0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pac0_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pac0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_pac0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_pac0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_pac0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pac0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pac0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pac0_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pac0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_pac0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_pac0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pac0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pac0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pac0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
// static void setup_lseek_pread_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
// static void setup_lseek_pread_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa6_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_0_proc1
// static void setup_lseek_pread_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_pa6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pa6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa6_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_0_proc1
// static void setup_lseek_pread_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pa6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pa6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa6_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa6_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pa6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_pa6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_pa6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_pa6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pa6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa6_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa6_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_pa6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_pa6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_pa6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_pa6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_pa6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa5_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pa5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_pa5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_pa5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_pa5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pa5_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa5_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_pa5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_pa5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pa5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pa5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pa5_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa40_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_pa40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_pa40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_pa40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_pa40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pa40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa40_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa40_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_pa40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_pa40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pa40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pa40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pa40_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_pa0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pae_0_0
// static int test_lseek_pread_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_p9f_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pread_p9f_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p9f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p9f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_2_proc0
// static void setup_lseek_pread_p9f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p9f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p9f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p9f_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p9f_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p9f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p9f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_3_proc0
// static void setup_lseek_pread_p9f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p9f_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p9f_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p9e8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p9e8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_p9e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p9e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_p9e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p9e8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p9e8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p9e8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p9e8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p9e8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p9e8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p9e8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p9e8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p9e8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p9e0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p9e0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p9e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p9e0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_p9e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p9e0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p9e0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p9e0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p9e0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p9e0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p9e0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p9e0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p9e0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p9e0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p9c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p9c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
// static void setup_lseek_pread_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p9b_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p9b_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p9b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p9b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_p9b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_p9b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p9b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p9b_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p9b_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p9b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p9b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_p9b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_p9b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p9b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p9a8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p9a8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p9a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p9a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p9a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p9a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p9a8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p9a0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p9a0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p9a0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p9a0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p9a0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p9a0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p9a0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p9f_0_0
// static int test_lseek_pread_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_p97_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_pread_p97_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p97_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p97_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_2_proc0
// static void setup_lseek_pread_p97_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p97_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p97_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p97_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p97_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p97_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p97_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_3_proc0
// static void setup_lseek_pread_p97_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p97_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p97_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p968_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p968_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_p968_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p968_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_p968_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p968_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p968_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p968_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p968_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p968_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p968_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p968_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p968_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p968_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p960_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p960_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p960_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p960_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_p960_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p960_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p960_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p960_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p960_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p960_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p960_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p960_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p960_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p960_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p94_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p94_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
// static void setup_lseek_pread_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p93_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p93_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p93_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p93_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_p93_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_p93_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p93_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p93_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p93_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p93_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p93_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_p93_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_p93_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p93_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p928_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p928_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p928_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p928_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p928_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p928_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p920_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p920_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p920_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p920_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p920_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p920_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p920_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p97_0_0
// static int test_lseek_pread_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_p8f8_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pread_p8f8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p8f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_p8f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_0_proc0
// static void setup_lseek_pread_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p8f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p8f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8f8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p8f8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_p8f8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_1_proc0
// static void setup_lseek_pread_p8f8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p8f8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p8f8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8f4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
static void setup_lseek_pread_p8f4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_pread_p8f4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8f4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
static void setup_lseek_pread_p8f4_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_lseek_pread_p8f4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
static int test_lseek_pread_p8f4_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 34291712);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_lseek_pread_p8f4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pread_p8f4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34291712, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34291712, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8f4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f4_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8f4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8f4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_p8f4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8f4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_proc0
// static void setup_lseek_pread_p8f4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8f4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f4_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
static int test_lseek_pread_p8f4_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 31617024);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_pread_p8f4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
static void setup_lseek_pread_p8f4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8f4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8f4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f4_4_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8f4_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p8f4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8f4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p8f4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8f4_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f4_5_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
static int test_lseek_pread_p8f4_5_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 31617024);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_pread_p8f4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
static void setup_lseek_pread_p8f4_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8f4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8f4_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8f0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
static void setup_lseek_pread_p8f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pread_p8f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_p8f0_1_0(void) {
  int r = lseek(10, -8192, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pread_p8f0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p8f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p8f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_proc0
// static void setup_lseek_pread_p8f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8f0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
static int test_lseek_pread_p8f0_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 20480);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_lseek_pread_p8f0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_pread_p8f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f0_0_proc0
// static void setup_lseek_pread_p8f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f0_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8f0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f0_3_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f0_1_0
// static int test_lseek_pread_p8f0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p8f0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p8f0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_p8f0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8f0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f0_4_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f0_1_0
// static int test_lseek_pread_p8f0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p8f0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p8f0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_p8f0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8f0_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8f0_5_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f0_1_0
// static int test_lseek_pread_p8f0_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p8f0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p8f0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p8f0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8f0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8f0_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8e_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
// static void setup_lseek_pread_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8d8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_0_proc1
// static void setup_lseek_pread_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_p8d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p8d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8d8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8d8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p8d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_p8d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_0_proc1
// static void setup_lseek_pread_p8d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_p8d8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p8d8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8d4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8d4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p8d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f4_0_common
// static void setup_lseek_pread_p8d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
static void setup_lseek_pread_p8d4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8d4_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8d4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8d4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8d4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p8d4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8d4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p8d4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p8d4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8d4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8d4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
static int test_lseek_pread_p8d4_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 10006528);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_pread_p8d4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f0_2_common
static void setup_lseek_pread_p8d4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 10006528, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pread_p8d4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 10006528, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8d4_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8d4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8d4_3_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8d4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 31617024);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_p8f4_5_1
// static void setup_lseek_pread_p8d4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8d4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f4_5_proc0
// static void setup_lseek_pread_p8d4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f4_5_proc0
// static void setup_lseek_pread_p8d4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8d4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8d0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f0_0_common
// static void setup_lseek_pread_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
static void setup_lseek_pread_p8d0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8d0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8d0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8d0_1_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f0_1_0
// static int test_lseek_pread_p8d0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p8d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p8d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_p8d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_p8d0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8d0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_p8d0_2_0(void) {
  int r = lseek(10, -12288, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pread_p8d0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
static void setup_lseek_pread_p8d0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_pread_p8d0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
static void setup_lseek_pread_p8d0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8d0_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8d0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8d0_3_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f0_1_0
// static int test_lseek_pread_p8d0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p8d0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p8d0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p8d0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p8d0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8d0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8f8_0_0
// static int test_lseek_pread_p8c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_p8b8_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_pread_p8b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p8b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_p8b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_0_proc0
// static void setup_lseek_pread_p8b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p8b8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p8b8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b8_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p8b8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p8b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_p8b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_1_proc0
// static void setup_lseek_pread_p8b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p8b8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p8b8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_p8b8_2_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_pread_p8b8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p8b8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p8b8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_2_proc0
// static void setup_lseek_pread_p8b8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p8b8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p8b8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b8_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_2_0
// static int test_lseek_pread_p8b8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p8b8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p8b8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_3_proc0
// static void setup_lseek_pread_p8b8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p8b8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p8b8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b4_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p8b4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_p8b4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f4_0_common
// static void setup_lseek_pread_p8b4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f4_0_proc0
// static void setup_lseek_pread_p8b4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b4_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8b4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b4_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_2_0
// static int test_lseek_pread_p8b4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
static void setup_lseek_pread_p8b4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_pread_p8b4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8b4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b4_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8b4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b4_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p8b4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_p8b4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8b4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_proc0
// static void setup_lseek_pread_p8b4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8b4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b4_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p8b4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_p8b4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8b4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_p8b4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8b4_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b4_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p8b4_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p8b4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8b4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p8b4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8b4_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b4_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p8b4_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p8b4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8b4_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p8b4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8b4_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b0_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p8b0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p8b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f0_0_common
static void setup_lseek_pread_p8b0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b0_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_2_0
// static int test_lseek_pread_p8b0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p8b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_p8d0_2_common
// static void setup_lseek_pread_p8b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8b4_1_proc0
// static void setup_lseek_pread_p8b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b0_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p8b0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_p8b0_2_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_pread_p8b0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p8b0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p8b0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_proc0
// static void setup_lseek_pread_p8b0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8b0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b0_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b0_2_0
// static int test_lseek_pread_p8b0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p8b0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p8b0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_p8b0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8b0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b0_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b0_2_0
// static int test_lseek_pread_p8b0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p8b0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p8b0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_p8b0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8b0_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8b0_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b0_2_0
// static int test_lseek_pread_p8b0_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p8b0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p8b0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p8b0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8b0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8b0_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8a_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p8a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
// static void setup_lseek_pread_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p8a_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_2_0
// static int test_lseek_pread_p8a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
// static void setup_lseek_pread_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p898_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p898_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p898_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_p898_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_0_proc1
// static void setup_lseek_pread_p898_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_p898_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p898_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p898_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p898_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p898_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf4_0_common
// static void setup_lseek_pread_p898_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_0_proc1
// static void setup_lseek_pread_p898_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_p898_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p898_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p898_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_2_0
// static int test_lseek_pread_p898_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p898_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p898_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_p898_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_p898_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p898_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p898_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_2_0
// static int test_lseek_pread_p898_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p898_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pae_0_common
// static void setup_lseek_pread_p898_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_p898_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_p898_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p898_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p894_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p894_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p894_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f4_0_common
// static void setup_lseek_pread_p894_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p894_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8d4_0_proc1
// static void setup_lseek_pread_p894_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p894_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p894_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_2_0
// static int test_lseek_pread_p894_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p894_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8b4_1_common
// static void setup_lseek_pread_p894_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p894_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8d0_2_proc1
// static void setup_lseek_pread_p894_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p894_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p894_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p894_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p894_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p894_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p894_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p894_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p894_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p894_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p894_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p894_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p894_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p894_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p894_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p894_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p890_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p890_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_p8f0_0_common
static void setup_lseek_pread_p890_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pread_p890_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p890_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p890_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p890_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_2_0
// static int test_lseek_pread_p890_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_p8d0_2_common
// static void setup_lseek_pread_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p890_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_p8d0_2_proc1
// static void setup_lseek_pread_p890_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pread_p8f4_0_final
// static void setup_lseek_pread_p890_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p890_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b0_2_0
// static int test_lseek_pread_p890_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p890_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p890_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_p890_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_p890_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p890_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p890_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b0_2_0
// static int test_lseek_pread_p890_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p890_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p890_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p890_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p890_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p890_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_0_0
// static int test_lseek_pread_p88_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p88_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p8b8_2_0
// static int test_lseek_pread_p88_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pb8_0_common
// static void setup_lseek_pread_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p88_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p87_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p87_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p87_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_p87_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_2_proc0
// static void setup_lseek_pread_p87_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p87_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p87_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p87_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p87_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p87_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_p87_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pae_3_proc0
// static void setup_lseek_pread_p87_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p87_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p87_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p868_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p868_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_p868_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p868_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_proc0
// static void setup_lseek_pread_p868_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p868_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p868_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p868_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p868_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p868_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p868_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p868_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p868_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p868_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p868_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p868_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_p868_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p868_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_p868_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p868_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p868_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p868_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p868_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p868_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p868_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p868_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p868_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p868_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p860_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p860_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p860_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p860_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_proc0
// static void setup_lseek_pread_p860_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p860_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p860_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p860_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p860_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p860_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p860_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p860_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p860_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p860_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p860_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p860_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p860_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p860_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_1_proc0
// static void setup_lseek_pread_p860_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p860_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p860_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p860_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p860_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p860_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p860_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p860_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p860_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p860_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p84_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
// static void setup_lseek_pread_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p83_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p83_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p83_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_p83_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_p83_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_p83_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p83_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p83_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p83_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p83_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_p83_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pd4_2_proc1
// static void setup_lseek_pread_p83_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_p83_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p83_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p828_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p828_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p828_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p828_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p828_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p828_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p828_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p828_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p828_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p828_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p828_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p828_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p828_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p828_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p820_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p820_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p820_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p820_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_p820_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_p820_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p820_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p820_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p820_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p820_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p820_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p820_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p820_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p820_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_pf8_0_0
// static int test_lseek_pread_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
static int test_lseek_pread_p7_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_pread_p7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
static void setup_lseek_pread_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p7_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_0_1
// static void setup_lseek_pread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
static void setup_lseek_pread_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p68_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
static void setup_lseek_pread_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p68_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf4_0_1
// static void setup_lseek_pread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
static void setup_lseek_pread_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p60_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
static void setup_lseek_pread_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p60_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p60_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf0_0_1
// static void setup_lseek_pread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_p68_1_proc0
// static void setup_lseek_pread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pe_0_1
static void setup_lseek_pread_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_pread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p4_0_final(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal
// static void setup_lseek_pread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_pread_p4_0_common
// static void setup_lseek_pread_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p4_1_final(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal
// static void setup_lseek_pread_p4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p3_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p3_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_3_proc0
// static void setup_lseek_pread_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p3_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p3_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pf8_3_1
// static void setup_lseek_pread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pread_pf8_0_common
// static void setup_lseek_pread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_0_proc1
// static void setup_lseek_pread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pread_pf8_4_proc0
// static void setup_lseek_pread_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_final
// static void setup_lseek_pread_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pread_pf8_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p28_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_2_proc0
// static void setup_lseek_pread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p28_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p28_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd4_0_1
// static void setup_lseek_pread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_0_common
// static void setup_lseek_pread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p20_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pb40_0_proc1
// static void setup_lseek_pread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p20_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p20_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pd0_0_1
// static void setup_lseek_pread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pread_pbc0_0_common
// static void setup_lseek_pread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pread_pbd_3_proc0
// static void setup_lseek_pread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pread_pbd_0_final
// static void setup_lseek_pread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal

/*
 * calls: lseek pread
 */
// static int test_lseek_pread_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pread_p7_0_0
// static int test_lseek_pread_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_pread_pc_0_1
// static void setup_lseek_pread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_pread_p4_0_common
// static void setup_lseek_pread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pread_pbd_0_proc1
// static void setup_lseek_pread_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal
// static void setup_lseek_pread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pread_pbd_0_procfinal


/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_pf8_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_pwrite_pf8_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_lseek_pwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_pwrite_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_pwrite_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_pwrite_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
static void setup_lseek_pwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf8_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
static void setup_lseek_pwrite_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf8_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
static int test_lseek_pwrite_pf8_3_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
// static void setup_lseek_pwrite_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
static void setup_lseek_pwrite_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf8_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf8_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
static void setup_lseek_pwrite_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf8_5_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf8_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pf8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
static void setup_lseek_pwrite_pf8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
static int test_lseek_pwrite_pf4_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_lseek_pwrite_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pwrite_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf4_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
static void setup_lseek_pwrite_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pwrite_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf4_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf4_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf4_1_common
static void setup_lseek_pwrite_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf4_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf4_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf4_1_common
static void setup_lseek_pwrite_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
static void setup_lseek_pwrite_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
static void setup_lseek_pwrite_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_pwrite_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf4_1_proc0
// static void setup_lseek_pwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf0_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf0_1_common
static void setup_lseek_pwrite_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pf0_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pf0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
static void setup_lseek_pwrite_pf0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_pwrite_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf4_3_proc0
// static void setup_lseek_pwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pe_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
static int test_lseek_pwrite_pe_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_lseek_pwrite_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pe_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
// static void setup_lseek_pwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd8_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
static int test_lseek_pwrite_pd4_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_lseek_pwrite_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf4_0_common
// static void setup_lseek_pwrite_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
static void setup_lseek_pwrite_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf4_1_common
// static void setup_lseek_pwrite_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
static void setup_lseek_pwrite_pd4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd4_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd4_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf4_1_common
// static void setup_lseek_pwrite_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
static void setup_lseek_pwrite_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd4_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd4_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf4_0_common
// static void setup_lseek_pwrite_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf0_0_common
// static void setup_lseek_pwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
static void setup_lseek_pwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf0_1_common
// static void setup_lseek_pwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd0_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf0_1_common
// static void setup_lseek_pwrite_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_0_proc1
// static void setup_lseek_pwrite_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pd0_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pd0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf0_1_common
// static void setup_lseek_pwrite_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
static int test_lseek_pwrite_pc_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_lseek_pwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_pc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_pbe_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pwrite_pbe_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
static void setup_lseek_pwrite_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pwrite_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pbe_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pbe_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pbe_0_common
static void setup_lseek_pwrite_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pbd0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pbd0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
static void setup_lseek_pwrite_pbd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_pwrite_pbd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pwrite_pbd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_pwrite_pbd0_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_pwrite_pbd0_0_procfinal(void) {
  
}

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pbd0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pbd0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_pbd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
static void setup_lseek_pwrite_pbd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pbd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pbd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pbd0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pbd0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pbd0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pbd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
static void setup_lseek_pwrite_pbd0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pbd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pbd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pbd0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pbd0_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pbd0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pbd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
static void setup_lseek_pwrite_pbd0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pbd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pbd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pbd0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pbc0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pbc0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
static void setup_lseek_pwrite_pbc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pwrite_pbc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pbc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pbc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pbc0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pbc0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pbc0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_pbc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pbc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_pbc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pbc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pbc0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pbc0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pbc0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pbc0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
static void setup_lseek_pwrite_pbc0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pbc0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pbc0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pbc0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pbc0_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pbc0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pbc0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pbc0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pbc0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pbc0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pbc0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb8_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
static void setup_lseek_pwrite_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pwrite_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb6_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pbe_0_common
// static void setup_lseek_pwrite_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_0_proc1
// static void setup_lseek_pwrite_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb6_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pbe_0_common
// static void setup_lseek_pwrite_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_0_proc1
// static void setup_lseek_pwrite_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb50_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb50_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pb50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pb50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_2_proc0
// static void setup_lseek_pwrite_pb50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_proc0
// static void setup_lseek_pwrite_pb50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pb50_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb50_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb50_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pb50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
static void setup_lseek_pwrite_pb50_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pwrite_pb50_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pb50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pb50_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb50_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb50_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pb50_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pb50_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pb50_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_pb50_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pb50_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb50_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb50_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pb50_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pb50_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pb50_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pb50_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pb50_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb40_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb40_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pb40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
static void setup_lseek_pwrite_pb40_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pwrite_pb40_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pb40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pb40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb40_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
static int test_lseek_pwrite_pb40_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_lseek_pwrite_pb40_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pwrite_pb40_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pwrite_pb40_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pb40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pb40_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb40_2_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb40_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pb40_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pb40_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pb40_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_pb40_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pb40_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb40_3_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb40_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pb40_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pb40_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pb40_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pb40_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pb40_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pbe_0_0
// static int test_lseek_pwrite_pb0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
// static void setup_lseek_pwrite_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_proc0
// static void setup_lseek_pwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_pae_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_pwrite_pae_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
static void setup_lseek_pwrite_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_pwrite_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pae_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pae_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
static void setup_lseek_pwrite_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pae_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pae_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_pae_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
static void setup_lseek_pwrite_pae_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pae_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pae_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pae_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pae_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pae_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_pae_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
static void setup_lseek_pwrite_pae_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pae_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_pae_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pae_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pad0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pad0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_pad0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pad0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc0
// static void setup_lseek_pwrite_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pad0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pad0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pad0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
static int test_lseek_pwrite_pad0_1_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_lseek_pwrite_pad0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_1_common
// static void setup_lseek_pwrite_pad0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_pad0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pad0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pad0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pad0_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
static int test_lseek_pwrite_pad0_2_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_lseek_pwrite_pad0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pad0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_2_proc0
// static void setup_lseek_pwrite_pad0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pad0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pad0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pad0_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pad0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_pad0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pad0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_pad0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pad0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pad0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pad0_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pad0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pad0_2_1
// static void setup_lseek_pwrite_pad0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pad0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pad0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pad0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pad0_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pad0_5_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pad0_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pad0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pad0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_0_proc0
// static void setup_lseek_pwrite_pad0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pad0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pad0_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pad0_6_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pad0_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pad0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pad0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pad0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pad0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pad0_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pac0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pac0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_pac0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pac0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_proc0
// static void setup_lseek_pwrite_pac0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pac0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pac0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pac0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pac0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_pac0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pac0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_pac0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pac0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pac0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pac0_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pac0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pac0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pac0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_2_proc0
// static void setup_lseek_pwrite_pac0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pac0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pac0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pac0_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pac0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pac0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pac0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pac0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pac0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pac0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa8_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
// static void setup_lseek_pwrite_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
static void setup_lseek_pwrite_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
// static void setup_lseek_pwrite_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
// static void setup_lseek_pwrite_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa6_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa6_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
static void setup_lseek_pwrite_pa6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_pa6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pa6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa6_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa6_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pa6_0_proc0
// static void setup_lseek_pwrite_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pa6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pa6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa6_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa6_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pa6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_pa6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_pa6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_pa6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pa6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa6_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa6_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_pa6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_pa6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_pa6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_pa6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_pa6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa50_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa50_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pa50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pa50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_2_proc0
// static void setup_lseek_pwrite_pa50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_proc0
// static void setup_lseek_pwrite_pa50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa50_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_pa50_1_0(void) {
  int r = lseek(10, 9981952, SEEK_SET);
  expect_result("r", r, 9981952);
  return xerrno(r);
}
// static int test_lseek_pwrite_pa50_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pa50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pa50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_0_proc1
static void setup_lseek_pwrite_pa50_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9986048, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pa50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa50_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa50_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa50_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pad0_2_1
// static void setup_lseek_pwrite_pa50_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pa50_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_pa50_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa50_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa50_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa50_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa50_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pad0_2_1
// static void setup_lseek_pwrite_pa50_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pa50_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa50_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa50_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa50_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa50_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa50_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pa50_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pa50_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_0_proc1
// static void setup_lseek_pwrite_pa50_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa50_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa50_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa50_5_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa50_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pa50_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pa50_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa50_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_pa50_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa50_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa50_6_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa50_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pa50_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_pa50_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa50_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa50_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa50_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa40_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa40_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pa40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pa40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_0_proc0
// static void setup_lseek_pwrite_pa40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_0_proc1
// static void setup_lseek_pwrite_pa40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_pa40_1_0(void) {
  int r = lseek(10, 5062656, SEEK_SET);
  expect_result("r", r, 5062656);
  return xerrno(r);
}
// static int test_lseek_pwrite_pa40_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pa40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pa40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
static void setup_lseek_pwrite_pa40_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5066752, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pa40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa40_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa40_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa40_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pad0_2_1
// static void setup_lseek_pwrite_pa40_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
static void setup_lseek_pwrite_pa40_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pwrite_pa40_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_pa40_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa40_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa40_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa40_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pa40_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pa40_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa40_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_pa40_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa40_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa40_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa40_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pa40_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pa40_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_pa40_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa40_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa40_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa40_5_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa40_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_pa40_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_pa40_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa40_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa40_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa40_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
// static void setup_lseek_pwrite_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pa8_0_proc0
// static void setup_lseek_pwrite_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_pa0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pae_0_0
// static int test_lseek_pwrite_pa0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
// static void setup_lseek_pwrite_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p9f_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pwrite_p9f_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p9f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p9f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_2_proc0
// static void setup_lseek_pwrite_p9f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p9f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p9f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9f_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p9f_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p9f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p9f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_3_proc0
// static void setup_lseek_pwrite_p9f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p9f_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p9f_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9e8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
static int test_lseek_pwrite_p9e8_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_lseek_pwrite_p9e8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_pwrite_p9e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p9e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p9e8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p9e8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9e8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p9e8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p9e8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p9e8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p9e8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p9e8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p9e8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9e8_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p9e8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p9e8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p9e8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p9e8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p9e8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p9e8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9e0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p9e0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p9e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p9e0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p9e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p9e0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p9e0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9e0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p9e0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p9e0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p9e0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p9e0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p9e0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p9e0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p9c_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
// static void setup_lseek_pwrite_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
// static void setup_lseek_pwrite_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9b_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p9b_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p9b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p9b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_p9b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_p9b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p9b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9b_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p9b_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p9b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p9b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_p9b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_p9b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p9b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9a8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
static int test_lseek_pwrite_p9a8_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_lseek_pwrite_p9a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p9e8_0_common
// static void setup_lseek_pwrite_p9a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p9a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p9a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p9a8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9a8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p9a8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p9a8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p9a8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p9a8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p9a8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p9a8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p9a0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p9a0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p9a0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p9a0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p9a0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p9a0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p9a0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9f_0_0
// static int test_lseek_pwrite_p98_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
// static void setup_lseek_pwrite_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p97_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_pwrite_p97_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p97_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p97_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_2_proc0
// static void setup_lseek_pwrite_p97_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p97_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p97_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p97_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p97_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p97_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p97_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_3_proc0
// static void setup_lseek_pwrite_p97_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p97_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p97_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p968_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p968_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pad0_1_1
// static void setup_lseek_pwrite_p968_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_1_common
// static void setup_lseek_pwrite_p968_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p968_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p968_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p968_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p968_1_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 5062656);
  return xerrno(r);
}
// static int test_lseek_pwrite_p968_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p968_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
static void setup_lseek_pwrite_p968_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p968_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p968_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p968_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p968_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p968_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p968_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p968_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p968_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p968_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p968_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p968_3_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_pwrite_p968_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p968_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p968_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pa40_2_proc1
// static void setup_lseek_pwrite_p968_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p968_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p968_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p968_4_0(void) {
  int r = lseek(10, 4096, SEEK_CUR);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_pwrite_p968_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p968_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p968_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pa40_2_proc1
// static void setup_lseek_pwrite_p968_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p968_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p968_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p968_5_0(void) {
  int r = lseek(10, 4096, SEEK_CUR);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_pwrite_p968_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pad0_2_1
// static void setup_lseek_pwrite_p968_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p968_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p968_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p968_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p968_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p968_6_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p968_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p968_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p968_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p968_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p968_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p968_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p960_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p960_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p960_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p960_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p960_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p960_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p960_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p960_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p960_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p960_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p960_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p960_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p960_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p960_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p94_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p94_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
// static void setup_lseek_pwrite_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
// static void setup_lseek_pwrite_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p93_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p93_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p93_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p93_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_p93_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_p93_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p93_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p93_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p93_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p93_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p93_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_p93_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_p93_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p93_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p928_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
static int test_lseek_pwrite_p928_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_lseek_pwrite_p928_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_1_common
// static void setup_lseek_pwrite_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p928_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p928_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p928_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p928_1_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 155648);
  return xerrno(r);
}
// static int test_lseek_pwrite_p928_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p928_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
static void setup_lseek_pwrite_p928_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pwrite_p928_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p928_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p928_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p928_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p928_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p928_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p928_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p928_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p928_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p928_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p920_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p920_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p920_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p920_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p920_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p920_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p920_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p97_0_0
// static int test_lseek_pwrite_p90_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
// static void setup_lseek_pwrite_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p8f8_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pwrite_p8f8_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
static void setup_lseek_pwrite_p8f8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_pwrite_p8f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_0_proc0
// static void setup_lseek_pwrite_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p8f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p8f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f8_0_0
// static int test_lseek_pwrite_p8f8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p8f8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_p8f8_0_common
// static void setup_lseek_pwrite_p8f8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_1_proc0
// static void setup_lseek_pwrite_p8f8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p8f8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p8f8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p8f6_0_0(void) {
  int r = lseek(10, -12288, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pwrite_p8f6_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
static void setup_lseek_pwrite_p8f6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_pwrite_p8f6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8f6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
static void setup_lseek_pwrite_p8f6_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_lseek_pwrite_p8f6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f8_0_0
static int test_lseek_pwrite_p8f6_1_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_lseek_pwrite_p8f6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pwrite_p8f6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8f6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f6_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8f6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p8f6_2_0(void) {
  int r = lseek(10, -8192, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_pwrite_p8f6_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p8f6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
static void setup_lseek_pwrite_p8f6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8f6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8f6_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f6_3_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8f6_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p8f6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p8f6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p8f6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8f6_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f6_4_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8f6_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8f6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p8f6_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_2_proc0
// static void setup_lseek_pwrite_p8f6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f6_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8f6_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f6_5_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8f6_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8f6_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p8f6_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p8f6_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f6_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8f6_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f8_0_0
// static int test_lseek_pwrite_p8f0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
static void setup_lseek_pwrite_p8f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pwrite_p8f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f0_1_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8f0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p8f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
static void setup_lseek_pwrite_p8f0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8f0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f0_2_0(void) {
//   int r = lseek(10, -12288, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_0_0
// static int test_lseek_pwrite_p8f0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
static void setup_lseek_pwrite_p8f0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pwrite_p8f0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f0_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8f0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f0_3_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8f0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p8f0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p8f0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p8f0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8f0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f0_4_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8f0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8f0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p8f0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_2_proc0
// static void setup_lseek_pwrite_p8f0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8f0_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8f0_5_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8f0_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8f0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p8f0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p8f0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8f0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8f0_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8e_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f8_0_0
// static int test_lseek_pwrite_p8e_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
// static void setup_lseek_pwrite_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pa8_0_proc0
// static void setup_lseek_pwrite_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f8_0_0
// static int test_lseek_pwrite_p8d8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_p8f8_0_common
// static void setup_lseek_pwrite_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pa6_0_proc0
// static void setup_lseek_pwrite_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_p8d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p8d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f8_0_0
// static int test_lseek_pwrite_p8d8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p8d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_p8f8_0_common
// static void setup_lseek_pwrite_p8d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pa6_0_proc0
// static void setup_lseek_pwrite_p8d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_p8d8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p8d8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d6_0_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8d6_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pad0_2_1
// static void setup_lseek_pwrite_p8d6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f0_0_common
// static void setup_lseek_pwrite_p8d6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_2_proc0
static void setup_lseek_pwrite_p8d6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8d6_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8d6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d6_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f8_0_0
static int test_lseek_pwrite_p8d6_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_lseek_pwrite_p8d6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f6_1_common
static void setup_lseek_pwrite_p8d6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pwrite_p8d6_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8d6_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8d6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d6_2_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8d6_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8d6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p8d6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_2_proc0
// static void setup_lseek_pwrite_p8d6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_2_proc0
// static void setup_lseek_pwrite_p8d6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8d6_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d6_3_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8d6_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8d6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p8d6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_p8d6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p8d6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8d6_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d6_4_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8d6_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8d6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p8d6_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p8d6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_p8d6_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8d6_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d6_5_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8d6_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8d6_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p8d6_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p8d6_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p8d6_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8d6_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f8_0_0
// static int test_lseek_pwrite_p8d0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f0_0_common
static void setup_lseek_pwrite_p8d0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pwrite_p8d0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8d0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8d0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d0_1_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8d0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p8d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8d0_0_proc0
// static void setup_lseek_pwrite_p8d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8d0_0_proc0
// static void setup_lseek_pwrite_p8d0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8d0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d0_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f8_0_0
// static int test_lseek_pwrite_p8d0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9a8_0_1
// static void setup_lseek_pwrite_p8d0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f6_1_common
static void setup_lseek_pwrite_p8d0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_pwrite_p8d0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8d0_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8d0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8d0_3_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f6_2_0
// static int test_lseek_pwrite_p8d0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8d0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p8d0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p8d0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p8d0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8d0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8f8_0_0
// static int test_lseek_pwrite_p8c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pa8_0_proc0
// static void setup_lseek_pwrite_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p8b8_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_pwrite_p8b8_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p8b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_p8f8_0_common
// static void setup_lseek_pwrite_p8b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_0_proc0
// static void setup_lseek_pwrite_p8b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p8b8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p8b8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8b8_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_0_0
// static int test_lseek_pwrite_p8b8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p8b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_p8f8_0_common
// static void setup_lseek_pwrite_p8b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_1_proc0
// static void setup_lseek_pwrite_p8b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p8b8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p8b8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p8b8_2_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_pwrite_p8b8_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p8b8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p8b8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_2_proc0
// static void setup_lseek_pwrite_p8b8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p8b8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p8b8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8b8_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_2_0
// static int test_lseek_pwrite_p8b8_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p8b8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p8b8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_3_proc0
// static void setup_lseek_pwrite_p8b8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p8b8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p8b8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8b6_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_0_0
// static int test_lseek_pwrite_p8b6_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pad0_1_1
static void setup_lseek_pwrite_p8b6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_pwrite_p8b6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f0_0_proc0
// static void setup_lseek_pwrite_p8b6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8b6_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8b6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p8b6_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 32768);
  return xerrno(r);
}
// static int test_lseek_pwrite_p8b6_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9e8_0_1
static void setup_lseek_pwrite_p8b6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pwrite_p8b6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8b6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8b6_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8b6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p8b6_2_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 28672);
  return xerrno(r);
}
// static int test_lseek_pwrite_p8b6_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pad0_1_1
static void setup_lseek_pwrite_p8b6_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_pwrite_p8b6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f0_2_proc0
// static void setup_lseek_pwrite_p8b6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8b6_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8b6_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p8b6_3_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 16384);
  return xerrno(r);
}
static int test_lseek_pwrite_p8b6_3_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_lseek_pwrite_p8b6_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_pwrite_p8b6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8b6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8b6_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8b6_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8b0_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_0_0
// static int test_lseek_pwrite_p8b0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p8b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f0_0_common
static void setup_lseek_pwrite_p8b0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8b0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8b0_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_2_0
// static int test_lseek_pwrite_p8b0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p8b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f0_2_common
// static void setup_lseek_pwrite_p8b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f0_2_proc0
// static void setup_lseek_pwrite_p8b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8b0_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p8b0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p8b0_2_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_pwrite_p8b0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p8b0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p8b0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc0
// static void setup_lseek_pwrite_p8b0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8b0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8b0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8b0_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b0_2_0
// static int test_lseek_pwrite_p8b0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p8b0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p8b0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p8b0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8b0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8b0_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8b0_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b0_2_0
// static int test_lseek_pwrite_p8b0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8b0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p8b0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_2_proc0
// static void setup_lseek_pwrite_p8b0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8b0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8b0_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8b0_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b0_2_0
// static int test_lseek_pwrite_p8b0_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p8b0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p8b0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p8b0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8b0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8b0_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8a_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_0_0
// static int test_lseek_pwrite_p8a_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
// static void setup_lseek_pwrite_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pa8_0_proc0
// static void setup_lseek_pwrite_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p8a_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_2_0
// static int test_lseek_pwrite_p8a_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
// static void setup_lseek_pwrite_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
// static void setup_lseek_pwrite_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p898_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_0_0
// static int test_lseek_pwrite_p898_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p898_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_p8f8_0_common
// static void setup_lseek_pwrite_p898_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pa6_0_proc0
// static void setup_lseek_pwrite_p898_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_p898_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p898_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p898_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_0_0
// static int test_lseek_pwrite_p898_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p898_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_p8f8_0_common
// static void setup_lseek_pwrite_p898_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pa6_0_proc0
// static void setup_lseek_pwrite_p898_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_p898_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p898_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p898_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_2_0
// static int test_lseek_pwrite_p898_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p898_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p898_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_p898_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_p898_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p898_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p898_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_2_0
// static int test_lseek_pwrite_p898_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p898_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pae_0_common
// static void setup_lseek_pwrite_p898_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_p898_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_p898_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p898_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p896_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_0_0
// static int test_lseek_pwrite_p896_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p928_0_1
// static void setup_lseek_pwrite_p896_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8b6_0_common
// static void setup_lseek_pwrite_p896_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8d0_0_proc0
// static void setup_lseek_pwrite_p896_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8d0_0_proc1
// static void setup_lseek_pwrite_p896_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p896_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p896_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 28672);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b6_2_0
// static int test_lseek_pwrite_p896_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p9a8_0_1
static void setup_lseek_pwrite_p896_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_pwrite_p896_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
static void setup_lseek_pwrite_p896_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p896_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p896_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p896_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_0_0
// static int test_lseek_pwrite_p896_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8d6_1_1
// static void setup_lseek_pwrite_p896_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f6_1_common
// static void setup_lseek_pwrite_p896_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8d6_1_proc0
// static void setup_lseek_pwrite_p896_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8d6_1_proc1
// static void setup_lseek_pwrite_p896_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p896_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p896_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 28672);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b6_2_0
static int test_lseek_pwrite_p896_3_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 16384);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_lseek_pwrite_p896_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_pwrite_p896_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
static void setup_lseek_pwrite_p896_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p896_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p896_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p890_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_0_0
// static int test_lseek_pwrite_p890_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f0_0_common
// static void setup_lseek_pwrite_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_2_proc0
static void setup_lseek_pwrite_p890_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p890_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p890_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p890_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_2_0
// static int test_lseek_pwrite_p890_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8f0_2_common
// static void setup_lseek_pwrite_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p890_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p896_1_proc1
// static void setup_lseek_pwrite_p890_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_pwrite_p8f6_0_final
// static void setup_lseek_pwrite_p890_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p890_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b0_2_0
// static int test_lseek_pwrite_p890_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p890_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p890_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_2_proc0
// static void setup_lseek_pwrite_p890_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_proc0
// static void setup_lseek_pwrite_p890_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p890_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p890_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b0_2_0
// static int test_lseek_pwrite_p890_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p890_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p890_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p890_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_p890_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p890_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p890_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b0_2_0
// static int test_lseek_pwrite_p890_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p890_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p890_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_p890_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p890_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p890_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p890_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b0_2_0
// static int test_lseek_pwrite_p890_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p890_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p890_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p890_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p890_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p890_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_0_0
// static int test_lseek_pwrite_p88_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pa8_0_proc0
// static void setup_lseek_pwrite_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p88_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p8b8_2_0
// static int test_lseek_pwrite_p88_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_common
// static void setup_lseek_pwrite_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p88_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p87_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p87_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p87_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_p87_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_2_proc0
// static void setup_lseek_pwrite_p87_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p87_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p87_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p87_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p87_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p87_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_p87_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pae_3_proc0
// static void setup_lseek_pwrite_p87_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p87_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p87_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p868_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p868_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p868_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p868_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc0
// static void setup_lseek_pwrite_p868_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p868_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p868_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p868_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p868_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p868_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
static void setup_lseek_pwrite_p868_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p868_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p868_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p868_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p868_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p868_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p868_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p868_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_2_proc0
// static void setup_lseek_pwrite_p868_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p868_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p868_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p868_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p868_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p868_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p868_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p868_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p868_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p868_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p868_4_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p868_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p868_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p868_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p868_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p868_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p868_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p860_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p860_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p860_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p860_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_proc0
// static void setup_lseek_pwrite_p860_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p860_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p860_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p860_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p860_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p860_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p860_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p8d0_0_proc0
// static void setup_lseek_pwrite_p860_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p860_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p860_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p860_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p860_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p860_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p860_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_1_proc0
// static void setup_lseek_pwrite_p860_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p860_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p860_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p860_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p860_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p860_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p860_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p860_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p860_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p860_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p84_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
// static void setup_lseek_pwrite_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p83_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p83_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p83_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_p83_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_p83_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_p83_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p83_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p83_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p83_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p83_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_p83_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pd4_1_proc1
// static void setup_lseek_pwrite_p83_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_p83_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p83_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p828_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p828_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p828_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p828_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_2_proc0
// static void setup_lseek_pwrite_p828_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_proc0
// static void setup_lseek_pwrite_p828_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p828_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p828_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p828_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pad0_2_1
// static void setup_lseek_pwrite_p828_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p828_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pa40_2_proc1
// static void setup_lseek_pwrite_p828_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p828_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p828_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p828_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p828_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p828_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p828_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_p828_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p828_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p828_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p828_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p828_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p828_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p828_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p828_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p828_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p828_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p820_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p820_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p820_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p820_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_0_proc0
// static void setup_lseek_pwrite_p820_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_0_proc1
// static void setup_lseek_pwrite_p820_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p820_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p820_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p820_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p820_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p820_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p820_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_p820_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p820_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p820_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p820_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p820_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p820_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb50_1_proc1
// static void setup_lseek_pwrite_p820_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p820_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p820_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p820_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p820_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p820_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p820_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p820_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p820_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p820_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_0
// static int test_lseek_pwrite_p80_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
static int test_lseek_pwrite_p7_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_pwrite_p7_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
static void setup_lseek_pwrite_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p7_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p7_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_0_1
// static void setup_lseek_pwrite_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
static void setup_lseek_pwrite_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_pwrite_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p68_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p68_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
static void setup_lseek_pwrite_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p68_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p68_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
static void setup_lseek_pwrite_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p68_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p60_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p60_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
static void setup_lseek_pwrite_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_pwrite_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p60_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p60_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p60_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf4_0_1
// static void setup_lseek_pwrite_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_p68_1_proc0
// static void setup_lseek_pwrite_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p60_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p4_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pe_0_1
static void setup_lseek_pwrite_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_pwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p4_0_final(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal
// static void setup_lseek_pwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_p4_0_common
// static void setup_lseek_pwrite_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p4_1_final(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal
// static void setup_lseek_pwrite_p4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p3_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p3_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_3_proc0
// static void setup_lseek_pwrite_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p3_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p3_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pf8_3_1
// static void setup_lseek_pwrite_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_pwrite_pf8_0_common
// static void setup_lseek_pwrite_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_0_proc1
// static void setup_lseek_pwrite_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_pwrite_pf8_5_proc0
// static void setup_lseek_pwrite_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_final
// static void setup_lseek_pwrite_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_pwrite_pf8_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p28_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p28_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb8_0_proc0
// static void setup_lseek_pwrite_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p28_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p28_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p28_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_0_common
// static void setup_lseek_pwrite_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p28_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p20_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p20_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pb40_0_proc1
// static void setup_lseek_pwrite_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p20_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p20_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p20_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pd4_0_1
// static void setup_lseek_pwrite_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbc0_0_common
// static void setup_lseek_pwrite_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_pwrite_pbd0_3_proc0
// static void setup_lseek_pwrite_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_pwrite_pbd0_0_final
// static void setup_lseek_pwrite_p20_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal

/*
 * calls: lseek pwrite
 */
// static int test_lseek_pwrite_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_p7_0_0
// static int test_lseek_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_pwrite_pc_0_1
// static void setup_lseek_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_p4_0_common
// static void setup_lseek_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_pwrite_pbd0_0_proc1
// static void setup_lseek_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal
// static void setup_lseek_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_pwrite_pbd0_0_procfinal


/*
 * calls: lseek read
 */
static int test_lseek_read_pfc_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_read_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_lseek_read_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_read_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_read_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_read_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek read
 */
// static int test_lseek_read_pfc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pfc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
static void setup_lseek_read_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pfc_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
static int test_lseek_read_pfc_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_read_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
static void setup_lseek_read_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pfb_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
static int test_lseek_read_pfb_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_lseek_read_pfb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_pfb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pfb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pfb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pfb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pfb_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pfb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
// static void setup_lseek_read_pfb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_pfb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pfb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pfb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pfb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pfb_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
static int test_lseek_read_pfb_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_read_pfb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_pfb_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pfb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pfb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pfb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pfa_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
static int test_lseek_read_pfa_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_lseek_read_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_read_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_read_pfa_0_final(void) {
  unlink("__i0");
  close(22);
  close(23);
  close(20);
  close(21);
}
static void setup_lseek_read_pfa_0_procfinal(void) {
  close(22);
  close(23);
  close(20);
  close(21);
}

/*
 * calls: lseek read
 */
// static int test_lseek_read_pfa_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pfa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
static void setup_lseek_read_pfa_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_read_pfa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_0_proc0
// static void setup_lseek_read_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pfa_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pfa_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pfa_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
static int test_lseek_read_pfa_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_read_pfa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
// static void setup_lseek_read_pfa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pfa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pfa_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pfa_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pfa_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pfa_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
static void setup_lseek_read_pfa_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_pfa_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_read_pfa_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_read_pfa_3_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_lseek_read_pfa_3_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: lseek read
 */
// static int test_lseek_read_pf8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
static int test_lseek_read_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_lseek_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_read_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_0_proc0
// static void setup_lseek_read_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pf8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_1_proc0
// static void setup_lseek_read_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pf8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
static int test_lseek_read_pf8_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_lseek_read_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pf4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pf4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
static void setup_lseek_read_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pf4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
static void setup_lseek_read_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pf0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
static void setup_lseek_read_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pf0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
static void setup_lseek_read_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pe_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
// static void setup_lseek_read_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
// static void setup_lseek_read_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pdc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
// static void setup_lseek_read_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pdc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pdc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
// static void setup_lseek_read_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pdb_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pdb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_pdb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_pdb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pdb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pdb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pdb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pdb_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pdb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_pdb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_pdb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pdb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pdb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pdb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pda_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pda_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
static void setup_lseek_read_pda_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_pda_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_read_pda_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pda_0_final(void) {
//   unlink("__i0");
//   close(22);
//   close(23);
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfa_0_final
// static void setup_lseek_read_pda_0_procfinal(void) {
//   close(22);
//   close(23);
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfa_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pda_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pda_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_3_common
static void setup_lseek_read_pda_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_read_pda_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pda_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_lseek_read_pfa_3_final
// static void setup_lseek_read_pda_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_lseek_read_pfa_3_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pda_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pda_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pda_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
static void setup_lseek_read_pda_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_read_pda_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pda_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pda_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pd8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pd8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pd4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf4_0_common
// static void setup_lseek_read_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
static void setup_lseek_read_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pd4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf4_0_common
// static void setup_lseek_read_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd4_0_proc1
// static void setup_lseek_read_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pd0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf0_0_common
// static void setup_lseek_read_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
static void setup_lseek_read_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pd0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf0_0_common
// static void setup_lseek_read_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd0_0_proc1
// static void setup_lseek_read_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
// static void setup_lseek_read_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
// static void setup_lseek_read_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_pbf_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_read_pbf_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_pbf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_pbf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pbf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pbf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pbf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pbec_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pbec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
// static void setup_lseek_read_pbec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_pbec_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pbec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pbec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pbec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pbe8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pbe8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_pbe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
static void setup_lseek_read_pbe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_read_pbe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pbe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pbe8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pbe0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pbe0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_pbe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_pbe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbec_0_proc0
// static void setup_lseek_read_pbe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pbe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pbe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pbd_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pbd_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
static void setup_lseek_read_pbd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_read_pbd_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_read_pbd_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_read_pbd_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_read_pbd_0_procfinal(void) {
  
}

/*
 * calls: lseek read
 */
// static int test_lseek_read_pbd_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pbd_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pbd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
static void setup_lseek_read_pbd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pbd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pbd_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pbd_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pbc0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pbc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
static void setup_lseek_read_pbc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_read_pbc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pbc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pbc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pbc0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pbc0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pbc0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_pbc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
static void setup_lseek_read_pbc0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pbc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pbc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pbc0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
static void setup_lseek_read_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_read_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pb7_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pb7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_pb7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_pb7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pb7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pb7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pb7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pb6c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pb6c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_pb6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_pb6c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pb6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pb6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pb6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pb68_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pb68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pb68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
static void setup_lseek_read_pb68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pb68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_pb68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pb68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pb60_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pb60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_pb60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_pb60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_pb60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pb60_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pb60_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pb5_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pb5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pb5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
static void setup_lseek_read_pb5_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_read_pb5_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pb5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pb5_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pb40_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pb40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_pb40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_pb40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_pb40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_pb40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pb40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pbf_0_0
// static int test_lseek_read_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_proc0
// static void setup_lseek_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_paf_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_read_paf_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
static void setup_lseek_read_paf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_paf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_paf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_paf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_paf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_paf_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_paf_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_paf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_paf_0_common
static void setup_lseek_read_paf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_paf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_paf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_paf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_paec_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_paec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
// static void setup_lseek_read_paec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_paec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbec_0_proc0
// static void setup_lseek_read_paec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_paec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_paec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_paec_1_0(void) {
  int r = lseek(10, 31617024, SEEK_SET);
  expect_result("r", r, 31617024);
  return xerrno(r);
}
// static int test_lseek_read_paec_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
// static void setup_lseek_read_paec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_paec_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_paec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_paec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_paec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pae8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pae8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_pae8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_pae8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pae8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_pae8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pae8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pae8_1_0(void) {
//   int r = lseek(10, 31617024, SEEK_SET);
//   expect_result("r", r, 31617024);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paec_1_0
// static int test_lseek_read_pae8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_pae8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
static void setup_lseek_read_pae8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pae8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_pae8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pae8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pae0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pae0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_pae0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_pae0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbec_0_proc0
// static void setup_lseek_read_pae0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pae0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pae0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pae0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pae0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_pae0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
static void setup_lseek_read_pae0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pae0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_pae0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pae0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_pad8_0_0(void) {
  int r = lseek(10, 5066752, SEEK_SET);
  expect_result("r", r, 5066752);
  return xerrno(r);
}
// static int test_lseek_read_pad8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_pad8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
static void setup_lseek_read_pad8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pad8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pad8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pad8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pad8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pad8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pad8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
static void setup_lseek_read_pad8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pad8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pad8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pad8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pad8_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pad8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_pad8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
static void setup_lseek_read_pad8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pad8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pad8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pad8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pad8_3_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pad8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_pad8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_pad8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_proc0
// static void setup_lseek_read_pad8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pad8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pad8_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pad8_4_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pad8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pad8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_pad8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_pad8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pad8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pad8_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pac4_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pac4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
static void setup_lseek_read_pac4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_read_pac4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pac4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pac4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pac4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_pac4_1_0(void) {
  int r = lseek(10, 7356416, SEEK_SET);
  expect_result("r", r, 7356416);
  return xerrno(r);
}
// static int test_lseek_read_pac4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
static void setup_lseek_read_pac4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_read_pac4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pac4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pac4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pac4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_pac4_2_0(void) {
  int r = lseek(10, 4096, SEEK_SET);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_read_pac4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_pac4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
static void setup_lseek_read_pac4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pac4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pac4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pac4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
static void setup_lseek_read_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa7_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_pa7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_paf_0_common
// static void setup_lseek_read_pa7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_pa7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pa7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pa7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa7_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_pa7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_paf_0_common
// static void setup_lseek_read_pa7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd0_0_proc1
// static void setup_lseek_read_pa7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_pa7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pa7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa6c_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa6c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_pa6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_pa6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_pa6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pa6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pa6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa6c_1_0(void) {
//   int r = lseek(10, 31617024, SEEK_SET);
//   expect_result("r", r, 31617024);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paec_1_0
// static int test_lseek_read_pa6c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_pa6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_pa6c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pa6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pa6c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pa6c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa68_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pa68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
// static void setup_lseek_read_pa68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb68_0_proc0
// static void setup_lseek_read_pa68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_pa68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pa68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa68_1_0(void) {
//   int r = lseek(10, 31617024, SEEK_SET);
//   expect_result("r", r, 31617024);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paec_1_0
// static int test_lseek_read_pa68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pa68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
static void setup_lseek_read_pa68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_pa68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_pa68_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pa68_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa60_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_pa60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_pa60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_pa60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pa60_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pa60_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa60_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa60_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_pa60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_pa60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd0_0_proc1
// static void setup_lseek_read_pa60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_pa60_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_pa60_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa5_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pa5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_pa5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_pa5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_pa5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pa5_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa5_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pa5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_pa5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_pa5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_pa5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pa5_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa5_2_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa5_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_pa5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_pa5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_pa5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_pa5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pa5_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa40_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_pa40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_pa40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_pa40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_pa40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pa40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pa8_0_proc0
// static void setup_lseek_read_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_pa0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_paf_0_0
// static int test_lseek_read_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p9f8_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_read_p9f8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p9f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_paf_0_common
// static void setup_lseek_read_p9f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_paf_1_proc0
// static void setup_lseek_read_p9f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p9f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p9f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p9f6_0_0(void) {
  int r = lseek(10, -31621120, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_read_p9f6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
static void setup_lseek_read_p9f6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_read_p9f6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_paec_1_proc0
// static void setup_lseek_read_p9f6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p9f6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p9f6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9f4_0_0(void) {
//   int r = lseek(10, -31621120, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f6_0_0
// static int test_lseek_read_p9f4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p9f4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
// static void setup_lseek_read_p9f4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pae8_1_proc0
// static void setup_lseek_read_p9f4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_p9f4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p9f4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9f0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p9f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_p9f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pae0_1_proc0
// static void setup_lseek_read_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p9f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p9f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9e8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9e8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p9e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p9e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pad8_2_proc0
// static void setup_lseek_read_p9e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p9e8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9e8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9e8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9e8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p9e8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p9e8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_proc0
// static void setup_lseek_read_p9e8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p9e8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9e8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9e8_2_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9e8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p9e8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p9e8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p9e8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p9e8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9e8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p9e4_0_0(void) {
  int r = lseek(10, -8192, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_read_p9e4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p9e4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
static void setup_lseek_read_p9e4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p9e4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p9e4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9e4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9e4_1_0(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9e4_0_0
// static int test_lseek_read_p9e4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p9e4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p9e4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_proc0
// static void setup_lseek_read_p9e4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p9e4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9e4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9e4_2_0(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9e4_0_0
// static int test_lseek_read_p9e4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p9e4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p9e4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p9e4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p9e4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9e4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9b8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p9b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_paf_0_common
// static void setup_lseek_read_p9b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd0_0_proc1
// static void setup_lseek_read_p9b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_p9b8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p9b8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9b6_0_0(void) {
//   int r = lseek(10, -31621120, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f6_0_0
// static int test_lseek_read_p9b6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_p9b6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p9f6_0_common
// static void setup_lseek_read_p9b6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pa6c_1_proc0
// static void setup_lseek_read_p9b6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p9b6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p9b6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9b4_0_0(void) {
//   int r = lseek(10, -31621120, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f6_0_0
// static int test_lseek_read_p9b4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p9b4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
// static void setup_lseek_read_p9b4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pa68_1_proc0
// static void setup_lseek_read_p9b4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_p9b4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p9b4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9b0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9b0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p9b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_p9b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd0_0_proc1
// static void setup_lseek_read_p9b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p9b0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p9b0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9a8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9a8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p9a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p9a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p9a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_1_proc0
// static void setup_lseek_read_p9a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9a8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9a8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9a8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p9a8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p9a8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p9a8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p9a8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9a8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9a0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9a0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p9a0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pac4_1_common
// static void setup_lseek_read_p9a0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
static void setup_lseek_read_p9a0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p9a0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9a0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p9a0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p9a0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p9a0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p9a0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p9a0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p9a0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p9a0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p9f8_0_0
// static int test_lseek_read_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p978_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_read_p978_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p978_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_paf_0_common
// static void setup_lseek_read_p978_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_paf_1_proc0
// static void setup_lseek_read_p978_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p978_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p978_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p976_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 155648);
  return xerrno(r);
}
// static int test_lseek_read_p976_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
// static void setup_lseek_read_p976_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_p976_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p976_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p976_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p976_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p976_1_0(void) {
  int r = lseek(10, 9981952, SEEK_CUR);
  expect_result("r", r, 19963904);
  return xerrno(r);
}
// static int test_lseek_read_p976_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
static void setup_lseek_read_p976_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_read_p976_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p976_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p976_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p976_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p974_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p976_0_0
// static int test_lseek_read_p974_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p974_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
static void setup_lseek_read_p974_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p974_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_p974_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p974_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p974_1_0(void) {
  int r = lseek(10, 31617024, SEEK_CUR);
  expect_result("r", r, 63234048);
  return xerrno(r);
}
// static int test_lseek_read_p974_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p974_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
// static void setup_lseek_read_p974_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pae8_1_proc0
// static void setup_lseek_read_p974_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_p974_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p974_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p970_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p970_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p970_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_p970_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pae0_1_proc0
// static void setup_lseek_read_p970_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p970_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p970_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p96c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p96c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p96c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p96c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p96c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p96c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p96c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p962_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p962_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p962_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pac4_0_common
static void setup_lseek_read_p962_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p962_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p962_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p962_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p962_1_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 31617024);
  return xerrno(r);
}
// static int test_lseek_read_p962_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p962_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
static void setup_lseek_read_p962_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p962_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p962_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p962_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p962_2_0(void) {
  int r = lseek(10, 8192, SEEK_CUR);
  expect_result("r", r, 16384);
  return xerrno(r);
}
// static int test_lseek_read_p962_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
static void setup_lseek_read_p962_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_read_p962_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p962_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p962_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p962_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p94_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p94_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p938_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p938_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p938_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_paf_0_common
// static void setup_lseek_read_p938_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd0_0_proc1
// static void setup_lseek_read_p938_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_p938_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p938_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p936_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p976_0_0
// static int test_lseek_read_p936_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_p936_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_p936_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd4_0_proc1
// static void setup_lseek_read_p936_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p936_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p936_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p936_1_0(void) {
//   int r = lseek(10, 9981952, SEEK_CUR);
//   expect_result("r", r, 19963904);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p976_1_0
// static int test_lseek_read_p936_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_p936_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p976_1_common
static void setup_lseek_read_p936_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p936_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p936_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p936_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p934_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p976_0_0
// static int test_lseek_read_p934_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p934_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
static void setup_lseek_read_p934_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p934_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_p934_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p934_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p934_1_0(void) {
//   int r = lseek(10, 31617024, SEEK_CUR);
//   expect_result("r", r, 63234048);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p974_1_0
// static int test_lseek_read_p934_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p934_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
// static void setup_lseek_read_p934_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pa68_1_proc0
// static void setup_lseek_read_p934_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_p934_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p934_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p930_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p930_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p930_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_p930_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd0_0_proc1
// static void setup_lseek_read_p930_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p930_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p930_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p928_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p928_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p928_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p928_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_p928_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p928_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p928_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p976_0_0
// static int test_lseek_read_p928_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p928_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p928_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_p928_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p928_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p928_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p928_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p928_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p928_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p928_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p928_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p928_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p928_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p920_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p920_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
static void setup_lseek_read_p920_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_read_p920_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
static void setup_lseek_read_p920_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p920_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p920_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p920_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p976_0_0
// static int test_lseek_read_p920_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p920_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p920_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_p920_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p920_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p920_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p920_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p920_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p920_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p920_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p920_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p920_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p920_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p978_0_0
// static int test_lseek_read_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p8fc_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_read_p8fc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
static void setup_lseek_read_p8fc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_read_p8fc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_paf_0_proc0
// static void setup_lseek_read_p8fc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p8fc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8fc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p8fb_0_0(void) {
  int r = lseek(10, -28672, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_read_p8fb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
static void setup_lseek_read_p8fb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_read_p8fb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbec_0_proc0
// static void setup_lseek_read_p8fb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p8fb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8fb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8fa_0_0(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fb_0_0
// static int test_lseek_read_p8fa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p8fa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8fb_0_common
// static void setup_lseek_read_p8fa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc0
// static void setup_lseek_read_p8fa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_p8fa_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8fa_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8f8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8f8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
static void setup_lseek_read_p8f8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_read_p8f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbec_0_proc0
// static void setup_lseek_read_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p8f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8f4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8f4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
static void setup_lseek_read_p8f4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_read_p8f4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p8f4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
static void setup_lseek_read_p8f4_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_lseek_read_p8f4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8f4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8f4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p8f4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
static void setup_lseek_read_p8f4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p8f4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8f4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8f4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8f4_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8f4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p8f4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
static void setup_lseek_read_p8f4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p8f4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8f4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8f4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8f0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
static void setup_lseek_read_p8f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_read_p8f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8f0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p8f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p8f0_1_0(void) {
  int r = lseek(10, -8192, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_read_p8f0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p8f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p8f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_proc0
// static void setup_lseek_read_p8f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8f0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8f0_2_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8f0_1_0
// static int test_lseek_read_p8f0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p8f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p8f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p8f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8f0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8f0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8e_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pa8_0_proc0
// static void setup_lseek_read_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8dc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8dc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p8dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8fc_0_common
// static void setup_lseek_read_p8dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_p8dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_p8dc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8dc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8db_0_0(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fb_0_0
// static int test_lseek_read_p8db_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_p8db_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8fb_0_common
// static void setup_lseek_read_p8db_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_p8db_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p8db_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8db_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8da_0_0(void) {
//   int r = lseek(10, -28672, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fb_0_0
// static int test_lseek_read_p8da_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p8da_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8fb_0_common
// static void setup_lseek_read_p8da_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb68_0_proc0
// static void setup_lseek_read_p8da_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_p8da_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8da_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8d8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8f8_0_common
// static void setup_lseek_read_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p8d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8d4_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8d4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p8d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_p8f4_0_common
// static void setup_lseek_read_p8d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_1_proc0
static void setup_lseek_read_p8d4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p8d4_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p8d4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8d4_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8d4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p8d4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p8d4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_1_proc0
// static void setup_lseek_read_p8d4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_1_proc0
// static void setup_lseek_read_p8d4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8d4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8d0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_p8f0_0_common
// static void setup_lseek_read_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_p9a0_0_proc1
static void setup_lseek_read_p8d0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p8d0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p8d0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8d0_1_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8f0_1_0
// static int test_lseek_read_p8d0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p8d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p8d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p8d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p8d0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8d0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8fc_0_0
// static int test_lseek_read_p8c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pa8_0_proc0
// static void setup_lseek_read_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p8bc_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_read_p8bc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p8bc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8fc_0_common
// static void setup_lseek_read_p8bc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_paf_0_proc0
// static void setup_lseek_read_p8bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p8bc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8bc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p8bc_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_read_p8bc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p8bc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_paf_0_common
// static void setup_lseek_read_p8bc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_paf_1_proc0
// static void setup_lseek_read_p8bc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p8bc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8bc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8bb_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p8bb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
// static void setup_lseek_read_p8bb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_p8bb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbec_0_proc0
// static void setup_lseek_read_p8bb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p8bb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8bb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p8bb_1_0(void) {
  int r = lseek(10, 5062656, SEEK_END);
  expect_result("r", r, 5087232);
  return xerrno(r);
}
// static int test_lseek_read_p8bb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
// static void setup_lseek_read_p8bb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8fb_0_common
static void setup_lseek_read_p8bb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p8bb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p8bb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8bb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8ba_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p8ba_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p8ba_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_p8ba_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc0
// static void setup_lseek_read_p8ba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_p8ba_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8ba_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8ba_1_0(void) {
//   int r = lseek(10, 5062656, SEEK_END);
//   expect_result("r", r, 5087232);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bb_1_0
// static int test_lseek_read_p8ba_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p8ba_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8fb_0_common
static void setup_lseek_read_p8ba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p8ba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_p8ba_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8ba_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b8_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p8b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p8b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8f8_0_common
// static void setup_lseek_read_p8b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbec_0_proc0
// static void setup_lseek_read_p8b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p8b8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8b8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b8_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p8b8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p8b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_p8b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pae0_1_proc0
// static void setup_lseek_read_p8b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p8b8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p8b8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p8b6_0_0(void) {
  int r = lseek(10, 5070848, SEEK_END);
  expect_result("r", r, 5099520);
  return xerrno(r);
}
// static int test_lseek_read_p8b6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
static void setup_lseek_read_p8b6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_read_p8b6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5095424, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5095424, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p8b6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b6_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p8b6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b6_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p8b6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
static void setup_lseek_read_p8b6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_read_p8b6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p8b6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b6_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p8b6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b6_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p8b6_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p8b6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p8b6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_p8f4_1_proc0
// static void setup_lseek_read_p8b6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8b6_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b6_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p8b6_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p8b6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p8b6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pad8_2_proc0
// static void setup_lseek_read_p8b6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8b6_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b6_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p8b6_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p8b6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_p8b6_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pa8_0_proc0
// static void setup_lseek_read_p8b6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b6_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8b6_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b6_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p8b6_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p8b6_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p8b6_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_proc0
// static void setup_lseek_read_p8b6_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b6_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8b6_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b6_6_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p8b6_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p8b6_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p8b6_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p8b6_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b6_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8b6_6_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b10_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p8b10_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
static void setup_lseek_read_p8b10_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_read_p8b10_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p8b10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b10_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p8b10_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b10_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p8b10_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p8b10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_p8f0_0_common
static void setup_lseek_read_p8b10_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p8b10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b10_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p8b10_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8b10_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p8b10_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p8b10_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_p8b10_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pac4_2_proc0
// static void setup_lseek_read_p8b10_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b10_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8b10_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p8b10_3_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 24576);
  return xerrno(r);
}
// static int test_lseek_read_p8b10_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p8b10_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pac4_0_common
// static void setup_lseek_read_p8b10_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_p962_0_proc0
// static void setup_lseek_read_p8b10_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b10_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8b10_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p8b10_4_0(void) {
  int r = lseek(10, 20480, SEEK_END);
  expect_result("r", r, 45056);
  return xerrno(r);
}
// static int test_lseek_read_p8b10_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p8b10_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pac4_0_common
// static void setup_lseek_read_p8b10_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pac4_0_proc0
// static void setup_lseek_read_p8b10_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8b10_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8b10_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8a_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p8a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pa8_0_proc0
// static void setup_lseek_read_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p8a_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p8a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p89c_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p89c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p89c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8fc_0_common
// static void setup_lseek_read_p89c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_p89c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_p89c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p89c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p89c_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p89c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p89c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_paf_0_common
// static void setup_lseek_read_p89c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd0_0_proc1
// static void setup_lseek_read_p89c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_p89c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p89c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p89b_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p89b_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_p89b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_p89b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_p89b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p89b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p89b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p89b_1_0(void) {
//   int r = lseek(10, 5062656, SEEK_END);
//   expect_result("r", r, 5087232);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bb_1_0
// static int test_lseek_read_p89b_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_p89b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8fb_0_common
static void setup_lseek_read_p89b_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p89b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p89b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p89b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p89a_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p89a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p89a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_p89a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb68_0_proc0
// static void setup_lseek_read_p89a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_p89a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p89a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p89a_1_0(void) {
//   int r = lseek(10, 5062656, SEEK_END);
//   expect_result("r", r, 5087232);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bb_1_0
// static int test_lseek_read_p89a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p89a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8fb_0_common
static void setup_lseek_read_p89a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p89a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_p89a_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p89a_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p898_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p898_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p898_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_p8f8_0_common
// static void setup_lseek_read_p898_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_p898_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p898_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p898_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p898_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p898_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p898_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_p898_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd0_0_proc1
// static void setup_lseek_read_p898_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p898_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p898_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p894_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p894_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p894_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_p8f4_0_common
// static void setup_lseek_read_p894_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
static void setup_lseek_read_p894_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p894_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p894_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p894_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 28672);
  return xerrno(r);
}
// static int test_lseek_read_p894_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p894_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_p8b6_0_common
// static void setup_lseek_read_p894_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
static void setup_lseek_read_p894_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5095424, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p894_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p894_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p894_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p894_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p894_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p894_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_1_proc0
// static void setup_lseek_read_p894_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_1_proc0
// static void setup_lseek_read_p894_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p894_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p894_3_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p894_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p894_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p894_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p894_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_p894_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p894_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p894_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p894_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p894_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p894_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p894_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p894_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p894_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p890_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p890_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
static void setup_lseek_read_p890_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_read_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_p920_0_proc1
static void setup_lseek_read_p890_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p890_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p890_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p890_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 28672);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p894_1_0
// static int test_lseek_read_p890_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
static void setup_lseek_read_p890_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_read_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
static void setup_lseek_read_p890_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p890_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_read_p8f4_0_final
// static void setup_lseek_read_p890_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p890_2_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_read_p890_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p890_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p890_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p890_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p890_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p890_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_0_0
// static int test_lseek_read_p88_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pa8_0_proc0
// static void setup_lseek_read_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p88_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p8bc_1_0
// static int test_lseek_read_p88_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pb8_0_common
// static void setup_lseek_read_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p88_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p878_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p878_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p878_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
// static void setup_lseek_read_p878_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_paf_1_proc0
// static void setup_lseek_read_p878_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p878_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p878_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p876_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p876_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
// static void setup_lseek_read_p876_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_p876_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbec_0_proc0
// static void setup_lseek_read_p876_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p876_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p876_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p874_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p874_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p874_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
// static void setup_lseek_read_p874_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc0
// static void setup_lseek_read_p874_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_p874_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p874_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p870_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p870_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p870_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_p870_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbec_0_proc0
// static void setup_lseek_read_p870_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p870_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p870_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p868_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p868_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p868_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p868_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_proc0
// static void setup_lseek_read_p868_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p868_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p868_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p868_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p868_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p868_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p868_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_p868_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p868_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p868_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p860_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p860_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p860_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p860_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_proc0
// static void setup_lseek_read_p860_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p860_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p860_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p860_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p860_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p860_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p860_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p860_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p860_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p860_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p84_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p838_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p838_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p838_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
// static void setup_lseek_read_p838_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pd0_0_proc1
// static void setup_lseek_read_p838_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_p838_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p838_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p836_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p836_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_p836_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_p836_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_p836_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p836_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p836_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p834_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p834_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p834_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
// static void setup_lseek_read_p834_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb68_0_proc0
// static void setup_lseek_read_p834_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_p834_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p834_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p830_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p830_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p830_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_p830_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pb6c_0_proc0
// static void setup_lseek_read_p830_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p830_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p830_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p828_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p828_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p828_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p828_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_p828_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_p828_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p828_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p820_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p820_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p820_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p820_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p820_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p820_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p820_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_read_pfc_0_0
// static int test_lseek_read_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
static int test_lseek_read_p78_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_read_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
// static void setup_lseek_read_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
static void setup_lseek_read_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p76_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_0_1
// static void setup_lseek_read_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_p76_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p74_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
static void setup_lseek_read_p74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_p74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p70_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_p76_0_proc0
// static void setup_lseek_read_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p68_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_0_1
// static void setup_lseek_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
static void setup_lseek_read_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p60_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_0_1
// static void setup_lseek_read_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
static void setup_lseek_read_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p60_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_0_1
static void setup_lseek_read_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_read_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p4_0_final(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal
// static void setup_lseek_read_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_read_p4_0_common
// static void setup_lseek_read_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p4_1_final(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal
// static void setup_lseek_read_p4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p38_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfc_0_common
// static void setup_lseek_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_2_proc0
// static void setup_lseek_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p36_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfb_2_1
// static void setup_lseek_read_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfb_0_common
// static void setup_lseek_read_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p34_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pfa_1_common
// static void setup_lseek_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pbe8_0_proc1
// static void setup_lseek_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pda_2_proc1
// static void setup_lseek_read_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p30_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_read_pf8_0_common
// static void setup_lseek_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfc_0_proc1
// static void setup_lseek_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_read_pfb_2_proc0
// static void setup_lseek_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_final
// static void setup_lseek_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_read_pfc_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p28_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfa_2_1
// static void setup_lseek_read_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_read_pbd_0_common
// static void setup_lseek_read_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pb5_0_proc1
// static void setup_lseek_read_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p28_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p20_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pf8_2_1
// static void setup_lseek_read_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_0_common
// static void setup_lseek_read_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_read_pbc0_1_proc0
// static void setup_lseek_read_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_read_pbd_0_final
// static void setup_lseek_read_p20_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal

/*
 * calls: lseek read
 */
// static int test_lseek_read_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_read_p78_0_0
// static int test_lseek_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_lseek_read_pfc_2_1
// static void setup_lseek_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_read_p4_0_common
// static void setup_lseek_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_read_pbd_0_proc1
// static void setup_lseek_read_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal
// static void setup_lseek_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_read_pbd_0_procfinal


/*
 * calls: lseek rename
 */
static int test_lseek_rename_pf_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_rename_pf_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_lseek_rename_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_rename_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_rename_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_rename_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_rename_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pf_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
// static int test_lseek_rename_pf_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_1
// static void setup_lseek_rename_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pf_0_common
static void setup_lseek_rename_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_rename_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_0_proc1
// static void setup_lseek_rename_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_final
// static void setup_lseek_rename_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pe8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
static int test_lseek_rename_pe8_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_lseek_rename_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_rename_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_0_proc0
// static void setup_lseek_rename_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_0_proc1
// static void setup_lseek_rename_pe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_final
// static void setup_lseek_rename_pe8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pe8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
// static int test_lseek_rename_pe8_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pe8_0_common
// static void setup_lseek_rename_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_1_proc0
// static void setup_lseek_rename_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_0_proc1
// static void setup_lseek_rename_pe8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_final
// static void setup_lseek_rename_pe8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pe0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
// static int test_lseek_rename_pe0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pf_0_common
// static void setup_lseek_rename_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_0_proc0
// static void setup_lseek_rename_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_0_proc1
// static void setup_lseek_rename_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_final
// static void setup_lseek_rename_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pe0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
// static int test_lseek_rename_pe0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pf_0_common
// static void setup_lseek_rename_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_1_proc0
// static void setup_lseek_rename_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_0_proc1
// static void setup_lseek_rename_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_final
// static void setup_lseek_rename_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
static int test_lseek_rename_pc_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_lseek_rename_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_rename_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_0_proc0
// static void setup_lseek_rename_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_0_proc1
// static void setup_lseek_rename_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_final
// static void setup_lseek_rename_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
// static int test_lseek_rename_pc_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pc_0_1
// static void setup_lseek_rename_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_rename_pc_0_common
// static void setup_lseek_rename_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_1_proc0
// static void setup_lseek_rename_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_rename_pf_0_proc1
// static void setup_lseek_rename_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_final
// static void setup_lseek_rename_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_rename_pf_0_procfinal

/*
 * calls: lseek rename
 */
static int test_lseek_rename_pbc_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_rename_pbc_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_1
static void setup_lseek_rename_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_rename_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_rename_pbc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_rename_pbc_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_rename_pbc_0_procfinal(void) {
  
}

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pba_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pbc_0_0
// static int test_lseek_rename_pba_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
static void setup_lseek_rename_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_lseek_rename_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_rename_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_pba_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_pba_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pbc_0_0
// static int test_lseek_rename_pb8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pbc_0_common
// static void setup_lseek_rename_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pbc_0_proc0
// static void setup_lseek_rename_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pbc_0_0
// static int test_lseek_rename_pb0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pc_0_1
static void setup_lseek_rename_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_rename_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pbc_0_proc0
// static void setup_lseek_rename_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
static int test_lseek_rename_pac_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_rename_pac_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_1
static void setup_lseek_rename_pac_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_rename_pac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_rename_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_pac_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_paa_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pac_0_0
// static int test_lseek_rename_paa_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pba_0_common
// static void setup_lseek_rename_paa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pba_0_proc0
// static void setup_lseek_rename_paa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_paa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_paa_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_paa_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pac_0_0
// static int test_lseek_rename_paa_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
static void setup_lseek_rename_paa_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_rename_paa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_paa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_paa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_paa_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pac_0_0
// static int test_lseek_rename_pa8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
// static void setup_lseek_rename_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pac_0_0
// static int test_lseek_rename_pa0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pc_0_1
static void setup_lseek_rename_pa0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_lseek_rename_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
static int test_lseek_rename_p9e_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_rename_p9e_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_1
static void setup_lseek_rename_p9e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_rename_p9e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p9e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p9e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p9d0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p9e_0_0
// static int test_lseek_rename_p9d0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p9d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_paa_1_common
// static void setup_lseek_rename_p9d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p9d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p9d0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p9d0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p9c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p9e_0_0
// static int test_lseek_rename_p9c_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_p9e_0_common
// static void setup_lseek_rename_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p9e_0_0
// static int test_lseek_rename_p98_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pc_0_1
static void setup_lseek_rename_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_rename_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
static int test_lseek_rename_p96_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_rename_p96_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_1
// static void setup_lseek_rename_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
// static void setup_lseek_rename_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p96_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p96_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p950_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p96_0_0
// static int test_lseek_rename_p950_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p950_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_paa_1_common
// static void setup_lseek_rename_p950_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p950_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p950_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p950_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p94_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p96_0_0
// static int test_lseek_rename_p94_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
// static void setup_lseek_rename_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p96_0_0
// static int test_lseek_rename_p90_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pc_0_1
// static void setup_lseek_rename_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_rename_pa0_0_common
// static void setup_lseek_rename_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
static int test_lseek_rename_p8f_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_rename_p8f_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_1
// static void setup_lseek_rename_p8f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
static void setup_lseek_rename_p8f_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_rename_p8f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8f_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p8f_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p8e8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8f_0_0
// static int test_lseek_rename_p8e8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
static void setup_lseek_rename_p8e8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_rename_p8e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pba_0_proc0
// static void setup_lseek_rename_p8e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
static void setup_lseek_rename_p8e8_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_lseek_rename_p8e8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p8e8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8f_0_0
// static int test_lseek_rename_p8e8_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
static void setup_lseek_rename_p8e8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_rename_p8e8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pba_0_proc0
// static void setup_lseek_rename_p8e8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
static void setup_lseek_rename_p8e8_1_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_lseek_rename_p8e8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p8e8_2_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8f_0_0
// static int test_lseek_rename_p8e8_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p8e8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pba_0_common
// static void setup_lseek_rename_p8e8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pba_0_proc0
// static void setup_lseek_rename_p8e8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8e8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p8e8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p8e0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8f_0_0
// static int test_lseek_rename_p8e0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p8e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
// static void setup_lseek_rename_p8e0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_p8f_0_proc0
// static void setup_lseek_rename_p8e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8e0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p8e0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8f_0_0
// static int test_lseek_rename_p8c_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pc_0_1
// static void setup_lseek_rename_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_rename_pa0_0_common
// static void setup_lseek_rename_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_p8f_0_proc0
// static void setup_lseek_rename_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
static int test_lseek_rename_p8b_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_rename_p8b_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_1
// static void setup_lseek_rename_p8b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
// static void setup_lseek_rename_p8b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p8b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8b_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p8b_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p8a8_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8b_0_0
// static int test_lseek_rename_p8a8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p8a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_p8e8_0_common
// static void setup_lseek_rename_p8a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_p8f_0_proc0
// static void setup_lseek_rename_p8a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8a8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_rename_p8e8_0_final
// static void setup_lseek_rename_p8a8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
static int test_lseek_rename_p8a8_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_rename_p8a8_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
static void setup_lseek_rename_p8a8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_rename_p8a8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p8a8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8a8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_rename_p8e8_0_final
// static void setup_lseek_rename_p8a8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p8a8_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8b_0_0
// static int test_lseek_rename_p8a8_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p8a8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_p8e8_1_common
static void setup_lseek_rename_p8a8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_rename_p8a8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8a8_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_p8e8_1_final
// static void setup_lseek_rename_p8a8_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
static int test_lseek_rename_p8a8_3_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 28672);
  return xerrno(r);
}
// static int test_lseek_rename_p8a8_3_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
static void setup_lseek_rename_p8a8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_rename_p8a8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p8a8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8a8_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_p8e8_1_final
// static void setup_lseek_rename_p8a8_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p8a8_4_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8b_0_0
// static int test_lseek_rename_p8a8_4_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p8a8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pba_0_common
// static void setup_lseek_rename_p8a8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_p8a8_2_proc0
// static void setup_lseek_rename_p8a8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8a8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p8a8_4_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p8a8_5_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 28672);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8a8_3_0
// static int test_lseek_rename_p8a8_5_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p8a8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_paa_1_common
// static void setup_lseek_rename_p8a8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p8a8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8a8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p8a8_5_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p8a0_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8b_0_0
// static int test_lseek_rename_p8a0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p8a0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
// static void setup_lseek_rename_p8a0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p8a0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p8a0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p8a0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p8b_0_0
// static int test_lseek_rename_p88_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pc_0_1
// static void setup_lseek_rename_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_rename_pa0_0_common
// static void setup_lseek_rename_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p86_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
// static int test_lseek_rename_p86_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_1
// static void setup_lseek_rename_p86_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
// static void setup_lseek_rename_p86_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p86_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p86_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p86_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p850_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
// static int test_lseek_rename_p850_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p850_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pba_0_common
// static void setup_lseek_rename_p850_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pba_0_proc0
// static void setup_lseek_rename_p850_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p850_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p850_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
// static int test_lseek_rename_p84_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
// static void setup_lseek_rename_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_0
// static int test_lseek_rename_p80_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pc_0_1
// static void setup_lseek_rename_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_rename_pa0_0_common
// static void setup_lseek_rename_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_rename_pac_0_proc0
// static void setup_lseek_rename_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
static int test_lseek_rename_p6_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_rename_p6_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pf_0_1
// static void setup_lseek_rename_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
// static void setup_lseek_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p50_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p6_0_0
// static int test_lseek_rename_p50_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pba_0_common
// static void setup_lseek_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p6_0_0
// static int test_lseek_rename_p4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pe8_0_1
// static void setup_lseek_rename_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_rename_pac_0_common
// static void setup_lseek_rename_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_rename_pbc_0_final
// static void setup_lseek_rename_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal

/*
 * calls: lseek rename
 */
// static int test_lseek_rename_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_p6_0_0
// static int test_lseek_rename_p0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_rename_pc_0_1
static void setup_lseek_rename_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_rename_pbc_0_proc1
// static void setup_lseek_rename_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal
// static void setup_lseek_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_rename_pbc_0_procfinal


/*
 * calls: lseek stat
 */
static int test_lseek_stat_pe_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_lseek_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_stat_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_stat_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_stat_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_stat_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_pe_0_0
// static int test_lseek_stat_pe_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pe_0_1
// static void setup_lseek_stat_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_stat_pe_0_common
static void setup_lseek_stat_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_stat_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_stat_pe_0_proc1
// static void setup_lseek_stat_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_stat_pe_0_final
// static void setup_lseek_stat_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_stat_pe_0_procfinal

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_pe_0_0
static int test_lseek_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_lseek_stat_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_stat_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_stat_pe_0_proc0
// static void setup_lseek_stat_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_stat_pe_0_proc1
// static void setup_lseek_stat_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_stat_pe_0_final
// static void setup_lseek_stat_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_stat_pe_0_procfinal

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_pe_0_0
// static int test_lseek_stat_pc_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pc_0_1
// static void setup_lseek_stat_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_stat_pc_0_common
// static void setup_lseek_stat_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_stat_pe_1_proc0
// static void setup_lseek_stat_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_stat_pe_0_proc1
// static void setup_lseek_stat_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_stat_pe_0_final
// static void setup_lseek_stat_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_stat_pe_0_procfinal

/*
 * calls: lseek stat
 */
static int test_lseek_stat_pb8_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_stat_pb8_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_lseek_stat_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_stat_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_stat_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_stat_pb8_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_stat_pb8_0_procfinal(void) {
  
}

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_pb8_0_0
// static int test_lseek_stat_pb0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pc_0_1
static void setup_lseek_stat_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_stat_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_pb8_0_proc0
// static void setup_lseek_stat_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
static int test_lseek_stat_pa8_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_stat_pa8_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pe_0_1
static void setup_lseek_stat_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_stat_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_stat_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_pa8_0_0
// static int test_lseek_stat_pa0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pc_0_1
static void setup_lseek_stat_pa0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_lseek_stat_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa8_0_proc0
// static void setup_lseek_stat_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
static int test_lseek_stat_p9c_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_stat_p9c_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 28672);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_lseek_stat_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_stat_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa8_0_proc0
// static void setup_lseek_stat_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_p9c_0_0
// static int test_lseek_stat_p98_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pc_0_1
static void setup_lseek_stat_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_stat_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa8_0_proc0
// static void setup_lseek_stat_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
static int test_lseek_stat_p94_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_stat_p94_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pe_0_1
// static void setup_lseek_stat_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_stat_pa8_0_common
// static void setup_lseek_stat_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa8_0_proc0
// static void setup_lseek_stat_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_p94_0_0
// static int test_lseek_stat_p90_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pc_0_1
// static void setup_lseek_stat_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa0_0_common
// static void setup_lseek_stat_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa8_0_proc0
// static void setup_lseek_stat_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
static int test_lseek_stat_p8e_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_stat_p8e_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pe_0_1
// static void setup_lseek_stat_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_stat_pa8_0_common
static void setup_lseek_stat_p8e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_stat_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_p8e_0_0
// static int test_lseek_stat_p8c_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pc_0_1
// static void setup_lseek_stat_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa0_0_common
// static void setup_lseek_stat_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_p8e_0_proc0
// static void setup_lseek_stat_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
static int test_lseek_stat_p8a_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_stat_p8a_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pe_0_1
// static void setup_lseek_stat_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_stat_pa8_0_common
// static void setup_lseek_stat_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa8_0_proc0
// static void setup_lseek_stat_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_p8a_0_0
// static int test_lseek_stat_p88_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pc_0_1
// static void setup_lseek_stat_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa0_0_common
// static void setup_lseek_stat_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa8_0_proc0
// static void setup_lseek_stat_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_pe_0_0
// static int test_lseek_stat_p84_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pe_0_1
// static void setup_lseek_stat_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_stat_pa8_0_common
// static void setup_lseek_stat_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa8_0_proc0
// static void setup_lseek_stat_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_pe_0_0
// static int test_lseek_stat_p80_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pc_0_1
// static void setup_lseek_stat_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa0_0_common
// static void setup_lseek_stat_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_stat_pa8_0_proc0
// static void setup_lseek_stat_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
static int test_lseek_stat_p4_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pe_0_1
// static void setup_lseek_stat_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_stat_pa8_0_common
// static void setup_lseek_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_stat_pb8_0_final
// static void setup_lseek_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal

/*
 * calls: lseek stat
 */
// static int test_lseek_stat_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_stat_p4_0_0
// static int test_lseek_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_lseek_stat_pc_0_1
static void setup_lseek_stat_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_stat_pb8_0_proc1
// static void setup_lseek_stat_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal
// static void setup_lseek_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_stat_pb8_0_procfinal


/*
 * calls: lseek unlink
 */
static int test_lseek_unlink_pe_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_unlink_pe_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_lseek_unlink_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_unlink_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_unlink_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_unlink_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_unlink_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_0
// static int test_lseek_unlink_pe_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
// static void setup_lseek_unlink_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_unlink_pe_0_common
static void setup_lseek_unlink_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_unlink_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_unlink_pe_0_proc1
// static void setup_lseek_unlink_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_unlink_pe_0_final
// static void setup_lseek_unlink_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_unlink_pe_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_0
static int test_lseek_unlink_pc_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_lseek_unlink_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_unlink_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_unlink_pe_0_proc0
// static void setup_lseek_unlink_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_unlink_pe_0_proc1
// static void setup_lseek_unlink_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_unlink_pe_0_final
// static void setup_lseek_unlink_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_unlink_pe_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_0
// static int test_lseek_unlink_pc_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pc_0_1
// static void setup_lseek_unlink_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_unlink_pc_0_common
// static void setup_lseek_unlink_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_unlink_pe_1_proc0
// static void setup_lseek_unlink_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_unlink_pe_0_proc1
// static void setup_lseek_unlink_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_unlink_pe_0_final
// static void setup_lseek_unlink_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_unlink_pe_0_procfinal

/*
 * calls: lseek unlink
 */
static int test_lseek_unlink_pb8_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_unlink_pb8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
static void setup_lseek_unlink_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_unlink_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_unlink_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_unlink_pb8_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_unlink_pb8_0_procfinal(void) {
  
}

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pb8_0_0
// static int test_lseek_unlink_pb0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pc_0_1
static void setup_lseek_unlink_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_unlink_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_unlink_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
static int test_lseek_unlink_pa8_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_unlink_pa8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
// static void setup_lseek_unlink_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_unlink_pb8_0_common
// static void setup_lseek_unlink_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pb8_0_proc0
// static void setup_lseek_unlink_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_pa8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pa8_0_0
// static int test_lseek_unlink_pa8_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
static void setup_lseek_unlink_pa8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_lseek_unlink_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_unlink_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pa8_0_0
// static int test_lseek_unlink_pa0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pc_0_1
static void setup_lseek_unlink_pa0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_lseek_unlink_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa8_1_proc0
// static void setup_lseek_unlink_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
static int test_lseek_unlink_p9c_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_unlink_p9c_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
// static void setup_lseek_unlink_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_unlink_pa8_1_common
// static void setup_lseek_unlink_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa8_1_proc0
// static void setup_lseek_unlink_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_p9c_0_0
// static int test_lseek_unlink_p98_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pc_0_1
static void setup_lseek_unlink_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_unlink_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa8_1_proc0
// static void setup_lseek_unlink_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
static int test_lseek_unlink_p94_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_unlink_p94_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
// static void setup_lseek_unlink_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_unlink_pa8_1_common
// static void setup_lseek_unlink_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa8_1_proc0
// static void setup_lseek_unlink_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_p94_0_0
// static int test_lseek_unlink_p90_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pc_0_1
// static void setup_lseek_unlink_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa0_0_common
// static void setup_lseek_unlink_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa8_1_proc0
// static void setup_lseek_unlink_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
static int test_lseek_unlink_p8e_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_unlink_p8e_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
static void setup_lseek_unlink_p8e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_unlink_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pb8_0_proc0
// static void setup_lseek_unlink_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
static void setup_lseek_unlink_p8e_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_lseek_unlink_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_p8e_1_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_p8e_0_0
// static int test_lseek_unlink_p8e_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
// static void setup_lseek_unlink_p8e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_unlink_pb8_0_common
// static void setup_lseek_unlink_p8e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pb8_0_proc0
// static void setup_lseek_unlink_p8e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p8e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p8e_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_p8e_0_0
// static int test_lseek_unlink_p8c_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pc_0_1
// static void setup_lseek_unlink_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa0_0_common
static void setup_lseek_unlink_p8c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_unlink_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
static int test_lseek_unlink_p8a_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_unlink_p8a_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
// static void setup_lseek_unlink_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_unlink_p8e_0_common
// static void setup_lseek_unlink_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_p8c_0_proc0
// static void setup_lseek_unlink_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p8a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_unlink_p8e_0_final
// static void setup_lseek_unlink_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
static int test_lseek_unlink_p8a_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 24576);
  return xerrno(r);
}
// static int test_lseek_unlink_p8a_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
static void setup_lseek_unlink_p8a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_lseek_unlink_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa8_1_proc0
// static void setup_lseek_unlink_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p8a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_unlink_p8e_0_final
// static void setup_lseek_unlink_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_p8a_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_p8a_0_0
// static int test_lseek_unlink_p8a_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
// static void setup_lseek_unlink_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_unlink_pb8_0_common
static void setup_lseek_unlink_p8a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_unlink_p8a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p8a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
static int test_lseek_unlink_p8a_3_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 28672);
  return xerrno(r);
}
// static int test_lseek_unlink_p8a_3_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
// static void setup_lseek_unlink_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_unlink_pa8_1_common
// static void setup_lseek_unlink_p8a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa8_1_proc0
// static void setup_lseek_unlink_p8a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p8a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_p8a_0_0
// static int test_lseek_unlink_p88_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pc_0_1
// static void setup_lseek_unlink_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa0_0_common
// static void setup_lseek_unlink_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa8_1_proc0
// static void setup_lseek_unlink_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_0
// static int test_lseek_unlink_p84_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
// static void setup_lseek_unlink_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_unlink_pb8_0_common
// static void setup_lseek_unlink_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pb8_0_proc0
// static void setup_lseek_unlink_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_0
// static int test_lseek_unlink_p80_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pc_0_1
// static void setup_lseek_unlink_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa0_0_common
// static void setup_lseek_unlink_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_unlink_pa8_1_proc0
// static void setup_lseek_unlink_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
static int test_lseek_unlink_p4_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_unlink_p4_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pe_0_1
// static void setup_lseek_unlink_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_lseek_unlink_pb8_0_common
// static void setup_lseek_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_unlink_pb8_0_final
// static void setup_lseek_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal

/*
 * calls: lseek unlink
 */
// static int test_lseek_unlink_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_p4_0_0
// static int test_lseek_unlink_p0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_lseek_unlink_pc_0_1
static void setup_lseek_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_unlink_pb8_0_proc1
// static void setup_lseek_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal
// static void setup_lseek_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_unlink_pb8_0_procfinal


/*
 * calls: lseek write
 */
static int test_lseek_write_pfe_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
static int test_lseek_write_pfe_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_lseek_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_write_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_lseek_write_pfe_0_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: lseek write
 */
// static int test_lseek_write_pfe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pfe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
// static void setup_lseek_write_pfe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_0_common
static void setup_lseek_write_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pfe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_0_proc1
// static void setup_lseek_write_pfe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_lseek_write_pfe_0_final
// static void setup_lseek_write_pfe_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_lseek_write_pfe_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pfe_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pfe_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
static void setup_lseek_write_pfe_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_write_pfe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_write_pfe_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_write_pfe_2_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_lseek_write_pfe_2_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: lseek write
 */
// static int test_lseek_write_pfe_3_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
static int test_lseek_write_pfe_3_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_lseek_write_pfe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
static void setup_lseek_write_pfe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pfe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_pfe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pfe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pfc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
static int test_lseek_write_pfc_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_lseek_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_write_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pfc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pfc_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
static void setup_lseek_write_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pfc_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
static int test_lseek_write_pfc_2_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_lseek_write_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
static void setup_lseek_write_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pf8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
static int test_lseek_write_pf8_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_lseek_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pf8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pf8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
static void setup_lseek_write_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pf8_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
static int test_lseek_write_pf8_2_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_lseek_write_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
static void setup_lseek_write_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pf4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pf4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_write_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pf4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pf4_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_write_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pf0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf4_0_proc0
// static void setup_lseek_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pf0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pf0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_write_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf4_1_proc0
// static void setup_lseek_write_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pe_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pe_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
// static void setup_lseek_write_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pe_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
// static void setup_lseek_write_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pde_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pde_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
static void setup_lseek_write_pde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_lseek_write_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_lseek_write_pde_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_lseek_write_pfe_0_final
// static void setup_lseek_write_pde_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_lseek_write_pfe_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pde_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pde_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
// static void setup_lseek_write_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pde_0_common
static void setup_lseek_write_pde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pde_0_proc1
// static void setup_lseek_write_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_lseek_write_pfe_0_final
// static void setup_lseek_write_pde_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_lseek_write_pfe_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pde_2_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pde_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
static void setup_lseek_write_pde_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_write_pde_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_pde_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_pde_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pde_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pdc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pdc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
// static void setup_lseek_write_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pdc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pdc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
// static void setup_lseek_write_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pd8_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
// static void setup_lseek_write_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pd8_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pd8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
// static void setup_lseek_write_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pd4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pd4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf4_0_common
// static void setup_lseek_write_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
static void setup_lseek_write_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pd4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pd4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf4_0_common
// static void setup_lseek_write_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pd0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf0_0_common
// static void setup_lseek_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pd0_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pd0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf0_0_common
// static void setup_lseek_write_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pc_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
// static void setup_lseek_write_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pc_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_pc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
// static void setup_lseek_write_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_pbf8_0_0(void) {
  int r = lseek(10, -4096, SEEK_SET);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_write_pbf8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
// static void setup_lseek_write_pbf8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
static void setup_lseek_write_pbf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pbf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_pbf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pbf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pbf0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pbf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_pbf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
static void setup_lseek_write_pbf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pbf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pbf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pbf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pbe_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pbe_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
static void setup_lseek_write_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pbd0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pbd0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_pbd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_lseek_write_pbd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_write_pbd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_lseek_write_pbd0_0_final(void) {
  unlink("__i0");
}
static void setup_lseek_write_pbd0_0_procfinal(void) {
  
}

/*
 * calls: lseek write
 */
// static int test_lseek_write_pbd0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pbd0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pbd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
static void setup_lseek_write_pbd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_pbd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pbd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pbd0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pbc0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pbc0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_pbc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_write_pbc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_proc0
// static void setup_lseek_write_pbc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pbc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pbc0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pbc0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pbc0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pbc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_pbc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pbc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pbc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pbc0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pb8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pb8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
static void setup_lseek_write_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_write_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pb78_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pb78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
// static void setup_lseek_write_pb78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pde_2_common
static void setup_lseek_write_pb78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pb78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_pb78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pb78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pb70_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pb70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pb70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
static void setup_lseek_write_pb70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pb70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pb70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pb70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pb6_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pb6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
static void setup_lseek_write_pb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pb50_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pb50_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pb50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_pb50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pb50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pb50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pb50_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pb40_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pb40_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pb40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_pb40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pb40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pb40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pb40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pb0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_SET);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pbf8_0_0
// static int test_lseek_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_proc0
// static void setup_lseek_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_paf8_0_0(void) {
  int r = lseek(10, 0, SEEK_SET);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_write_paf8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
// static void setup_lseek_write_paf8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_paf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pbf8_0_proc0
// static void setup_lseek_write_paf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_paf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_paf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_paf8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_paf8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
// static void setup_lseek_write_paf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pde_2_common
static void setup_lseek_write_paf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_paf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_paf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_paf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_paf0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_paf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_paf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
// static void setup_lseek_write_paf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pbf0_0_proc0
// static void setup_lseek_write_paf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_paf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_paf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_paf0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_paf0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_paf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
static void setup_lseek_write_paf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_paf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_paf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_paf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pae_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pae_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
static void setup_lseek_write_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pae_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pae_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
static void setup_lseek_write_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pad8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pad8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_pad8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_pad8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_proc0
// static void setup_lseek_write_pad8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pad8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pad8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pac0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pac0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_pac0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_pac0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_proc0
// static void setup_lseek_write_pac0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pac0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pac0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa8_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
static void setup_lseek_write_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa8_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa78_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
// static void setup_lseek_write_pa78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pde_2_common
// static void setup_lseek_write_pa78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb78_0_proc0
// static void setup_lseek_write_pa78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_pa78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pa78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa78_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa78_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
// static void setup_lseek_write_pa78_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pde_2_common
static void setup_lseek_write_pa78_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_pa78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_pa78_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pa78_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa70_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pa70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
// static void setup_lseek_write_pa70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb70_0_proc0
// static void setup_lseek_write_pa70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pa70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pa70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa70_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa70_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pa70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_pa70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_pa70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_pa70_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pa70_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa6_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb70_0_proc0
// static void setup_lseek_write_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_pa6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pa6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa6_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa6_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_pa6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_pa6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa50_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa50_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pa50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_pa50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pa50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pa50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pa50_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa40_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa40_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_pa40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_pa40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pa40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pa40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pa40_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa0_0_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pa8_0_proc0
// static void setup_lseek_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_pa0_1_0(void) {
//   int r = lseek(10, 0, SEEK_SET);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_paf8_0_0
// static int test_lseek_write_pa0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p9fc_0_0(void) {
  int r = lseek(10, -4096, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_write_p9fc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
// static void setup_lseek_write_p9fc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p9fc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_paf8_1_proc0
// static void setup_lseek_write_p9fc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_p9fc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p9fc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9f8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9f8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_p9f8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_write_p9f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_paf0_1_proc0
// static void setup_lseek_write_p9f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p9f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p9f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9f0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p9f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p9f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pae_1_proc0
// static void setup_lseek_write_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p9f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p9f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p9ec_0_0(void) {
  int r = lseek(10, -8192, SEEK_CUR);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_write_p9ec_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p9ec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
static void setup_lseek_write_p9ec_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p9ec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p9ec_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9ec_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9ec_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9ec_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p9ec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p9ec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_proc0
// static void setup_lseek_write_p9ec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p9ec_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9ec_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9ec_2_0(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9ec_0_0
// static int test_lseek_write_p9ec_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p9ec_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p9ec_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p9ec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p9ec_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9ec_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9e4_0_0(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9ec_0_0
// static int test_lseek_write_p9e4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p9e4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_p9e4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p9ec_0_proc0
// static void setup_lseek_write_p9e4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p9e4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9e4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9e4_1_0(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9ec_0_0
// static int test_lseek_write_p9e4_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p9e4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p9e4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_proc0
// static void setup_lseek_write_p9e4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p9e4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9e4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9e4_2_0(void) {
//   int r = lseek(10, -8192, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9ec_0_0
// static int test_lseek_write_p9e4_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p9e4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p9e4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p9e4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p9e4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9e4_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9bc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9bc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
// static void setup_lseek_write_p9bc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pde_2_common
// static void setup_lseek_write_p9bc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pa78_1_proc0
// static void setup_lseek_write_p9bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_p9bc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p9bc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9b8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9b8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p9b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p9f8_0_common
// static void setup_lseek_write_p9b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_p9b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_p9b8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p9b8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9b0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9b0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p9b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p9b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_p9b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_p9b0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p9b0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9a8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9a8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
static void setup_lseek_write_p9a8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_write_p9a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
static void setup_lseek_write_p9a8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p9a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9a8_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9a8_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9a8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p9a8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p9a8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p9a8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p9a8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9a8_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9a0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9a0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
static void setup_lseek_write_p9a0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_write_p9a0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p9a0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p9a8_0_proc1
// static void setup_lseek_write_p9a0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9a0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p9a0_1_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p9a0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p9a0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p9a0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p9a0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p9a0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p9a0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p98_0_0(void) {
//   int r = lseek(10, -4096, SEEK_CUR);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p9fc_0_0
// static int test_lseek_write_p98_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p98_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p97c_0_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_write_p97c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
// static void setup_lseek_write_p97c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p97c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_paf8_1_proc0
// static void setup_lseek_write_p97c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_p97c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p97c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p978_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p978_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p978_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p978_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_paf0_1_proc0
// static void setup_lseek_write_p978_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p978_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p978_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p970_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p970_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p970_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p970_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pae_1_proc0
// static void setup_lseek_write_p970_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p970_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p970_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p96e_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p96e_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p96e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_p9a8_0_common
static void setup_lseek_write_p96e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p96e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p96e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p96e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p96e_1_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 31617024);
  return xerrno(r);
}
// static int test_lseek_write_p96e_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p96e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
static void setup_lseek_write_p96e_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p96e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p96e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p96e_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p96e_2_0(void) {
  int r = lseek(10, 8192, SEEK_CUR);
  expect_result("r", r, 16384);
  return xerrno(r);
}
// static int test_lseek_write_p96e_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p96e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
static void setup_lseek_write_p96e_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p96e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p96e_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p96e_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p962_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p962_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p962_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_p9a0_0_common
// static void setup_lseek_write_p962_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p96e_0_proc0
// static void setup_lseek_write_p962_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p962_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p962_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p962_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 31617024);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p96e_1_0
// static int test_lseek_write_p962_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p962_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p962_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p96e_1_proc0
// static void setup_lseek_write_p962_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p962_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p962_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p962_2_0(void) {
//   int r = lseek(10, 8192, SEEK_CUR);
//   expect_result("r", r, 16384);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p96e_2_0
// static int test_lseek_write_p962_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_p962_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_write_p962_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p96e_2_proc0
// static void setup_lseek_write_p962_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p962_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p962_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p94_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p94_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p94_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p93c_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p93c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
// static void setup_lseek_write_p93c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pde_2_common
// static void setup_lseek_write_p93c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pa78_1_proc0
// static void setup_lseek_write_p93c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_p93c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p93c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p938_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p938_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p938_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p938_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_p938_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_p938_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p938_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p930_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p930_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p930_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p930_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_p930_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_p930_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p930_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p928_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p928_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
static void setup_lseek_write_p928_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_write_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
static void setup_lseek_write_p928_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p928_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p928_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p928_1_0(void) {
  int r = lseek(10, 0, SEEK_CUR);
  expect_result("r", r, 155648);
  return xerrno(r);
}
// static int test_lseek_write_p928_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p928_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
static void setup_lseek_write_p928_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p928_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p928_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p928_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p928_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p928_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p928_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p928_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p928_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p928_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p928_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p920_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p920_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p920_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_p9a8_0_common
// static void setup_lseek_write_p920_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p920_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p928_0_proc1
// static void setup_lseek_write_p920_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p920_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p920_1_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 155648);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p928_1_0
// static int test_lseek_write_p920_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p920_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p920_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p928_1_proc0
// static void setup_lseek_write_p920_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p920_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p920_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p920_2_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p920_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p920_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p920_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p920_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p920_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p920_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p90_0_0(void) {
//   int r = lseek(10, 0, SEEK_CUR);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p97c_0_0
// static int test_lseek_write_p90_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p90_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p8fe_0_0(void) {
  int r = lseek(10, -4096, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_write_p8fe_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
static void setup_lseek_write_p8fe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_write_p8fe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pbf8_0_proc0
// static void setup_lseek_write_p8fe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_p8fe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8fe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8fc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8fe_0_0
// static int test_lseek_write_p8fc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_p8fc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_write_p8fc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pbf0_0_proc0
// static void setup_lseek_write_p8fc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p8fc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8fc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8f8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8fe_0_0
// static int test_lseek_write_p8f8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p8f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p8fe_0_common
// static void setup_lseek_write_p8f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pae_0_proc0
// static void setup_lseek_write_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p8f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p8f6_0_0(void) {
  int r = lseek(10, -8192, SEEK_END);
  expect_result("r", r, -1);
  expect_errno(22);
  return xerrno(r);
}
// static int test_lseek_write_p8f6_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_p8f6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_write_p8f6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p8f6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
static void setup_lseek_write_p8f6_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_lseek_write_p8f6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8f6_1_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8f6_0_0
// static int test_lseek_write_p8f6_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p8f6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p8f6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_proc0
// static void setup_lseek_write_p8f6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8f6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8f6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8f6_2_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8f6_0_0
// static int test_lseek_write_p8f6_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p8f6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p8f6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p8f6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8f6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8f6_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8f0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8fe_0_0
// static int test_lseek_write_p8f0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_p8f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_write_p8f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8f0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p8f0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8f0_1_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8f6_0_0
// static int test_lseek_write_p8f0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p8f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p8f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_proc0
// static void setup_lseek_write_p8f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8f0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8f0_2_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8f6_0_0
// static int test_lseek_write_p8f0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p8f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p8f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p8f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8f0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8f0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8e_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8fe_0_0
// static int test_lseek_write_p8e_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pa8_0_proc0
// static void setup_lseek_write_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8de_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8fe_0_0
// static int test_lseek_write_p8de_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
static void setup_lseek_write_p8de_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_write_p8de_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb78_0_proc0
// static void setup_lseek_write_p8de_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_p8de_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8de_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8dc_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8fe_0_0
// static int test_lseek_write_p8dc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p8dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p8fc_0_common
// static void setup_lseek_write_p8dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb70_0_proc0
// static void setup_lseek_write_p8dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_p8dc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8dc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8d8_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8fe_0_0
// static int test_lseek_write_p8d8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p8fe_0_common
// static void setup_lseek_write_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb70_0_proc0
// static void setup_lseek_write_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_p8d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8d6_0_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8f6_0_0
// static int test_lseek_write_p8d6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p8d6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_p8f6_0_common
static void setup_lseek_write_p8d6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_lseek_write_p8d6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p8d6_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p8d6_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8d6_1_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8f6_0_0
// static int test_lseek_write_p8d6_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p8d6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p8d6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p8d6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p8d6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8d6_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8d0_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8fe_0_0
// static int test_lseek_write_p8d0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_p8f0_0_common
// static void setup_lseek_write_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p9a8_0_proc1
static void setup_lseek_write_p8d0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p8d0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p8d0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8d0_1_0(void) {
//   int r = lseek(10, -8192, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8f6_0_0
// static int test_lseek_write_p8d0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p8d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p8d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p8d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p8d0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8d0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8c_0_0(void) {
//   int r = lseek(10, -4096, SEEK_END);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8fe_0_0
// static int test_lseek_write_p8c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pa8_0_proc0
// static void setup_lseek_write_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p8be_0_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_lseek_write_p8be_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
// static void setup_lseek_write_p8be_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p8fe_0_common
// static void setup_lseek_write_p8be_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pbf8_0_proc0
// static void setup_lseek_write_p8be_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_p8be_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8be_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p8be_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 8192);
  return xerrno(r);
}
// static int test_lseek_write_p8be_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
static void setup_lseek_write_p8be_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_lseek_write_p8be_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_paf8_1_proc0
// static void setup_lseek_write_p8be_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_p8be_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8be_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8bc_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_0_0
// static int test_lseek_write_p8bc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p8bc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p8fe_0_common
// static void setup_lseek_write_p8bc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pbf0_0_proc0
// static void setup_lseek_write_p8bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p8bc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8bc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8bc_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_1_0
// static int test_lseek_write_p8bc_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p8bc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p9f8_0_common
// static void setup_lseek_write_p8bc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_paf0_1_proc0
// static void setup_lseek_write_p8bc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p8bc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8bc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8b8_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_0_0
// static int test_lseek_write_p8b8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p8b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p8fe_0_common
// static void setup_lseek_write_p8b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pae_0_proc0
// static void setup_lseek_write_p8b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p8b8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8b8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8b8_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_1_0
// static int test_lseek_write_p8b8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p8b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p8b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pae_1_proc0
// static void setup_lseek_write_p8b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p8b8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p8b8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p8b70_0_0(void) {
  int r = lseek(10, 12288, SEEK_END);
  expect_result("r", r, 12288);
  return xerrno(r);
}
// static int test_lseek_write_p8b70_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p8b70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_p8f6_0_common
// static void setup_lseek_write_p8b70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p8f6_0_proc0
// static void setup_lseek_write_p8b70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8b70_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p8b70_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8b70_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_1_0
// static int test_lseek_write_p8b70_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_p8b70_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_write_p8b70_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p8b70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8b70_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p8b70_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8b0_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_0_0
// static int test_lseek_write_p8b0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p8b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_p8f0_0_common
// static void setup_lseek_write_p8b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p8f0_0_proc0
// static void setup_lseek_write_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8b0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p8b0_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 12288);
  return xerrno(r);
}
// static int test_lseek_write_p8b0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
static void setup_lseek_write_p8b0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_lseek_write_p8b0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p8b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8b0_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p8b0_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p8b0_2_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_lseek_write_p8b0_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p8b0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p8b0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_proc0
// static void setup_lseek_write_p8b0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8b0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8b0_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8a_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_0_0
// static int test_lseek_write_p8a_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pa8_0_proc0
// static void setup_lseek_write_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p8a_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_1_0
// static int test_lseek_write_p8a_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p89e_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_0_0
// static int test_lseek_write_p89e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
// static void setup_lseek_write_p89e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p8de_0_common
// static void setup_lseek_write_p89e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb78_0_proc0
// static void setup_lseek_write_p89e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_p89e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p89e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p89e_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_1_0
// static int test_lseek_write_p89e_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
// static void setup_lseek_write_p89e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p8be_1_common
// static void setup_lseek_write_p89e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pa78_1_proc0
// static void setup_lseek_write_p89e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_p89e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p89e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p89c_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_0_0
// static int test_lseek_write_p89c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p89c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p8fe_0_common
// static void setup_lseek_write_p89c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb70_0_proc0
// static void setup_lseek_write_p89c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_p89c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p89c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p89c_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_1_0
// static int test_lseek_write_p89c_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p89c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p9f8_0_common
// static void setup_lseek_write_p89c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_p89c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_p89c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p89c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p898_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_0_0
// static int test_lseek_write_p898_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p898_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_p8fe_0_common
// static void setup_lseek_write_p898_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb70_0_proc0
// static void setup_lseek_write_p898_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_p898_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p898_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p898_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_1_0
// static int test_lseek_write_p898_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p898_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p898_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_p898_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_p898_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p898_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p896_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_0_0
// static int test_lseek_write_p896_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
static void setup_lseek_write_p896_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_write_p896_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p928_0_proc1
static void setup_lseek_write_p896_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p896_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p896_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p896_1_0(void) {
  int r = lseek(10, 0, SEEK_END);
  expect_result("r", r, 28672);
  return xerrno(r);
}
// static int test_lseek_write_p896_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
static void setup_lseek_write_p896_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_write_p896_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p896_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p8d0_0_proc1
// static void setup_lseek_write_p896_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p896_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p890_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_0_0
// static int test_lseek_write_p890_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
static void setup_lseek_write_p890_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_write_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p928_0_proc1
// static void setup_lseek_write_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p896_0_proc1
// static void setup_lseek_write_p890_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p890_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p890_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_1_0
// static int test_lseek_write_p890_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
static void setup_lseek_write_p890_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_lseek_write_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
static void setup_lseek_write_p890_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p890_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_lseek_write_p8f6_0_final
// static void setup_lseek_write_p890_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p890_2_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8b0_2_0
// static int test_lseek_write_p890_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p890_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p890_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p890_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p890_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p890_2_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p88_0_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_0_0
// static int test_lseek_write_p88_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pa8_0_proc0
// static void setup_lseek_write_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p88_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p88_1_0(void) {
//   int r = lseek(10, 0, SEEK_END);
//   expect_result("r", r, 8192);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p8be_1_0
// static int test_lseek_write_p88_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pb8_0_common
// static void setup_lseek_write_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p88_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p87c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p87c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
// static void setup_lseek_write_p87c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
// static void setup_lseek_write_p87c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pbf8_0_proc0
// static void setup_lseek_write_p87c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_p87c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p87c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p878_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p878_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p878_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
// static void setup_lseek_write_p878_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pbf0_0_proc0
// static void setup_lseek_write_p878_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p878_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p878_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p870_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p870_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p870_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
// static void setup_lseek_write_p870_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pae_1_proc0
// static void setup_lseek_write_p870_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p870_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p870_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p868_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p868_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p868_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p868_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_proc0
// static void setup_lseek_write_p868_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p868_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p868_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p868_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p868_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p868_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p868_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p868_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p868_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p868_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p860_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p860_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p860_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p860_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_proc0
// static void setup_lseek_write_p860_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p860_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p860_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p860_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p860_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p860_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p860_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p860_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p860_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p860_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p84_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p84_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p84_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p83c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p83c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
// static void setup_lseek_write_p83c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pde_2_common
// static void setup_lseek_write_p83c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb78_0_proc0
// static void setup_lseek_write_p83c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_p83c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p83c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p838_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p838_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p838_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
// static void setup_lseek_write_p838_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pb70_0_proc0
// static void setup_lseek_write_p838_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_p838_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p838_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p830_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p830_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p830_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
// static void setup_lseek_write_p830_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pd4_0_proc1
// static void setup_lseek_write_p830_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_p830_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p830_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p828_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p828_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p828_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p828_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p828_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p828_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p828_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p820_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p820_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p820_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p820_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p820_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p820_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p820_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p80_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(22);
//   return xerrno(r);
// }
// ^ See test_lseek_write_pfe_0_0
// static int test_lseek_write_p80_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p80_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
static int test_lseek_write_p7c_0_0(void) {
  int r = lseek(10, 0, 999);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_lseek_write_p7c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_0_1
// static void setup_lseek_write_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfe_2_common
static void setup_lseek_write_p7c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p78_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p78_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
static void setup_lseek_write_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p70_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p70_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
// static void setup_lseek_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
static void setup_lseek_write_p70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_lseek_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p68_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p68_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
static void setup_lseek_write_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_lseek_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p60_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p60_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_0_1
// static void setup_lseek_write_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_p68_0_proc0
// static void setup_lseek_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p4_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_0_1
static void setup_lseek_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_lseek_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p4_0_final(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal
// static void setup_lseek_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p4_1_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_write_p4_0_common
// static void setup_lseek_write_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p4_1_final(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal
// static void setup_lseek_write_p4_1_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p3c_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfe_3_1
// static void setup_lseek_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pde_2_common
// static void setup_lseek_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_2_proc1
// static void setup_lseek_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfe_3_proc0
// static void setup_lseek_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p38_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pfc_0_common
// static void setup_lseek_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_2_proc0
// static void setup_lseek_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p30_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_lseek_write_pf8_0_common
// static void setup_lseek_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pfc_0_proc1
// static void setup_lseek_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_lseek_write_pf8_2_proc0
// static void setup_lseek_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_final
// static void setup_lseek_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_lseek_write_pfe_2_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p28_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_0_common
// static void setup_lseek_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p20_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pfc_2_1
// static void setup_lseek_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_lseek_write_pbc0_0_common
// static void setup_lseek_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_lseek_write_pbd0_1_proc0
// static void setup_lseek_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_lseek_write_pbd0_0_final
// static void setup_lseek_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal

/*
 * calls: lseek write
 */
// static int test_lseek_write_p0_0_0(void) {
//   int r = lseek(10, 0, 999);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_lseek_write_p7c_0_0
// static int test_lseek_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_lseek_write_pf8_2_1
// static void setup_lseek_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_lseek_write_p4_0_common
// static void setup_lseek_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_lseek_write_pbd0_0_proc1
// static void setup_lseek_write_p0_0_final(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal
// static void setup_lseek_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_lseek_write_pbd0_0_procfinal


/*
 * calls: memread memread
 */
static int test_memread_memread_pf8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_memread_pf8_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static void setup_memread_memread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memread_memread_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
static void setup_memread_memread_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_memread_pf8_0_final(void) {
  
}
static void setup_memread_memread_pf8_0_procfinal(void) {
  
}

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf8_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
static void setup_memread_memread_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf8_1_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf8_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
static void setup_memread_memread_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memread_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf8_2_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pf8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
static void setup_memread_memread_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_memread_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf8_3_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pf8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf8_4_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
static void setup_memread_memread_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memread_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf8_4_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pf8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf8_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pf8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
static void setup_memread_memread_pf8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_memread_pf8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf8_5_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pf8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
static int test_memread_memread_pf4_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
static void setup_memread_memread_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_memread_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x26000);
}
// static void setup_memread_memread_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
static void setup_memread_memread_pf4_0_final(void) {
  unlink("__i0");
}
// static void setup_memread_memread_pf4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf4_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_memread_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf4_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_memread_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pf4_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf4_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_memread_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pf4_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf0_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
static void setup_memread_memread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memread_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_memread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf0_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_memread_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf0_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_memread_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pf0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pf0_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_pf0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_memread_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
static int test_memread_memread_pe_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_memread_memread_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pe_0_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pe_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pe_0_1
// static void setup_memread_memread_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pe_1_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_pd8_0_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_pd8_1_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pd8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_pd8_2_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pd8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_pd8_3_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pd8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
static int test_memread_memread_pd4_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static void setup_memread_memread_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
static void setup_memread_memread_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_memread_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
static void setup_memread_memread_pd4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_memread_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd4_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
static void setup_memread_memread_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_memread_pd4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pd4_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd4_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
static void setup_memread_memread_pd4_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_memread_pd4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pd4_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_pd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pd0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pd0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pd0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_pd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pd0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
static int test_memread_memread_pc_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_memread_memread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pc_0_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_pc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static void setup_memread_memread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pc_1_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pbc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pbc_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memread_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pbc_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memread_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pbc_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pbc_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memread_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pbc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pbc_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pbc_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pbc_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memread_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pbc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pbc_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
static void setup_memread_memread_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_memread_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
  init_map_file(0x12345601000, 0, "__i1", 0x1e27000);
}
// static void setup_memread_memread_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
static void setup_memread_memread_pba_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_memread_memread_pba_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
static void setup_memread_memread_pba_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_memread_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
  init_map_file(0x12345601000, 1, "__i1", 0x1e27000);
}
// static void setup_memread_memread_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pba_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pba_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pba_1_common
static void setup_memread_memread_pba_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
  init_map_file(0x12345601000, 1, "__i1", 0x1e27000);
}
// static void setup_memread_memread_pba_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pba_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pba_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pba_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_memread_pba_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pba_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_4_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pba_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pba_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
  init_map_file(0x12345601000, 0, "__i0", 0x985000);
}
// static void setup_memread_memread_pba_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pba_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_5_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pba_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pba_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d5000);
  init_map_file(0x12345601000, 1, "__i0", 0x4d4000);
}
// static void setup_memread_memread_pba_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pba_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_6_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pba_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pba_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
  init_map_file(0x12345601000, 1, "__i0", 0x985000);
}
// static void setup_memread_memread_pba_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pba_6_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_pba_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pba_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_memread_memread_pba_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pba_7_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_8_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
static void setup_memread_memread_pba_8_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memread_pba_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
  init_map_file(0x12345601000, 0, "__i1", 0x4d5000);
}
// static void setup_memread_memread_pba_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_8_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pba_8_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_9_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pba_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pba_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e28000);
}
// static void setup_memread_memread_pba_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pba_9_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_10_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pba_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pba_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_memread_pba_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pba_10_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_11_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pba_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pba_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_memread_pba_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pba_11_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_12_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_12_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_pba_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pba_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_memread_pba_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pba_12_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pba_13_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pba_13_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_pba_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pba_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_memread_pba_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pba_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pba_13_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pb8_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
static void setup_memread_memread_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memread_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
  init_map_file(0x12345601000, 0, "__i1", 0x7000);
}
// static void setup_memread_memread_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pb8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pb8_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
static void setup_memread_memread_pb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memread_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
  init_map_file(0x12345601000, 1, "__i1", 0x5000);
}
// static void setup_memread_memread_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pb8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pb8_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_1_common
static void setup_memread_memread_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
  init_map_file(0x12345601000, 1, "__i1", 0x5000);
}
// static void setup_memread_memread_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pb8_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pb8_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d5000);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_memread_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pb8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pb8_4_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
static void setup_memread_memread_pb8_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memread_pb8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x3000);
  init_map_file(0x12345601000, 0, "__i1", 0x4000);
}
// static void setup_memread_memread_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pb8_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pb8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pb8_5_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
static void setup_memread_memread_pb8_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memread_pb8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 1, "__i0", 0x6000);
}
// static void setup_memread_memread_pb8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pb8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pb8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pb8_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pb8_6_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pb8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
static void setup_memread_memread_pb8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
  init_map_file(0x12345601000, 1, "__i0", 0x6000);
}
// static void setup_memread_memread_pb8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pb8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pb8_6_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pb8_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pb8_7_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_pb8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
static void setup_memread_memread_pb8_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 0, "__i0", 0x6000);
}
// static void setup_memread_memread_pb8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pb8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pb8_7_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pb0_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pe_0_1
// static void setup_memread_memread_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_memread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pb0_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pe_0_1
// static void setup_memread_memread_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memread_pba_13_proc0
// static void setup_memread_memread_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pac_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pac_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
// static void setup_memread_memread_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pac_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pac_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pac_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pac_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_memread_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pac_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pac_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pac_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_pac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memread_pba_13_proc0
// static void setup_memread_memread_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_pac_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pac_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pac_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pac_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_pac_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_memread_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_pac_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pac_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pba_8_common
// static void setup_memread_memread_paa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
static void setup_memread_memread_paa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x1e27000);
}
// static void setup_memread_memread_paa_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_paa_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pba_8_common
// static void setup_memread_memread_paa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
static void setup_memread_memread_paa_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x1e27000);
}
// static void setup_memread_memread_paa_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_paa_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
// static void setup_memread_memread_paa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
// static void setup_memread_memread_paa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memread_pac_1_proc0
// static void setup_memread_memread_paa_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_paa_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
static void setup_memread_memread_paa_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memread_paa_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x25000);
}
// static void setup_memread_memread_paa_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pac_3_proc0
// static void setup_memread_memread_paa_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_paa_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_paa_3_common
// static void setup_memread_memread_paa_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
// static void setup_memread_memread_paa_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
// static void setup_memread_memread_paa_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_paa_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_paa_3_common
// static void setup_memread_memread_paa_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
// static void setup_memread_memread_paa_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pac_3_proc0
// static void setup_memread_memread_paa_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_paa_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_1_common
static void setup_memread_memread_paa_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x25000);
}
static void setup_memread_memread_paa_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_memread_memread_paa_6_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_paa_6_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_paa_3_common
// static void setup_memread_memread_paa_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x25000);
// }
// ^ See setup_memread_memread_paa_6_proc0
// static void setup_memread_memread_paa_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
// static void setup_memread_memread_paa_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_paa_7_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_8_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_paa_3_common
// static void setup_memread_memread_paa_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pac_3_proc0
// static void setup_memread_memread_paa_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
// static void setup_memread_memread_paa_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_paa_8_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_9_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_1_common
static void setup_memread_memread_paa_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x27000);
}
static void setup_memread_memread_paa_9_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_memread_memread_paa_9_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_paa_9_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_10_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_paa_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x25000);
// }
// ^ See setup_memread_memread_paa_6_proc0
// static void setup_memread_memread_paa_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pac_3_proc0
// static void setup_memread_memread_paa_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_paa_10_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_paa_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_paa_11_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_paa_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_paa_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memread_pba_13_proc0
// static void setup_memread_memread_paa_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memread_pba_13_proc0
// static void setup_memread_memread_paa_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_paa_11_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pa8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_0_common
// static void setup_memread_memread_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
static void setup_memread_memread_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x7000);
}
// static void setup_memread_memread_pa8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pa8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pa8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_0_common
// static void setup_memread_memread_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
static void setup_memread_memread_pa8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
// static void setup_memread_memread_pa8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pa8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pa8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
static void setup_memread_memread_pa8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_memread_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
static void setup_memread_memread_pa8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_memread_memread_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pa8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pa8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pa8_2_common
static void setup_memread_memread_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x9000);
}
static void setup_memread_memread_pa8_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memread_memread_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pa8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pa8_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_0_common
// static void setup_memread_memread_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_memread_pa8_3_proc1
static void setup_memread_memread_pa8_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x6000);
}
// static void setup_memread_memread_pa8_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pa8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pa8_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_0_common
// static void setup_memread_memread_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_memread_pa8_3_proc1
static void setup_memread_memread_pa8_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
}
// static void setup_memread_memread_pa8_5_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pa8_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pa8_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pa8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
// static void setup_memread_memread_pa8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_memread_pa8_3_proc1
static void setup_memread_memread_pa8_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_memread_pa8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pa8_6_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pa8_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pa8_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_pa8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
// static void setup_memread_memread_pa8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_memread_pa8_3_proc1
static void setup_memread_memread_pa8_7_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_memread_pa8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pa8_7_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pa0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static void setup_memread_memread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
// static void setup_memread_memread_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static int test_memread_memread_pa0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static void setup_memread_memread_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pac_3_proc0
// static void setup_memread_memread_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9c_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memread_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9c_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_p9c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memread_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p9c_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9c_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9c_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p9c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_p9c_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memread_p9c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p9c_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9c_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9c_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p9c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_p9c_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memread_p9c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p9c_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9a_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pba_1_common
static void setup_memread_memread_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i1", 0x26000);
}
// static void setup_memread_memread_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9a_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
static void setup_memread_memread_p9a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memread_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 1, "__i1", 0x26000);
}
// static void setup_memread_memread_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9a_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_p9a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_p9a_1_common
static void setup_memread_memread_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
  init_map_file(0x12345601000, 1, "__i1", 0x26000);
}
// static void setup_memread_memread_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9a_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9a_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_p9a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_p9a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x26000);
}
// static void setup_memread_memread_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9a_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9a_4_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_p9a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pa8_2_common
static void setup_memread_memread_p9a_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
  init_map_file(0x12345601000, 1, "__i0", 0x9000);
}
// static void setup_memread_memread_p9a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p9a_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9a_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9a_5_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
static void setup_memread_memread_p9a_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_memread_p9a_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 0, "__i1", 0x9000);
}
// static void setup_memread_memread_p9a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9a_5_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p9a_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9a_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9a_6_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_p9a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
static void setup_memread_memread_p9a_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_file(0x12345601000, 1, "__i0", 0x7000);
}
// static void setup_memread_memread_p9a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9a_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p9a_6_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p9a_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p9a_7_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_p9a_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
static void setup_memread_memread_p9a_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_file(0x12345601000, 0, "__i0", 0x7000);
}
// static void setup_memread_memread_p9a_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p9a_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p9a_7_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p98_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
static void setup_memread_memread_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memread_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i1", 0x7000);
}
// static void setup_memread_memread_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p98_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p98_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_p98_0_common
static void setup_memread_memread_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i1", 0x7000);
}
// static void setup_memread_memread_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p98_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p98_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p98_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_p98_0_common
static void setup_memread_memread_p98_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i1", 0x7000);
}
// static void setup_memread_memread_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p98_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p98_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p98_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p98_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_p98_0_common
static void setup_memread_memread_p98_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i1", 0x7000);
}
// static void setup_memread_memread_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p98_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p98_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p98_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p98_4_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p98_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
static void setup_memread_memread_p98_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
  init_map_file(0x12345601000, 0, "__i0", 0x6000);
}
// static void setup_memread_memread_p98_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p98_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p98_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p98_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p98_5_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p98_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
static void setup_memread_memread_p98_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_file(0x12345601000, 1, "__i0", 0x6000);
}
// static void setup_memread_memread_p98_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p98_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p98_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p98_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p98_6_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p98_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
static void setup_memread_memread_p98_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
  init_map_file(0x12345601000, 1, "__i0", 0x6000);
}
// static void setup_memread_memread_p98_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p98_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p98_6_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p98_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p98_7_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p98_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
static void setup_memread_memread_p98_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_file(0x12345601000, 0, "__i0", 0x6000);
}
// static void setup_memread_memread_p98_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p98_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p98_7_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p98_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p98_8_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p98_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p98_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p98_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p98_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p98_8_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p98_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p98_9_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p98_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p98_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_p98_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p98_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p98_9_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p90_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pe_0_1
// static void setup_memread_memread_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p90_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pe_0_1
// static void setup_memread_memread_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8c_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8c_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_p8c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p8c_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8c_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8c_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p8c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p8c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p8c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_p8c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p8c_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8c_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8c_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p8c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p8c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_p8c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_p8c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p8c_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8a_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
static void setup_memread_memread_p8a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_memread_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x26000);
// }
// ^ See setup_memread_memread_paa_6_proc1
// static void setup_memread_memread_p8a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8a_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_p8a_0_common
// static void setup_memread_memread_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x26000);
// }
// ^ See setup_memread_memread_paa_9_proc1
// static void setup_memread_memread_p8a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8a_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p8a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p8a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memread_pb0_0_proc0
// static void setup_memread_memread_p8a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8a_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
static void setup_memread_memread_p8a_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_memread_memread_p8a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_memread_pd4_1_proc1
static void setup_memread_memread_p8a_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_memread_p8a_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8a_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8a_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_p8a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_p8a_3_common
// static void setup_memread_memread_p8a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_memread_pd4_1_proc1
static void setup_memread_memread_p8a_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_memread_p8a_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p8a_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8a_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8a_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_p8a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
// static void setup_memread_memread_p8a_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x6000);
// }
// ^ See setup_memread_memread_pa8_6_proc1
// static void setup_memread_memread_p8a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_memread_pa8_3_proc1
// static void setup_memread_memread_p8a_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p8a_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8a_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8a_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_p8a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
// static void setup_memread_memread_p8a_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_memread_memread_pa8_7_proc1
// static void setup_memread_memread_p8a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x7000);
// }
// ^ See setup_memread_memread_pa8_2_proc1
// static void setup_memread_memread_p8a_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p8a_6_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p8a_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p8a_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_p8a_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
// static void setup_memread_memread_p8a_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_memread_memread_pa8_7_proc1
// static void setup_memread_memread_p8a_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_memread_pa8_3_proc1
// static void setup_memread_memread_p8a_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p8a_7_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p88_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p88_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_p98_0_common
// static void setup_memread_memread_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x7000);
// }
// ^ See setup_memread_memread_pa8_0_proc1
// static void setup_memread_memread_p88_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p88_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p88_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p88_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_p98_0_common
// static void setup_memread_memread_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x7000);
// }
// ^ See setup_memread_memread_pa8_1_proc1
// static void setup_memread_memread_p88_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p88_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p88_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p88_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p88_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_paa_3_common
static void setup_memread_memread_p88_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x5000);
}
static void setup_memread_memread_p88_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x5000);
}
// static void setup_memread_memread_p88_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p88_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p88_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p88_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p88_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_paa_3_common
// static void setup_memread_memread_p88_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x5000);
// }
// ^ See setup_memread_memread_p88_2_proc1
static void setup_memread_memread_p88_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
}
// static void setup_memread_memread_p88_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p88_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p88_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p88_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p88_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_p98_0_common
// static void setup_memread_memread_p88_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_p88_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x7000);
// }
// ^ See setup_memread_memread_pa8_0_proc1
// static void setup_memread_memread_p88_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p88_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p88_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p88_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p88_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_paa_3_common
// static void setup_memread_memread_p88_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x5000);
// }
// ^ See setup_memread_memread_p88_3_proc1
// static void setup_memread_memread_p88_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x5000);
// }
// ^ See setup_memread_memread_p88_2_proc1
// static void setup_memread_memread_p88_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p88_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p88_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p88_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p88_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_p98_0_common
// static void setup_memread_memread_p88_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_p88_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x7000);
// }
// ^ See setup_memread_memread_pa8_1_proc1
// static void setup_memread_memread_p88_6_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memread_pba_0_final
// static void setup_memread_memread_p88_6_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p88_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p88_7_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p88_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pb8_5_common
// static void setup_memread_memread_p88_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_memread_memread_pa8_7_proc1
// static void setup_memread_memread_p88_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_memread_memread_pa8_7_proc1
// static void setup_memread_memread_p88_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p88_7_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p80_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p80_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static void setup_memread_memread_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p80_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p80_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static int test_memread_memread_p80_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static void setup_memread_memread_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p80_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p7_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p7_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
static void setup_memread_memread_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p7_0_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_p7_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p7_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p7_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
static void setup_memread_memread_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p7_1_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_p7_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p68_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x26000);
}
// static void setup_memread_memread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p68_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p68_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pf4_0_1
// static void setup_memread_memread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
static void setup_memread_memread_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_memread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p60_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_memread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p60_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p60_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_1
// static void setup_memread_memread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
static void setup_memread_memread_p60_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_memread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p4_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pe_0_1
// static void setup_memread_memread_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p4_0_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static void setup_memread_memread_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p4_1_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_p4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p3_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memread_pf8_3_proc0
// static void setup_memread_memread_p3_0_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_p3_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p3_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memread_pf8_5_proc0
// static void setup_memread_memread_p3_1_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_p3_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p28_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p28_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p28_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pd4_0_1
// static void setup_memread_memread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memread_pf4_0_common
// static void setup_memread_memread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p20_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_0_proc1
// static void setup_memread_memread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p20_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p20_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memread_pf8_0_0
// static void setup_memread_memread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memread_pf0_0_common
// static void setup_memread_memread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memread_pd4_3_proc1
// static void setup_memread_memread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memread_pf4_0_final
// static void setup_memread_memread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal

/*
 * calls: memread memread
 */
// static int test_memread_memread_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static int test_memread_memread_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memread_pc_0_1
// static void setup_memread_memread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_common
// static void setup_memread_memread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memread_pf8_0_proc1
// static void setup_memread_memread_p0_0_final(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal
// static void setup_memread_memread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memread_pf8_0_procfinal


/*
 * calls: memread memwrite
 */
static int test_memread_memwrite_pfe_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_memwrite_pfe_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static void setup_memread_memwrite_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memread_memwrite_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
static void setup_memread_memwrite_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_memwrite_pfe_0_final(void) {
  
}
static void setup_memread_memwrite_pfe_0_procfinal(void) {
  
}

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pfe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pfe_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
// static void setup_memread_memwrite_pfe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
static void setup_memread_memwrite_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memwrite_pfe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pfe_1_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pfe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pfe_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
static int test_memread_memwrite_pfe_2_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
// static void setup_memread_memwrite_pfe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
static void setup_memread_memwrite_pfe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_memwrite_pfe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pfe_2_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pfe_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pfa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
static int test_memread_memwrite_pfa_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
static void setup_memread_memwrite_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_memwrite_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x26000);
}
// static void setup_memread_memwrite_pfa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
static void setup_memread_memwrite_pfa_0_final(void) {
  unlink("__i0");
}
// static void setup_memread_memwrite_pfa_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pfa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pfa_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
// static void setup_memread_memwrite_pfa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pfa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_memwrite_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pfa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pfa_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pf8_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
static void setup_memread_memwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_memwrite_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pf8_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
// static void setup_memread_memwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
static void setup_memread_memwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_memwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
static int test_memread_memwrite_pf0_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_memread_memwrite_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
static void setup_memread_memwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pf0_0_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pf0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pf0_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_memwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pf0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
static int test_memread_memwrite_pf0_2_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_memread_memwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
static void setup_memread_memwrite_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_memwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pf0_2_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pf0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pf0_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
static void setup_memread_memwrite_pf0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pf0_3_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pf0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pf0_4_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pf0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pf0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_memwrite_pf0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pf0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pf0_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pe_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pe_0_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pe_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pe_1_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pdc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pdc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pdc_0_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pdc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pdc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pdc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pdc_1_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pdc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pda_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
static int test_memread_memwrite_pda_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static void setup_memread_memwrite_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
static void setup_memread_memwrite_pda_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_memwrite_pda_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pda_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pda_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pda_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
// static void setup_memread_memwrite_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pda_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_pda_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pda_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pd8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pd8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_pd8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pd8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pd0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
static void setup_memread_memwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_memwrite_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pd0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pd0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pd0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pd0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_pd0_2_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pd0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pd0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pd0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_pd0_3_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pd0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pc_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pc_0_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_pc_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pc_1_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
static int test_memread_memwrite_pbe_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_memwrite_pbe_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
// static void setup_memread_memwrite_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memwrite_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pbe_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbe_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
// static void setup_memread_memwrite_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memwrite_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pbe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbd_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbd_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
static void setup_memread_memwrite_pbd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_memwrite_pbd_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
  init_map_file(0x12345601000, 1, "__i1", 0x1e27000);
}
// static void setup_memread_memwrite_pbd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
static void setup_memread_memwrite_pbd_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_memread_memwrite_pbd_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbd_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbd_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
static void setup_memread_memwrite_pbd_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memwrite_pbd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
  init_map_file(0x12345601000, 1, "__i1", 0x1e27000);
}
// static void setup_memread_memwrite_pbd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbd_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_pbd_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbd_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbd_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
// static void setup_memread_memwrite_pbd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pbd_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
  init_map_file(0x12345601000, 1, "__i0", 0x985000);
}
// static void setup_memread_memwrite_pbd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbd_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pbd_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbd_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbd_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
// static void setup_memread_memwrite_pbd_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pbd_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e28000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_memwrite_pbd_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbd_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pbd_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbd_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbd_4_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
// static void setup_memread_memwrite_pbd_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pbd_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_memwrite_pbd_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbd_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pbd_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbd_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbd_5_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
// static void setup_memread_memwrite_pbd_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pbd_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_memwrite_pbd_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbd_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pbd_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbd_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbd_6_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
// static void setup_memread_memwrite_pbd_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pbd_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_memwrite_pbd_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbd_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pbd_6_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbc_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
static void setup_memread_memwrite_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memwrite_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
  init_map_file(0x12345601000, 1, "__i1", 0x7000);
}
// static void setup_memread_memwrite_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbc_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbc_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
static void setup_memread_memwrite_pbc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memwrite_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
  init_map_file(0x12345601000, 1, "__i1", 0x5000);
}
// static void setup_memread_memwrite_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbc_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbc_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbc_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
// static void setup_memread_memwrite_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
static void setup_memread_memwrite_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e28000);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_memwrite_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pbc_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pbc_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pbc_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
static void setup_memread_memwrite_pbc_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memwrite_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 1, "__i0", 0x6000);
}
// static void setup_memread_memwrite_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pbc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pbc_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pb8_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
  init_map_file(0x12345601000, 0, "__i0", 0x26000);
}
// static void setup_memread_memwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pb8_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memwrite_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pb8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_memwrite_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pb8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pb8_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_memwrite_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pb8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pb8_4_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pb8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pb8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memwrite_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pb8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pb0_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_memwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pb0_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memwrite_pbd_6_proc0
// static void setup_memread_memwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pae_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pae_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pb0_0_proc0
// static void setup_memread_memwrite_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pae_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pae_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pae_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_memwrite_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_pae_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pae_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pad_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pad_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
static void setup_memread_memwrite_pad_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_memwrite_pad_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pb0_0_proc0
static void setup_memread_memwrite_pad_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x1e27000);
}
// static void setup_memread_memwrite_pad_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_pad_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pad_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pad_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
// static void setup_memread_memwrite_pad_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pbc_3_common
// static void setup_memread_memwrite_pad_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pb0_0_proc0
// static void setup_memread_memwrite_pad_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memwrite_pbd_6_proc0
// static void setup_memread_memwrite_pad_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pad_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pad_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pad_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
// static void setup_memread_memwrite_pad_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pbc_1_common
static void setup_memread_memwrite_pad_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x25000);
}
static void setup_memread_memwrite_pad_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_memread_memwrite_pad_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_pad_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pad_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pad_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
// static void setup_memread_memwrite_pad_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pad_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pb0_0_proc0
// static void setup_memread_memwrite_pad_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pae_1_proc0
// static void setup_memread_memwrite_pad_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pad_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pad_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pad_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
// static void setup_memread_memwrite_pad_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pad_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x25000);
// }
// ^ See setup_memread_memwrite_pad_2_proc0
// static void setup_memread_memwrite_pad_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pae_1_proc0
// static void setup_memread_memwrite_pad_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pad_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pad_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pad_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
// static void setup_memread_memwrite_pad_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pad_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memwrite_pbd_6_proc0
// static void setup_memread_memwrite_pad_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memwrite_pbd_6_proc0
// static void setup_memread_memwrite_pad_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pad_5_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pac_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pac_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pbc_0_common
// static void setup_memread_memwrite_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pb0_0_proc0
static void setup_memread_memwrite_pac_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
// static void setup_memread_memwrite_pac_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_pac_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pac_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pac_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
static void setup_memread_memwrite_pac_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_memwrite_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pb0_0_proc0
static void setup_memread_memwrite_pac_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memread_memwrite_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pac_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pac_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pac_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pbc_0_common
static void setup_memread_memwrite_pac_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_memwrite_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x7000);
// }
// ^ See setup_memread_memwrite_pac_0_proc1
// static void setup_memread_memwrite_pac_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_pac_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pac_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pac_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pbc_3_common
// static void setup_memread_memwrite_pac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_memwrite_pac_1_proc1
// static void setup_memread_memwrite_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_memread_memwrite_pac_2_proc0
// static void setup_memread_memwrite_pac_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pac_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pa8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pb0_0_proc0
// static void setup_memread_memwrite_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pb0_0_proc0
// static void setup_memread_memwrite_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pa8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pa8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memwrite_pb8_2_proc0
// static void setup_memread_memwrite_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pa8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pa8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memwrite_pbd_6_proc0
// static void setup_memread_memwrite_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_memwrite_pb8_2_proc0
// static void setup_memread_memwrite_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pa8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pa8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pa8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pae_1_proc0
// static void setup_memread_memwrite_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pa0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pb0_0_proc0
// static void setup_memread_memwrite_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pbe_0_0
// static int test_memread_memwrite_pa0_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pae_1_proc0
// static void setup_memread_memwrite_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9e_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p9e_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
// static void setup_memread_memwrite_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
static void setup_memread_memwrite_p9e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memwrite_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p9e_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9e_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p9e_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
// static void setup_memread_memwrite_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
static void setup_memread_memwrite_p9e_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memwrite_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p9e_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9d_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p9d_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
static void setup_memread_memwrite_p9d_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_memwrite_p9d_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i1", 0x26000);
}
// static void setup_memread_memwrite_p9d_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9d_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_p9d_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9d_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p9d_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
static void setup_memread_memwrite_p9d_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memwrite_p9d_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
  init_map_file(0x12345601000, 1, "__i1", 0x26000);
}
// static void setup_memread_memwrite_p9d_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9d_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_p9d_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9d_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p9d_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
// static void setup_memread_memwrite_p9d_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
static void setup_memread_memwrite_p9d_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x1e28000);
}
// static void setup_memread_memwrite_p9d_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9d_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p9d_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9d_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p9d_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
// static void setup_memread_memwrite_p9d_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pbc_3_common
static void setup_memread_memwrite_p9d_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_file(0x12345601000, 1, "__i0", 0x7000);
}
// static void setup_memread_memwrite_p9d_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9d_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p9d_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9c8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
static int test_memread_memwrite_p9c8_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 1;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static void setup_memread_memwrite_p9c8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memwrite_p9c8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x1000);
}
// static void setup_memread_memwrite_p9c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9c8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p9c8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9c8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p9c8_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 1;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_p9c8_0_1
// static void setup_memread_memwrite_p9c8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_p9c8_0_common
static void setup_memread_memwrite_p9c8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_memwrite_p9c8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9c8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p9c8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9c8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p9c8_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
static void setup_memread_memwrite_p9c8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memwrite_p9c8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_memwrite_p9c8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9c8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p9c8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9c8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p9c8_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
// static void setup_memread_memwrite_p9c8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_p9c8_2_common
static void setup_memread_memwrite_p9c8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_memwrite_p9c8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9c8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p9c8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p9c8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p9c8_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_p9c8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_p9c8_2_common
// static void setup_memread_memwrite_p9c8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p9c8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p9c8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p9c8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p98_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
static void setup_memread_memwrite_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_memwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p98_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
static void setup_memread_memwrite_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_memwrite_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p98_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p98_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
static void setup_memread_memwrite_p98_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memwrite_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p98_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p98_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p98_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p98_3_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
static void setup_memread_memwrite_p98_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memwrite_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p98_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p98_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p98_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p98_4_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p98_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p98_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p98_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p98_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p98_4_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p90_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p90_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p8e_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p8e_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_p8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p8e_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p8e_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_p8e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p8e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p8e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_p8e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p8e_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p8d_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p8d_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
static void setup_memread_memwrite_p8d_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_memwrite_p8d_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p8d_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x26000);
// }
// ^ See setup_memread_memwrite_pad_2_proc1
// static void setup_memread_memwrite_p8d_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_p8d_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p8d_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p8d_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
// static void setup_memread_memwrite_p8d_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p8d_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p8d_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_memwrite_pae_1_proc0
// static void setup_memread_memwrite_p8d_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p8d_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p8d_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p8d_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
static void setup_memread_memwrite_p8d_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_memwrite_p8d_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
static void setup_memread_memwrite_p8d_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_memwrite_p8d_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memread_memwrite_pbd_0_final
// static void setup_memread_memwrite_p8d_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p8d_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p8d_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
// static void setup_memread_memwrite_p8d_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pbc_3_common
// static void setup_memread_memwrite_p8d_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_memread_memwrite_pac_2_proc0
// static void setup_memread_memwrite_p8d_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_memwrite_pac_1_proc1
// static void setup_memread_memwrite_p8d_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p8d_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p8c8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
static int test_memread_memwrite_p8c8_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 1;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
// static void setup_memread_memwrite_p8c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_p9c8_0_common
static void setup_memread_memwrite_p8c8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_memwrite_p8c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p8c8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p8c8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p8c8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p8c8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 1;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_p8c8_0_1
static void setup_memread_memwrite_p8c8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_memwrite_p8c8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_memread_memwrite_p8c8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_memwrite_p8d_2_proc0
// static void setup_memread_memwrite_p8c8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p8c8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p8c8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p8c8_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_p8c8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_p9c8_2_common
// static void setup_memread_memwrite_p8c8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p8c8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p8c8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p8c8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p8c8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p8c8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_p8c8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_p9c8_2_common
// static void setup_memread_memwrite_p8c8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p8c8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p8c8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p8c8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p88_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p88_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p88_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p88_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p88_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p88_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p88_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p88_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p88_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p88_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p88_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_p88_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p88_2_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p88_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p88_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p88_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p88_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p88_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_p88_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p88_3_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p80_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p80_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p80_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p80_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_0
// static int test_memread_memwrite_p80_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p80_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
static int test_memread_memwrite_p78_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_memwrite_p78_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
// static void setup_memread_memwrite_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
static void setup_memread_memwrite_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_memwrite_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p78_0_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_p78_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p74_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p74_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pfa_0_1
// static void setup_memread_memwrite_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_p74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x26000);
}
// static void setup_memread_memwrite_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p74_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p74_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p70_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_0_1
// static void setup_memread_memwrite_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
static void setup_memread_memwrite_p70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_memwrite_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p70_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p6_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
static void setup_memread_memwrite_p6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_memwrite_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p6_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p6_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
static void setup_memread_memwrite_p6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_memwrite_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p6_1_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_p6_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p4_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_0_1
// static void setup_memread_memwrite_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p4_0_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p4_1_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_p4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p38_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p38_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_memwrite_pfe_2_proc0
// static void setup_memread_memwrite_p38_0_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_p38_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p34_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p34_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pda_0_1
// static void setup_memread_memwrite_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p34_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p30_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memread_memwrite_pfe_2_1
// static void setup_memread_memwrite_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_memwrite_pf8_0_common
// static void setup_memread_memwrite_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pda_0_proc1
// static void setup_memread_memwrite_p30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p30_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p2_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p2_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_memwrite_pfa_0_common
// static void setup_memread_memwrite_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_memwrite_pd0_0_proc1
// static void setup_memread_memwrite_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_memwrite_pfa_0_final
// static void setup_memread_memwrite_p2_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p2_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p2_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_memwrite_pf0_2_proc0
// static void setup_memread_memwrite_p2_1_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_p2_1_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal

/*
 * calls: memread memwrite
 */
// static int test_memread_memwrite_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_p78_0_0
// static int test_memread_memwrite_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_memwrite_pf0_2_1
// static void setup_memread_memwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_common
// static void setup_memread_memwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_memwrite_pfe_0_proc1
// static void setup_memread_memwrite_p0_0_final(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal
// static void setup_memread_memwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_memwrite_pfe_0_procfinal


/*
 * calls: memread mmap
 */
static int test_memread_mmap_pfc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_mmap_pfc_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
static void setup_memread_mmap_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memread_mmap_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
static void setup_memread_mmap_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_mmap_pfc_0_final(void) {
  
}
static void setup_memread_mmap_pfc_0_procfinal(void) {
  
}

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pfc_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
static void setup_memread_mmap_pfc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_mmap_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
static void setup_memread_mmap_pfc_1_final(void) {
  unlink("__i0");
}
// static void setup_memread_mmap_pfc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pfc_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
static void setup_memread_mmap_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_mmap_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pfc_2_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pfc_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pfc_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pfc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pfc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_pfc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pfc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pfc_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pfc_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pfc_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
static void setup_memread_mmap_pfc_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_mmap_pfc_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pfc_4_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pfc_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pfc_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pfc_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
static void setup_memread_mmap_pfc_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_pfc_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pfc_5_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pfc_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pfc_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pfc_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pfc_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_pfc_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pfc_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pfc_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pfc_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pfc_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
static void setup_memread_mmap_pfc_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_pfc_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pfc_7_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pfc_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pfc_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pfc_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pfc_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_pfc_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pfc_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pfc_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pfc_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pfc_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
static void setup_memread_mmap_pfc_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_pfc_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pfc_9_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pfc_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pfc_10_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memread_mmap_pfc_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pfc_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pfc_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pfc_10_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pfc_10_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pfc_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pfc_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_10_1
// static void setup_memread_mmap_pfc_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pfc_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pfc_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pfc_11_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pfc_11_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pf6_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
static void setup_memread_mmap_pf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_mmap_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_mmap_pf6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_memread_mmap_pf6_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_memread_mmap_pf6_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
static void setup_memread_mmap_pf6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_mmap_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pf6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pf6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pf6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
static void setup_memread_mmap_pf6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_mmap_pf6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pf6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pf6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pf6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
static void setup_memread_mmap_pf6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_mmap_pf6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pf6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pf6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf5_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pf5_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memread_mmap_pf5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pf5_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_pf5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf5_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf5_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf5_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_pf5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pf5_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_pf5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf5_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf5_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf5_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_pf5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pf5_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_mmap_pf5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf5_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf5_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf5_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_pf5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pf5_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_pf5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf5_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf5_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf5_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_pf5_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pf5_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_mmap_pf5_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf5_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf5_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf5_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf5_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_pf5_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pf5_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_pf5_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf5_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf5_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf5_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf5_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_pf5_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pf5_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_pf5_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf5_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf5_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf5_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf5_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_pf5_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pf5_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_pf5_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf5_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf5_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf5_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf5_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_pf5_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pf5_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_pf5_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf5_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf5_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf5_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf5_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_pf5_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pf5_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_pf5_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf5_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf5_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf44_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pf44_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x6000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memread_mmap_pf44_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_mmap_pf44_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_mmap_pf44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf44_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf44_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf44_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf44_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x6000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_0_1
// static void setup_memread_mmap_pf44_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_0_common
static void setup_memread_mmap_pf44_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_mmap_pf44_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf44_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf44_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf44_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pf44_2_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memread_mmap_pf44_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_mmap_pf44_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pf5_2_proc0
// static void setup_memread_mmap_pf44_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf44_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf44_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf44_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf44_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_pf44_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_pf44_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pf5_4_proc0
// static void setup_memread_mmap_pf44_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf44_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pf44_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pf0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_memread_mmap_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf0_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pf0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pf0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pf0_1_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pec_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pec_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pec_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pec_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pec_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pec_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pec_1_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pec_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pec_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pec_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_pec_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pec_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pec_2_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pec_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pec_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pec_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_pec_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pec_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pec_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pec_3_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pec_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pe6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pe6_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_memread_mmap_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pf6_0_proc0
// static void setup_memread_mmap_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pe6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pe6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pe6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pe6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pf6_1_proc0
// static void setup_memread_mmap_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pe6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pe6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pe6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pe6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pe6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_pe6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pf6_2_proc0
// static void setup_memread_mmap_pe6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pe6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pe6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pe6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pe6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pe6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_pe6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pf6_3_proc0
// static void setup_memread_mmap_pe6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pe6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pe6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pe5_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pe5_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pe5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pe5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pf5_2_proc0
// static void setup_memread_mmap_pe5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pe5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pe5_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pe5_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pe5_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pe5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pe5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pf5_2_proc0
// static void setup_memread_mmap_pe5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pe5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pe5_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pe5_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pe5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_pe5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pe5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pf5_4_proc0
// static void setup_memread_mmap_pe5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pe5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pe5_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pe5_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pe5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_pe5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pe5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pf5_4_proc0
// static void setup_memread_mmap_pe5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pe5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pe5_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pe0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_pe0_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_memread_mmap_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pe0_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pe0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pe0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pe0_1_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pd8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_10_1
// static void setup_memread_mmap_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pd8_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pd8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_10_1
// static void setup_memread_mmap_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pd8_1_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pd8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pd6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pd6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
static void setup_memread_mmap_pd6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_mmap_pd6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_mmap_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pd6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pd6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
static void setup_memread_mmap_pd6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_mmap_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pd6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pd6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pd6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_pd6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pd6_0_proc0
static void setup_memread_mmap_pd6_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_mmap_pd6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pd6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pd6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pd6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pd6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_pd6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pd6_1_proc0
// static void setup_memread_mmap_pd6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_pd6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pd6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pd4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
static void setup_memread_mmap_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pd4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pd4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pd0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pd0_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pd0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pd0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pd0_1_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pcc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pcc_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pcc_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pcc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pcc_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_pcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pcc_1_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pcc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pcc_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pcc_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_pcc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pcc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pcc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pcc_2_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pcc_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pcc_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pcc_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_pcc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pcc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pcc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pcc_3_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pcc_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pc6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pc6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_pc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pd6_0_proc0
// static void setup_memread_mmap_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_pc6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pc6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pc6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pc6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pc6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_pc6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pd6_1_proc0
// static void setup_memread_mmap_pc6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_pc6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pc6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pc6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pc6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pc6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_pc6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pd6_0_proc0
// static void setup_memread_mmap_pc6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_pc6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pc6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pc6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pc6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pc6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_pc6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pd6_1_proc0
// static void setup_memread_mmap_pc6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_pc6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pc6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pc5_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pc5_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_pc5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pc5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pc5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_pc5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pc5_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pc5_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pc5_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_pc5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pc5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pc5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_pc5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pc5_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pc5_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pc5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_pc5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pc5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pc5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_pc5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pc5_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pc5_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pc5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_pc5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pc5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pc5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_pc5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pc5_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pc0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mmap_pfc_2_proc0
// static void setup_memread_mmap_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pc0_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pc0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_pc0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_pc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_pc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mmap_pfc_4_proc0
// static void setup_memread_mmap_pc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pc0_1_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_pc0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
static int test_memread_mmap_pbc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_mmap_pbc_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
  init_map_file(0x12345601000, 0, "__i0", 0x26000);
}
// static void setup_memread_mmap_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbc_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbc_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbc_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pbc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pbc_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbc_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbc_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pbc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pbc_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbc_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbc_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pbc_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pbc_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_pbc_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pbc_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pbc_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbc_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbc_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pbc_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pbc_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pbc_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pbc_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pbc_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbc_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbc_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pbc_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pbc_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_pbc_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pbc_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pbc_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbc_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbc_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pbc_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pbc_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pbc_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pbc_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pbc_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbc_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbc_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pbc_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pbc_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_pbc_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pbc_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pbc_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbc_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbc_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_pbc_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pbc_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_pbc_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pbc_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pbc_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbb_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbb_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
static void setup_memread_mmap_pbb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_mmap_pbb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_mmap_pbb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pbb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pbb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbb_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbb_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
static void setup_memread_mmap_pbb_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_mmap_pbb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pbb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pbb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pbb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbb_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbb_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pbb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_1_common
static void setup_memread_mmap_pbb_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pbb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pbb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pbb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pbb_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pbb_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pbb_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_0_common
static void setup_memread_mmap_pbb_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_mmap_pbb_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pbb_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pbb_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
static void setup_memread_mmap_pba8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_mmap_pba8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_memread_mmap_pba8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
static void setup_memread_mmap_pba8_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memread_mmap_pba8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_1_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memread_mmap_pba8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_mmap_pba8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_memread_mmap_pba8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pba8_0_final
// static void setup_memread_mmap_pba8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_2_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x4d5000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memread_mmap_pba8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5066752, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
  init_map_file(0x12345601000, 0, "__i0", 0x4d4000);
}
// static void setup_memread_mmap_pba8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_pba8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_mmap_pba8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_4_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memread_mmap_pba8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1e28000);
}
// static void setup_memread_mmap_pba8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_4_1
// static void setup_memread_mmap_pba8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e28000);
}
// static void setup_memread_mmap_pba8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_4_1
// static void setup_memread_mmap_pba8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e28000);
}
// static void setup_memread_mmap_pba8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_4_1
// static void setup_memread_mmap_pba8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
}
// static void setup_memread_mmap_pba8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_4_1
// static void setup_memread_mmap_pba8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1e28000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_pba8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_4_1
// static void setup_memread_mmap_pba8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1e28000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e28000);
}
// static void setup_memread_mmap_pba8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_4_1
// static void setup_memread_mmap_pba8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1e28000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_pba8_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_10_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_11_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memread_mmap_pba8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
// static void setup_memread_mmap_pba8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_11_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_12_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_11_1
// static void setup_memread_mmap_pba8_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8ea000);
}
// static void setup_memread_mmap_pba8_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_12_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_13_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_11_1
// static void setup_memread_mmap_pba8_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
  init_map_file(0x12345601000, 0, "__i0", 0x8ea000);
}
// static void setup_memread_mmap_pba8_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_13_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_14_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_11_1
// static void setup_memread_mmap_pba8_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
  init_map_file(0x12345601000, 1, "__i0", 0x8ea000);
}
// static void setup_memread_mmap_pba8_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_14_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_15_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_11_1
// static void setup_memread_mmap_pba8_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_pba8_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_15_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_16_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_11_1
// static void setup_memread_mmap_pba8_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_16_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_pba8_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_16_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_17_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_11_1
// static void setup_memread_mmap_pba8_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_17_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8ea000);
  init_map_file(0x12345601000, 0, "__i0", 0x8ea000);
}
// static void setup_memread_mmap_pba8_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_17_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_18_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_18_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x704000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memread_mmap_pba8_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x705000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_pba8_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_18_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_19_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_11_1
// static void setup_memread_mmap_pba8_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8ea000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_pba8_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_19_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_20_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_20_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e28000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memread_mmap_pba8_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_20_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pba8_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_20_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_21_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_21_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x4d4000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memread_mmap_pba8_21_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_mmap_pba8_21_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x4d5000);
}
// static void setup_memread_mmap_pba8_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_21_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pba8_0_final
// static void setup_memread_mmap_pba8_21_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_22_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_22_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x985000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memread_mmap_pba8_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_22_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x986000);
}
// static void setup_memread_mmap_pba8_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_22_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_23_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_11_1
// static void setup_memread_mmap_pba8_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_23_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8ea000);
  init_map_file(0x12345601000, 1, "__i0", 0x8ea000);
}
// static void setup_memread_mmap_pba8_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_23_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_24_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_11_1
// static void setup_memread_mmap_pba8_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_24_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8ea000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_pba8_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_24_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_25_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_25_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8ea000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memread_mmap_pba8_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pba8_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9347072, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
// }
// ^ See setup_memread_mmap_pba8_11_proc0
// static void setup_memread_mmap_pba8_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_25_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_25_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_26_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_26_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x20af000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memread_mmap_pba8_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pba8_0_common
static void setup_memread_mmap_pba8_26_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34271232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x20ae000);
}
// static void setup_memread_mmap_pba8_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_26_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pba8_0_final
// static void setup_memread_mmap_pba8_26_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_27_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_27_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_pba8_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_27_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_mmap_pba8_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_27_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_28_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_28_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e28000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_20_1
// static void setup_memread_mmap_pba8_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_28_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31621120, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pba8_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_28_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_29_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pba8_29_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x20ad000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memread_mmap_pba8_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_29_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
}
// static void setup_memread_mmap_pba8_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_29_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_29_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pba8_30_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pba8_30_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x985000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_22_1
// static void setup_memread_mmap_pba8_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pba8_30_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x985000);
}
// static void setup_memread_mmap_pba8_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pba8_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pba8_30_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_mmap_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_mmap_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_0_proc0
// static void setup_memread_mmap_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb6_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbc_3_proc0
// static void setup_memread_mmap_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb6_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_pb6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbc_1_proc0
// static void setup_memread_mmap_pb6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb6_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_pb6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_1_proc0
// static void setup_memread_mmap_pb6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb6_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb3_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pb3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_0_common
// static void setup_memread_mmap_pb3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pbb_0_proc0
// static void setup_memread_mmap_pb3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pb3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pb3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb3_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pb3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_1_common
// static void setup_memread_mmap_pb3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbb_1_proc0
// static void setup_memread_mmap_pb3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pb3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pb3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb3_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb3_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pb3_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_1_common
// static void setup_memread_mmap_pb3_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbb_2_proc0
// static void setup_memread_mmap_pb3_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pb3_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pb3_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb3_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb3_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pb3_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_0_common
// static void setup_memread_mmap_pb3_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pbb_3_proc0
// static void setup_memread_mmap_pb3_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_pb3_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pb3_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb28_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_pb28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pb28_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pb28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb28_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_pb28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_mmap_pba8_3_proc0
// static void setup_memread_mmap_pb28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pb28_2_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x705000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pb28_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pb28_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7360512, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
// static void setup_memread_mmap_pb28_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb28_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x705000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pb28_2_1
// static void setup_memread_mmap_pb28_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pb28_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7360512, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x704000);
}
// static void setup_memread_mmap_pb28_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pb28_4_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x705000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pb28_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb28_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7360512, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x704000);
// }
// ^ See setup_memread_mmap_pb28_2_proc0
// static void setup_memread_mmap_pb28_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pb28_5_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1c2000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pb28_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pb28_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 33169408, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1c1000);
}
// static void setup_memread_mmap_pb28_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb28_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x705000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pb28_4_1
// static void setup_memread_mmap_pb28_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb28_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7360512, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x704000);
// }
// ^ See setup_memread_mmap_pb28_3_proc0
// static void setup_memread_mmap_pb28_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pb28_7_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x20ad000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pb28_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pb28_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x20ad000);
}
// static void setup_memread_mmap_pb28_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pb28_8_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1c1000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pb28_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pb28_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1c1000);
}
// static void setup_memread_mmap_pb28_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb28_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x20ad000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pb28_7_1
// static void setup_memread_mmap_pb28_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pb28_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
}
// static void setup_memread_mmap_pb28_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pb28_10_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x20ad000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pb28_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb28_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x20ad000);
// }
// ^ See setup_memread_mmap_pb28_7_proc0
// static void setup_memread_mmap_pb28_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_10_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb28_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1c1000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pb28_8_1
// static void setup_memread_mmap_pb28_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pb28_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1c1000);
}
// static void setup_memread_mmap_pb28_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_11_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_12_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pb28_12_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1c1000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pb28_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb28_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x1c1000);
// }
// ^ See setup_memread_mmap_pb28_8_proc0
// static void setup_memread_mmap_pb28_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_12_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_13_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb28_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x20ad000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pb28_10_1
// static void setup_memread_mmap_pb28_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb28_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9347072, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
// }
// ^ See setup_memread_mmap_pba8_29_proc0
// static void setup_memread_mmap_pb28_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_13_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb28_14_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pb28_14_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x985000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pb28_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb28_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x985000);
// }
// ^ See setup_memread_mmap_pba8_30_proc0
// static void setup_memread_mmap_pb28_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb28_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb28_14_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_0_proc0
// static void setup_memread_mmap_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pb0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_1_proc0
// static void setup_memread_mmap_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pac_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pac_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_10_1
// static void setup_memread_mmap_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_0_proc0
// static void setup_memread_mmap_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pac_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pac_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pac_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_10_1
// static void setup_memread_mmap_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_1_proc0
// static void setup_memread_mmap_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pac_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pab_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pab_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pab_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_0_common
static void setup_memread_mmap_pab_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_mmap_pab_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_pab_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pab_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pab_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pab_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pab_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_1_common
static void setup_memread_mmap_pab_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pab_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_pab_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pab_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pab_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pab_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pab_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_1_common
static void setup_memread_mmap_pab_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_mmap_pab_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_pab_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pab_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pab_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pab_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_pab_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_0_common
static void setup_memread_mmap_pab_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_mmap_pab_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_pab_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pab_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_paa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_paa_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_paa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_0_proc0
static void setup_memread_mmap_paa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_paa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_paa_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_paa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_paa_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_paa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_paa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
static void setup_memread_mmap_paa_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_paa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_paa_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_paa_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_paa_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_paa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_paa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbc_3_proc0
static void setup_memread_mmap_paa_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_paa_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_paa_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_paa_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_paa_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_paa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_paa_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbc_3_proc0
static void setup_memread_mmap_paa_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_paa_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_paa_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_0_proc0
// static void setup_memread_mmap_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_1_proc0
// static void setup_memread_mmap_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_0_proc0
// static void setup_memread_mmap_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbc_3_proc0
// static void setup_memread_mmap_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pa6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa6_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_pa6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbc_1_proc0
// static void setup_memread_mmap_pa6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pa6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa6_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_pa6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_1_proc0
// static void setup_memread_mmap_pa6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pa6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa6_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa3_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pa3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_0_common
// static void setup_memread_mmap_pa3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pab_0_proc0
// static void setup_memread_mmap_pa3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_pa3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pa3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa3_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pa3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_1_common
// static void setup_memread_mmap_pa3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pab_1_proc0
// static void setup_memread_mmap_pa3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_pa3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pa3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa3_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa3_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pa3_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_1_common
// static void setup_memread_mmap_pa3_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pab_2_proc0
// static void setup_memread_mmap_pa3_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_pa3_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pa3_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa3_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa3_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_pa3_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pbb_0_common
// static void setup_memread_mmap_pa3_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pab_3_proc0
// static void setup_memread_mmap_pa3_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_pa3_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_pa3_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa28_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_pa28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_0_proc0
// static void setup_memread_mmap_pa28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_paa_0_proc1
// static void setup_memread_mmap_pa28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa28_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_pa28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pa28_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
static void setup_memread_mmap_pa28_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_pa28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa28_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_pa28_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa28_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_mmap_pa28_1_proc0
// static void setup_memread_mmap_pa28_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pa28_1_proc1
// static void setup_memread_mmap_pa28_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pa28_3_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x985000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pa28_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pa28_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
static void setup_memread_mmap_pa28_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9986048, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_pa28_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pa28_4_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x2297000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pa28_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pa28_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
static void setup_memread_mmap_pa28_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_pa28_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pa28_5_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x4d5000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pa28_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pa28_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
}
static void setup_memread_mmap_pa28_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_pa28_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa28_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_pa28_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pa28_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_mmap_pa28_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pa28_1_proc1
// static void setup_memread_mmap_pa28_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa28_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_pa28_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa28_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_mmap_pa28_6_proc0
// static void setup_memread_mmap_pa28_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pa28_1_proc1
// static void setup_memread_mmap_pa28_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pa28_8_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1e27000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pa28_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa28_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbc_3_proc0
// static void setup_memread_mmap_pa28_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_paa_0_proc1
// static void setup_memread_mmap_pa28_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pa28_9_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x4d4000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pa28_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa28_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
// }
// ^ See setup_memread_mmap_pa28_5_proc0
// static void setup_memread_mmap_pa28_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_paa_0_proc1
// static void setup_memread_mmap_pa28_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pa28_10_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pa28_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa28_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbc_1_proc0
// static void setup_memread_mmap_pa28_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_paa_0_proc1
// static void setup_memread_mmap_pa28_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_10_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
static int test_memread_mmap_pa28_11_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x4d4000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_pa28_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_pa28_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
// static void setup_memread_mmap_pa28_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_paa_0_proc1
// static void setup_memread_mmap_pa28_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_11_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_12_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa28_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pa28_10_1
// static void setup_memread_mmap_pa28_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa28_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mmap_pbc_3_proc0
static void setup_memread_mmap_pa28_12_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_pa28_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_12_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa28_13_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa28_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x4d4000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pa28_11_1
// static void setup_memread_mmap_pa28_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa28_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
// }
// ^ See setup_memread_mmap_pa28_5_proc0
// static void setup_memread_mmap_pa28_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_paa_0_proc1
// static void setup_memread_mmap_pa28_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa28_13_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_0_proc0
// static void setup_memread_mmap_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_pbc_0_0
// static int test_memread_mmap_pa0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_mmap_pb8_1_proc0
// static void setup_memread_mmap_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9f0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9f0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_10_1
// static void setup_memread_mmap_p9f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
static void setup_memread_mmap_p9f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9f0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9f0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9f0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_10_1
// static void setup_memread_mmap_p9f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
static void setup_memread_mmap_p9f0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_p9f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9f0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9c_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
static void setup_memread_mmap_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9c_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p9c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9c_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9c_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9c_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p9c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
static void setup_memread_mmap_p9c_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_p9c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9c_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9c_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9c_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p9c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p9c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p9c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9c_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9c_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9c_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p9c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
static void setup_memread_mmap_p9c_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_p9c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9c_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9c_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9c_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9c_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p9c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
static void setup_memread_mmap_p9c_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_p9c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9c_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9c_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9c_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9c_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p9c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
static void setup_memread_mmap_p9c_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_p9c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9c_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9c_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9c_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9c_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p9c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
static void setup_memread_mmap_p9c_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_p9c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9c_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9c_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9c_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9c_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p9c_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
static void setup_memread_mmap_p9c_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_p9c_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9c_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9c_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9c_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9c_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p9c_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
static void setup_memread_mmap_p9c_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_p9c_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9c_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9c_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9b_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9b_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
static void setup_memread_mmap_p9b_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_mmap_p9b_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_p9b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p9b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p9b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9b_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9b_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p9b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
static void setup_memread_mmap_p9b_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_p9b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p9b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p9b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9b_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9b_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p9b_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
static void setup_memread_mmap_p9b_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_p9b_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p9b_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p9b_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9b_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9b_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p9b_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
static void setup_memread_mmap_p9b_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_p9b_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p9b_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p9b_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x6000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_0_1
static void setup_memread_mmap_p9a4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_mmap_p9a4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_mmap_p9a4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pba8_0_final
// static void setup_memread_mmap_p9a4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x6000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_0_1
// static void setup_memread_mmap_p9a4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_0_common
static void setup_memread_mmap_p9a4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_mmap_p9a4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pba8_0_final
// static void setup_memread_mmap_p9a4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_1_1
static void setup_memread_mmap_p9a4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_mmap_p9a4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_mmap_p9a4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pba8_0_final
// static void setup_memread_mmap_p9a4_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pba8_1_1
// static void setup_memread_mmap_p9a4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_2_common
static void setup_memread_mmap_p9a4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_mmap_p9a4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pba8_0_final
// static void setup_memread_mmap_p9a4_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p9a4_4_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memread_mmap_p9a4_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_mmap_p9a4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x6000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_0_1
// static void setup_memread_mmap_p9a4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p9a4_6_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x3000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memread_mmap_p9a4_6_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_mmap_p9a4_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x4000);
}
// static void setup_memread_mmap_p9a4_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p9a4_7_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x4000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memread_mmap_p9a4_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_0_common
static void setup_memread_mmap_p9a4_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
  init_map_file(0x12345601000, 1, "__i0", 0x5000);
}
// static void setup_memread_mmap_p9a4_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
static void setup_memread_mmap_p9a4_8_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_mmap_p9a4_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_memread_mmap_p9a4_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p9a4_9_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memread_mmap_p9a4_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 1, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_10_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_11_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_12_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_12_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_13_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
  init_map_file(0x12345601000, 0, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_13_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_14_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_p9a4_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_14_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_15_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
  init_map_file(0x12345601000, 1, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_15_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_16_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_16_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_p9a4_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_16_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_17_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p9a4_17_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memread_mmap_p9a4_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_0_common
static void setup_memread_mmap_p9a4_17_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_file(0x12345601000, 0, "__i0", 0x6000);
}
// static void setup_memread_mmap_p9a4_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_17_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_18_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 0, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_18_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_19_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 0, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_19_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_20_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_20_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 1, "__i0", 0x7000);
}
// static void setup_memread_mmap_p9a4_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_20_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_21_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_17_1
// static void setup_memread_mmap_p9a4_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_0_common
static void setup_memread_mmap_p9a4_21_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_p9a4_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_21_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_22_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_17_1
// static void setup_memread_mmap_p9a4_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_0_common
static void setup_memread_mmap_p9a4_22_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_p9a4_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_22_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_23_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_23_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_p9a4_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_23_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_24_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_24_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_p9a4_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_24_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_25_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_25_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_25_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_p9a4_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_25_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_25_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_26_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_26_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_9_1
// static void setup_memread_mmap_p9a4_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p9a4_26_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_p9a4_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_26_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_27_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_27_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_4_1
// static void setup_memread_mmap_p9a4_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p9a4_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_9_proc0
// static void setup_memread_mmap_p9a4_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_27_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_28_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p9a4_28_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memread_mmap_p9a4_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_0_common
static void setup_memread_mmap_p9a4_28_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_mmap_p9a4_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_28_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_29_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_29_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_4_1
// static void setup_memread_mmap_p9a4_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p9a4_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_11_proc0
// static void setup_memread_mmap_p9a4_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_29_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_29_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p9a4_30_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p9a4_30_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p9a4_4_1
// static void setup_memread_mmap_p9a4_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p9a4_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_12_proc0
// static void setup_memread_mmap_p9a4_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p9a4_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p9a4_30_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p98_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p98_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p96_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p96_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p96_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p96_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p96_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p96_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_p96_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p96_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p96_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p96_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p96_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p96_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p96_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_p96_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p96_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p96_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p96_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p96_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p96_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p96_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_p96_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p96_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p96_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p96_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p96_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p93_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p93_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p93_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
// static void setup_memread_mmap_p93_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9b_0_proc0
// static void setup_memread_mmap_p93_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p93_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p93_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p93_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p93_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p93_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
// static void setup_memread_mmap_p93_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9b_1_proc0
// static void setup_memread_mmap_p93_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p93_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p93_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p93_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p93_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p93_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
// static void setup_memread_mmap_p93_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9b_2_proc0
// static void setup_memread_mmap_p93_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p93_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p93_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p93_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p93_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p93_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
// static void setup_memread_mmap_p93_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9b_3_proc0
// static void setup_memread_mmap_p93_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p93_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p93_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p928_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_p928_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_4_proc0
// static void setup_memread_mmap_p928_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p928_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x3000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_p928_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_6_common
static void setup_memread_mmap_p928_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x4000);
}
// static void setup_memread_mmap_p928_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p928_2_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x8000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_p928_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p928_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memread_mmap_p928_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p928_3_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x8000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_p928_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p928_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p928_2_proc0
// static void setup_memread_mmap_p928_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p928_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x8000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p928_2_1
// static void setup_memread_mmap_p928_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p928_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_9_proc0
// static void setup_memread_mmap_p928_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p928_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_p928_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_8_common
static void setup_memread_mmap_p928_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memread_mmap_p928_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p928_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_p928_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_8_common
// static void setup_memread_mmap_p928_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_memread_mmap_p928_5_proc0
// static void setup_memread_mmap_p928_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p928_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x8000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p928_2_1
// static void setup_memread_mmap_p928_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p928_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_12_proc0
// static void setup_memread_mmap_p928_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p928_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x8000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p928_3_1
// static void setup_memread_mmap_p928_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p928_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_12_proc0
// static void setup_memread_mmap_p928_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p928_9_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x7000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_p928_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p928_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_memread_mmap_p928_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p928_10_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x7000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_p928_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p928_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_9_proc0
// static void setup_memread_mmap_p928_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_10_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p928_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x7000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p928_9_1
// static void setup_memread_mmap_p928_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p928_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_9_proc0
// static void setup_memread_mmap_p928_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_11_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_12_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p928_12_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x6000UL);
  
  return xerrno(r);
}
static void setup_memread_mmap_p928_12_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_mmap_p928_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
}
// static void setup_memread_mmap_p928_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_12_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_13_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p928_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x7000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p928_10_1
// static void setup_memread_mmap_p928_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p928_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_12_proc0
// static void setup_memread_mmap_p928_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_13_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_14_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
static int test_memread_mmap_p928_14_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x6000UL);
  
  return xerrno(r);
}
// static void setup_memread_mmap_p928_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p928_12_common
// static void setup_memread_mmap_p928_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x5000);
// }
// ^ See setup_memread_mmap_p928_12_proc0
// static void setup_memread_mmap_p928_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_14_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p928_15_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p928_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x7000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p928_9_1
// static void setup_memread_mmap_p928_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p928_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p9a4_12_proc0
// static void setup_memread_mmap_p928_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p928_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p928_15_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p90_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p90_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p8c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p8c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_10_1
// static void setup_memread_mmap_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p8c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p8c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_10_1
// static void setup_memread_mmap_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p8c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p8c_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p8b_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p8b_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p8b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
static void setup_memread_mmap_p8b_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_p8b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_p8b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p8b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p8b_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p8b_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p8b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
static void setup_memread_mmap_p8b_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_p8b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_p8b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p8b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p8b_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p8b_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p8b_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
// static void setup_memread_mmap_p8b_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p8b_0_proc0
// static void setup_memread_mmap_p8b_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_p8b_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p8b_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p8b_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p8b_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p8b_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
// static void setup_memread_mmap_p8b_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p8b_1_proc0
// static void setup_memread_mmap_p8b_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_p8b_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p8b_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p8a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p8a_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pa28_12_proc1
// static void setup_memread_mmap_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p8a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p8a_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pa28_12_proc1
// static void setup_memread_mmap_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p8a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p8a_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p8a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p8a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p8a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p8a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p8a_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p8a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p8a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p8a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p88_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p88_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p88_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p88_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p88_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p88_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p86_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p86_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_p86_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p86_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p86_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p86_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p86_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p86_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p86_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_p86_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p86_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p86_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p86_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p86_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p86_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p86_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_p86_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p86_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p86_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p86_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p86_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p86_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p86_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_p86_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p86_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p86_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p86_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p86_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p83_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p83_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p83_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
// static void setup_memread_mmap_p83_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p8b_0_proc0
// static void setup_memread_mmap_p83_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_p83_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p83_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p83_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p83_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p83_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
// static void setup_memread_mmap_p83_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p8b_1_proc0
// static void setup_memread_mmap_p83_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_p83_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p83_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p83_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p83_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p83_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
// static void setup_memread_mmap_p83_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p8b_0_proc0
// static void setup_memread_mmap_p83_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_p83_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p83_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p83_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p83_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p83_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_p9b_0_common
// static void setup_memread_mmap_p83_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p8b_1_proc0
// static void setup_memread_mmap_p83_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_p83_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p83_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_p828_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p828_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p828_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pa28_12_proc1
// static void setup_memread_mmap_p828_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_p828_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p828_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p828_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pa28_12_proc1
// static void setup_memread_mmap_p828_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_p828_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p828_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p828_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pa28_12_proc1
// static void setup_memread_mmap_p828_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_p828_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p828_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p828_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pa28_12_proc1
// static void setup_memread_mmap_p828_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pa28_8_1
// static void setup_memread_mmap_p828_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p828_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p828_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_paa_3_proc1
// static void setup_memread_mmap_p828_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_p828_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p828_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p828_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p828_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x8000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p928_2_1
// static void setup_memread_mmap_p828_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p828_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
static void setup_memread_mmap_p828_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_mmap_p828_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_p828_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p828_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p828_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p828_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x8000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p928_3_1
// static void setup_memread_mmap_p828_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
static void setup_memread_mmap_p828_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_memread_mmap_p828_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_p828_6_proc1
// static void setup_memread_mmap_p828_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_p828_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p828_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p828_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p828_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x8000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_p928_3_1
// static void setup_memread_mmap_p828_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_p9a4_4_common
// static void setup_memread_mmap_p828_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_mmap_p828_6_proc0
// static void setup_memread_mmap_p828_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_p828_6_proc1
// static void setup_memread_mmap_p828_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_10_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p828_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p828_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_p828_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p828_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p828_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p828_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p828_11_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p80_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p80_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_0_proc0
// static void setup_memread_mmap_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p80_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p80_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mmap_pfc_0_0
// static int test_memread_mmap_p80_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mmap_pf44_2_common
// static void setup_memread_mmap_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mmap_p9f0_1_proc0
// static void setup_memread_mmap_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p80_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
static int test_memread_mmap_p70_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_mmap_p70_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p70_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p70_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p70_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p70_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_p70_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_p70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p70_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p70_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p70_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p70_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
static void setup_memread_mmap_p70_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_p70_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p70_2_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p70_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p70_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p70_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p70_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_p70_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_p70_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p70_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p70_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p70_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p70_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_0_1
// static void setup_memread_mmap_p70_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
static void setup_memread_mmap_p70_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_p70_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p70_4_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p70_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p6c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p6c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_p6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p6c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p6c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_p6c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_p6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p6c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p6c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p68_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p68_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p68_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mmap_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p68_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p68_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p68_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_p68_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_p68_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mmap_p68_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p68_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p68_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p68_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p68_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_p68_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_p68_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mmap_p68_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p68_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p68_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p68_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p68_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf5_0_1
// static void setup_memread_mmap_p68_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
static void setup_memread_mmap_p68_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mmap_p68_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p68_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p68_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p60_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p60_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p54_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p54_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p54_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p54_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p54_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p54_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_p54_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_p54_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p54_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p54_1_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p54_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p4c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p4c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p4c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p4c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p4c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p4c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_p4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_p4c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p4c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p4c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p49_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p49_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_p49_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_p49_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p49_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p49_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p49_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p49_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p49_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_p49_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_p49_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p49_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p49_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p49_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p40_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p40_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_p40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p40_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p40_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p30_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pfc_10_1
// static void setup_memread_mmap_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p30_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p30_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p2c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p2c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_p2c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p2c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p2c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p2c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf6_0_1
// static void setup_memread_mmap_p2c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_p2c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p2c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_p2c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p2c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p28_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf44_2_1
// static void setup_memread_mmap_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p20_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pf0_0_1
// static void setup_memread_mmap_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p20_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p18_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_0_1
// static void setup_memread_mmap_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p18_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p18_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p18_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pec_1_1
// static void setup_memread_mmap_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p18_1_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p18_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p0c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p0c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_0_proc1
// static void setup_memread_mmap_p0c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p0c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p0c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p0c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe6_0_1
// static void setup_memread_mmap_p0c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_mmap_pf6_0_common
// static void setup_memread_mmap_p0c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pf6_0_proc1
// static void setup_memread_mmap_p0c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_mmap_pd6_2_proc1
// static void setup_memread_mmap_p0c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_final
// static void setup_memread_mmap_p0c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_mmap_pf6_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p0a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p0a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_0_1
// static void setup_memread_mmap_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p0a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p0a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe5_1_1
// static void setup_memread_mmap_p0a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mmap_pfc_1_common
// static void setup_memread_mmap_p0a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p0a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_mmap_pd4_0_proc1
// static void setup_memread_mmap_p0a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mmap_pfc_1_final
// static void setup_memread_mmap_p0a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal

/*
 * calls: memread mmap
 */
// static int test_memread_mmap_p00_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mmap_p70_0_0
// static int test_memread_mmap_p00_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_mmap_pe0_0_1
// static void setup_memread_mmap_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_common
// static void setup_memread_mmap_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mmap_pfc_0_proc1
// static void setup_memread_mmap_p00_0_final(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal
// static void setup_memread_mmap_p00_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mmap_pfc_0_procfinal


/*
 * calls: memread mprotect
 */
static int test_memread_mprotect_pf_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_mprotect_pf_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memread_mprotect_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memread_mprotect_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
static void setup_memread_mprotect_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_mprotect_pf_0_final(void) {
  
}
static void setup_memread_mprotect_pf_0_procfinal(void) {
  
}

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pf_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pf_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
static void setup_memread_mprotect_pf_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_mprotect_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mprotect_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
static void setup_memread_mprotect_pf_1_final(void) {
  unlink("__i0");
}
// static void setup_memread_mprotect_pf_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pf_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pf_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
static void setup_memread_mprotect_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mprotect_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pf_2_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pf_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pf_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pf_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
static void setup_memread_mprotect_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mprotect_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pf_3_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pf_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pf_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pf_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pf_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mprotect_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pf_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pf_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pf_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
static int test_memread_mprotect_pf_5_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_memread_mprotect_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
static void setup_memread_mprotect_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_mprotect_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pf_5_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pf_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pf_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pf_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pf_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pf_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mprotect_pf_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pf_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pf_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pf_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pf_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pf_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
static void setup_memread_mprotect_pf_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_mprotect_pf_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pf_7_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pf_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
static int test_memread_mprotect_pe_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_memread_mprotect_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pe_0_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pe_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pe_0_1
// static void setup_memread_mprotect_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pe_1_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pd_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pd_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pd_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pd_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
static void setup_memread_mprotect_pd_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_mprotect_pd_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pd_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pd_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pd_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pd_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_pd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_pd_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pd_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pd_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pd_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_pd_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_pd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_pd_2_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pd_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pd_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pd_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pd_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_pd_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_pd_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_pd_3_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pd_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pd_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pd_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pd_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pd_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
static void setup_memread_mprotect_pd_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_mprotect_pd_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pd_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pd_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pd_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pd_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_pd_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_pd_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_pd_5_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pd_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pd_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pd_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pd_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pd_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_pd_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_pd_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pd_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pd_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pd_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pd_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_pd_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_pd_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_pd_7_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pd_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
static int test_memread_mprotect_pc_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_memread_mprotect_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pc_0_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_pc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pc_0_1
// static void setup_memread_mprotect_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pc_1_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
static int test_memread_mprotect_pb8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_mprotect_pb8_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
  init_map_file(0x12345601000, 0, "__i0", 0x26000);
}
// static void setup_memread_mprotect_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb8_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_mprotect_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb8_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_mprotect_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb8_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mprotect_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb8_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pb8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mprotect_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb8_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pb8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_mprotect_pb8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb8_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb8_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pb8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_mprotect_pb8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb8_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb8_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb8_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pb8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb8_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mprotect_pb8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb8_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb8_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb8_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_pb8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb8_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mprotect_pb8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb8_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb8_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb8_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pb8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb8_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_mprotect_pb8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb8_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb0_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pe_0_1
// static void setup_memread_mprotect_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_mprotect_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pb0_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pe_0_1
// static void setup_memread_mprotect_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_mprotect_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pa8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mprotect_pb0_0_proc0
// static void setup_memread_mprotect_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mprotect_pb0_0_proc0
// static void setup_memread_mprotect_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pa8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pa8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mprotect_pb8_5_proc0
// static void setup_memread_mprotect_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pa8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pa8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mprotect_pb8_5_proc0
// static void setup_memread_mprotect_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mprotect_pb0_1_proc0
// static void setup_memread_mprotect_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pa8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pa8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pa8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mprotect_pb8_5_proc0
// static void setup_memread_mprotect_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pa8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pa8_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mprotect_pb0_1_proc0
// static void setup_memread_mprotect_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mprotect_pb8_5_proc0
// static void setup_memread_mprotect_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pa8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pa8_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mprotect_pb0_1_proc0
// static void setup_memread_mprotect_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mprotect_pb0_1_proc0
// static void setup_memread_mprotect_pa8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pa8_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pa8_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pa8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pa8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_mprotect_pb0_1_proc0
// static void setup_memread_mprotect_pa8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_pa8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pa8_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pa8_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pa8_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_pa8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pa8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_mprotect_pb8_9_proc0
// static void setup_memread_mprotect_pa8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_pa8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pa8_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pa0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pc_0_1
// static void setup_memread_mprotect_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_mprotect_pb0_0_proc0
// static void setup_memread_mprotect_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_pb8_0_0
// static int test_memread_mprotect_pa0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pc_0_1
// static void setup_memread_mprotect_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_mprotect_pb8_9_proc0
// static void setup_memread_mprotect_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p98_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
static void setup_memread_mprotect_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_mprotect_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mprotect_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p98_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
static void setup_memread_mprotect_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mprotect_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p98_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p98_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
static void setup_memread_mprotect_p98_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mprotect_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p98_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p98_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p98_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p98_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
static void setup_memread_mprotect_p98_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mprotect_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p98_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p98_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p98_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p98_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p98_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
static void setup_memread_mprotect_p98_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mprotect_p98_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p98_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p98_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p98_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p98_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p98_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
static void setup_memread_mprotect_p98_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mprotect_p98_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p98_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p98_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p98_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p98_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p98_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
static void setup_memread_mprotect_p98_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mprotect_p98_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p98_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p98_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p98_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p98_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p98_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
static void setup_memread_mprotect_p98_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mprotect_p98_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p98_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p98_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p98_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p98_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p98_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p98_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_p98_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p98_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p98_8_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p98_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p98_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p98_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p98_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_p98_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p98_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p98_9_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p90_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pe_0_1
// static void setup_memread_mprotect_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p90_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pe_0_1
// static void setup_memread_mprotect_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p88_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p88_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p88_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p88_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p88_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p88_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p88_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p88_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p88_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p88_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_p88_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_p88_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p88_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p88_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p88_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p88_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p88_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_p88_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_p88_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p88_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p88_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p88_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p88_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p88_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_p88_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_p88_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p88_4_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p88_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p88_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p88_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p88_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_p88_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_p88_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p88_5_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p88_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p88_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p88_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p88_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_p88_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_p88_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p88_6_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p88_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p88_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p88_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p88_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_p88_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_p88_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p88_7_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p80_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p80_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pc_0_1
// static void setup_memread_mprotect_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p80_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p80_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_mprotect_pf_0_0
// static int test_memread_mprotect_p80_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pc_0_1
// static void setup_memread_mprotect_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_mprotect_p98_0_common
// static void setup_memread_mprotect_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p80_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
static int test_memread_mprotect_p6_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_mprotect_p6_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_p6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_mprotect_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p6_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_p6_0_0
// static int test_memread_mprotect_p6_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
static void setup_memread_mprotect_p6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_mprotect_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p6_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_p6_0_0
// static int test_memread_mprotect_p6_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
static void setup_memread_mprotect_p6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_mprotect_p6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p6_2_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_p6_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_p6_0_0
// static int test_memread_mprotect_p6_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_0_1
// static void setup_memread_mprotect_p6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
static void setup_memread_mprotect_p6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_mprotect_p6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p6_3_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_p6_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_p6_0_0
// static int test_memread_mprotect_p4_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pe_0_1
// static void setup_memread_mprotect_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p4_0_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_p6_0_0
// static int test_memread_mprotect_p4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pc_0_1
// static void setup_memread_mprotect_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p4_1_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_p4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p2_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_p6_0_0
// static int test_memread_mprotect_p2_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_0_proc1
// static void setup_memread_mprotect_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p2_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p2_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_p6_0_0
// static int test_memread_mprotect_p2_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_mprotect_pf_5_proc0
// static void setup_memread_mprotect_p2_1_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_p2_1_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p2_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_p6_0_0
// static int test_memread_mprotect_p2_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_mprotect_pf_1_common
// static void setup_memread_mprotect_p2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_mprotect_pd_4_proc1
// static void setup_memread_mprotect_p2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_mprotect_pf_1_final
// static void setup_memread_mprotect_p2_2_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p2_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_p6_0_0
// static int test_memread_mprotect_p2_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pf_5_1
// static void setup_memread_mprotect_p2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_p2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_mprotect_pf_7_proc0
// static void setup_memread_mprotect_p2_3_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_p2_3_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal

/*
 * calls: memread mprotect
 */
// static int test_memread_mprotect_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_mprotect_p6_0_0
// static int test_memread_mprotect_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memread_mprotect_pc_0_1
// static void setup_memread_mprotect_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_common
// static void setup_memread_mprotect_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_mprotect_pf_0_proc1
// static void setup_memread_mprotect_p0_0_final(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal
// static void setup_memread_mprotect_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_mprotect_pf_0_procfinal


/*
 * calls: memread munmap
 */
static int test_memread_munmap_pf_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_munmap_pf_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memread_munmap_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memread_munmap_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
static void setup_memread_munmap_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_munmap_pf_0_final(void) {
  
}
static void setup_memread_munmap_pf_0_procfinal(void) {
  
}

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pf_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_pf_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_common
static void setup_memread_munmap_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_munmap_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pf_1_final(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal
// static void setup_memread_munmap_pf_1_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pf_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_pf_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_common
static void setup_memread_munmap_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_munmap_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pf_2_final(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal
// static void setup_memread_munmap_pf_2_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pf_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_pf_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_common
static void setup_memread_munmap_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_munmap_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pf_3_final(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal
// static void setup_memread_munmap_pf_3_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pf_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_pf_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
static void setup_memread_munmap_pf_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_munmap_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_munmap_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
static void setup_memread_munmap_pf_4_final(void) {
  unlink("__i0");
}
// static void setup_memread_munmap_pf_4_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pf_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_pf_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_munmap_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pf_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pf_5_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pf_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_pf_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pf_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_common
static void setup_memread_munmap_pf_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_munmap_pf_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pf_6_final(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal
// static void setup_memread_munmap_pf_6_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pf_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_pf_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pf_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_common
static void setup_memread_munmap_pf_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_munmap_pf_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pf_7_final(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal
// static void setup_memread_munmap_pf_7_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pf_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_pf_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pf_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pf_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_munmap_pf_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pf_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pf_8_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pf_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_pf_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pf_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pf_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_munmap_pf_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pf_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pf_9_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
static int test_memread_munmap_pc_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_memread_munmap_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_common
// static void setup_memread_munmap_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_munmap_pf_1_proc0
// static void setup_memread_munmap_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pc_0_final(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal
// static void setup_memread_munmap_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_pc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pc_0_1
// static void setup_memread_munmap_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_common
// static void setup_memread_munmap_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_munmap_pf_3_proc0
// static void setup_memread_munmap_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pc_1_final(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal
// static void setup_memread_munmap_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
static int test_memread_munmap_pb8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_munmap_pb8_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_munmap_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pb8_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_munmap_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pb8_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_file(0x12345601000, 1, "__i0", 0x1000);
}
// static void setup_memread_munmap_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pb8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pb8_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
  init_map_file(0x12345601000, 1, "__i0", 0x1000);
}
// static void setup_memread_munmap_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pb8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pb8_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pb8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pb8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_file(0x12345601000, 0, "__i0", 0x1000);
}
// static void setup_memread_munmap_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pb8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pb8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pb8_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pb8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pb8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_munmap_pb8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pb8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pb8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pb8_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pb8_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pb8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pb8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_munmap_pb8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pb8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pb8_6_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pb8_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pb8_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pb8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pb8_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_munmap_pb8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pb8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pb8_7_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pb8_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pb8_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pb8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pb8_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_munmap_pb8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pb8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pb8_8_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pb8_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pb8_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_pb8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pb8_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_munmap_pb8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pb8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pb8_9_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pa_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pc_0_1
// static void setup_memread_munmap_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_munmap_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_pb8_0_0
// static int test_memread_munmap_pa_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pc_0_1
// static void setup_memread_munmap_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_munmap_pf_4_common
static void setup_memread_munmap_pa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_munmap_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p98_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
static void setup_memread_munmap_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_munmap_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_munmap_pb8_0_proc0
// static void setup_memread_munmap_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p98_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
// static void setup_memread_munmap_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_munmap_pa_0_proc0
// static void setup_memread_munmap_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p98_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p98_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
static void setup_memread_munmap_p98_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_munmap_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p98_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p98_2_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p98_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p98_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
// static void setup_memread_munmap_p98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_munmap_pa_1_proc0
// static void setup_memread_munmap_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p98_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p98_3_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p98_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p98_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_p98_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
static void setup_memread_munmap_p98_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memread_munmap_p98_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p98_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p98_4_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p98_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p98_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_p98_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
static void setup_memread_munmap_p98_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_munmap_p98_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p98_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p98_5_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p98_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p98_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_p98_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
static void setup_memread_munmap_p98_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_munmap_p98_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p98_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p98_6_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p98_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p98_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_p98_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
static void setup_memread_munmap_p98_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memread_munmap_p98_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p98_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p98_7_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p98_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p98_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_p98_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
static void setup_memread_munmap_p98_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memread_munmap_p98_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p98_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p98_8_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p98_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p98_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pf_0_1
// static void setup_memread_munmap_p98_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
static void setup_memread_munmap_p98_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memread_munmap_p98_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p98_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p98_9_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pc_0_1
// static void setup_memread_munmap_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
// static void setup_memread_munmap_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_munmap_pa_0_proc0
// static void setup_memread_munmap_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_munmap_pf_0_0
// static int test_memread_munmap_p8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pc_0_1
// static void setup_memread_munmap_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_munmap_p98_0_common
// static void setup_memread_munmap_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_munmap_pa_1_proc0
// static void setup_memread_munmap_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_munmap_pf_4_final
// static void setup_memread_munmap_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
static int test_memread_munmap_p4_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_munmap_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pc_0_1
// static void setup_memread_munmap_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_common
// static void setup_memread_munmap_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p4_0_final(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal
// static void setup_memread_munmap_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal

/*
 * calls: memread munmap
 */
// static int test_memread_munmap_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_munmap_p4_0_0
// static int test_memread_munmap_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_munmap_pc_0_1
// static void setup_memread_munmap_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_common
// static void setup_memread_munmap_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_munmap_pf_0_proc1
// static void setup_memread_munmap_p0_0_final(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal
// static void setup_memread_munmap_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_munmap_pf_0_procfinal


/*
 * calls: memread open
 */
static int test_memread_open_pf8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_open_pf8_0_1(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_memread_open_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memread_open_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_open_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_open_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_memread_open_pf8_0_procfinal(void) {
  
}

/*
 * calls: memread open
 */
// static int test_memread_open_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pf8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memread_open_pf8_0_1
// static void setup_memread_open_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
static void setup_memread_open_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_open_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pf70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
static int test_memread_open_pf70_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_memread_open_pf70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memread_open_pf70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pf70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pf70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pf70_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pf70_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pf70_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pf70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pf70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pf70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pf70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pf70_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pf50_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pf50_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pf50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pf50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pf50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pf50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pf50_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pf50_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pf50_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pf50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pf50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pf50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pf50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pf50_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pf3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
static int test_memread_open_pf3_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_memread_open_pf3_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memread_open_pf3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pf3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pf3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pf3_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pf3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pf3_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pf3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_pf3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pf3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pf3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pf3_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pf1_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pf1_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pf1_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_pf1_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pf1_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pf1_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pf1_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pf1_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pf1_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pf1_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_pf1_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pf1_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pf1_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pf1_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pee_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pee_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
static void setup_memread_open_pee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_memread_open_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pee_0_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_pee_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pee_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pee_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pee_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_pee_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pee_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pee_1_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_pee_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pea_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pea_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pea_0_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_pea_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pea_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pea_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pea_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_pea_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pea_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pea_1_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_pea_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pe6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pe6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pe6_0_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_pe6_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pe6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pe6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pe6_1_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_pe6_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pe2_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pe2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pe2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_pe2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pe2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pe2_0_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_pe2_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pe2_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pe2_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pe2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_pe2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pe2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pe2_1_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_pe2_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pde_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
static int test_memread_open_pde_0_1(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_memread_open_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf70_0_common
// static void setup_memread_open_pde_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pde_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pde_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pde_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pde_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pde_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pde_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pde_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pda_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pda_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pda_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pda_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pda_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pda_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
static void setup_memread_open_pda_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memread_open_pda_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pda_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pda_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pd6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
static int test_memread_open_pd6_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_memread_open_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pd6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pd6_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pd6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pd6_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pd6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pd6_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pd2_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pd2_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pd2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pd2_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pd2_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pd2_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_pd2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_pd2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pd2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pd2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pd2_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
static int test_memread_open_pc_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_memread_open_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_open_pf8_0_proc0
// static void setup_memread_open_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pc_0_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_pc_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_open_pc_0_1
// static void setup_memread_open_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_open_pf8_1_proc0
// static void setup_memread_open_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pc_1_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
static int test_memread_open_pbc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_open_pbc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memread_open_pf8_0_1
// static void setup_memread_open_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
static void setup_memread_open_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_open_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pbc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memread_open_pf8_0_1
// static void setup_memread_open_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
static void setup_memread_open_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_open_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pbb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pbb8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
static void setup_memread_open_pbb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memread_open_pbb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
}
// static void setup_memread_open_pbb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
static void setup_memread_open_pbb8_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memread_open_pbb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pbb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pbb8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
static void setup_memread_open_pbb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memread_open_pbb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x1000);
}
// static void setup_memread_open_pbb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pbb8_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_pbb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pbb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pbb8_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pbb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
static void setup_memread_open_pbb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_open_pbb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pbb8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pbb8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pbb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pbb8_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pbb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
static void setup_memread_open_pbb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_open_pbb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pbb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pbb8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pba8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pba8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pba8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
// static void setup_memread_open_pba8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_memread_open_pbb8_0_proc0
// static void setup_memread_open_pba8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pba8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_pba8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pba8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pba8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pba8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_1_common
// static void setup_memread_open_pba8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x1000);
// }
// ^ See setup_memread_open_pbb8_1_proc0
// static void setup_memread_open_pba8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pba8_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_pba8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pba8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pba8_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pba8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pba8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_2_proc0
// static void setup_memread_open_pba8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pba8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pba8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pba8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pba8_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pba8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pba8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_3_proc0
// static void setup_memread_open_pba8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pba8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pba8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb98_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pb98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pb98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_pb98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb98_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb98_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pb98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pb98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_pb98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb98_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb88_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb88_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pb88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pb88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_pb88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb88_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb88_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb88_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pb88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pb88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_pb88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb88_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb70_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
static void setup_memread_open_pb70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_memread_open_pb70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_2_proc0
// static void setup_memread_open_pb70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb70_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb70_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb70_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pb70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_open_pb70_0_common
// static void setup_memread_open_pb70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_3_proc0
// static void setup_memread_open_pb70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb70_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb50_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb50_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pb50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_open_pb70_0_common
// static void setup_memread_open_pb50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_2_proc0
// static void setup_memread_open_pb50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb50_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb50_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb50_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_pb50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_open_pb70_0_common
// static void setup_memread_open_pb50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_3_proc0
// static void setup_memread_open_pb50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb50_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb30_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pb30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_open_pb70_0_common
// static void setup_memread_open_pb30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_2_proc0
// static void setup_memread_open_pb30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb30_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb30_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb30_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pb30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_open_pb70_0_common
// static void setup_memread_open_pb30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_3_proc0
// static void setup_memread_open_pb30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb30_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb30_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb10_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb10_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pb10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_open_pb70_0_common
// static void setup_memread_open_pb10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_2_proc0
// static void setup_memread_open_pb10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb10_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pb10_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pb10_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_pb10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_open_pb70_0_common
// static void setup_memread_open_pb10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_3_proc0
// static void setup_memread_open_pb10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pb10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pb10_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_paf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_paf0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_paf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
// static void setup_memread_open_paf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_memread_open_pbb8_0_proc0
// static void setup_memread_open_paf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_paf0_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_paf0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_paf0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_paf0_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_paf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_1_common
// static void setup_memread_open_paf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x1000);
// }
// ^ See setup_memread_open_pbb8_1_proc0
// static void setup_memread_open_paf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_paf0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_paf0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_paf0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_paf0_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_paf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_paf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_2_proc0
// static void setup_memread_open_paf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_paf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_paf0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_paf0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_paf0_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_paf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_paf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_3_proc0
// static void setup_memread_open_paf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_paf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_paf0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pad0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pad0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_pad0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
// static void setup_memread_open_pad0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_memread_open_pbb8_0_proc0
// static void setup_memread_open_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pad0_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_pad0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pad0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pad0_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_pad0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_1_common
// static void setup_memread_open_pad0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x1000);
// }
// ^ See setup_memread_open_pbb8_1_proc0
// static void setup_memread_open_pad0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pad0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_pad0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pad0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pad0_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_pad0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pad0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_2_proc0
// static void setup_memread_open_pad0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pad0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pad0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pad0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pad0_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_pad0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pad0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_open_pbb8_3_proc0
// static void setup_memread_open_pad0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pad0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pad0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pab_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pab_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_pab_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pab_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_pab_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pab_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pab_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pab_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pab_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_pab_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pab_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_pab_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pab_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pab_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pa9_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pa9_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_pa9_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pa9_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_pa9_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pa9_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pa9_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pa9_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pa9_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_pa9_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_pa9_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_pa9_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pa9_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pa9_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pa0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_open_pc_0_1
// static void setup_memread_open_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_open_pb70_0_common
// static void setup_memread_open_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_pbc_0_0
// static int test_memread_open_pa0_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_open_pc_0_1
// static void setup_memread_open_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_open_pb70_0_common
// static void setup_memread_open_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p9c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memread_open_pf8_0_1
static void setup_memread_open_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memread_open_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p9c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memread_open_pf8_0_1
// static void setup_memread_open_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_p9c_0_common
// static void setup_memread_open_p9c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p9c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p9c_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p9b4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p9b4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p9b4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
static void setup_memread_open_p9b4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_open_p9b4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p9b4_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_p9b4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p9b4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p9b4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p9b4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
static void setup_memread_open_p9b4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_open_p9b4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p9b4_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_p9b4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p9a4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p9a4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p9a4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
// static void setup_memread_open_p9a4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
// }
// ^ See setup_memread_open_p9b4_0_proc0
// static void setup_memread_open_p9a4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p9a4_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_p9a4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p9a4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p9a4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p9a4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
// static void setup_memread_open_p9a4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memread_open_p9b4_1_proc0
// static void setup_memread_open_p9a4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p9a4_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_p9a4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p998_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p998_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p998_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_p9c_0_common
// static void setup_memread_open_p998_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_p998_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p998_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p998_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p998_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p998_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p998_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_p9c_0_common
// static void setup_memread_open_p998_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_p998_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p998_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p998_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p988_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p988_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p988_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_p9c_0_common
// static void setup_memread_open_p988_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_p988_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p988_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p988_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p988_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p988_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p988_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_p9c_0_common
// static void setup_memread_open_p988_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_p988_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p988_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p988_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p968_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p968_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
static void setup_memread_open_p968_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_open_p968_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_p968_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p968_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p968_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p968_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p968_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p968_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_open_p968_0_common
// static void setup_memread_open_p968_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_p968_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p968_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p968_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p948_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p948_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p948_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_open_p968_0_common
// static void setup_memread_open_p948_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_p948_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p948_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p948_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p948_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p948_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p948_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_open_p968_0_common
// static void setup_memread_open_p948_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_p948_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p948_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p948_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p928_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p928_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p928_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_open_p968_0_common
// static void setup_memread_open_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_p928_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p928_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p928_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p928_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p928_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p928_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_open_p968_0_common
// static void setup_memread_open_p928_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_p928_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p928_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p928_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p908_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p908_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p908_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_open_p968_0_common
// static void setup_memread_open_p908_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_p908_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p908_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p908_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p908_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p908_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p908_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_open_p968_0_common
// static void setup_memread_open_p908_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_p908_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p908_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p908_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p8e8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p8e8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_p8e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
// static void setup_memread_open_p8e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
// }
// ^ See setup_memread_open_p9b4_0_proc0
// static void setup_memread_open_p8e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p8e8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_p8e8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p8e8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p8e8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_p8e8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
// static void setup_memread_open_p8e8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memread_open_p9b4_1_proc0
// static void setup_memread_open_p8e8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p8e8_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_p8e8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p8c8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p8c8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_p8c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
// static void setup_memread_open_p8c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
// }
// ^ See setup_memread_open_p9b4_0_proc0
// static void setup_memread_open_p8c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p8c8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_p8c8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p8c8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p8c8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_p8c8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pbb8_0_common
// static void setup_memread_open_p8c8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memread_open_p9b4_1_proc0
// static void setup_memread_open_p8c8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p8c8_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_open_pbb8_0_final
// static void setup_memread_open_p8c8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p8b_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p8b_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_p8b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_p9c_0_common
// static void setup_memread_open_p8b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_p8b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p8b_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p8b_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p8b_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p8b_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_p8b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_p9c_0_common
// static void setup_memread_open_p8b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_p8b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p8b_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p8b_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p89_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p89_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_p89_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_p9c_0_common
// static void setup_memread_open_p89_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_p89_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p89_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p89_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p89_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p89_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_p89_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_p9c_0_common
// static void setup_memread_open_p89_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_p89_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p89_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p89_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p80_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p80_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_open_pc_0_1
// static void setup_memread_open_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_open_p968_0_common
// static void setup_memread_open_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_0_proc0
// static void setup_memread_open_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p80_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p80_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_open_pf8_0_0
// static int test_memread_open_p80_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_open_pc_0_1
// static void setup_memread_open_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_open_p968_0_common
// static void setup_memread_open_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_open_pbc_1_proc0
// static void setup_memread_open_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p80_1_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
static int test_memread_open_p7_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_open_p7_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memread_open_pf8_0_1
// static void setup_memread_open_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p7_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p6e_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p6e_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p6e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_p6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p6e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p6e_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p6a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p6a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p6a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_p6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p6a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p6a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p66_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p66_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p66_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_p66_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p66_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p66_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p66_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p62_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p62_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p62_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p5c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p5c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p5c_0_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p54_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p54_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf70_0_1
// static void setup_memread_open_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p54_0_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_p54_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p4c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p4c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p4c_0_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_p4c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p44_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p44_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pf3_0_1
// static void setup_memread_open_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p44_0_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_p44_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p3c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p3c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf8_0_common
// static void setup_memread_open_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p3c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p3c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p34_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p34_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pde_0_1
// static void setup_memread_open_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf70_0_common
// static void setup_memread_open_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p34_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p2c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p2c_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p24_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p24_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memread_open_pd6_0_1
// static void setup_memread_open_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_open_pf3_0_common
// static void setup_memread_open_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_open_pf8_0_final
// static void setup_memread_open_p24_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal

/*
 * calls: memread open
 */
// static int test_memread_open_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_open_p7_0_0
// static int test_memread_open_p0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_open_pc_0_1
// static void setup_memread_open_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_open_pee_0_common
// static void setup_memread_open_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_open_pf8_0_proc1
// static void setup_memread_open_p0_0_final(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal
// static void setup_memread_open_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_open_pf8_0_procfinal


/*
 * calls: memread pipe
 */
static int test_memread_pipe_pf8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_pipe_pf8_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memread_pipe_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memread_pipe_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_pipe_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_pipe_pf8_0_final(void) {
  
}
static void setup_memread_pipe_pf8_0_procfinal(void) {
  
}

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pipe_pf8_0_0
// static int test_memread_pipe_pf8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_common
static void setup_memread_pipe_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pipe_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_pf8_1_final(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal
// static void setup_memread_pipe_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pipe_pf8_0_0
// static int test_memread_pipe_pd8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_common
// static void setup_memread_pipe_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pipe_pf8_0_proc0
// static void setup_memread_pipe_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_pd8_0_final(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal
// static void setup_memread_pipe_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_pd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pipe_pf8_0_0
// static int test_memread_pipe_pd8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_common
// static void setup_memread_pipe_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pipe_pf8_1_proc0
// static void setup_memread_pipe_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_pd8_1_final(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal
// static void setup_memread_pipe_pd8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
static int test_memread_pipe_pbc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_pipe_pbc_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
static void setup_memread_pipe_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_pipe_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_memread_pipe_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
static void setup_memread_pipe_pbc_0_final(void) {
  unlink("__i0");
}
// static void setup_memread_pipe_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pipe_pbc_0_0
// static int test_memread_pipe_pbc_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pipe_pbc_0_common
static void setup_memread_pipe_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x985000);
}
// static void setup_memread_pipe_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pipe_pbc_0_final
// static void setup_memread_pipe_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_pac_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pipe_pbc_0_0
// static int test_memread_pipe_pac_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pipe_pbc_0_common
// static void setup_memread_pipe_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x985000);
// }
// ^ See setup_memread_pipe_pbc_0_proc0
// static void setup_memread_pipe_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pipe_pbc_0_final
// static void setup_memread_pipe_pac_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_pac_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pipe_pbc_0_0
// static int test_memread_pipe_pac_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pipe_pbc_0_common
// static void setup_memread_pipe_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x985000);
// }
// ^ See setup_memread_pipe_pbc_1_proc0
// static void setup_memread_pipe_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pipe_pbc_0_final
// static void setup_memread_pipe_pac_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pipe_pf8_0_0
// static int test_memread_pipe_p9c_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
static void setup_memread_pipe_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pipe_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pipe_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pipe_pbc_0_final
// static void setup_memread_pipe_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pipe_pf8_0_0
// static int test_memread_pipe_p9c_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pipe_p9c_0_common
static void setup_memread_pipe_p9c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pipe_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_p9c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pipe_pbc_0_final
// static void setup_memread_pipe_p9c_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_p8c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pipe_pf8_0_0
// static int test_memread_pipe_p8c_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pipe_p9c_0_common
// static void setup_memread_pipe_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_pipe_p9c_0_proc0
// static void setup_memread_pipe_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pipe_pbc_0_final
// static void setup_memread_pipe_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_p8c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pipe_pf8_0_0
// static int test_memread_pipe_p8c_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pipe_p9c_0_common
// static void setup_memread_pipe_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_pipe_p9c_1_proc0
// static void setup_memread_pipe_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_p8c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pipe_pbc_0_final
// static void setup_memread_pipe_p8c_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
static int test_memread_pipe_p70_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_pipe_p70_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_common
// static void setup_memread_pipe_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_p70_0_final(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal
// static void setup_memread_pipe_p70_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal

/*
 * calls: memread pipe
 */
// static int test_memread_pipe_p30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pipe_p70_0_0
// static int test_memread_pipe_p30_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_pipe_pf8_0_1
// static void setup_memread_pipe_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_common
// static void setup_memread_pipe_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pipe_pf8_0_proc1
// static void setup_memread_pipe_p30_0_final(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal
// static void setup_memread_pipe_p30_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pipe_pf8_0_procfinal


/*
 * calls: memread pread
 */
static int test_memread_pread_pf8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_pread_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memread_pread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_pread_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_pread_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_memread_pread_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_memread_pread_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
static void setup_memread_pread_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pf8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
static void setup_memread_pread_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_pread_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pf8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
static void setup_memread_pread_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pread_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
static int test_memread_pread_pf4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memread_pread_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_pread_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_pread_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_pread_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_memread_pread_pf4_0_procfinal(void) {
  
}

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pread_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pf4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_pread_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pf4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pf4_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pf4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pread_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pf4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pf4_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
static int test_memread_pread_pf0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memread_pread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_pread_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pread_pf4_0_proc0
// static void setup_memread_pread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pread_pf4_1_proc0
// static void setup_memread_pread_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pf0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pread_pf4_2_proc0
// static void setup_memread_pread_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pf0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pf0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pread_pf4_3_proc0
// static void setup_memread_pread_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
static int test_memread_pread_pe_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memread_pread_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memread_pread_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_pread_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pe_0_final(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal
// static void setup_memread_pread_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pread_pe_0_common
static void setup_memread_pread_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pread_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pe_1_final(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal
// static void setup_memread_pread_pe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
static void setup_memread_pread_pd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_pread_pd8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_pread_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
static void setup_memread_pread_pd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pread_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_0_proc1
// static void setup_memread_pread_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
// static void setup_memread_pread_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pread_pd8_0_proc0
static void setup_memread_pread_pd8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_pread_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
// static void setup_memread_pread_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pread_pd8_1_proc0
// static void setup_memread_pread_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_2_proc1
// static void setup_memread_pread_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pread_pe_0_proc0
static void setup_memread_pread_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pread_pe_1_proc0
// static void setup_memread_pread_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pread_pe_0_proc0
static void setup_memread_pread_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_pd4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pd4_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pread_pe_1_proc0
// static void setup_memread_pread_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_2_proc1
// static void setup_memread_pread_pd4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pd4_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pread_pe_0_proc0
// static void setup_memread_pread_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pread_pe_1_proc0
// static void setup_memread_pread_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pread_pe_0_proc0
// static void setup_memread_pread_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_2_proc1
// static void setup_memread_pread_pd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pd0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pd0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pd0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pread_pe_1_proc0
// static void setup_memread_pread_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_2_proc1
// static void setup_memread_pread_pd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pd0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pread_pe_0_common
// static void setup_memread_pread_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pread_pe_0_proc0
// static void setup_memread_pread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pc_0_final(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal
// static void setup_memread_pread_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pread_pe_0_common
// static void setup_memread_pread_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pread_pe_1_proc0
// static void setup_memread_pread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pc_1_final(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal
// static void setup_memread_pread_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
static int test_memread_pread_pbc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_pread_pbc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
static void setup_memread_pread_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_pread_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_pread_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pbc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
static void setup_memread_pread_pbc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_pread_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_pread_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pbc_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pbc_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pbc_1_common
static void setup_memread_pread_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_pread_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_pbc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pbc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pbc_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pbc_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pbc_0_common
static void setup_memread_pread_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_pread_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_pbc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pbc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pba_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
static void setup_memread_pread_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_pread_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_memread_pread_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
static void setup_memread_pread_pba_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memread_pread_pba_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pba_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
static void setup_memread_pread_pba_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_pread_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_memread_pread_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_pba_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pba_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pba_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pba_1_common
static void setup_memread_pread_pba_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_memread_pread_pba_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_pba_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pba_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pba_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pba_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2494464, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x20ad000);
}
// static void setup_memread_pread_pba_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pba_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pba_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pba_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pba_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_pread_pba_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pba_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pba_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pba_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pba_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_pread_pba_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pba_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pba_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_pba_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pba_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_pread_pba_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pba_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
static int test_memread_pread_pba_7_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 9981952);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memread_pread_pba_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pba_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x986000);
}
// static void setup_memread_pread_pba_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pba_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
static int test_memread_pread_pba_8_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 7389184);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memread_pread_pba_8_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pread_pba_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7389184, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x70d000);
}
// static void setup_memread_pread_pba_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_8_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_pba_8_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pba_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 9981952);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pba_7_1
// static void setup_memread_pread_pba_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pba_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x986000);
}
// static void setup_memread_pread_pba_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pba_9_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
static int test_memread_pread_pba_10_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 5062656);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memread_pread_pba_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pba_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
// static void setup_memread_pread_pba_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pba_10_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pba_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pba_11_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5062656);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pba_10_1
// static void setup_memread_pread_pba_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pba_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
}
// static void setup_memread_pread_pba_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pba_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pba_11_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
static void setup_memread_pread_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pread_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_memread_pread_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pb8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
static void setup_memread_pread_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x4d5000);
}
// static void setup_memread_pread_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
static int test_memread_pread_pb8_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 20480);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memread_pread_pb8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pread_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x7000);
}
// static void setup_memread_pread_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pb8_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
static int test_memread_pread_pb8_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memread_pread_pb8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pread_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_memread_pread_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pb8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pb8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_2_1
// static void setup_memread_pread_pb8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pb8_2_common
static void setup_memread_pread_pb8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
// static void setup_memread_pread_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pb8_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pb8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pb8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_3_1
// static void setup_memread_pread_pb8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pb8_3_common
static void setup_memread_pread_pb8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memread_pread_pb8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pb8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pb8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_pread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_pread_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pac_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pac_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pbc_0_common
static void setup_memread_pread_pac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_pread_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_0_proc1
// static void setup_memread_pread_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pac_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pac_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pbc_1_common
static void setup_memread_pread_pac_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_pread_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_2_proc1
// static void setup_memread_pread_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pac_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pac_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pbc_1_common
static void setup_memread_pread_pac_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_pread_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_0_proc1
// static void setup_memread_pread_pac_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pac_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pac_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pac_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pbc_0_common
static void setup_memread_pread_pac_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_pread_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_2_proc1
// static void setup_memread_pread_pac_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_pac_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_paa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pba_0_common
static void setup_memread_pread_paa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
static void setup_memread_pread_paa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_paa_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_paa_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_paa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_paa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_paa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_pread_pb0_0_proc0
// static void setup_memread_pread_paa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_paa_0_proc1
// static void setup_memread_pread_paa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_paa_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_paa_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 7389184);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pba_8_1
// static void setup_memread_pread_paa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pba_8_common
static void setup_memread_pread_paa_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x70d000);
}
static void setup_memread_pread_paa_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7389184, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_paa_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_paa_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
static int test_memread_pread_paa_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 36270080);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memread_pread_paa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_paa_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2298000);
}
static void setup_memread_pread_paa_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_paa_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_paa_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_paa_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_paa_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pba_0_common
static void setup_memread_pread_paa_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x1000);
}
static void setup_memread_pread_paa_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_paa_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_paa_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_paa_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 7389184);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pba_8_1
// static void setup_memread_pread_paa_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pba_8_common
static void setup_memread_pread_paa_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x70d000);
}
// static void setup_memread_pread_paa_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7389184, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_paa_2_proc1
// static void setup_memread_pread_paa_5_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_paa_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
static int test_memread_pread_paa_6_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 31617024);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memread_pread_paa_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_paa_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
}
static void setup_memread_pread_paa_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_paa_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_paa_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_paa_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 36270080);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_paa_3_1
// static void setup_memread_pread_paa_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_paa_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
static void setup_memread_pread_paa_7_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_paa_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_paa_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_paa_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5062656);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pba_10_1
// static void setup_memread_pread_paa_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_paa_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
// static void setup_memread_pread_paa_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_paa_0_proc1
// static void setup_memread_pread_paa_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_paa_8_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_paa_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 31617024);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_paa_6_1
// static void setup_memread_pread_paa_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_paa_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_pread_paa_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_paa_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_paa_9_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_paa_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_paa_10_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5062656);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pba_10_1
// static void setup_memread_pread_paa_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
static void setup_memread_pread_paa_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
}
// static void setup_memread_pread_paa_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_paa_0_proc1
// static void setup_memread_pread_paa_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_paa_10_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pb8_0_common
// static void setup_memread_pread_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x26000);
// }
// ^ See setup_memread_pread_paa_0_proc0
static void setup_memread_pread_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_pa8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pa8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pa8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
static void setup_memread_pread_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d5000);
}
// static void setup_memread_pread_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_paa_3_proc1
// static void setup_memread_pread_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pa8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pa8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_2_1
// static void setup_memread_pread_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pb8_2_common
static void setup_memread_pread_pa8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x4000);
}
static void setup_memread_pread_pa8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_pa8_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pa8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pa8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_2_1
static void setup_memread_pread_pa8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pread_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_memread_pread_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_paa_4_proc1
// static void setup_memread_pread_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pa8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pa8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_2_1
// static void setup_memread_pread_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pb8_2_common
static void setup_memread_pread_pa8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x4000);
}
// static void setup_memread_pread_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pa8_2_proc1
// static void setup_memread_pread_pa8_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pa8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pa8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_3_1
// static void setup_memread_pread_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pb8_3_common
static void setup_memread_pread_pa8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memread_pread_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pa8_2_proc1
// static void setup_memread_pread_pa8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pa8_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pa8_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_3_1
// static void setup_memread_pread_pa8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pb8_3_common
// static void setup_memread_pread_pa8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_pread_pa8_5_proc0
static void setup_memread_pread_pa8_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_pa8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pa8_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_pread_pb0_0_proc0
// static void setup_memread_pread_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_pbc_0_0
// static int test_memread_pread_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_pread_pb0_1_proc0
// static void setup_memread_pread_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p9c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
static void setup_memread_pread_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_pread_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pread_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p9c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_p9c_0_common
static void setup_memread_pread_p9c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pread_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9c_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p9c_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p9c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_p9c_0_common
static void setup_memread_pread_p9c_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pread_p9c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_p9c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p9c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9c_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p9c_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p9c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_p9c_0_common
static void setup_memread_pread_p9c_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pread_p9c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_p9c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p9c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p9a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pba_1_common
static void setup_memread_pread_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_pread_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p9a_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p9a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pba_1_common
static void setup_memread_pread_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_pread_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p9a_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
static int test_memread_pread_p9a_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 5087232);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memread_pread_p9a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pread_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_pread_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p9a_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p9a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5087232);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_p9a_2_1
// static void setup_memread_pread_p9a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_p9a_2_common
static void setup_memread_pread_p9a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_pread_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p9a_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9a_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
static int test_memread_pread_p9a_4_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memread_pread_p9a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
static void setup_memread_pread_p9a_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pread_p9a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p9a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p9a_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9a_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
static int test_memread_pread_p9a_5_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 32768);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memread_pread_p9a_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pread_p9a_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_memread_pread_p9a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p9a_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p9a_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9a_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p9a_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_p9a_4_1
// static void setup_memread_pread_p9a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
static void setup_memread_pread_p9a_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pread_p9a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p9a_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p9a_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p9a_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p9a_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 32768);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_p9a_5_1
// static void setup_memread_pread_p9a_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_p9a_5_common
static void setup_memread_pread_p9a_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memread_pread_p9a_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p9a_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p9a_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_3_1
static void setup_memread_pread_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pread_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_pread_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p98_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p98_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_3_1
// static void setup_memread_pread_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_p98_0_common
static void setup_memread_pread_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_pread_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p98_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p98_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p98_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_2_1
// static void setup_memread_pread_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_p9a_2_common
// static void setup_memread_pread_p98_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
// }
// ^ See setup_memread_pread_p98_0_proc0
// static void setup_memread_pread_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p98_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p98_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p98_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p98_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_2_1
// static void setup_memread_pread_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_p9a_2_common
// static void setup_memread_pread_p98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memread_pread_p98_1_proc0
// static void setup_memread_pread_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p98_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p98_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p98_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p98_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_p98_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
static void setup_memread_pread_p98_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pread_p98_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p98_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p98_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p98_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p98_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_3_1
// static void setup_memread_pread_p98_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pb8_3_common
static void setup_memread_pread_p98_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_pread_p98_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p98_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p98_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p98_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p98_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_p98_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
static void setup_memread_pread_p98_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pread_p98_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p98_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p98_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p98_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p98_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_3_1
// static void setup_memread_pread_p98_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pb8_3_common
static void setup_memread_pread_p98_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_pread_p98_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p98_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p98_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
static void setup_memread_pread_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pread_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
static void setup_memread_pread_p90_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pread_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_p9c_0_common
static void setup_memread_pread_p8c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pread_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_0_proc1
// static void setup_memread_pread_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_p9c_0_common
static void setup_memread_pread_p8c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pread_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_0_proc1
// static void setup_memread_pread_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8c_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8c_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p8c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_p9c_0_common
// static void setup_memread_pread_p8c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_pread_p8c_0_proc0
// static void setup_memread_pread_p8c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_2_proc1
// static void setup_memread_pread_p8c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p8c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8c_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8c_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p8c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_p9c_0_common
// static void setup_memread_pread_p8c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_pread_p8c_1_proc0
// static void setup_memread_pread_p8c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_2_proc1
// static void setup_memread_pread_p8c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p8c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pba_1_common
static void setup_memread_pread_p8a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_pread_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_p8a_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pba_1_common
static void setup_memread_pread_p8a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_pread_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_p8a_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_p9a_4_1
// static void setup_memread_pread_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_p8a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_pread_p90_0_proc0
// static void setup_memread_pread_p8a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_p8a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
static void setup_memread_pread_p8a_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_pread_p8a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x1000);
}
// static void setup_memread_pread_p8a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_2_proc1
// static void setup_memread_pread_p8a_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8a_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8a_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_p8a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_p8a_3_common
// static void setup_memread_pread_p8a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x1000);
// }
// ^ See setup_memread_pread_paa_4_proc0
// static void setup_memread_pread_p8a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_2_proc1
// static void setup_memread_pread_p8a_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p8a_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8a_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8a_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 32768);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_p9a_5_1
// static void setup_memread_pread_p8a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_p9a_5_common
// static void setup_memread_pread_p8a_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x7000);
// }
// ^ See setup_memread_pread_pa8_3_proc0
static void setup_memread_pread_p8a_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_p8a_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p8a_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8a_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8a_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_p9a_4_1
// static void setup_memread_pread_p8a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_p8a_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_pread_p90_1_proc0
// static void setup_memread_pread_p8a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_p8a_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p8a_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p8a_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p8a_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 32768);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_p9a_5_1
// static void setup_memread_pread_p8a_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_p9a_5_common
// static void setup_memread_pread_p8a_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memread_pread_pa8_5_proc0
// static void setup_memread_pread_p8a_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_p8a_5_proc1
// static void setup_memread_pread_p8a_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p8a_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p88_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p88_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_3_1
// static void setup_memread_pread_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_p98_0_common
// static void setup_memread_pread_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
// }
// ^ See setup_memread_pread_p8a_0_proc0
// static void setup_memread_pread_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pa8_2_proc1
// static void setup_memread_pread_p88_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p88_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p88_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p88_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_3_1
// static void setup_memread_pread_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_p98_0_common
// static void setup_memread_pread_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memread_pread_p8a_1_proc0
// static void setup_memread_pread_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pa8_2_proc1
// static void setup_memread_pread_p88_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p88_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p88_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p88_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_p88_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_p88_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_pread_p90_0_proc0
// static void setup_memread_pread_p88_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pa8_0_proc1
// static void setup_memread_pread_p88_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p88_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p88_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
static int test_memread_pread_p88_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memread_pread_p88_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_pread_p88_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
// }
// ^ See setup_memread_pread_p8a_0_proc0
static void setup_memread_pread_p88_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pread_p88_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p88_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p88_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p88_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_p88_3_1
// static void setup_memread_pread_p88_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_p88_3_common
// static void setup_memread_pread_p88_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memread_pread_p8a_1_proc0
// static void setup_memread_pread_p88_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_p88_3_proc1
// static void setup_memread_pread_p88_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pba_0_final
// static void setup_memread_pread_p88_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p88_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p88_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_2_1
// static void setup_memread_pread_p88_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pa8_3_common
static void setup_memread_pread_p88_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x5000);
}
// static void setup_memread_pread_p88_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pa8_2_proc1
// static void setup_memread_pread_p88_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p88_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p88_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p88_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_p88_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_p88_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_pread_p90_1_proc0
// static void setup_memread_pread_p88_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pa8_0_proc1
// static void setup_memread_pread_p88_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p88_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p88_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p88_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pb8_3_1
// static void setup_memread_pread_p88_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pb8_3_common
static void setup_memread_pread_p88_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_pread_p88_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pa8_6_proc1
// static void setup_memread_pread_p88_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p88_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p80_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_pread_p90_0_proc0
// static void setup_memread_pread_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p80_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p80_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pread_pf8_0_0
// static int test_memread_pread_p80_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_pread_p90_1_proc0
// static void setup_memread_pread_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p80_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
static int test_memread_pread_p7_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_pread_p7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
// static void setup_memread_pread_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_0_proc1
// static void setup_memread_pread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p7_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
// static void setup_memread_pread_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_2_proc1
// static void setup_memread_pread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p68_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_2_proc1
// static void setup_memread_pread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p60_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p60_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_2_proc1
// static void setup_memread_pread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pread_pe_0_common
// static void setup_memread_pread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p4_0_final(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal
// static void setup_memread_pread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p3_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
// static void setup_memread_pread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_0_proc1
// static void setup_memread_pread_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p3_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf8_0_1
// static void setup_memread_pread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pread_pf8_0_common
// static void setup_memread_pread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pf8_0_proc1
// static void setup_memread_pread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pread_pd8_2_proc1
// static void setup_memread_pread_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_final
// static void setup_memread_pread_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pread_pf8_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p28_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p28_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf4_0_1
// static void setup_memread_pread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pread_pf4_0_common
// static void setup_memread_pread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_2_proc1
// static void setup_memread_pread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_0_proc1
// static void setup_memread_pread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p20_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p20_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pf0_0_1
// static void setup_memread_pread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pread_pf0_0_common
// static void setup_memread_pread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pread_pd4_2_proc1
// static void setup_memread_pread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pread_pf4_0_final
// static void setup_memread_pread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal

/*
 * calls: memread pread
 */
// static int test_memread_pread_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pread_p7_0_0
// static int test_memread_pread_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_pread_pe_0_1
// static void setup_memread_pread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pread_pe_0_common
// static void setup_memread_pread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pread_pf4_0_proc1
// static void setup_memread_pread_p0_0_final(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal
// static void setup_memread_pread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pread_pf4_0_procfinal


/*
 * calls: memread pwrite
 */
static int test_memread_pwrite_pf8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_pwrite_pf8_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_memread_pwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_pwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_pwrite_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_memread_pwrite_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_memread_pwrite_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pf8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
static void setup_memread_pwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pf8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
static void setup_memread_pwrite_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_pwrite_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pf8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
static void setup_memread_pwrite_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pwrite_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
static int test_memread_pwrite_pf4_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_pwrite_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_pwrite_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_pwrite_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_memread_pwrite_pf4_0_procfinal(void) {
  
}

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pf4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_pwrite_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pf4_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pwrite_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pf4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pf4_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pf4_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pwrite_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pf4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pf4_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pf0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
static void setup_memread_pwrite_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_pwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pf0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pwrite_pf4_1_proc0
// static void setup_memread_pwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pf0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
static void setup_memread_pwrite_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pf0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pf0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pwrite_pf4_3_proc0
// static void setup_memread_pwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
static int test_memread_pwrite_pe_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
static void setup_memread_pwrite_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memread_pwrite_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_pwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pe_0_final(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal
// static void setup_memread_pwrite_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pe_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pe_0_common
static void setup_memread_pwrite_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pe_1_final(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal
// static void setup_memread_pwrite_pe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
static void setup_memread_pwrite_pd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_pwrite_pd8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_pwrite_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
static void setup_memread_pwrite_pd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_pwrite_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_0_proc1
// static void setup_memread_pwrite_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
// static void setup_memread_pwrite_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pwrite_pd8_0_proc0
static void setup_memread_pwrite_pd8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_pwrite_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
// static void setup_memread_pwrite_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pwrite_pd8_1_proc0
// static void setup_memread_pwrite_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_2_proc1
// static void setup_memread_pwrite_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd4_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pwrite_pe_0_proc0
static void setup_memread_pwrite_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pwrite_pe_0_proc0
static void setup_memread_pwrite_pd4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd4_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pwrite_pe_1_proc0
static void setup_memread_pwrite_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pd4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pd4_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd4_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pwrite_pe_1_proc0
// static void setup_memread_pwrite_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_pd4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pd4_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pwrite_pe_0_proc0
static void setup_memread_pwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pwrite_pe_0_proc0
// static void setup_memread_pwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pwrite_pe_1_proc0
// static void setup_memread_pwrite_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_0_proc1
// static void setup_memread_pwrite_pd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pd0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pd0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pd0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pwrite_pe_1_proc0
// static void setup_memread_pwrite_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_pd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pd0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pc_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pe_0_common
// static void setup_memread_pwrite_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_pwrite_pe_0_proc0
// static void setup_memread_pwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pc_0_final(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal
// static void setup_memread_pwrite_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_pc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pe_0_common
// static void setup_memread_pwrite_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_pwrite_pe_1_proc0
// static void setup_memread_pwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pc_1_final(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal
// static void setup_memread_pwrite_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
static int test_memread_pwrite_pbc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_pwrite_pbc_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
static void setup_memread_pwrite_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_pwrite_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_pwrite_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pbc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
static void setup_memread_pwrite_pbc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_pwrite_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_pwrite_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbc_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pbc_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pbc_1_common
static void setup_memread_pwrite_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_pwrite_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_pbc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pbc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbc_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pbc_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pbc_0_common
static void setup_memread_pwrite_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_pwrite_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_pbc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pbc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pbb0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
static void setup_memread_pwrite_pbb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_pwrite_pbb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x4d5000);
}
// static void setup_memread_pwrite_pbb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
static void setup_memread_pwrite_pbb0_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memread_pwrite_pbb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
static int test_memread_pwrite_pbb0_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_pbb0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_pbb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4677632, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x704000);
}
// static void setup_memread_pwrite_pbb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pbb0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pbb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbb0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pbb0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pbb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pbb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_pwrite_pbb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pbb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pbb0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbb0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
static int test_memread_pwrite_pbb0_3_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_pbb0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_pbb0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x9000);
}
// static void setup_memread_pwrite_pbb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pbb0_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pbb0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbb0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pbb0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pbb0_3_1
// static void setup_memread_pwrite_pbb0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pbb0_3_common
static void setup_memread_pwrite_pbb0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x9000);
}
// static void setup_memread_pwrite_pbb0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pbb0_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pbb0_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbb0_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pbb0_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pbb0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pbb0_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_pwrite_pbb0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pbb0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pbb0_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbb0_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pbb0_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pbb0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pbb0_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_pwrite_pbb0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pbb0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pbb0_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbb0_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pbb0_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pbb0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pbb0_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_pwrite_pbb0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pbb0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pbb0_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pbb0_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pbb0_8_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pbb0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pbb0_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_pwrite_pbb0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pbb0_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pbb0_8_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pb8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
static void setup_memread_pwrite_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_memread_pwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pb8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pb8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
static void setup_memread_pwrite_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x986000);
}
// static void setup_memread_pwrite_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
static int test_memread_pwrite_pb8_2_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_memread_pwrite_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pbb0_3_common
static void setup_memread_pwrite_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x8000);
}
// static void setup_memread_pwrite_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pb8_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pb8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pb8_2_1
// static void setup_memread_pwrite_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pbb0_3_common
static void setup_memread_pwrite_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x8000);
}
// static void setup_memread_pwrite_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pb8_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pb8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
static int test_memread_pwrite_pb8_4_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_pb8_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_pb8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
// static void setup_memread_pwrite_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pb8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pb8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
static int test_memread_pwrite_pb8_5_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_pb8_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_pb8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_pwrite_pb8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pb8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pb8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pb0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_pwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pb0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_pwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pac_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pac_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pbc_0_common
static void setup_memread_pwrite_pac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_pwrite_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_0_proc1
// static void setup_memread_pwrite_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pac_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pac_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pbc_1_common
static void setup_memread_pwrite_pac_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x1e27000);
}
// static void setup_memread_pwrite_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_2_proc1
// static void setup_memread_pwrite_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pac_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pac_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pbc_1_common
static void setup_memread_pwrite_pac_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_pwrite_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_0_proc1
// static void setup_memread_pwrite_pac_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pac_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pac_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pac_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pbc_0_common
static void setup_memread_pwrite_pac_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_pwrite_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_2_proc1
// static void setup_memread_pwrite_pac_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_pac_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pab0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pab0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pab0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pbb0_0_common
static void setup_memread_pwrite_pab0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x4d5000);
}
// static void setup_memread_pwrite_pab0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_2_proc1
// static void setup_memread_pwrite_pab0_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pab0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pab0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pbb0_1_1
// static void setup_memread_pwrite_pab0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pbb0_1_common
static void setup_memread_pwrite_pab0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x704000);
}
static void setup_memread_pwrite_pab0_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 33169408, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pab0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pab0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pab0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pab0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pab0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pbb0_0_common
// static void setup_memread_pwrite_pab0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x4d5000);
// }
// ^ See setup_memread_pwrite_pab0_0_proc0
// static void setup_memread_pwrite_pab0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_pab0_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pab0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pab0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pab0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pab0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pab0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
static void setup_memread_pwrite_pab0_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pab0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pab0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pab0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pab0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pbb0_3_1
// static void setup_memread_pwrite_pab0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pbb0_3_common
static void setup_memread_pwrite_pab0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x9000);
}
static void setup_memread_pwrite_pab0_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pab0_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pab0_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pab0_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pab0_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pab0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_pab0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_pwrite_pab0_3_proc0
static void setup_memread_pwrite_pab0_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pab0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pab0_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pab0_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pab0_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pab0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
static void setup_memread_pwrite_pab0_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
static void setup_memread_pwrite_pab0_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pab0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pab0_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pab0_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pab0_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pab0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_pab0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_pwrite_pab0_6_proc0
// static void setup_memread_pwrite_pab0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_pab0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pab0_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pa8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pb8_0_common
static void setup_memread_pwrite_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_memread_pwrite_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_0_proc1
// static void setup_memread_pwrite_pa8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pa8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pa8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
static void setup_memread_pwrite_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x986000);
}
// static void setup_memread_pwrite_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_2_proc1
// static void setup_memread_pwrite_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pa8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pa8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pb8_2_1
// static void setup_memread_pwrite_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pbb0_3_common
static void setup_memread_pwrite_pa8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x8000);
}
static void setup_memread_pwrite_pa8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pa8_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pa8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pa8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pb8_2_1
// static void setup_memread_pwrite_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pbb0_3_common
static void setup_memread_pwrite_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x8000);
}
// static void setup_memread_pwrite_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pa8_2_proc1
// static void setup_memread_pwrite_pa8_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pa8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pa8_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pb8_4_1
// static void setup_memread_pwrite_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pb8_4_common
static void setup_memread_pwrite_pa8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x7000);
}
static void setup_memread_pwrite_pa8_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pa8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pa8_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pb8_5_1
// static void setup_memread_pwrite_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pb8_5_common
static void setup_memread_pwrite_pa8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_pwrite_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pab0_6_proc1
// static void setup_memread_pwrite_pa8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pa0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_pwrite_pb0_0_proc0
// static void setup_memread_pwrite_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_pbc_0_0
// static int test_memread_pwrite_pa0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_pwrite_pb0_1_proc0
// static void setup_memread_pwrite_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
static void setup_memread_pwrite_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_pwrite_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pwrite_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9c_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_p9c_0_common
static void setup_memread_pwrite_p9c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pwrite_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9c_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9c_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p9c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_p9c_0_common
static void setup_memread_pwrite_p9c_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pwrite_p9c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_p9c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p9c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9c_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9c_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p9c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_p9c_0_common
static void setup_memread_pwrite_p9c_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pwrite_p9c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_p9c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p9c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
static int test_memread_pwrite_p9a_0_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_p9a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_pwrite_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p9a_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9a_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_0_1
// static void setup_memread_pwrite_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p9a_0_common
static void setup_memread_pwrite_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_pwrite_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p9a_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
static int test_memread_pwrite_p9a_2_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 12288);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_p9a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x1000);
}
// static void setup_memread_pwrite_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p9a_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9a_3_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_0_1
static void setup_memread_pwrite_p9a_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p9a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x1000);
}
// static void setup_memread_pwrite_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p9a_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9a_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
static int test_memread_pwrite_p9a_4_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_p9a_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p9a_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_pwrite_p9a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p9a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p9a_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9a_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9a_5_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_4_1
// static void setup_memread_pwrite_p9a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p9a_4_common
static void setup_memread_pwrite_p9a_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_pwrite_p9a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p9a_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p9a_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9a_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9a_6_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_4_1
// static void setup_memread_pwrite_p9a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p9a_4_common
static void setup_memread_pwrite_p9a_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_pwrite_p9a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p9a_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p9a_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9a_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9a_7_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_4_1
// static void setup_memread_pwrite_p9a_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p9a_4_common
static void setup_memread_pwrite_p9a_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_pwrite_p9a_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p9a_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p9a_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9a_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9a_8_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_4_1
// static void setup_memread_pwrite_p9a_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p9a_4_common
static void setup_memread_pwrite_p9a_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_pwrite_p9a_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p9a_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p9a_8_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p9a_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p9a_9_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_4_1
// static void setup_memread_pwrite_p9a_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p9a_4_common
static void setup_memread_pwrite_p9a_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_pwrite_p9a_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p9a_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p9a_9_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
static int test_memread_pwrite_p990_0_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_p990_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p990_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_pwrite_p990_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p990_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p990_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_0_1
static void setup_memread_pwrite_p990_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p990_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x3000);
}
// static void setup_memread_pwrite_p990_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p990_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p990_2_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_0_1
// static void setup_memread_pwrite_p990_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_1_common
static void setup_memread_pwrite_p990_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x3000);
}
// static void setup_memread_pwrite_p990_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p990_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p990_3_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_0_1
static void setup_memread_pwrite_p990_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p990_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x1000);
}
// static void setup_memread_pwrite_p990_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p990_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p990_4_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_0_1
// static void setup_memread_pwrite_p990_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_3_common
static void setup_memread_pwrite_p990_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x1000);
}
// static void setup_memread_pwrite_p990_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p990_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
static int test_memread_pwrite_p990_5_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_memread_pwrite_p990_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_0_common
static void setup_memread_pwrite_p990_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pwrite_p990_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p990_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p990_6_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_5_1
static void setup_memread_pwrite_p990_6_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p990_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memread_pwrite_p990_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p990_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p990_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
static void setup_memread_pwrite_p990_7_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_pwrite_p990_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_pwrite_p990_5_proc0
// static void setup_memread_pwrite_p990_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p990_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p990_8_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_0_1
static void setup_memread_pwrite_p990_8_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p990_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x3000);
}
// static void setup_memread_pwrite_p990_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p990_8_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p990_9_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_5_1
// static void setup_memread_pwrite_p990_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_0_common
static void setup_memread_pwrite_p990_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pwrite_p990_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p990_9_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p990_10_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_5_1
// static void setup_memread_pwrite_p990_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_6_common
static void setup_memread_pwrite_p990_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_memread_pwrite_p990_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p990_10_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p990_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p990_11_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p990_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_7_common
// static void setup_memread_pwrite_p990_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_pwrite_p990_9_proc0
// static void setup_memread_pwrite_p990_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p990_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p990_11_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p90_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
static void setup_memread_pwrite_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p90_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
static void setup_memread_pwrite_p90_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pwrite_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_p9c_0_common
static void setup_memread_pwrite_p8c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_pwrite_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_0_proc1
// static void setup_memread_pwrite_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8c_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_p9c_0_common
static void setup_memread_pwrite_p8c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_pwrite_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_0_proc1
// static void setup_memread_pwrite_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8c_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8c_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p8c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_p9c_0_common
// static void setup_memread_pwrite_p8c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_pwrite_p8c_0_proc0
// static void setup_memread_pwrite_p8c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_2_proc1
// static void setup_memread_pwrite_p8c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p8c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8c_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8c_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p8c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_p9c_0_common
// static void setup_memread_pwrite_p8c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_pwrite_p8c_1_proc0
// static void setup_memread_pwrite_p8c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_2_proc1
// static void setup_memread_pwrite_p8c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p8c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
static int test_memread_pwrite_p8a_0_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_p8a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p8a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4000);
}
static void setup_memread_pwrite_p8a_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8a_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_5_1
static void setup_memread_pwrite_p8a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p8a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x3000);
}
static void setup_memread_pwrite_p8a_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_p8a_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8a_2_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_5_1
static void setup_memread_pwrite_p8a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_pwrite_p8a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
}
// static void setup_memread_pwrite_p8a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pab0_5_proc1
// static void setup_memread_pwrite_p8a_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8a_3_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_5_1
// static void setup_memread_pwrite_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p8a_2_common
static void setup_memread_pwrite_p8a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
}
static void setup_memread_pwrite_p8a_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 65536, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_p8a_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8a_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8a_4_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_0_1
// static void setup_memread_pwrite_p8a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_0_common
// static void setup_memread_pwrite_p8a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_pwrite_pab0_3_proc0
// static void setup_memread_pwrite_p8a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pab0_5_proc1
// static void setup_memread_pwrite_p8a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p8a_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8a_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8a_5_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p9a_0_1
// static void setup_memread_pwrite_p8a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p9a_3_common
static void setup_memread_pwrite_p8a_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x1000);
}
static void setup_memread_pwrite_p8a_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_p8a_5_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pbb0_0_final
// static void setup_memread_pwrite_p8a_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8a_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8a_6_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p8a_0_1
// static void setup_memread_pwrite_p8a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p8a_0_common
static void setup_memread_pwrite_p8a_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4000);
}
// static void setup_memread_pwrite_p8a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_p8a_0_proc1
// static void setup_memread_pwrite_p8a_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p8a_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p8a_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p8a_7_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p8a_0_1
// static void setup_memread_pwrite_p8a_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p8a_0_common
// static void setup_memread_pwrite_p8a_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x4000);
// }
// ^ See setup_memread_pwrite_p8a_6_proc0
static void setup_memread_pwrite_p8a_7_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_p8a_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p8a_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p890_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p890_0_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_0_1
// static void setup_memread_pwrite_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_0_common
// static void setup_memread_pwrite_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_pwrite_pab0_3_proc0
// static void setup_memread_pwrite_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pab0_6_proc1
// static void setup_memread_pwrite_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p890_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p890_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p890_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_5_1
// static void setup_memread_pwrite_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_6_common
static void setup_memread_pwrite_p890_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memread_pwrite_p890_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_p8a_5_proc1
// static void setup_memread_pwrite_p890_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p890_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p890_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p890_2_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_5_1
// static void setup_memread_pwrite_p890_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_6_common
static void setup_memread_pwrite_p890_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_memread_pwrite_p890_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_p8a_0_proc1
// static void setup_memread_pwrite_p890_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p890_2_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p890_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p890_3_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_p990_5_1
// static void setup_memread_pwrite_p890_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_6_common
// static void setup_memread_pwrite_p890_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_memread_pwrite_p890_2_proc0
// static void setup_memread_pwrite_p890_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pab0_5_proc1
// static void setup_memread_pwrite_p890_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p890_3_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p890_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
static int test_memread_pwrite_p890_4_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memread_pwrite_p890_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_pwrite_p890_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x1000);
// }
// ^ See setup_memread_pwrite_pab0_3_proc0
static void setup_memread_pwrite_p890_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2191360, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_p890_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p890_4_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p890_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p890_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p890_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_7_common
// static void setup_memread_pwrite_p890_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_pwrite_p90_0_proc0
// static void setup_memread_pwrite_p890_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_p890_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p890_5_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p890_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p890_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p890_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_7_common
// static void setup_memread_pwrite_p890_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_pwrite_p90_1_proc0
static void setup_memread_pwrite_p890_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_pwrite_p890_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p890_6_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p890_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p890_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p890_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_p990_7_common
// static void setup_memread_pwrite_p890_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_pwrite_p90_1_proc0
// static void setup_memread_pwrite_p890_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_p890_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p890_7_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p80_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p80_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_pwrite_p90_0_proc0
// static void setup_memread_pwrite_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p80_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p80_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_pwrite_pf8_0_0
// static int test_memread_pwrite_p80_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_pwrite_p90_1_proc0
// static void setup_memread_pwrite_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p80_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
static int test_memread_pwrite_p7_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_pwrite_p7_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
// static void setup_memread_pwrite_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_0_proc1
// static void setup_memread_pwrite_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p7_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p7_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
// static void setup_memread_pwrite_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_2_proc1
// static void setup_memread_pwrite_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p68_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_2_proc1
// static void setup_memread_pwrite_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p68_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p68_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p68_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p60_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pab0_3_proc1
// static void setup_memread_pwrite_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p60_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p60_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p60_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p4_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pe_0_common
// static void setup_memread_pwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p4_0_final(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal
// static void setup_memread_pwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p3_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
// static void setup_memread_pwrite_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_0_proc1
// static void setup_memread_pwrite_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p3_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf8_0_1
// static void setup_memread_pwrite_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_pwrite_pf8_0_common
// static void setup_memread_pwrite_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pf8_0_proc1
// static void setup_memread_pwrite_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_pwrite_pd8_2_proc1
// static void setup_memread_pwrite_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_final
// static void setup_memread_pwrite_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_pwrite_pf8_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p28_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_0_proc1
// static void setup_memread_pwrite_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p28_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p28_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf4_0_common
// static void setup_memread_pwrite_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p28_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p20_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd0_0_proc1
// static void setup_memread_pwrite_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p20_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p20_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pf4_0_1
// static void setup_memread_pwrite_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_pwrite_pf0_0_common
// static void setup_memread_pwrite_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_pwrite_pd4_1_proc1
// static void setup_memread_pwrite_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_pwrite_pf4_0_final
// static void setup_memread_pwrite_p20_1_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal

/*
 * calls: memread pwrite
 */
// static int test_memread_pwrite_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_pwrite_p7_0_0
// static int test_memread_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memread_pwrite_pe_0_1
// static void setup_memread_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pe_0_common
// static void setup_memread_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_pwrite_pf4_0_proc1
// static void setup_memread_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal
// static void setup_memread_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_pwrite_pf4_0_procfinal


/*
 * calls: memread read
 */
static int test_memread_read_pfc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_read_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_memread_read_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_read_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_read_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_memread_read_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_memread_read_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: memread read
 */
// static int test_memread_read_pfc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pfc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfc_0_common
static void setup_memread_read_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_read_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pfb_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
static int test_memread_read_pfb_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_memread_read_pfb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_read_pfb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_read_pfb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pfb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pfb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pfb_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pfb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_pfb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfb_0_common
static void setup_memread_read_pfb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_read_pfb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pfb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pfb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pfa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
static int test_memread_read_pfa_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_memread_read_pfa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfb_0_common
static void setup_memread_read_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_read_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_read_pfa_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pfa_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pfa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pfa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
static void setup_memread_read_pfa_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_read_pfa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_read_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfa_0_proc1
// static void setup_memread_read_pfa_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pfa_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
static int test_memread_read_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_memread_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_memread_read_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_read_pfb_0_proc0
// static void setup_memread_read_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pf8_0_common
// static void setup_memread_read_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_read_pfb_1_proc0
// static void setup_memread_read_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pf4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pf4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
static void setup_memread_read_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_read_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_read_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_read_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_memread_read_pf4_0_procfinal(void) {
  
}

/*
 * calls: memread read
 */
// static int test_memread_read_pf4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
static void setup_memread_read_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_read_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
static void setup_memread_read_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_read_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pf0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
static void setup_memread_read_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_read_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
static void setup_memread_read_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memread_read_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_read_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pe_0_final(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal
// static void setup_memread_read_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_read_pe_0_common
static void setup_memread_read_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_read_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pe_1_final(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal
// static void setup_memread_read_pe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pdc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfc_0_common
static void setup_memread_read_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_read_pdc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_read_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pdc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pdc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfc_0_common
static void setup_memread_read_pdc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_read_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdc_0_proc1
// static void setup_memread_read_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pdb_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pdb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_pdb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfb_0_common
// static void setup_memread_read_pdb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_read_pdc_0_proc0
static void setup_memread_read_pdb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_read_pdb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pdb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pdb_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pdb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_pdb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfb_0_common
// static void setup_memread_read_pdb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_read_pdc_1_proc0
// static void setup_memread_read_pdb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_pdb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pdb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pda_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pda_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfb_0_common
static void setup_memread_read_pda_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_read_pda_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_read_pda_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pda_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pda_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pda_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfa_1_common
static void setup_memread_read_pda_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_read_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pda_0_proc1
// static void setup_memread_read_pda_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pda_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pf8_0_common
// static void setup_memread_read_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_read_pdc_0_proc0
// static void setup_memread_read_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pf8_0_common
// static void setup_memread_read_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_read_pdc_1_proc0
// static void setup_memread_read_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
// static void setup_memread_read_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_read_pe_0_proc0
static void setup_memread_read_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_read_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pd4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
// static void setup_memread_read_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_read_pe_1_proc0
// static void setup_memread_read_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pd4_0_proc1
// static void setup_memread_read_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
// static void setup_memread_read_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_read_pe_0_proc0
static void setup_memread_read_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_read_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pd0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
// static void setup_memread_read_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_read_pe_1_proc0
// static void setup_memread_read_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pd0_0_proc1
// static void setup_memread_read_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_read_pe_0_common
// static void setup_memread_read_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_read_pe_0_proc0
// static void setup_memread_read_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pc_0_final(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal
// static void setup_memread_read_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_read_pe_0_common
// static void setup_memread_read_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_read_pe_1_proc0
// static void setup_memread_read_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pc_1_final(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal
// static void setup_memread_read_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
static int test_memread_read_pbe_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_read_pbe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
static void setup_memread_read_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_read_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_read_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pbe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pbe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pbe_0_common
static void setup_memread_read_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_read_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pbd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pbd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
static void setup_memread_read_pbd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_read_pbd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_read_pbd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pbd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pbd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pbd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pbd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_pbd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pbd8_0_common
static void setup_memread_read_pbd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_read_pbd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pbd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pbd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pbd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pbd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pbd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfc_0_common
static void setup_memread_read_pbd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_read_pbd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfa_0_proc1
// static void setup_memread_read_pbd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pbd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pbd0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pbd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pbd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfc_0_common
static void setup_memread_read_pbd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_read_pbd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfa_0_proc1
// static void setup_memread_read_pbd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pbd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pbc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pbc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
static void setup_memread_read_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_memread_read_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_read_pbd8_0_proc0
// static void setup_memread_read_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pbc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pbc_0_common
// static void setup_memread_read_pbc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_read_pbd8_1_proc0
// static void setup_memread_read_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pba_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pba_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
static void setup_memread_read_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_read_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_memread_read_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
static void setup_memread_read_pba_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memread_read_pba_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pba_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pba_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pba_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
static void setup_memread_read_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_read_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pba_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pba_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pba_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pba_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
static void setup_memread_read_pba_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_read_pba_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x25000);
}
// static void setup_memread_read_pba_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pba_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_pba_2_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pba_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pba_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pba_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
static void setup_memread_read_pba_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
// static void setup_memread_read_pba_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pba_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pba_3_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pba_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pba_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pba_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
static void setup_memread_read_pba_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
}
// static void setup_memread_read_pba_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pba_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pba_4_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pba_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pba_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pba_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
static void setup_memread_read_pba_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memread_read_pba_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pba_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pba_5_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
static void setup_memread_read_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_read_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_memread_read_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pb8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
static void setup_memread_read_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x986000);
}
// static void setup_memread_read_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pb8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pb8_0_common
static void setup_memread_read_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
// static void setup_memread_read_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pb8_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pb8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
static void setup_memread_read_pb8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_read_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memread_read_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
static void setup_memread_read_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
static void setup_memread_read_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_read_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pae_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pae_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pbe_0_common
static void setup_memread_read_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_read_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdc_0_proc1
// static void setup_memread_read_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pae_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pae_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pbe_0_common
static void setup_memread_read_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_read_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdc_0_proc1
// static void setup_memread_read_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pad8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pad8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_pad8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pbd8_0_common
// static void setup_memread_read_pad8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_read_pae_0_proc0
// static void setup_memread_read_pad8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_pad8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pad8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pad8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pad8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_pad8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pbd8_0_common
// static void setup_memread_read_pad8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_read_pae_1_proc0
// static void setup_memread_read_pad8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_pad8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pad8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pad0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pad0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pad0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfc_0_common
static void setup_memread_read_pad0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_read_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pda_0_proc1
// static void setup_memread_read_pad0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pad0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pad0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pad0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_pad0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfc_0_common
static void setup_memread_read_pad0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_read_pad0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pda_0_proc1
// static void setup_memread_read_pad0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pad0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pac_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pac_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pbc_0_common
// static void setup_memread_read_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_read_pae_0_proc0
// static void setup_memread_read_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pac_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pac_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pbc_0_common
// static void setup_memread_read_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_read_pae_1_proc0
// static void setup_memread_read_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_paa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_paa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pba_0_common
static void setup_memread_read_paa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
static void setup_memread_read_paa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_read_paa_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_paa_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_paa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_paa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_paa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
// static void setup_memread_read_paa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_read_pb0_0_proc0
// static void setup_memread_read_paa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_paa_0_proc1
// static void setup_memread_read_paa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_paa_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_paa_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_paa_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_paa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pba_2_common
static void setup_memread_read_paa_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x27000);
}
// static void setup_memread_read_paa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pd4_0_proc1
// static void setup_memread_read_paa_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_paa_2_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_paa_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_paa_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_paa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
static void setup_memread_read_paa_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
static void setup_memread_read_paa_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_read_paa_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_paa_3_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_paa_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_paa_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_paa_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
static void setup_memread_read_paa_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
static void setup_memread_read_paa_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31621120, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_read_paa_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_paa_4_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_paa_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_paa_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_paa_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
// static void setup_memread_read_paa_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memread_read_paa_4_proc0
// static void setup_memread_read_paa_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_paa_0_proc1
// static void setup_memread_read_paa_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_paa_5_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pb8_0_common
// static void setup_memread_read_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x26000);
// }
// ^ See setup_memread_read_paa_0_proc0
static void setup_memread_read_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_read_pa8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pa8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pa8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
static void setup_memread_read_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x986000);
}
// static void setup_memread_read_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pd0_0_proc1
// static void setup_memread_read_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pa8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pa8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pb8_0_common
static void setup_memread_read_pa8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x7000);
}
static void setup_memread_read_pa8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_read_pa8_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pa8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pa8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pb8_3_common
static void setup_memread_read_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memread_read_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pa8_2_proc1
// static void setup_memread_read_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
// static void setup_memread_read_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_read_pb0_0_proc0
// static void setup_memread_read_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_pbe_0_0
// static int test_memread_read_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
// static void setup_memread_read_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_read_pb0_1_proc0
// static void setup_memread_read_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9e_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
static void setup_memread_read_p9e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_read_p9e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_read_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9e_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9e_0_common
static void setup_memread_read_p9e_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_read_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p9e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p9e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9d8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
static void setup_memread_read_p9d8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_read_p9d8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_read_p9d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p9d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p9d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9d8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9d8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_p9d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9d8_0_common
static void setup_memread_read_p9d8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_read_p9d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p9d8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p9d8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9d0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p9d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9d8_0_common
static void setup_memread_read_p9d0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_read_p9d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfa_0_proc1
// static void setup_memread_read_p9d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p9d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9d0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9d0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p9d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9d8_0_common
static void setup_memread_read_p9d0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_read_p9d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfa_0_proc1
// static void setup_memread_read_p9d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p9d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
static void setup_memread_read_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_read_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_read_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9c_0_common
static void setup_memread_read_p9c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_read_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
static void setup_memread_read_p9a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_read_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_read_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p9a_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
static void setup_memread_read_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_read_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
static void setup_memread_read_p9a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_read_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x4000);
}
// static void setup_memread_read_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p9a_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p9a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p9a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p9a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pb8_3_common
static void setup_memread_read_p9a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_read_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p9a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
static void setup_memread_read_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_read_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_read_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p98_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p98_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_p98_0_common
static void setup_memread_read_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_read_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p98_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p98_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p98_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pb8_3_common
static void setup_memread_read_p98_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_read_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p98_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p98_2_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p98_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p98_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pb8_3_common
static void setup_memread_read_p98_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_read_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p98_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p98_3_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
static void setup_memread_read_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_read_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
static void setup_memread_read_p90_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_read_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8e_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9e_0_common
static void setup_memread_read_p8e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_read_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdc_0_proc1
// static void setup_memread_read_p8e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p8e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8e_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p8e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9e_0_common
static void setup_memread_read_p8e_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_read_p8e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdc_0_proc1
// static void setup_memread_read_p8e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p8e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8d8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9d8_0_common
static void setup_memread_read_p8d8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_read_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_p8d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p8d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8d8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8d8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_p8d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9d8_0_common
static void setup_memread_read_p8d8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_read_p8d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_p8d8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p8d8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8d0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9d8_0_common
static void setup_memread_read_p8d0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_read_p8d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pda_0_proc1
// static void setup_memread_read_p8d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p8d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8d0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8d0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p8d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9d8_0_common
static void setup_memread_read_p8d0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_read_p8d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pda_0_proc1
// static void setup_memread_read_p8d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p8d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9c_0_common
// static void setup_memread_read_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_read_p8e_0_proc0
// static void setup_memread_read_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_p9c_0_common
// static void setup_memread_read_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_read_p8e_1_proc0
// static void setup_memread_read_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_p9a_0_common
static void setup_memread_read_p8a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_read_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pd4_0_proc1
// static void setup_memread_read_p8a_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
// static void setup_memread_read_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_read_p90_0_proc0
// static void setup_memread_read_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pd4_0_proc1
// static void setup_memread_read_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_p9a_2_common
static void setup_memread_read_p8a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x4000);
}
static void setup_memread_read_p8a_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_read_p8a_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p8a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p8a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pb8_3_common
static void setup_memread_read_p8a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memread_read_p8a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pa8_0_proc1
// static void setup_memread_read_p8a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p88_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p88_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_p98_0_common
// static void setup_memread_read_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
// }
// ^ See setup_memread_read_p8a_0_proc0
// static void setup_memread_read_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pa8_0_proc1
// static void setup_memread_read_p88_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_p88_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p88_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p88_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_p98_0_common
static void setup_memread_read_p88_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_read_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pa8_0_proc1
// static void setup_memread_read_p88_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_read_pba_0_final
// static void setup_memread_read_p88_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p88_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p88_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p88_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pb8_3_common
static void setup_memread_read_p88_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x6000);
}
// static void setup_memread_read_p88_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pa8_2_proc1
// static void setup_memread_read_p88_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p88_2_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p88_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p88_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p88_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pb8_3_common
// static void setup_memread_read_p88_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_memread_read_p8a_3_proc0
// static void setup_memread_read_p88_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pa8_2_proc1
// static void setup_memread_read_p88_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p88_3_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p80_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
// static void setup_memread_read_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_read_p90_0_proc0
// static void setup_memread_read_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p80_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p80_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_read_pfc_0_0
// static int test_memread_read_p80_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
// static void setup_memread_read_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_read_p90_1_proc0
// static void setup_memread_read_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p80_1_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
static int test_memread_read_p78_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_read_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfc_0_common
// static void setup_memread_read_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdc_0_proc1
// static void setup_memread_read_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p76_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfb_0_common
// static void setup_memread_read_p76_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p74_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfa_1_common
// static void setup_memread_read_p74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pda_0_proc1
// static void setup_memread_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfa_0_proc1
// static void setup_memread_read_p74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pf8_0_common
// static void setup_memread_read_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
// static void setup_memread_read_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pd4_0_proc1
// static void setup_memread_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
// static void setup_memread_read_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pd0_0_proc1
// static void setup_memread_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_read_pe_0_common
// static void setup_memread_read_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p4_0_final(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal
// static void setup_memread_read_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p38_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfc_0_common
// static void setup_memread_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdc_0_proc1
// static void setup_memread_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p36_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfb_0_1
// static void setup_memread_read_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfb_0_common
// static void setup_memread_read_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p34_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pfa_1_common
// static void setup_memread_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfa_0_proc1
// static void setup_memread_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pda_0_proc1
// static void setup_memread_read_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_read_pf8_0_common
// static void setup_memread_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pfc_0_proc1
// static void setup_memread_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_read_pdb_0_proc1
// static void setup_memread_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_final
// static void setup_memread_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_read_pfc_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfa_0_1
// static void setup_memread_read_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_read_pf4_0_common
// static void setup_memread_read_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pd4_0_proc1
// static void setup_memread_read_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pf8_0_1
// static void setup_memread_read_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_read_pf0_0_common
// static void setup_memread_read_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_read_pd0_0_proc1
// static void setup_memread_read_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_read_pf4_0_final
// static void setup_memread_read_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal

/*
 * calls: memread read
 */
// static int test_memread_read_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_read_p78_0_0
// static int test_memread_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memread_read_pfc_0_1
// static void setup_memread_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_read_pe_0_common
// static void setup_memread_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_read_pf4_0_proc1
// static void setup_memread_read_p0_0_final(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal
// static void setup_memread_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_read_pf4_0_procfinal


/*
 * calls: memread rename
 */
static int test_memread_rename_pf_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_rename_pf_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memread_rename_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memread_rename_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_rename_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_rename_pf_0_final(void) {
  unlink("__i0");
}
static void setup_memread_rename_pf_0_procfinal(void) {
  
}

/*
 * calls: memread rename
 */
// static int test_memread_rename_pf_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_pf_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pf_0_1
// static void setup_memread_rename_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pf_0_common
static void setup_memread_rename_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_rename_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pf_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pf_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pe8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
static int test_memread_rename_pe8_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memread_rename_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_memread_rename_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_rename_pf_0_proc0
// static void setup_memread_rename_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pe8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_pe8_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pe8_0_common
// static void setup_memread_rename_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_rename_pf_1_proc0
// static void setup_memread_rename_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pe0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_pe0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pf_0_common
// static void setup_memread_rename_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_rename_pf_0_proc0
// static void setup_memread_rename_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pe0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_pe0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pf_0_common
// static void setup_memread_rename_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_rename_pf_1_proc0
// static void setup_memread_rename_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
static int test_memread_rename_pc_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_memread_rename_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_memread_rename_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_rename_pf_0_proc0
// static void setup_memread_rename_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pc_0_final(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal
// static void setup_memread_rename_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_pc_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pc_0_1
// static void setup_memread_rename_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_rename_pc_0_common
// static void setup_memread_rename_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_rename_pf_1_proc0
// static void setup_memread_rename_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pc_1_final(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal
// static void setup_memread_rename_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
static int test_memread_rename_pb8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_rename_pb8_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pf_0_1
// static void setup_memread_rename_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pf_0_common
static void setup_memread_rename_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_rename_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pb8_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pf_0_1
// static void setup_memread_rename_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pf_0_common
static void setup_memread_rename_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_rename_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pb4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pb4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
static void setup_memread_rename_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_memread_rename_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x26000);
}
// static void setup_memread_rename_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
static void setup_memread_rename_pb4_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memread_rename_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pb4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pb4_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
static void setup_memread_rename_pb4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_memread_rename_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
}
// static void setup_memread_rename_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pb4_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pb4_0_final
// static void setup_memread_rename_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pb4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pb4_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pb4_0_common
static void setup_memread_rename_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x4d4000);
}
// static void setup_memread_rename_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pb4_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pb4_0_final
// static void setup_memread_rename_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pb4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pb4_3_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pe8_0_common
// static void setup_memread_rename_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x4d4000);
// }
// ^ See setup_memread_rename_pb4_1_proc0
// static void setup_memread_rename_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pb4_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pb4_4_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_pb4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pb4_1_common
static void setup_memread_rename_pb4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
}
// static void setup_memread_rename_pb4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pb4_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pb4_0_final
// static void setup_memread_rename_pb4_4_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pb4_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pb4_5_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_pb4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pe8_0_common
// static void setup_memread_rename_pb4_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_rename_pb8_1_proc0
// static void setup_memread_rename_pb4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pb4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pb4_5_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pb0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pf_0_common
// static void setup_memread_rename_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_rename_pb8_0_proc0
// static void setup_memread_rename_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pb0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pf_0_common
// static void setup_memread_rename_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_rename_pb8_1_proc0
// static void setup_memread_rename_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pa_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pc_0_1
static void setup_memread_rename_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_memread_rename_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_rename_pb8_0_proc0
// static void setup_memread_rename_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_pb8_0_0
// static int test_memread_rename_pa_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pc_0_1
// static void setup_memread_rename_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_rename_pa_0_common
// static void setup_memread_rename_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_rename_pb8_1_proc0
// static void setup_memread_rename_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p98_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pf_0_1
static void setup_memread_rename_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memread_rename_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_rename_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p98_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pf_0_1
// static void setup_memread_rename_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_p98_0_common
static void setup_memread_rename_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_rename_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p94_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p94_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
static void setup_memread_rename_p94_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_memread_rename_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_rename_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p94_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pb4_0_final
// static void setup_memread_rename_p94_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p94_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p94_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
static void setup_memread_rename_p94_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_memread_rename_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_rename_p98_0_proc0
// static void setup_memread_rename_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p94_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pb4_0_final
// static void setup_memread_rename_p94_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p94_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p94_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_p94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_p94_0_common
static void setup_memread_rename_p94_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_rename_p94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p94_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pb4_0_final
// static void setup_memread_rename_p94_2_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p94_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p94_3_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
static void setup_memread_rename_p94_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_memread_rename_p94_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_rename_p98_0_proc0
// static void setup_memread_rename_p94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p94_3_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p94_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p94_4_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_p94_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_p94_1_common
// static void setup_memread_rename_p94_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_rename_p98_1_proc0
// static void setup_memread_rename_p94_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p94_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pb4_0_final
// static void setup_memread_rename_p94_4_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p94_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p94_5_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_p94_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_p94_3_common
// static void setup_memread_rename_p94_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_rename_p98_1_proc0
// static void setup_memread_rename_p94_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p94_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p94_5_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p90_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_p98_0_common
// static void setup_memread_rename_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_rename_p98_0_proc0
// static void setup_memread_rename_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p90_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_p98_0_common
// static void setup_memread_rename_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_rename_p98_1_proc0
// static void setup_memread_rename_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p8_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pc_0_1
static void setup_memread_rename_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_rename_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_rename_p98_0_proc0
// static void setup_memread_rename_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_rename_pf_0_0
// static int test_memread_rename_p8_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pc_0_1
// static void setup_memread_rename_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_rename_p8_0_common
// static void setup_memread_rename_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_rename_p98_1_proc0
// static void setup_memread_rename_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
static int test_memread_rename_p6_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_rename_p6_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pf_0_1
// static void setup_memread_rename_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pf_0_common
// static void setup_memread_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p50_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_p6_0_0
// static int test_memread_rename_p50_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pe8_0_common
// static void setup_memread_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_p6_0_0
// static int test_memread_rename_p4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pe8_0_1
// static void setup_memread_rename_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_rename_pf_0_common
// static void setup_memread_rename_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_rename_pf_0_final
// static void setup_memread_rename_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal

/*
 * calls: memread rename
 */
// static int test_memread_rename_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_rename_p6_0_0
// static int test_memread_rename_p0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_rename_pc_0_1
// static void setup_memread_rename_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_rename_pc_0_common
// static void setup_memread_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_rename_pf_0_proc1
// static void setup_memread_rename_p0_0_final(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal
// static void setup_memread_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_rename_pf_0_procfinal


/*
 * calls: memread stat
 */
static int test_memread_stat_pe_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_memread_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memread_stat_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_stat_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_stat_pe_0_final(void) {
  unlink("__i0");
}
static void setup_memread_stat_pe_0_procfinal(void) {
  
}

/*
 * calls: memread stat
 */
// static int test_memread_stat_pe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_stat_pe_0_0
// static int test_memread_stat_pe_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_pe_0_1
// static void setup_memread_stat_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_stat_pe_0_common
static void setup_memread_stat_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_stat_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_stat_pe_0_final
// static void setup_memread_stat_pe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
// static int test_memread_stat_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_stat_pe_0_0
static int test_memread_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_memread_stat_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_memread_stat_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_stat_pe_0_proc0
// static void setup_memread_stat_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_pc_0_final(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal
// static void setup_memread_stat_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
// static int test_memread_stat_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_stat_pe_0_0
// static int test_memread_stat_pc_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_pc_0_1
// static void setup_memread_stat_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_stat_pc_0_common
// static void setup_memread_stat_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_stat_pe_1_proc0
// static void setup_memread_stat_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_pc_1_final(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal
// static void setup_memread_stat_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
static int test_memread_stat_pb_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_stat_pb_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_pe_0_1
// static void setup_memread_stat_pb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_stat_pe_0_common
static void setup_memread_stat_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memread_stat_pb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_pb_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_stat_pe_0_final
// static void setup_memread_stat_pb_0_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
// static int test_memread_stat_pb_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_stat_pb_0_0
// static int test_memread_stat_pb_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_pe_0_1
// static void setup_memread_stat_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_stat_pe_0_common
static void setup_memread_stat_pb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memread_stat_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_pb_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_stat_pe_0_final
// static void setup_memread_stat_pb_1_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
// static int test_memread_stat_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_stat_pb_0_0
// static int test_memread_stat_pa_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_pc_0_1
static void setup_memread_stat_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_memread_stat_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x26000);
// }
// ^ See setup_memread_stat_pb_0_proc0
// static void setup_memread_stat_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_stat_pe_0_final
// static void setup_memread_stat_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
// static int test_memread_stat_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_stat_pb_0_0
// static int test_memread_stat_pa_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_pc_0_1
// static void setup_memread_stat_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_stat_pa_0_common
// static void setup_memread_stat_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memread_stat_pb_1_proc0
// static void setup_memread_stat_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_stat_pe_0_final
// static void setup_memread_stat_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
// static int test_memread_stat_p9_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_stat_pe_0_0
static int test_memread_stat_p9_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_memread_stat_p9_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memread_stat_p9_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_stat_p9_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_p9_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_stat_pe_0_final
// static void setup_memread_stat_p9_0_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
// static int test_memread_stat_p9_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_stat_pe_0_0
// static int test_memread_stat_p9_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_p9_0_1
// static void setup_memread_stat_p9_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_stat_p9_0_common
static void setup_memread_stat_p9_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_stat_p9_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_p9_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_stat_pe_0_final
// static void setup_memread_stat_p9_1_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
// static int test_memread_stat_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_stat_pe_0_0
// static int test_memread_stat_p8_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_pc_0_1
static void setup_memread_stat_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_stat_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_stat_p9_0_proc0
// static void setup_memread_stat_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_stat_pe_0_final
// static void setup_memread_stat_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
// static int test_memread_stat_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_stat_pe_0_0
// static int test_memread_stat_p8_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_pc_0_1
// static void setup_memread_stat_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_stat_p8_0_common
// static void setup_memread_stat_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_stat_p9_1_proc0
// static void setup_memread_stat_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_p8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_stat_pe_0_final
// static void setup_memread_stat_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
static int test_memread_stat_p4_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_pe_0_1
// static void setup_memread_stat_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_stat_pe_0_common
// static void setup_memread_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_stat_pe_0_final
// static void setup_memread_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal

/*
 * calls: memread stat
 */
// static int test_memread_stat_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_stat_p4_0_0
// static int test_memread_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memread_stat_pc_0_1
// static void setup_memread_stat_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_stat_pc_0_common
// static void setup_memread_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_stat_pe_0_proc1
// static void setup_memread_stat_p0_0_final(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal
// static void setup_memread_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_stat_pe_0_procfinal


/*
 * calls: memread unlink
 */
static int test_memread_unlink_pe_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_unlink_pe_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memread_unlink_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memread_unlink_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_unlink_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_unlink_pe_0_final(void) {
  unlink("__i0");
}
static void setup_memread_unlink_pe_0_procfinal(void) {
  
}

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_pe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_unlink_pe_0_0
// static int test_memread_unlink_pe_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pe_0_1
// static void setup_memread_unlink_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_unlink_pe_0_common
static void setup_memread_unlink_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_unlink_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pe_0_final
// static void setup_memread_unlink_pe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_unlink_pe_0_0
static int test_memread_unlink_pc_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_memread_unlink_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_memread_unlink_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_unlink_pe_0_proc0
// static void setup_memread_unlink_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_pc_0_final(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal
// static void setup_memread_unlink_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_unlink_pe_0_0
// static int test_memread_unlink_pc_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pc_0_1
// static void setup_memread_unlink_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_unlink_pc_0_common
// static void setup_memread_unlink_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_unlink_pe_1_proc0
// static void setup_memread_unlink_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_pc_1_final(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal
// static void setup_memread_unlink_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
static int test_memread_unlink_pb0_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_unlink_pb0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pe_0_1
static void setup_memread_unlink_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memread_unlink_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_unlink_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
static void setup_memread_unlink_pb0_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memread_unlink_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_unlink_pb0_0_0
// static int test_memread_unlink_pb0_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pe_0_1
// static void setup_memread_unlink_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_unlink_pe_0_common
static void setup_memread_unlink_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_unlink_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pe_0_final
// static void setup_memread_unlink_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_pb0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_unlink_pb0_0_0
// static int test_memread_unlink_pb0_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pe_0_1
// static void setup_memread_unlink_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_unlink_pb0_0_common
static void setup_memread_unlink_pb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x1000);
}
// static void setup_memread_unlink_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_pb0_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pb0_0_final
// static void setup_memread_unlink_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_pb0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_unlink_pb0_0_0
// static int test_memread_unlink_pb0_3_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pe_0_1
// static void setup_memread_unlink_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_unlink_pe_0_common
static void setup_memread_unlink_pb0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_unlink_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pe_0_final
// static void setup_memread_unlink_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_unlink_pb0_0_0
// static int test_memread_unlink_pa_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pc_0_1
static void setup_memread_unlink_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_unlink_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_unlink_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pe_0_final
// static void setup_memread_unlink_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_unlink_pb0_0_0
// static int test_memread_unlink_pa_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pc_0_1
// static void setup_memread_unlink_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_unlink_pa_0_common
// static void setup_memread_unlink_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_unlink_pb0_3_proc0
// static void setup_memread_unlink_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pe_0_final
// static void setup_memread_unlink_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_unlink_pe_0_0
// static int test_memread_unlink_p90_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pe_0_1
static void setup_memread_unlink_p90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memread_unlink_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
// }
// ^ See setup_memread_unlink_pb0_0_proc0
// static void setup_memread_unlink_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_p90_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pb0_0_final
// static void setup_memread_unlink_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_unlink_pe_0_0
// static int test_memread_unlink_p90_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pe_0_1
static void setup_memread_unlink_p90_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memread_unlink_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_unlink_pa_0_proc0
// static void setup_memread_unlink_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pe_0_final
// static void setup_memread_unlink_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_p90_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_unlink_pe_0_0
// static int test_memread_unlink_p90_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pe_0_1
// static void setup_memread_unlink_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_unlink_p90_0_common
static void setup_memread_unlink_p90_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_unlink_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_p90_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pb0_0_final
// static void setup_memread_unlink_p90_2_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_p90_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_unlink_pe_0_0
// static int test_memread_unlink_p90_3_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pe_0_1
// static void setup_memread_unlink_p90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_unlink_p90_1_common
// static void setup_memread_unlink_p90_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_unlink_pb0_3_proc0
// static void setup_memread_unlink_p90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_p90_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pe_0_final
// static void setup_memread_unlink_p90_3_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_unlink_pe_0_0
// static int test_memread_unlink_p8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pc_0_1
static void setup_memread_unlink_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_unlink_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_unlink_pa_0_proc0
// static void setup_memread_unlink_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pe_0_final
// static void setup_memread_unlink_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_unlink_pe_0_0
// static int test_memread_unlink_p8_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pc_0_1
// static void setup_memread_unlink_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_unlink_p8_0_common
// static void setup_memread_unlink_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_unlink_pb0_3_proc0
// static void setup_memread_unlink_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_p8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pe_0_final
// static void setup_memread_unlink_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
static int test_memread_unlink_p4_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_unlink_p4_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pe_0_1
// static void setup_memread_unlink_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memread_unlink_pe_0_common
// static void setup_memread_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_unlink_pe_0_final
// static void setup_memread_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal

/*
 * calls: memread unlink
 */
// static int test_memread_unlink_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_unlink_p4_0_0
// static int test_memread_unlink_p0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memread_unlink_pc_0_1
// static void setup_memread_unlink_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_unlink_pc_0_common
// static void setup_memread_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_unlink_pe_0_proc1
// static void setup_memread_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal
// static void setup_memread_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_unlink_pe_0_procfinal


/*
 * calls: memread write
 */
static int test_memread_write_pfe_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("r", r, 0);
  expect_result("signal", signal, 0);
  return r;
}
static int test_memread_write_pfe_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_memread_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_memread_write_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_memread_write_pfe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: memread write
 */
// static int test_memread_write_pfe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pfe_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_pfe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pfe_0_common
static void setup_memread_write_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_write_pfe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfe_0_proc1
// static void setup_memread_write_pfe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pfe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pfc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
static int test_memread_write_pfc_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_memread_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_write_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pfc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pfc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pfc_0_common
static void setup_memread_write_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_write_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
static int test_memread_write_pf8_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_memread_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pf8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pf8_0_common
static void setup_memread_write_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_write_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pf4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pf4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
static void setup_memread_write_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memread_write_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_write_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memread_write_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_memread_write_pf4_0_procfinal(void) {
  
}

/*
 * calls: memread write
 */
// static int test_memread_write_pf4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pf4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
static void setup_memread_write_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_write_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
static void setup_memread_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memread_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_write_pf4_0_proc0
// static void setup_memread_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pf0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pf0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pf0_0_common
// static void setup_memread_write_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_write_pf4_1_proc0
// static void setup_memread_write_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pe_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
static void setup_memread_write_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memread_write_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memread_write_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pe_0_final(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal
// static void setup_memread_write_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pe_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_write_pe_0_common
static void setup_memread_write_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_write_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pe_1_final(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal
// static void setup_memread_write_pe_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pde_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pde_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pfe_0_common
static void setup_memread_write_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_write_pde_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_write_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pde_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pde_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pfe_0_common
static void setup_memread_write_pde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_write_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pde_0_proc1
// static void setup_memread_write_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pde_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pdc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pdc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pfc_0_common
static void setup_memread_write_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
static void setup_memread_write_pdc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_write_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pdc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pdc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pfc_0_common
static void setup_memread_write_pdc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memread_write_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pdc_0_proc1
// static void setup_memread_write_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pf8_0_common
// static void setup_memread_write_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_write_pdc_0_proc0
static void setup_memread_write_pd8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memread_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pd8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pf8_0_common
// static void setup_memread_write_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_write_pdc_1_proc0
// static void setup_memread_write_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pd8_0_proc1
// static void setup_memread_write_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pd4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
// static void setup_memread_write_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_write_pe_0_proc0
static void setup_memread_write_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_write_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pd4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pd4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
// static void setup_memread_write_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_write_pe_1_proc0
// static void setup_memread_write_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pf0_0_common
// static void setup_memread_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_write_pe_0_proc0
// static void setup_memread_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pd0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pd0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pf0_0_common
// static void setup_memread_write_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_write_pe_1_proc0
// static void setup_memread_write_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_write_pe_0_common
// static void setup_memread_write_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memread_write_pe_0_proc0
// static void setup_memread_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pc_0_final(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal
// static void setup_memread_write_pc_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_pc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_write_pe_0_common
// static void setup_memread_write_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memread_write_pe_1_proc0
// static void setup_memread_write_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pc_1_final(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal
// static void setup_memread_write_pc_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
static int test_memread_write_pbf_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_write_pbf_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
static void setup_memread_write_pbf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memread_write_pbf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_write_pbf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfe_0_proc1
// static void setup_memread_write_pbf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pbf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pbf_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pbf_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_pbf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
static void setup_memread_write_pbf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_write_pbf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfe_0_proc1
// static void setup_memread_write_pbf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pbf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pbe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pbe_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
static void setup_memread_write_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_write_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pbe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pbe_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
static void setup_memread_write_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_write_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pbc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pbc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
static void setup_memread_write_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pbc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
static void setup_memread_write_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_write_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pbb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pbb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
static void setup_memread_write_pbb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_write_pbb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_write_pbb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
static void setup_memread_write_pbb0_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memread_write_pbb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pbb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pbb0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
static void setup_memread_write_pbb0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_write_pbb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memread_write_pbb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pbb0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_pbb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pbb0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pbb0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pbb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
static void setup_memread_write_pbb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_write_pbb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pbb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pbb0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pbb0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pbb0_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pbb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
static void setup_memread_write_pbb0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_write_pbb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pbb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pbb0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pb8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
static void setup_memread_write_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_write_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
// static void setup_memread_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pb8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pb8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pb8_0_common
// static void setup_memread_write_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memread_write_pbb0_1_proc0
// static void setup_memread_write_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pb8_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pb8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
static void setup_memread_write_pb8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_write_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x8000);
}
// static void setup_memread_write_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pb8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pb8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pb8_2_common
static void setup_memread_write_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
}
// static void setup_memread_write_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
static void setup_memread_write_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pb0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
static void setup_memread_write_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_write_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_paf_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_paf_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_paf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
static void setup_memread_write_paf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_write_paf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pde_0_proc1
// static void setup_memread_write_paf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_paf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_paf_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_paf_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_paf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
static void setup_memread_write_paf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_write_paf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pde_0_proc1
// static void setup_memread_write_paf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_paf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pae_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pae_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
static void setup_memread_write_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_write_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pdc_0_proc1
// static void setup_memread_write_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pae_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pae_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
static void setup_memread_write_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_write_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pdc_0_proc1
// static void setup_memread_write_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pac_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pac_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
// static void setup_memread_write_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pae_0_proc0
// static void setup_memread_write_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pd8_0_proc1
// static void setup_memread_write_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pac_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pac_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pbf_0_common
// static void setup_memread_write_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_pae_1_proc0
// static void setup_memread_write_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pd8_0_proc1
// static void setup_memread_write_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pab0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pab0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pab0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pbb0_0_common
static void setup_memread_write_pab0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x0);
}
static void setup_memread_write_pab0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_write_pab0_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pab0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pab0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pab0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pbb0_1_common
static void setup_memread_write_pab0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
static void setup_memread_write_pab0_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_write_pab0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_pab0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pab0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pab0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pab0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
static void setup_memread_write_pab0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memread_write_pab0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_pab0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pab0_2_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pab0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pab0_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pab0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
static void setup_memread_write_pab0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memread_write_pab0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_pab0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pab0_3_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pa8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pb8_0_common
// static void setup_memread_write_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
// }
// ^ See setup_memread_write_pab0_0_proc0
// static void setup_memread_write_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pab0_1_proc1
// static void setup_memread_write_pa8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pa8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pa8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pb8_0_common
// static void setup_memread_write_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memread_write_pab0_1_proc0
// static void setup_memread_write_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pab0_1_proc1
// static void setup_memread_write_pa8_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pa8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pa8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pb8_2_common
static void setup_memread_write_pa8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x8000);
}
static void setup_memread_write_pa8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_write_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pa8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pa8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pb8_2_common
static void setup_memread_write_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
}
// static void setup_memread_write_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pa8_2_proc1
// static void setup_memread_write_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
// static void setup_memread_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pb0_0_proc0
// static void setup_memread_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_pbf_0_0
// static int test_memread_write_pa0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
// static void setup_memread_write_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_pb0_1_proc0
// static void setup_memread_write_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p9f_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p9f_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
static void setup_memread_write_p9f_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_memread_write_p9f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pbf_0_proc0
// static void setup_memread_write_p9f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfe_0_proc1
// static void setup_memread_write_p9f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p9f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p9f_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p9f_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_p9f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_p9f_0_common
// static void setup_memread_write_p9f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_pbf_1_proc0
// static void setup_memread_write_p9f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfe_0_proc1
// static void setup_memread_write_p9f_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p9f_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p9e_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p9e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
static void setup_memread_write_p9e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_memread_write_p9e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pbe_0_proc0
// static void setup_memread_write_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p9e_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p9e_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_p9e_0_common
// static void setup_memread_write_p9e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_pbe_1_proc0
// static void setup_memread_write_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_p9e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p9e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p9c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_p9e_0_common
// static void setup_memread_write_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pbc_0_proc0
// static void setup_memread_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p9c_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_p9e_0_common
// static void setup_memread_write_p9c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_pbc_1_proc0
// static void setup_memread_write_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p9a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
static int test_memread_write_p9a_0_1(void) {
  ssize_t r = write(10, dataval1, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_memread_write_p9a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_write_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x4000);
}
// static void setup_memread_write_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p9a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p9a_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
static void setup_memread_write_p9a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_write_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
}
// static void setup_memread_write_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p9a_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p9a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p9a_2_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
static void setup_memread_write_p9a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_write_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x5000);
}
// static void setup_memread_write_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p9a_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p9a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p9a_3_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
// static void setup_memread_write_p9a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_p9a_0_common
static void setup_memread_write_p9a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x4000);
}
// static void setup_memread_write_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p9a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p990_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p990_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
static void setup_memread_write_p990_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_write_p990_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memread_write_p990_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p990_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p990_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p990_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p990_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
// static void setup_memread_write_p990_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_p990_0_common
// static void setup_memread_write_p990_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_write_pbb0_3_proc0
// static void setup_memread_write_p990_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p990_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p990_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p990_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p990_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
static void setup_memread_write_p990_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_write_p990_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x5000);
}
// static void setup_memread_write_p990_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p990_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p990_2_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p990_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p990_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
static void setup_memread_write_p990_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memread_write_p990_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memread_write_p990_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p990_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p990_3_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p90_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pf0_0_common
// static void setup_memread_write_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pb0_0_proc0
// static void setup_memread_write_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p90_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pf0_0_common
// static void setup_memread_write_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_pb0_1_proc0
// static void setup_memread_write_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p8f_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p8f_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_p8f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_p9f_0_common
// static void setup_memread_write_p8f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_paf_0_proc0
// static void setup_memread_write_p8f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pde_0_proc1
// static void setup_memread_write_p8f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p8f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p8f_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p8f_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_p8f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_p9f_0_common
// static void setup_memread_write_p8f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_paf_1_proc0
// static void setup_memread_write_p8f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pde_0_proc1
// static void setup_memread_write_p8f_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p8f_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p8e_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p8e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_p9e_0_common
// static void setup_memread_write_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pae_0_proc0
// static void setup_memread_write_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pdc_0_proc1
// static void setup_memread_write_p8e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p8e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p8e_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p8e_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p8e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_p9e_0_common
// static void setup_memread_write_p8e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_pae_1_proc0
// static void setup_memread_write_p8e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pdc_0_proc1
// static void setup_memread_write_p8e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p8e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p8c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p8c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_p9e_0_common
// static void setup_memread_write_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pae_0_proc0
// static void setup_memread_write_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pd8_0_proc1
// static void setup_memread_write_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p8c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p8c_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_p9e_0_common
// static void setup_memread_write_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_pae_1_proc0
// static void setup_memread_write_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pd8_0_proc1
// static void setup_memread_write_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p8a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p8a_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
// static void setup_memread_write_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_p9a_0_common
static void setup_memread_write_p8a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x4000);
}
static void setup_memread_write_p8a_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memread_write_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p8a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p8a_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
// static void setup_memread_write_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_p9a_1_common
static void setup_memread_write_p8a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
}
// static void setup_memread_write_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pab0_0_proc1
// static void setup_memread_write_p8a_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p8a_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p8a_2_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
// static void setup_memread_write_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_p9a_2_common
static void setup_memread_write_p8a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i1", 0x5000);
}
// static void setup_memread_write_p8a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_p8a_0_proc1
// static void setup_memread_write_p8a_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memread_write_pbb0_0_final
// static void setup_memread_write_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p8a_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p8a_3_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
// static void setup_memread_write_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_p9a_0_common
static void setup_memread_write_p8a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4000);
}
// static void setup_memread_write_p8a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_p8a_0_proc1
// static void setup_memread_write_p8a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p890_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p890_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
// static void setup_memread_write_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_p990_0_common
// static void setup_memread_write_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pb0_0_proc0
// static void setup_memread_write_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pab0_0_proc1
// static void setup_memread_write_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p890_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p890_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p890_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_p9a_0_1
// static void setup_memread_write_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_p990_0_common
// static void setup_memread_write_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memread_write_pab0_3_proc0
// static void setup_memread_write_p890_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_p890_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p890_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p890_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p890_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p890_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_p990_3_common
// static void setup_memread_write_p890_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pb0_0_proc0
// static void setup_memread_write_p890_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_p890_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p890_2_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p890_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p890_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p890_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_p990_3_common
// static void setup_memread_write_p890_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_pb0_1_proc0
// static void setup_memread_write_p890_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_p890_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p890_3_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p80_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p80_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pf0_0_common
// static void setup_memread_write_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memread_write_pb0_0_proc0
// static void setup_memread_write_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p80_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p80_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("r", r, 0);
//   expect_result("signal", signal, 0);
//   return r;
// }
// ^ See test_memread_write_pfe_0_0
// static int test_memread_write_p80_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pf0_0_common
// static void setup_memread_write_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memread_write_pb0_1_proc0
// static void setup_memread_write_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p80_1_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
static int test_memread_write_p7c_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int r, signal;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    r = *p;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memread_write_p7c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pfe_0_common
// static void setup_memread_write_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pde_0_proc1
// static void setup_memread_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfe_0_proc1
// static void setup_memread_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p78_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pfc_0_common
// static void setup_memread_write_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pdc_0_proc1
// static void setup_memread_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pf8_0_common
// static void setup_memread_write_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pd8_0_proc1
// static void setup_memread_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p68_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
// static void setup_memread_write_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p60_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pf0_0_common
// static void setup_memread_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_write_pe_0_common
// static void setup_memread_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p4_0_final(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal
// static void setup_memread_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p3c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfe_0_1
// static void setup_memread_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pfe_0_common
// static void setup_memread_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfe_0_proc1
// static void setup_memread_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pde_0_proc1
// static void setup_memread_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p38_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pfc_0_common
// static void setup_memread_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pdc_0_proc1
// static void setup_memread_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memread_write_pf8_0_common
// static void setup_memread_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pfc_0_proc1
// static void setup_memread_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memread_write_pd8_0_proc1
// static void setup_memread_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_final
// static void setup_memread_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memread_write_pfe_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memread_write_pf4_0_common
// static void setup_memread_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pfc_0_1
// static void setup_memread_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memread_write_pf0_0_common
// static void setup_memread_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memread_write_pd4_0_proc1
// static void setup_memread_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memread_write_pf4_0_final
// static void setup_memread_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal

/*
 * calls: memread write
 */
// static int test_memread_write_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int r, signal;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     r = *p;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memread_write_p7c_0_0
// static int test_memread_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memread_write_pf8_0_1
// static void setup_memread_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memread_write_pe_0_common
// static void setup_memread_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memread_write_pf4_0_proc1
// static void setup_memread_write_p0_0_final(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal
// static void setup_memread_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memread_write_pf4_0_procfinal


/*
 * calls: memwrite memwrite
 */
static int test_memwrite_memwrite_pfe_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_memwrite_pfe_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 1;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static void setup_memwrite_memwrite_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memwrite_memwrite_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
static void setup_memwrite_memwrite_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_memwrite_pfe_0_final(void) {
  
}
static void setup_memwrite_memwrite_pfe_0_procfinal(void) {
  
}

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pfe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pfe_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_pfe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
static void setup_memwrite_memwrite_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_memwrite_pfe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pfe_1_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_pfe_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pfd_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
static int test_memwrite_memwrite_pfd_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
static void setup_memwrite_memwrite_pfd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_memwrite_pfd_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_memwrite_pfd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
static void setup_memwrite_memwrite_pfd_0_final(void) {
  unlink("__i0");
}
// static void setup_memwrite_memwrite_pfd_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pfc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
static int test_memwrite_memwrite_pfc_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static void setup_memwrite_memwrite_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_memwrite_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pfc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pfc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
static int test_memwrite_memwrite_pf8_0_1(void) {
  char* p = (char*) 0x12345601000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_memwrite_memwrite_pf8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
static void setup_memwrite_memwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_memwrite_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pf8_0_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pf8_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pf0_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
// static void setup_memwrite_memwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pf0_0_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pee_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pee_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_pee_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
// static void setup_memwrite_memwrite_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
// static void setup_memwrite_memwrite_pee_0_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_pee_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_ped_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
static int test_memwrite_memwrite_ped_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static void setup_memwrite_memwrite_ped_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_ped_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
static void setup_memwrite_memwrite_ped_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_memwrite_ped_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_ped_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pec_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pec_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
static void setup_memwrite_memwrite_pec_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pec_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pec_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pe8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
static int test_memwrite_memwrite_pe8_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static void setup_memwrite_memwrite_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
static void setup_memwrite_memwrite_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pe8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pe8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
static void setup_memwrite_memwrite_pe8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_memwrite_pe8_1_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pe0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pe0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
// static void setup_memwrite_memwrite_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pe0_0_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pdf_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pdf_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
// static void setup_memwrite_memwrite_pdf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pdf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_memwrite_pdf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pdf_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pdf_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pde8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pde8_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfd_0_1
static void setup_memwrite_memwrite_pde8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_memwrite_pde8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i1", 0x26000);
}
// static void setup_memwrite_memwrite_pde8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
static void setup_memwrite_memwrite_pde8_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_memwrite_memwrite_pde8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pde8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pde8_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfd_0_1
// static void setup_memwrite_memwrite_pde8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pde8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_file(0x12345601000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_memwrite_pde8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pde8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pde8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pde8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pde8_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfd_0_1
// static void setup_memwrite_memwrite_pde8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pde8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pde8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pde8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pde8_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pde8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pde8_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static void setup_memwrite_memwrite_pde8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pde8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pde8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pde8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pde8_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pde0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pde0_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
static void setup_memwrite_memwrite_pde0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_memwrite_pde0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i1", 0x6000);
}
// static void setup_memwrite_memwrite_pde0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pde0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_memwrite_pde8_0_final
// static void setup_memwrite_memwrite_pde0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pde0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pde0_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
static void setup_memwrite_memwrite_pde0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_memwrite_pde0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
  init_map_file(0x12345601000, 1, "__i0", 0x7000);
}
// static void setup_memwrite_memwrite_pde0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pde0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pde0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pdc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pdc_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pdc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pdc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pdc_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pdc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_memwrite_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pdc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pdc_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pd8_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pd7_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pd7_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_pd7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pd7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pd7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
// static void setup_memwrite_memwrite_pd7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pd7_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pd68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pd68_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static void setup_memwrite_memwrite_pd68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pde8_0_common
// static void setup_memwrite_memwrite_pd68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
static void setup_memwrite_memwrite_pd68_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_memwrite_memwrite_pd68_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_memwrite_pde8_0_final
// static void setup_memwrite_memwrite_pd68_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pd68_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pd68_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static void setup_memwrite_memwrite_pd68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pd68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pd68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_memwrite_ped_0_proc1
// static void setup_memwrite_memwrite_pd68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pd68_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pd68_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pd68_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static void setup_memwrite_memwrite_pd68_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pd68_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pd68_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pd68_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pd68_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pd60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pd60_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_pd60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pde0_0_common
// static void setup_memwrite_memwrite_pd60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
static void setup_memwrite_memwrite_pd60_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
}
// static void setup_memwrite_memwrite_pd60_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_memwrite_pde8_0_final
// static void setup_memwrite_memwrite_pd60_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pd60_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pd60_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_pd60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pde0_1_common
static void setup_memwrite_memwrite_pd60_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
}
static void setup_memwrite_memwrite_pd60_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memwrite_memwrite_pd60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pd60_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pd4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pd4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pd4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static int test_memwrite_memwrite_pd0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pcf_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pcf_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
// static void setup_memwrite_memwrite_pcf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_pcf_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pdf_0_proc0
// static void setup_memwrite_memwrite_pcf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pcf_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pcf_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pce8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pce8_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfd_0_1
static void setup_memwrite_memwrite_pce8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_memwrite_memwrite_pce8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i1", 0x26000);
// }
// ^ See setup_memwrite_memwrite_pde8_0_proc0
// static void setup_memwrite_memwrite_pce8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pce8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_memwrite_pde8_0_final
// static void setup_memwrite_memwrite_pce8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pce8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pce8_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfd_0_1
// static void setup_memwrite_memwrite_pce8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
static void setup_memwrite_memwrite_pce8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x986000);
}
// static void setup_memwrite_memwrite_pce8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pce8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pce8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pce0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pce0_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 1;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_1
static void setup_memwrite_memwrite_pce0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_memwrite_pce0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pce0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pce0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pce0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pce0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pce0_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
static void setup_memwrite_memwrite_pce0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_memwrite_pce0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pde8_2_proc0
// static void setup_memwrite_memwrite_pce0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pce0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pce0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pce0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pce0_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_pce0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pce0_1_common
// static void setup_memwrite_memwrite_pce0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pce0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pce0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pce0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pcc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pcc_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pdc_0_proc0
// static void setup_memwrite_memwrite_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pcc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pcc_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
static void setup_memwrite_memwrite_pcc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_memwrite_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pcc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pcc_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pc8_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pc7_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pc7_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_pc7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_pc7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pc7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
// static void setup_memwrite_memwrite_pc7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pc7_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pc68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pc68_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static void setup_memwrite_memwrite_pc68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pce8_0_common
// static void setup_memwrite_memwrite_pc68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pc68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x26000);
// }
// ^ See setup_memwrite_memwrite_pd68_0_proc1
// static void setup_memwrite_memwrite_pc68_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_memwrite_pde8_0_final
// static void setup_memwrite_memwrite_pc68_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pc68_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pc68_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static void setup_memwrite_memwrite_pc68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_pc68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
static void setup_memwrite_memwrite_pc68_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x27000);
}
// static void setup_memwrite_memwrite_pc68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pc68_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pc60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
static int test_memwrite_memwrite_pc60_0_1(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 1;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
// static void setup_memwrite_memwrite_pc60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pce0_0_common
// static void setup_memwrite_memwrite_pc60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
static void setup_memwrite_memwrite_pc60_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_memwrite_pc60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pc60_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pc60_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pc60_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_pc60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pce0_1_common
// static void setup_memwrite_memwrite_pc60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pc60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pc60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pc60_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pc4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pc4_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_pc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_pc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_pc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pc4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pc4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pc4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_pc4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_pc4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pc4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_pc4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pc4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static int test_memwrite_memwrite_pc0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pbc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pbc_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
// static void setup_memwrite_memwrite_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
static void setup_memwrite_memwrite_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_memwrite_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pbc_0_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pbc_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
// static void setup_memwrite_memwrite_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_memwrite_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pba_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pba_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfd_0_1
// static void setup_memwrite_memwrite_pba_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
  init_map_file(0x12345601000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_memwrite_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pba_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pba_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pba_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pba_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfd_0_1
// static void setup_memwrite_memwrite_pba_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memwrite_memwrite_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pba_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pba_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pb8_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
// static void setup_memwrite_memwrite_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
static void setup_memwrite_memwrite_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pb8_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
// static void setup_memwrite_memwrite_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
static void setup_memwrite_memwrite_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pb0_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pb0_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
static void setup_memwrite_memwrite_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_memwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pb0_1_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pb0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pb0_2_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_memwrite_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pb0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pb0_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pb0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pb0_4_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pb0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_pb0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_pb0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pb0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pb0_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pb0_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pb0_5_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_pb0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_pb0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_pb0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pb0_5_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_pb0_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pa_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_pa_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_pa_1_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p9c_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
// static void setup_memwrite_memwrite_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p9c_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_p9c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
// static void setup_memwrite_memwrite_p9c_1_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_p9c_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p9a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p9a_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static void setup_memwrite_memwrite_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memwrite_memwrite_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_memwrite_ped_0_proc1
// static void setup_memwrite_memwrite_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p9a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p9a_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static void setup_memwrite_memwrite_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_p9a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_memwrite_ped_0_proc1
// static void setup_memwrite_memwrite_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p98_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p98_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p90_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p90_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p90_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p90_2_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_p90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_p90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p90_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p90_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p90_3_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_p90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_p90_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_p90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_p90_3_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_p90_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p8_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p8_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p78_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p78_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
// static void setup_memwrite_memwrite_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
static void setup_memwrite_memwrite_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_memwrite_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p78_0_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_p78_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p74_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p74_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfd_0_1
// static void setup_memwrite_memwrite_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_p74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_memwrite_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p74_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p74_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p70_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfc_0_1
// static void setup_memwrite_memwrite_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
static void setup_memwrite_memwrite_p70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p70_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p6_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
static void setup_memwrite_memwrite_p6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_memwrite_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p6_1_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
static void setup_memwrite_memwrite_p6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_memwrite_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p6_1_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_p6_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p4_0_1(void) {
//   char* p = (char*) 0x12345601000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pf8_0_1
// static void setup_memwrite_memwrite_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p4_0_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p4_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p4_1_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_p4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p38_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p38_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_memwrite_pfe_1_proc0
// static void setup_memwrite_memwrite_p38_0_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_p38_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p34_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p34_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_ped_0_1
// static void setup_memwrite_memwrite_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_memwrite_ped_0_proc1
// static void setup_memwrite_memwrite_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p34_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p30_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_memwrite_pfe_0_0
// static void setup_memwrite_memwrite_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfc_0_common
// static void setup_memwrite_memwrite_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pec_0_proc1
// static void setup_memwrite_memwrite_p30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p30_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p2_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p2_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_memwrite_pfd_0_common
// static void setup_memwrite_memwrite_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_memwrite_pe8_0_proc1
// static void setup_memwrite_memwrite_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_memwrite_pfd_0_final
// static void setup_memwrite_memwrite_p2_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p2_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p2_1_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_memwrite_pe8_1_proc1
// static void setup_memwrite_memwrite_p2_1_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_p2_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal

/*
 * calls: memwrite memwrite
 */
// static int test_memwrite_memwrite_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static int test_memwrite_memwrite_p0_0_1(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_memwrite_pe8_0_1
// static void setup_memwrite_memwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_common
// static void setup_memwrite_memwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_memwrite_pfe_0_proc1
// static void setup_memwrite_memwrite_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal
// static void setup_memwrite_memwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_memwrite_pfe_0_procfinal


/*
 * calls: memwrite mmap
 */
static int test_memwrite_mmap_pfe_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_mmap_pfe_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
static void setup_memwrite_mmap_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memwrite_mmap_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
static void setup_memwrite_mmap_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_mmap_pfe_0_final(void) {
  
}
static void setup_memwrite_mmap_pfe_0_procfinal(void) {
  
}

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfe_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pfe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
static void setup_memwrite_mmap_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pfe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfe_1_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pfe_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfe_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfe_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
static void setup_memwrite_mmap_pfe_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_mmap_pfe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pfe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
static void setup_memwrite_mmap_pfe_2_final(void) {
  unlink("__i0");
}
// static void setup_memwrite_mmap_pfe_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfe_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfe_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pfe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
static void setup_memwrite_mmap_pfe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_mmap_pfe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfe_3_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pfe_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfe_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pfe_4_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pfe_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pfe_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pfe_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfe_4_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pfe_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfe_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfe_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pfe_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pfe_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pfe_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfe_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pfe_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfe_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfe_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pfe_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pfe_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_0_proc0
// static void setup_memwrite_mmap_pfe_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfe_6_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pfe_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfe_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfe_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pfe_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pfe_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pfe_1_proc0
// static void setup_memwrite_mmap_pfe_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfe_7_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pfe_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfe_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfe_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pfe_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pfe_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pfe_2_proc0
// static void setup_memwrite_mmap_pfe_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfe_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pfe_8_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfe_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfe_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pfe_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pfe_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pfe_5_proc0
// static void setup_memwrite_mmap_pfe_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfe_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pfe_9_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfe_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pfe_10_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pfe_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pfe_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pfe_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfe_10_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pfe_10_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfb_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pfb_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
static void setup_memwrite_mmap_pfb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_mmap_pfb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_mmap_pfb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_memwrite_mmap_pfb_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_memwrite_mmap_pfb_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfb_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfb_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pfb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
static void setup_memwrite_mmap_pfb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_mmap_pfb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pfb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pfb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfac_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pfac_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pfac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pfac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_pfac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pfac_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfac_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfac_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pfac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pfac_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pfac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pfac_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfac_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfac_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pfac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pfac_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_mmap_pfac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfac_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pfac_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfac_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfac_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pfac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pfac_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pfac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfac_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pfac_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfac_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pfac_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pfac_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pfac_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pfac_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfac_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pfac_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pfa8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x6000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memwrite_mmap_pfa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pfa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_mmap_pfa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pfa8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pfa8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pfa8_1_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memwrite_mmap_pfa8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_mmap_pfa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfac_2_proc0
// static void setup_memwrite_mmap_pfa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pfa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pfa8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pf8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pf8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pf8_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pf6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pf6_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pf6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pf6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pf6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pf6_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pf6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pf6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pf6_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pf6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pf6_1_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pf6_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pf3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pf3_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pf3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_pf3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfb_0_proc0
// static void setup_memwrite_mmap_pf3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pf3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pf3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pf3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pf3_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pf3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_pf3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfb_1_proc0
// static void setup_memwrite_mmap_pf3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pf3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pf3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pf28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pf28_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pf28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pf28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfac_2_proc0
// static void setup_memwrite_mmap_pf28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pf28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pf28_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pf28_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pf28_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pf28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pf28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfac_2_proc0
// static void setup_memwrite_mmap_pf28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pf28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pf28_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pf0_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pf0_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pec_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pec_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pec_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pec_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_peb_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_peb_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_peb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
static void setup_memwrite_mmap_peb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_mmap_peb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_mmap_peb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_peb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_peb_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_peb_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_peb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_peb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_peb_0_proc0
static void setup_memwrite_mmap_peb_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_mmap_peb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_peb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pea_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pea_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
static void setup_memwrite_mmap_pea_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_mmap_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pea_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pe8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pe8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pe8_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pe6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pe6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pe6_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pe6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pe6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pe6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pe6_1_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pe6_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pe3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pe3_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pe3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_pe3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_peb_0_proc0
// static void setup_memwrite_mmap_pe3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_pe3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pe3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pe3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pe3_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pe3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_pe3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_peb_0_proc0
// static void setup_memwrite_mmap_pe3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_pe3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pe3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pe28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pe28_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_pe28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pe28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pe28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_pe28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pe28_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pe28_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pe28_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_pe28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pe28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pe28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_pe28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pe28_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pe0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pe0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pfe_3_proc0
// static void setup_memwrite_mmap_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pe0_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
static int test_memwrite_mmap_pdf0_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_mmap_pdf0_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pdf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
  init_map_file(0x12345601000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_mmap_pdf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdf0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdf0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdf0_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pdf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
}
// static void setup_memwrite_mmap_pdf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdf0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdf0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdf0_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pdf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memwrite_mmap_pdf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdf0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdf0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdf0_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pdf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdf0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_pdf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdf0_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdf0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdf0_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pdf0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdf0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pdf0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdf0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdf0_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
static void setup_memwrite_mmap_pdd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_mmap_pdd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_mmap_pdd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pdd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pdd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pdd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pdd8_0_common
static void setup_memwrite_mmap_pdd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_mmap_pdd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pdd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pdd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pdd6_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memwrite_mmap_pdd6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pdd6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_memwrite_mmap_pdd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
static void setup_memwrite_mmap_pdd6_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memwrite_mmap_pdd6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pdd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memwrite_mmap_pdd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pdd6_2_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pdd6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e28000);
}
// static void setup_memwrite_mmap_pdd6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_2_1
// static void setup_memwrite_mmap_pdd6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e28000);
}
// static void setup_memwrite_mmap_pdd6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_2_1
// static void setup_memwrite_mmap_pdd6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
}
// static void setup_memwrite_mmap_pdd6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pdd6_5_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pdd6_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdd6_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
//   init_map_file(0x12345601000, 0, "__i0", 0x1e28000);
// }
// ^ See setup_memwrite_mmap_pdd6_3_proc0
// static void setup_memwrite_mmap_pdd6_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_5_1
// static void setup_memwrite_mmap_pdd6_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdd6_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
// }
// ^ See setup_memwrite_mmap_pdd6_4_proc0
// static void setup_memwrite_mmap_pdd6_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_2_1
// static void setup_memwrite_mmap_pdd6_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_pdd6_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_2_1
// static void setup_memwrite_mmap_pdd6_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pdd6_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_8_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_5_1
// static void setup_memwrite_mmap_pdd6_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdd6_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pdd6_7_proc0
// static void setup_memwrite_mmap_pdd6_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_9_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_5_1
// static void setup_memwrite_mmap_pdd6_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdd6_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pdd6_8_proc0
// static void setup_memwrite_mmap_pdd6_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_10_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1e27000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_5_1
// static void setup_memwrite_mmap_pdd6_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdd6_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
//   init_map_file(0x12345601000, 1, "__i0", 0x1e28000);
// }
// ^ See setup_memwrite_mmap_pdd6_2_proc0
// static void setup_memwrite_mmap_pdd6_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_11_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_12_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pdd6_12_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x20ad000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pdd6_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34267136, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
  init_map_file(0x12345601000, 1, "__i0", 0x20ad000);
}
// static void setup_memwrite_mmap_pdd6_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_12_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_13_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfa8_1_1
// static void setup_memwrite_mmap_pdd6_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_mmap_pdd6_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_13_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_14_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pdd6_14_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pdd6_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_mmap_pdd6_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_14_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_15_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_14_1
// static void setup_memwrite_mmap_pdd6_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_file(0x12345601000, 0, "__i0", 0x1000);
}
// static void setup_memwrite_mmap_pdd6_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_15_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_16_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_14_1
// static void setup_memwrite_mmap_pdd6_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdd6_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_mmap_pdd6_13_proc0
// static void setup_memwrite_mmap_pdd6_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_16_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_17_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pdd6_17_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pdd6_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdd6_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
//   init_map_file(0x12345601000, 0, "__i0", 0x1000);
// }
// ^ See setup_memwrite_mmap_pdd6_15_proc0
// static void setup_memwrite_mmap_pdd6_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_17_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_18_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_17_1
// static void setup_memwrite_mmap_pdd6_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdd6_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_mmap_pdd6_13_proc0
// static void setup_memwrite_mmap_pdd6_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_18_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_19_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_14_1
// static void setup_memwrite_mmap_pdd6_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_file(0x12345601000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_mmap_pdd6_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_19_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_20_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_17_1
// static void setup_memwrite_mmap_pdd6_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdd6_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
//   init_map_file(0x12345601000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_mmap_pdd6_19_proc0
// static void setup_memwrite_mmap_pdd6_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_20_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_21_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pdd6_21_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x985000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memwrite_mmap_pdd6_21_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_mmap_pdd6_21_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x986000);
}
// static void setup_memwrite_mmap_pdd6_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_21_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pdd6_0_final
// static void setup_memwrite_mmap_pdd6_21_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_22_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_22_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_0_1
// static void setup_memwrite_mmap_pdd6_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_22_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_memwrite_mmap_pdd6_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_22_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_23_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_23_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_0_1
// static void setup_memwrite_mmap_pdd6_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdd6_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_mmap_pdd6_13_proc0
// static void setup_memwrite_mmap_pdd6_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_23_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_24_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x20ad000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_12_1
// static void setup_memwrite_mmap_pdd6_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_24_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34267136, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_pdd6_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_24_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_25_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pdd6_25_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x4d4000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pdd6_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_25_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5066752, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pdd6_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_25_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_25_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_26_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pdd6_26_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x985000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pdd6_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_26_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x985000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pdd6_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_26_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdd6_27_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdd6_27_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x985000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_26_1
// static void setup_memwrite_mmap_pdd6_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdd6_27_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x985000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_pdd6_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdd6_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdd6_27_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_mmap_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdb0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_pdb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdc_0_proc0
// static void setup_memwrite_mmap_pdb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdb0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pdb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pdb0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_pdb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pdb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdc_0_proc0
// static void setup_memwrite_mmap_pdb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pdb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pdb0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd98_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pd98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pdd8_0_common
// static void setup_memwrite_mmap_pd98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdd8_0_proc0
// static void setup_memwrite_mmap_pd98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pd98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pd98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd98_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pd98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pdd8_0_common
// static void setup_memwrite_mmap_pd98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdd8_1_proc0
// static void setup_memwrite_mmap_pd98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pd98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pd98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd94_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd94_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_pd94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pd94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memwrite_mmap_pd94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd94_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd94_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd94_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_pd94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pd94_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_mmap_pd94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd94_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd94_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pd94_2_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x20ad000UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pd94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pd94_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x20ae000);
}
// static void setup_memwrite_mmap_pd94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd94_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd94_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd94_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pd94_3_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x20ad000UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pd94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd94_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x20ae000);
// }
// ^ See setup_memwrite_mmap_pd94_2_proc0
// static void setup_memwrite_mmap_pd94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd94_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd94_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd94_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x20ad000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pd94_2_1
// static void setup_memwrite_mmap_pd94_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pd94_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
}
// static void setup_memwrite_mmap_pd94_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd94_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd94_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd94_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pd94_5_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1000UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pd94_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd94_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_mmap_pdd6_13_proc0
// static void setup_memwrite_mmap_pd94_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd94_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd94_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd94_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd94_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x20ad000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pd94_3_1
// static void setup_memwrite_mmap_pd94_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pd94_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
}
// static void setup_memwrite_mmap_pd94_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd94_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd94_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd94_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pd94_7_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x985000UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pd94_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pd94_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x985000);
}
// static void setup_memwrite_mmap_pd94_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd94_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd94_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd8_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdc_0_proc0
// static void setup_memwrite_mmap_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pec_0_1
// static void setup_memwrite_mmap_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdc_0_proc0
// static void setup_memwrite_mmap_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd58_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd58_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pd58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pdd8_0_common
static void setup_memwrite_mmap_pd58_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_mmap_pd58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_pd58_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pd58_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd58_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd58_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pd58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pdd8_0_common
// static void setup_memwrite_mmap_pd58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pd58_0_proc0
// static void setup_memwrite_mmap_pd58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_pd58_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pd58_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd50_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd50_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pea_0_1
// static void setup_memwrite_mmap_pd50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdc_0_proc0
static void setup_memwrite_mmap_pd50_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_mmap_pd50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd50_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd50_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd50_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pea_0_1
// static void setup_memwrite_mmap_pd50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memwrite_mmap_pdf0_2_proc0
static void setup_memwrite_mmap_pd50_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_mmap_pd50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd50_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdc_0_proc0
// static void setup_memwrite_mmap_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd30_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_pd30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdc_0_proc0
// static void setup_memwrite_mmap_pd30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd30_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd30_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd30_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_pd30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdc_0_proc0
// static void setup_memwrite_mmap_pd30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd30_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd30_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd18_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pd18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pdd8_0_common
// static void setup_memwrite_mmap_pd18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pd58_0_proc0
// static void setup_memwrite_mmap_pd18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_pd18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pd18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd18_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pd18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pdd8_0_common
// static void setup_memwrite_mmap_pd18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pd58_0_proc0
// static void setup_memwrite_mmap_pd18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_pd18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pd18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd14_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd14_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_pd14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdc_0_proc0
// static void setup_memwrite_mmap_pd14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pd50_0_proc1
// static void setup_memwrite_mmap_pd14_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd14_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd14_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd14_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_pd14_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pd14_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
static void setup_memwrite_mmap_pd14_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_mmap_pd14_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd14_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd14_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd14_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_pd14_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd14_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_mmap_pd14_1_proc0
// static void setup_memwrite_mmap_pd14_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pd14_1_proc1
// static void setup_memwrite_mmap_pd14_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd14_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd14_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pd14_3_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1e27000UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pd14_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd14_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memwrite_mmap_pdf0_2_proc0
// static void setup_memwrite_mmap_pd14_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pd50_0_proc1
// static void setup_memwrite_mmap_pd14_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd14_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd14_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pd14_4_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x4d4000UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pd14_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pd14_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
}
// static void setup_memwrite_mmap_pd14_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pd50_0_proc1
// static void setup_memwrite_mmap_pd14_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd14_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd14_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pd14_5_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pd14_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd14_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memwrite_mmap_pdf0_2_proc0
static void setup_memwrite_mmap_pd14_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_mmap_pd14_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd14_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd14_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
static int test_memwrite_mmap_pd14_6_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x4d4000UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pd14_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd14_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
// }
// ^ See setup_memwrite_mmap_pd14_4_proc0
// static void setup_memwrite_mmap_pd14_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pd50_0_proc1
// static void setup_memwrite_mmap_pd14_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd14_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pdf0_0_0
// static int test_memwrite_mmap_pd0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mmap_pdc_0_proc0
// static void setup_memwrite_mmap_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcf8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_10_1
// static void setup_memwrite_mmap_pcf8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
static void setup_memwrite_mmap_pcf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pcf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcf8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcf0_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pcf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
static void setup_memwrite_mmap_pcf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pcf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcf0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcf0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcf0_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pcf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pcf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pcf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcf0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcf0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcf0_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pcf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
static void setup_memwrite_mmap_pcf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pcf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcf0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcf0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcf0_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pcf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
static void setup_memwrite_mmap_pcf0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_pcf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcf0_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcf0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcf0_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pcf0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
static void setup_memwrite_mmap_pcf0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pcf0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcf0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcf0_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
static void setup_memwrite_mmap_pcd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_mmap_pcd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pcd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pcd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pcd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pcd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pcd8_0_common
static void setup_memwrite_mmap_pcd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pcd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pcd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pcd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pcd4_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static void setup_memwrite_mmap_pcd4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memwrite_mmap_pcd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pcd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_0_common
// static void setup_memwrite_mmap_pcd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
// }
// ^ See setup_memwrite_mmap_pcd4_0_proc0
// static void setup_memwrite_mmap_pcd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
static void setup_memwrite_mmap_pcd4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_memwrite_mmap_pcd4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pcd4_3_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pcd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_2_common
// static void setup_memwrite_mmap_pcd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_memwrite_mmap_pcd4_2_proc0
// static void setup_memwrite_mmap_pcd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
static void setup_memwrite_mmap_pcd4_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i1", 0x5000);
}
// static void setup_memwrite_mmap_pcd4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
static void setup_memwrite_mmap_pcd4_4_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_memwrite_mmap_pcd4_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
static void setup_memwrite_mmap_pcd4_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 0, "__i1", 0x3000);
}
// static void setup_memwrite_mmap_pcd4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_5_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pcd4_6_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x6000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
static void setup_memwrite_mmap_pcd4_6_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memwrite_mmap_pcd4_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
static void setup_memwrite_mmap_pcd4_7_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pcd4_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pcd4_8_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pcd4_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_5_common
static void setup_memwrite_mmap_pcd4_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_file(0x12345601000, 0, "__i1", 0x3000);
}
// static void setup_memwrite_mmap_pcd4_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_8_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_8_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
static void setup_memwrite_mmap_pcd4_9_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i1", 0x3000);
}
// static void setup_memwrite_mmap_pcd4_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_9_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_9_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pcd4_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
// static void setup_memwrite_mmap_pcd4_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcd4_7_proc0
// static void setup_memwrite_mmap_pcd4_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_10_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pcd4_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_9_common
// static void setup_memwrite_mmap_pcd4_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i1", 0x3000);
// }
// ^ See setup_memwrite_mmap_pcd4_9_proc0
// static void setup_memwrite_mmap_pcd4_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_11_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_11_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_12_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
static void setup_memwrite_mmap_pcd4_12_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_file(0x12345601000, 1, "__i1", 0x4000);
}
// static void setup_memwrite_mmap_pcd4_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_12_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_12_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_13_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pcd4_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_12_common
static void setup_memwrite_mmap_pcd4_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_file(0x12345601000, 1, "__i1", 0x4000);
}
// static void setup_memwrite_mmap_pcd4_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_13_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_13_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_14_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pcd4_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_12_common
static void setup_memwrite_mmap_pcd4_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
  init_map_file(0x12345601000, 1, "__i1", 0x4000);
}
// static void setup_memwrite_mmap_pcd4_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_14_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_14_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_15_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pcd4_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_9_common
static void setup_memwrite_mmap_pcd4_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i1", 0x3000);
}
// static void setup_memwrite_mmap_pcd4_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_15_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_15_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_16_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pcd4_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_12_common
// static void setup_memwrite_mmap_pcd4_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
//   init_map_file(0x12345601000, 1, "__i1", 0x4000);
// }
// ^ See setup_memwrite_mmap_pcd4_14_proc0
// static void setup_memwrite_mmap_pcd4_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_16_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_16_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_17_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pcd4_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_9_common
// static void setup_memwrite_mmap_pcd4_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i1", 0x3000);
// }
// ^ See setup_memwrite_mmap_pcd4_15_proc0
// static void setup_memwrite_mmap_pcd4_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_17_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_17_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_18_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_18_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_0_1
static void setup_memwrite_mmap_pcd4_18_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_mmap_pcd4_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_18_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_memwrite_mmap_pcd4_4_final
// static void setup_memwrite_mmap_pcd4_18_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_19_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pcd4_19_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
static void setup_memwrite_mmap_pcd4_19_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_anon(0x12345601000, 0, 1);
}
// static void setup_memwrite_mmap_pcd4_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_19_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_20_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pcd4_20_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x20ae000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
static void setup_memwrite_mmap_pcd4_20_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_20_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34267136, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x3000);
}
// static void setup_memwrite_mmap_pcd4_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_20_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pdd6_0_final
// static void setup_memwrite_mmap_pcd4_20_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_21_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x8000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_19_1
// static void setup_memwrite_mmap_pcd4_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_19_common
static void setup_memwrite_mmap_pcd4_21_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_anon(0x12345601000, 0, 1);
}
// static void setup_memwrite_mmap_pcd4_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_21_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_22_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pdd6_14_1
// static void setup_memwrite_mmap_pcd4_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_20_common
static void setup_memwrite_mmap_pcd4_22_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x3000);
}
// static void setup_memwrite_mmap_pcd4_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_22_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pdd6_0_final
// static void setup_memwrite_mmap_pcd4_22_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_23_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pcd4_23_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x20b4000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
static void setup_memwrite_mmap_pcd4_23_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_23_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34291712, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_anon(0x12345601000, 0, 1);
}
// static void setup_memwrite_mmap_pcd4_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_23_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_24_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_8_1
// static void setup_memwrite_mmap_pcd4_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_19_common
// static void setup_memwrite_mmap_pcd4_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x7000);
//   init_map_anon(0x12345601000, 0, 1);
// }
// ^ See setup_memwrite_mmap_pcd4_21_proc0
// static void setup_memwrite_mmap_pcd4_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_24_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_25_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_25_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x20b4000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_23_1
// static void setup_memwrite_mmap_pcd4_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_23_common
static void setup_memwrite_mmap_pcd4_25_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34291712, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_anon(0x12345601000, 1, 1);
}
// static void setup_memwrite_mmap_pcd4_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_25_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_25_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_26_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_26_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_8_1
// static void setup_memwrite_mmap_pcd4_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_19_common
static void setup_memwrite_mmap_pcd4_26_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
  init_map_anon(0x12345601000, 1, 1);
}
// static void setup_memwrite_mmap_pcd4_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_26_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_27_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_27_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x20b4000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_23_1
static void setup_memwrite_mmap_pcd4_27_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_27_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34291712, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
  init_map_file(0x12345601000, 1, "__i0", 0x704000);
}
// static void setup_memwrite_mmap_pcd4_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_27_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pdd6_0_final
// static void setup_memwrite_mmap_pcd4_27_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_28_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_28_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x6000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_6_1
static void setup_memwrite_mmap_pcd4_28_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_28_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
  init_map_file(0x12345601000, 0, "__i0", 0x20ad000);
}
// static void setup_memwrite_mmap_pcd4_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_28_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_29_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_29_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pcd4_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
static void setup_memwrite_mmap_pcd4_29_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x20ad000);
}
// static void setup_memwrite_mmap_pcd4_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_29_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_29_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_30_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_30_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pcd4_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
static void setup_memwrite_mmap_pcd4_30_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x704000);
}
// static void setup_memwrite_mmap_pcd4_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_30_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_31_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_31_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pcd4_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
static void setup_memwrite_mmap_pcd4_31_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x20ad000);
}
// static void setup_memwrite_mmap_pcd4_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_31_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_31_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_32_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_32_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pcd4_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
static void setup_memwrite_mmap_pcd4_32_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x704000);
}
// static void setup_memwrite_mmap_pcd4_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_32_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_32_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_33_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_33_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pcd4_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
// static void setup_memwrite_mmap_pcd4_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x704000);
// }
// ^ See setup_memwrite_mmap_pcd4_30_proc0
// static void setup_memwrite_mmap_pcd4_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_33_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_33_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_34_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_34_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
static void setup_memwrite_mmap_pcd4_34_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mmap_pcd4_34_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 1);
}
// static void setup_memwrite_mmap_pcd4_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_34_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_34_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_35_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_35_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pcd4_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
// static void setup_memwrite_mmap_pcd4_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x704000);
// }
// ^ See setup_memwrite_mmap_pcd4_32_proc0
// static void setup_memwrite_mmap_pcd4_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_35_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_36_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_36_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pcd4_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_34_common
static void setup_memwrite_mmap_pcd4_36_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 1);
}
// static void setup_memwrite_mmap_pcd4_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_36_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_37_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pcd4_37_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pcd4_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_27_common
static void setup_memwrite_mmap_pcd4_37_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
  init_map_file(0x12345601000, 0, "__i0", 0x5000);
}
// static void setup_memwrite_mmap_pcd4_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_37_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pdd6_0_final
// static void setup_memwrite_mmap_pcd4_37_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_38_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_38_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_37_1
// static void setup_memwrite_mmap_pcd4_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_6_common
static void setup_memwrite_mmap_pcd4_38_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_file(0x12345601000, 0, "__i0", 0x5000);
}
// static void setup_memwrite_mmap_pcd4_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_38_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_39_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_39_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_37_1
// static void setup_memwrite_mmap_pcd4_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_27_common
static void setup_memwrite_mmap_pcd4_39_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x6000);
  init_map_file(0x12345601000, 1, "__i0", 0x5000);
}
// static void setup_memwrite_mmap_pcd4_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_39_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pdd6_0_final
// static void setup_memwrite_mmap_pcd4_39_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_40_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_40_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_37_1
// static void setup_memwrite_mmap_pcd4_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_6_common
static void setup_memwrite_mmap_pcd4_40_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
  init_map_file(0x12345601000, 1, "__i0", 0x5000);
}
// static void setup_memwrite_mmap_pcd4_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_40_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_40_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_41_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pcd4_41_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pcd4_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_6_common
// static void setup_memwrite_mmap_pcd4_41_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
//   init_map_file(0x12345601000, 0, "__i0", 0x5000);
// }
// ^ See setup_memwrite_mmap_pcd4_38_proc0
// static void setup_memwrite_mmap_pcd4_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_41_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_41_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_42_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_42_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_41_1
// static void setup_memwrite_mmap_pcd4_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_6_common
// static void setup_memwrite_mmap_pcd4_42_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
//   init_map_file(0x12345601000, 1, "__i0", 0x5000);
// }
// ^ See setup_memwrite_mmap_pcd4_40_proc0
// static void setup_memwrite_mmap_pcd4_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_42_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_42_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_43_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_43_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pcd4_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
static void setup_memwrite_mmap_pcd4_43_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pcd4_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_43_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_43_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_44_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_44_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_pcd4_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
static void setup_memwrite_mmap_pcd4_44_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pcd4_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_44_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_44_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_45_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_45_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pcd4_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
// static void setup_memwrite_mmap_pcd4_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcd4_43_proc0
// static void setup_memwrite_mmap_pcd4_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_45_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_45_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_46_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_46_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pcd4_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
// static void setup_memwrite_mmap_pcd4_46_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcd4_44_proc0
// static void setup_memwrite_mmap_pcd4_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_46_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_46_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_47_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pcd4_47_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x5000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_memwrite_mmap_pcd4_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_6_common
static void setup_memwrite_mmap_pcd4_47_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memwrite_mmap_pcd4_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_47_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_47_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcd4_48_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcd4_48_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x7000UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_0_1
// static void setup_memwrite_mmap_pcd4_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_0_common
static void setup_memwrite_mmap_pcd4_48_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memwrite_mmap_pcd4_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcd4_48_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcd4_48_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcb0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_pcb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pcb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pcb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcb0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pcb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pcb0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_pcb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pcb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pcb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pcb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pcb0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc98_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pc98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pcd8_0_common
// static void setup_memwrite_mmap_pc98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcd8_0_proc0
// static void setup_memwrite_mmap_pc98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pc98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pc98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc98_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pc98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pcd8_0_common
// static void setup_memwrite_mmap_pc98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcd8_1_proc0
// static void setup_memwrite_mmap_pc98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pc98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pc98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc94_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc94_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_pc94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_28_common
static void setup_memwrite_mmap_pc94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
}
// static void setup_memwrite_mmap_pc94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc94_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc94_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc94_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_pc94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_28_common
// static void setup_memwrite_mmap_pc94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x5000);
// }
// ^ See setup_memwrite_mmap_pc94_0_proc0
// static void setup_memwrite_mmap_pc94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc94_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc94_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
static int test_memwrite_mmap_pc94_2_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x704000UL);
  
  return xerrno(r);
}
// static void setup_memwrite_mmap_pc94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_6_common
// static void setup_memwrite_mmap_pc94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_memwrite_mmap_pcd4_6_proc0
// static void setup_memwrite_mmap_pc94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc94_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc94_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc94_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc94_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_pc94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_0_common
static void setup_memwrite_mmap_pc94_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x7000);
}
// static void setup_memwrite_mmap_pc94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc94_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc94_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc94_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_pc94_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
// static void setup_memwrite_mmap_pc94_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcd4_7_proc0
// static void setup_memwrite_mmap_pc94_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc94_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc94_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc94_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc94_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_pc94_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pcd4_7_common
// static void setup_memwrite_mmap_pc94_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcd4_7_proc0
// static void setup_memwrite_mmap_pc94_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc94_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc94_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc8_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pec_0_1
// static void setup_memwrite_mmap_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc58_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc58_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pc58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pcd8_0_common
static void setup_memwrite_mmap_pc58_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pc58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_pc58_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pc58_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc58_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc58_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pc58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pcd8_0_common
// static void setup_memwrite_mmap_pc58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pc58_0_proc0
// static void setup_memwrite_mmap_pc58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_pc58_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pc58_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc50_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc50_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pea_0_1
// static void setup_memwrite_mmap_pc50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pd14_5_proc1
// static void setup_memwrite_mmap_pc50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc50_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc50_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc50_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pea_0_1
// static void setup_memwrite_mmap_pc50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_pc50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc50_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_pc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc30_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_pc30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc30_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc30_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc30_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_pc30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc30_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc30_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc18_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pc18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pcd8_0_common
// static void setup_memwrite_mmap_pc18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pc58_0_proc0
// static void setup_memwrite_mmap_pc18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_pc18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pc18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc18_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pc18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pcd8_0_common
// static void setup_memwrite_mmap_pc18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pc58_0_proc0
// static void setup_memwrite_mmap_pc18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_pc18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pc18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc14_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc14_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_pc14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pd14_5_proc1
// static void setup_memwrite_mmap_pc14_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc14_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc14_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc14_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_pc14_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc14_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc14_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pd14_5_proc1
// static void setup_memwrite_mmap_pc14_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc14_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc14_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc14_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pd14_3_1
// static void setup_memwrite_mmap_pc14_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc14_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc14_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pd50_1_proc1
// static void setup_memwrite_mmap_pc14_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc14_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc14_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc14_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
static void setup_memwrite_mmap_pc14_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_mmap_pc14_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_mmap_pd14_1_proc0
// static void setup_memwrite_mmap_pc14_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_pc14_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc14_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc14_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc14_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_pc14_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc14_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc14_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_pc14_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc14_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc14_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc14_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_pc14_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc14_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc14_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_pc14_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc14_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mmap_pfe_0_0
// static int test_memwrite_mmap_pc0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfa8_1_common
// static void setup_memwrite_mmap_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pcf8_0_proc0
// static void setup_memwrite_mmap_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
static int test_memwrite_mmap_pb8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_mmap_pb8_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
static void setup_memwrite_mmap_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_mmap_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_3_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pb8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pb8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_4_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pb8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
static void setup_memwrite_mmap_pb8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pb8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_5_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pb8_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pb8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pb8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pb8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb8_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pb8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb8_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_pb8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_8_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pb8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb8_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_9_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pb8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
static void setup_memwrite_mmap_pb8_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_pb8_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_10_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pb8_10_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_pb8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb8_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_11_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_12_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pb8_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb8_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_0_proc0
// static void setup_memwrite_mmap_pb8_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_12_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_13_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pb8_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb8_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_7_proc0
// static void setup_memwrite_mmap_pb8_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_13_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_14_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pb8_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pb8_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_5_proc0
// static void setup_memwrite_mmap_pb8_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_14_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pb8_14_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_15_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pb8_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb8_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_6_proc0
// static void setup_memwrite_mmap_pb8_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_15_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_16_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pb8_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb8_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pb8_8_proc0
// static void setup_memwrite_mmap_pb8_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_16_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_17_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pb8_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb8_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_9_proc0
// static void setup_memwrite_mmap_pb8_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_17_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_18_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pb8_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pb8_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_memwrite_mmap_pb8_10_proc0
// static void setup_memwrite_mmap_pb8_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_18_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pb8_18_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_19_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_4_1
// static void setup_memwrite_mmap_pb8_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb8_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_11_proc0
// static void setup_memwrite_mmap_pb8_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_19_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_20_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_20_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pec_0_1
// static void setup_memwrite_mmap_pb8_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb8_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_pb8_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb8_20_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb8_21_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb8_21_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pec_0_1
// static void setup_memwrite_mmap_pb8_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pb8_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_pb8_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb8_21_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pb8_21_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
static void setup_memwrite_mmap_pb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
static void setup_memwrite_mmap_pb6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pb6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
static void setup_memwrite_mmap_pb6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_mmap_pb6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pb6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pb6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_pb6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
static void setup_memwrite_mmap_pb6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_mmap_pb6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pb6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pb6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pea_0_1
// static void setup_memwrite_mmap_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pea_0_1
// static void setup_memwrite_mmap_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_mmap_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb4_0_proc0
// static void setup_memwrite_mmap_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pb4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pb4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb4_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pb4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pb4_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb4_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_pb4_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pb4_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb4_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_pb4_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pb4_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb4_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb4_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_8_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pb4_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb4_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb4_2_proc0
// static void setup_memwrite_mmap_pb4_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_9_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pb4_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb4_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_pb4_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_10_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb4_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb4_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pcd4_3_1
// static void setup_memwrite_mmap_pb4_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_pb4_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_pb4_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb4_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb4_11_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pb0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pb0_1_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pac_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pac_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pac_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pac_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pac_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pac_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pac_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pac_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pac_2_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pac_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pac_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pac_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pac_3_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pac_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pa6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pa6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb6_0_proc0
// static void setup_memwrite_mmap_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pa6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pa6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pa6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pa6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb6_1_proc0
// static void setup_memwrite_mmap_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pa6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pa6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pa6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pa6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pa6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_pa6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb6_2_proc0
// static void setup_memwrite_mmap_pa6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pa6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pa6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pa6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pa6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_pa6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_pa6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb6_3_proc0
// static void setup_memwrite_mmap_pa6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_pa6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_pa6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pa5_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pa5_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_pa5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pa5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb4_0_proc0
// static void setup_memwrite_mmap_pa5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pa5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pa5_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pa5_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pa5_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_pa5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pa5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb4_0_proc0
// static void setup_memwrite_mmap_pa5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pa5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pa5_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pa5_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pa5_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_pa5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pa5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb4_2_proc0
// static void setup_memwrite_mmap_pa5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pa5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pa5_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pa5_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pa5_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_pa5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pa5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb4_2_proc0
// static void setup_memwrite_mmap_pa5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pa5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pa5_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pa0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_pa0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_pa0_1_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p98_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pec_0_1
// static void setup_memwrite_mmap_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p98_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pec_0_1
// static void setup_memwrite_mmap_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p98_1_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p96_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p96_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
static void setup_memwrite_mmap_p96_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_p96_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p96_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p96_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p96_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_p96_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
static void setup_memwrite_mmap_p96_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_mmap_p96_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_p96_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p96_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p96_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p96_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_p96_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p96_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_p96_0_proc0
// static void setup_memwrite_mmap_p96_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_p96_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p96_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p96_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p96_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_p96_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p96_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_p96_1_proc0
// static void setup_memwrite_mmap_p96_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_p96_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p96_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p94_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p94_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pea_0_1
// static void setup_memwrite_mmap_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p94_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p94_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p94_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pea_0_1
// static void setup_memwrite_mmap_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p94_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p90_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p90_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p90_1_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p8c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p8c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p8c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p8c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p8c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p8c_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p8c_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p8c_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_p8c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p8c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_p8c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p8c_2_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p8c_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p8c_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p8c_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_p8c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p8c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_p8c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p8c_3_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p8c_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p86_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p86_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_p86_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p86_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_p96_0_proc0
// static void setup_memwrite_mmap_p86_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_p86_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p86_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p86_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p86_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_p86_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p86_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_p96_1_proc0
// static void setup_memwrite_mmap_p86_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_p86_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p86_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p86_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p86_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_p86_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p86_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_p96_0_proc0
// static void setup_memwrite_mmap_p86_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_p86_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p86_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p86_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p86_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_p86_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p86_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_p96_1_proc0
// static void setup_memwrite_mmap_p86_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_p86_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p86_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p85_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p85_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_p85_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p85_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_p85_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p85_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p85_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p85_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p85_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_p85_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p85_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_p85_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p85_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p85_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p85_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p85_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_p85_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p85_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_p85_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p85_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p85_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p85_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p85_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_p85_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p85_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_p85_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p85_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p85_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p80_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p80_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mmap_pb8_1_proc0
// static void setup_memwrite_mmap_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p80_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p80_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p80_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mmap_pb8_3_proc0
// static void setup_memwrite_mmap_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p80_1_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p80_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p78_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p78_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pec_0_1
// static void setup_memwrite_mmap_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p78_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p78_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p70_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p70_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p70_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p70_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p70_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_p70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_p70_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_p70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p70_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p70_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p70_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_p70_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
static void setup_memwrite_mmap_p70_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_p70_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p70_2_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p70_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p70_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p70_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_p70_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_p70_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_p70_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p70_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p70_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p70_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p70_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfe_0_1
// static void setup_memwrite_mmap_p70_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
static void setup_memwrite_mmap_p70_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_p70_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p70_4_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p70_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p6c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p6c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_p6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_p6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p6c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p6c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_p6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p6c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_p6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_p6c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p6c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p6a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p6a_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pea_0_1
// static void setup_memwrite_mmap_p6a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p6a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p6a_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p68_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p68_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p68_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mmap_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p68_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p68_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p68_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_p68_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_p68_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mmap_p68_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p68_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p68_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p68_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p68_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_p68_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_p68_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mmap_p68_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p68_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p68_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p68_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p68_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfac_0_1
// static void setup_memwrite_mmap_p68_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
static void setup_memwrite_mmap_p68_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mmap_p68_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p68_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p68_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p60_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p60_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p5a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p5a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_p5a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p5a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p5a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p5a_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p5a_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p54_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p54_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p54_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p54_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p54_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p54_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_p54_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p54_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p54_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p54_1_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p54_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p4c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p4c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_p4c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p4c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p4c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p4c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_p4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_p4c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_p4c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p4c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p4a8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p4a8_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_p4a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p4a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p4a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p4a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p4a8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p49_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p49_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_p49_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p49_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p49_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p49_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p49_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p49_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p49_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_p49_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p49_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p49_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p49_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p49_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p40_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p40_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_p40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p40_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p40_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p30_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pec_0_1
// static void setup_memwrite_mmap_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p30_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p30_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p2c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p2c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_p2c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p2c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p2c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p2c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pfb_0_1
// static void setup_memwrite_mmap_p2c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p2c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_p2c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_p2c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p2c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p28_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pea_0_1
// static void setup_memwrite_mmap_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p20_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf8_0_1
// static void setup_memwrite_mmap_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p20_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p18_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_0_1
// static void setup_memwrite_mmap_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p18_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p18_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p18_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf6_1_1
// static void setup_memwrite_mmap_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p18_1_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p18_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p0c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p0c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_0_proc1
// static void setup_memwrite_mmap_p0c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p0c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p0c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p0c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf3_0_1
// static void setup_memwrite_mmap_p0c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_mmap_pfb_0_common
// static void setup_memwrite_mmap_p0c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_pfb_0_proc1
// static void setup_memwrite_mmap_p0c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_mmap_peb_1_proc1
// static void setup_memwrite_mmap_p0c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_final
// static void setup_memwrite_mmap_p0c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_mmap_pfb_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p0a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p0a_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_0_1
// static void setup_memwrite_mmap_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p0a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p0a_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf28_1_1
// static void setup_memwrite_mmap_p0a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pfe_2_common
// static void setup_memwrite_mmap_p0a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p0a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_mmap_pea_0_proc1
// static void setup_memwrite_mmap_p0a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mmap_pfe_2_final
// static void setup_memwrite_mmap_p0a_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal

/*
 * calls: memwrite mmap
 */
// static int test_memwrite_mmap_p00_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mmap_pb8_0_0
// static int test_memwrite_mmap_p00_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_mmap_pf0_0_1
// static void setup_memwrite_mmap_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_common
// static void setup_memwrite_mmap_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mmap_pfe_0_proc1
// static void setup_memwrite_mmap_p00_0_final(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal
// static void setup_memwrite_mmap_p00_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mmap_pfe_0_procfinal


/*
 * calls: memwrite mprotect
 */
static int test_memwrite_mprotect_pfc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_mprotect_pfc_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memwrite_mprotect_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memwrite_mprotect_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
static void setup_memwrite_mprotect_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_mprotect_pfc_0_final(void) {
  
}
static void setup_memwrite_mprotect_pfc_0_procfinal(void) {
  
}

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pfc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pfc_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
static void setup_memwrite_mprotect_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mprotect_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pfc_1_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pfc_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pfc_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pfc_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
static void setup_memwrite_mprotect_pfc_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_mprotect_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
static void setup_memwrite_mprotect_pfc_2_final(void) {
  unlink("__i0");
}
// static void setup_memwrite_mprotect_pfc_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pfc_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
static int test_memwrite_mprotect_pfc_3_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_memwrite_mprotect_pfc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_pfc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_1_proc0
// static void setup_memwrite_mprotect_pfc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pfc_3_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pfc_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pfc_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pfc_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pfc_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pfc_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pfc_2_proc0
// static void setup_memwrite_mprotect_pfc_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pfc_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pfc_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pfc_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pfc_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pfc_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pfc_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_pfc_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pfc_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pfc_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pfc_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pfc_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pfc_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_pfc_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc0
// static void setup_memwrite_mprotect_pfc_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pfc_6_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pfc_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pfc_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pfc_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pfc_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pfc_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pfc_5_proc0
// static void setup_memwrite_mprotect_pfc_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pfc_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pfc_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pfc_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
static int test_memwrite_mprotect_pfc_8_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_memwrite_mprotect_pfc_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
static void setup_memwrite_mprotect_pfc_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_mprotect_pfc_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pfc_8_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pfc_8_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
static int test_memwrite_mprotect_pf0_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_memwrite_mprotect_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
// static void setup_memwrite_mprotect_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pf0_0_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pe8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
static int test_memwrite_mprotect_pe8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_memwrite_mprotect_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
static void setup_memwrite_mprotect_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pe8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pe8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
static void setup_memwrite_mprotect_pe8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_mprotect_pe8_1_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pe8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pe8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pe8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
static void setup_memwrite_mprotect_pe8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_pe8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pe8_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pe8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pe8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pe8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_pe8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
// static void setup_memwrite_mprotect_pe8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
// static void setup_memwrite_mprotect_pe8_3_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pe8_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pe0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
static int test_memwrite_mprotect_pe0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_memwrite_mprotect_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
// static void setup_memwrite_mprotect_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pe0_0_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
static int test_memwrite_mprotect_pde_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_mprotect_pde_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
}
// static void setup_memwrite_mprotect_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pde_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pde_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pde_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pde_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
}
// static void setup_memwrite_mprotect_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pde_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pde_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pde_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pde_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pde_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pde_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
//   init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
// }
// ^ See setup_memwrite_mprotect_pde_1_proc0
// static void setup_memwrite_mprotect_pde_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pde_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pde_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pde_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pde_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pde_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pde_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mprotect_pde_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pde_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pde_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pde_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pde_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pde_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pde_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mprotect_pde_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pde_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pde_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pde_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pde_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pde_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pde_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
//   init_map_file(0x12345601000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memwrite_mprotect_pde_0_proc0
// static void setup_memwrite_mprotect_pde_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pde_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pde_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pde_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pde_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_8_1
// static void setup_memwrite_mprotect_pde_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pde_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memwrite_mprotect_pde_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pde_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pde_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pd8_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pf0_0_1
// static void setup_memwrite_mprotect_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_mprotect_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pd4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mprotect_pd8_0_proc0
static void setup_memwrite_mprotect_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x26000);
}
// static void setup_memwrite_mprotect_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pd4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pd4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memwrite_mprotect_pde_6_proc0
// static void setup_memwrite_mprotect_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memwrite_mprotect_pde_6_proc0
// static void setup_memwrite_mprotect_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pd4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pd4_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
// }
// ^ See setup_memwrite_mprotect_pde_6_proc0
// static void setup_memwrite_mprotect_pd4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_pd4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pd4_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pd4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pd4_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mprotect_pd8_0_proc0
// static void setup_memwrite_mprotect_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
// static void setup_memwrite_mprotect_pd4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pd4_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pde_0_0
// static int test_memwrite_mprotect_pd0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe0_0_1
// static void setup_memwrite_mprotect_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_mprotect_pd8_0_proc0
// static void setup_memwrite_mprotect_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pce_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pce_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
static void setup_memwrite_mprotect_pce_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_mprotect_pce_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_pce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pce_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pce_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pce_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pce_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pce_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
static void setup_memwrite_mprotect_pce_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_pce_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pce_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pce_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pce_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pce_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pce_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pce_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pce_1_proc0
// static void setup_memwrite_mprotect_pce_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pce_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pce_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pce_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pce_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pce_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
static void setup_memwrite_mprotect_pce_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mprotect_pce_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pce_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pce_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pce_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pce_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pce_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pce_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pce_3_proc0
// static void setup_memwrite_mprotect_pce_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pce_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pce_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pce_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pce_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pce_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
static void setup_memwrite_mprotect_pce_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mprotect_pce_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pce_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pce_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pce_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pce_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pce_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pce_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pce_0_proc0
// static void setup_memwrite_mprotect_pce_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pce_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pce_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pce_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pce_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pce_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pce_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pce_5_proc0
// static void setup_memwrite_mprotect_pce_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pce_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pce_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pce_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pce_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_8_1
// static void setup_memwrite_mprotect_pce_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pce_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_pce_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pce_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pce_8_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pc8_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pf0_0_1
// static void setup_memwrite_mprotect_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pc4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pc4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_pc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_pc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pc4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pc4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pc4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pc4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pc4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_pc4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_pc4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pc4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pc4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pc4_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pc4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pc4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_pc4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_pc4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pc4_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pc4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pc4_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pc4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pc4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_pc4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
// static void setup_memwrite_mprotect_pc4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pc4_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_mprotect_pfc_0_0
// static int test_memwrite_mprotect_pc0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe0_0_1
// static void setup_memwrite_mprotect_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pce_0_common
// static void setup_memwrite_mprotect_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
static int test_memwrite_mprotect_pb0_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_mprotect_pb0_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pb0_0_proc0
// static void setup_memwrite_mprotect_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
static void setup_memwrite_mprotect_pb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mprotect_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_2_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pb0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pb0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pb0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pb0_3_proc0
// static void setup_memwrite_mprotect_pb0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pb0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pb0_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_pb0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pb0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pb0_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_pb0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pb0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pb0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pb0_5_proc0
// static void setup_memwrite_mprotect_pb0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pb0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pb0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pb0_6_proc0
// static void setup_memwrite_mprotect_pb0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_8_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pb0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pb0_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mprotect_pb0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_9_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_10_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pb0_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_pb0_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mprotect_pb0_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_10_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_11_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pb0_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pb0_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pb0_9_proc0
// static void setup_memwrite_mprotect_pb0_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_11_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_12_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pb0_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pb0_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pb0_10_proc0
// static void setup_memwrite_mprotect_pb0_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_12_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_13_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pb0_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_pb0_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pb0_2_proc0
// static void setup_memwrite_mprotect_pb0_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_13_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pb0_13_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_14_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_pb0_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
static void setup_memwrite_mprotect_pb0_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mprotect_pb0_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_14_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pb0_14_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_15_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_3_1
// static void setup_memwrite_mprotect_pb0_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_pb0_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pb0_14_proc0
// static void setup_memwrite_mprotect_pb0_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_15_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pb0_15_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_16_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_16_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pb0_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pb0_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_pb0_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pb0_16_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pb0_17_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pb0_17_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_pb0_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_pb0_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_pb0_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pb0_17_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pb0_17_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pa_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pf0_0_1
// static void setup_memwrite_mprotect_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_pa_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pf0_0_1
// static void setup_memwrite_mprotect_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_pa_1_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p9_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p9_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p9_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_p9_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_p9_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_p9_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p9_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p9_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p9_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p9_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_p9_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_p9_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_p9_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p9_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p9_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p9_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p9_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_p9_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_p9_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_p9_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p9_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p9_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p9_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p9_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_p9_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_p9_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_p9_3_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_p9_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p9_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p9_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p9_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_p9_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_p9_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_p9_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p9_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p9_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p9_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p9_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_p9_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_p9_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_p9_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p9_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p9_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p9_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p9_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_p9_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_p9_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
// static void setup_memwrite_mprotect_p9_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p9_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p9_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p9_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p9_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_p9_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_p9_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
// static void setup_memwrite_mprotect_p9_7_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_p9_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe0_0_1
// static void setup_memwrite_mprotect_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe0_0_1
// static void setup_memwrite_mprotect_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p6_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_p6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p6_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
static void setup_memwrite_mprotect_p6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_mprotect_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p6_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p6_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p6_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_p6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
static void setup_memwrite_mprotect_p6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_mprotect_p6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p6_2_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_p6_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p6_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p6_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pfc_0_1
// static void setup_memwrite_mprotect_p6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
static void setup_memwrite_mprotect_p6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_mprotect_p6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p6_3_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_p6_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p4_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pf0_0_1
// static void setup_memwrite_mprotect_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p4_0_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe0_0_1
// static void setup_memwrite_mprotect_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p4_1_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_p4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p2_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p2_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_0_proc1
// static void setup_memwrite_mprotect_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p2_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p2_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p2_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_mprotect_pe8_1_proc1
// static void setup_memwrite_mprotect_p2_1_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_p2_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p2_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p2_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_mprotect_pfc_2_common
// static void setup_memwrite_mprotect_p2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_mprotect_pe8_2_proc1
// static void setup_memwrite_mprotect_p2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_mprotect_pfc_2_final
// static void setup_memwrite_mprotect_p2_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p2_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p2_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe8_0_1
// static void setup_memwrite_mprotect_p2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_p2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_mprotect_pfc_8_proc0
// static void setup_memwrite_mprotect_p2_3_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_p2_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal

/*
 * calls: memwrite mprotect
 */
// static int test_memwrite_mprotect_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_mprotect_pb0_0_0
// static int test_memwrite_mprotect_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_memwrite_mprotect_pe0_0_1
// static void setup_memwrite_mprotect_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_common
// static void setup_memwrite_mprotect_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_mprotect_pfc_0_proc1
// static void setup_memwrite_mprotect_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal
// static void setup_memwrite_mprotect_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_mprotect_pfc_0_procfinal


/*
 * calls: memwrite munmap
 */
static int test_memwrite_munmap_pf8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_munmap_pf8_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memwrite_munmap_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memwrite_munmap_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
static void setup_memwrite_munmap_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_munmap_pf8_0_final(void) {
  
}
static void setup_memwrite_munmap_pf8_0_procfinal(void) {
  
}

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
// static int test_memwrite_munmap_pf8_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_common
static void setup_memwrite_munmap_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_munmap_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pf8_1_final(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal
// static void setup_memwrite_munmap_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pf8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
// static int test_memwrite_munmap_pf8_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_common
static void setup_memwrite_munmap_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_munmap_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pf8_2_final(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal
// static void setup_memwrite_munmap_pf8_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pf8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
// static int test_memwrite_munmap_pf8_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
static void setup_memwrite_munmap_pf8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_munmap_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_munmap_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
static void setup_memwrite_munmap_pf8_3_final(void) {
  unlink("__i0");
}
// static void setup_memwrite_munmap_pf8_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pf8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
// static int test_memwrite_munmap_pf8_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_munmap_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pf8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pf8_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
static int test_memwrite_munmap_pe_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_memwrite_munmap_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_common
// static void setup_memwrite_munmap_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_munmap_pf8_1_proc0
// static void setup_memwrite_munmap_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pe_0_final(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal
// static void setup_memwrite_munmap_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
static int test_memwrite_munmap_pdc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_munmap_pdc_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
  init_map_file(0x12345601000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_munmap_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pdc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pdc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pdc_0_0
// static int test_memwrite_munmap_pdc_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pdc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_file(0x12345601000, 0, "__i0", 0x1e27000);
}
// static void setup_memwrite_munmap_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pdc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pdc_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pdc_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pdc_0_0
// static int test_memwrite_munmap_pdc_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pdc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pdc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memwrite_munmap_pdc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pdc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pdc_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pdc_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pdc_0_0
// static int test_memwrite_munmap_pdc_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pdc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pdc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_munmap_pdc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pdc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pdc_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pdc_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pdc_0_0
// static int test_memwrite_munmap_pdc_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pdc_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pdc_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_munmap_pdc_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pdc_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pdc_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pdc_0_0
// static int test_memwrite_munmap_pd0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pe_0_1
// static void setup_memwrite_munmap_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_munmap_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pcc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
// static int test_memwrite_munmap_pcc_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
static void setup_memwrite_munmap_pcc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_munmap_pcc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_munmap_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pcc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
// static int test_memwrite_munmap_pcc_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pcc_0_common
static void setup_memwrite_munmap_pcc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_munmap_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pcc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pcc_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pcc_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
// static int test_memwrite_munmap_pcc_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pcc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pcc_0_common
static void setup_memwrite_munmap_pcc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_munmap_pcc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pcc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pcc_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pcc_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
// static int test_memwrite_munmap_pcc_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pcc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pcc_0_common
static void setup_memwrite_munmap_pcc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_munmap_pcc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pcc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pcc_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pcc_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
// static int test_memwrite_munmap_pcc_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pcc_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pcc_0_common
static void setup_memwrite_munmap_pcc_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_munmap_pcc_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pcc_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pcc_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_munmap_pf8_0_0
// static int test_memwrite_munmap_pc0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pe_0_1
// static void setup_memwrite_munmap_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pcc_0_common
// static void setup_memwrite_munmap_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_munmap_pcc_1_proc0
// static void setup_memwrite_munmap_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
static int test_memwrite_munmap_pb_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_munmap_pb_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_munmap_pb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pb_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pb_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pb_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pb_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_munmap_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pb_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pb_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pb_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pb_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_common
static void setup_memwrite_munmap_pb_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_munmap_pb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pb_2_final(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal
// static void setup_memwrite_munmap_pb_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pb_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pb_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pb_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_common
static void setup_memwrite_munmap_pb_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_munmap_pb_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pb_3_final(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal
// static void setup_memwrite_munmap_pb_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pb_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pb_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pb_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pb_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_munmap_pb_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pb_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pb_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pb_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pb_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pb_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pb_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_memwrite_munmap_pb_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pb_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pb_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pb_6_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pb_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pb_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pb_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_munmap_pb_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pb_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pb_6_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pb_7_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pb_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pb_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pb_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_memwrite_munmap_pb_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pb_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pb_7_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pb_8_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pb_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pb_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_common
static void setup_memwrite_munmap_pb_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_memwrite_munmap_pb_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pb_8_final(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal
// static void setup_memwrite_munmap_pb_8_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pb_9_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pb_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pf8_0_1
// static void setup_memwrite_munmap_pb_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
static void setup_memwrite_munmap_pb_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_memwrite_munmap_pb_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pb_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pb_9_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pa_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pe_0_1
// static void setup_memwrite_munmap_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
// static void setup_memwrite_munmap_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_munmap_pb_1_proc0
// static void setup_memwrite_munmap_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_pa_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pe_0_1
// static void setup_memwrite_munmap_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_common
// static void setup_memwrite_munmap_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_munmap_pb_3_proc0
// static void setup_memwrite_munmap_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_pa_1_final(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal
// static void setup_memwrite_munmap_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_p8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pe_0_1
// static void setup_memwrite_munmap_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_munmap_pf8_3_common
// static void setup_memwrite_munmap_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_munmap_pb_1_proc0
// static void setup_memwrite_munmap_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_munmap_pf8_3_final
// static void setup_memwrite_munmap_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_p8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pe_0_1
// static void setup_memwrite_munmap_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_common
// static void setup_memwrite_munmap_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_munmap_pb_3_proc0
// static void setup_memwrite_munmap_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal
// static void setup_memwrite_munmap_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pe_0_1
// static void setup_memwrite_munmap_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_common
// static void setup_memwrite_munmap_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_p4_0_final(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal
// static void setup_memwrite_munmap_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal

/*
 * calls: memwrite munmap
 */
// static int test_memwrite_munmap_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_munmap_pb_0_0
// static int test_memwrite_munmap_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_munmap_pe_0_1
// static void setup_memwrite_munmap_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_common
// static void setup_memwrite_munmap_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_munmap_pf8_0_proc1
// static void setup_memwrite_munmap_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal
// static void setup_memwrite_munmap_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_munmap_pf8_0_procfinal


/*
 * calls: memwrite open
 */
static int test_memwrite_open_pfc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_open_pfc_0_1(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_memwrite_open_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memwrite_open_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_open_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_open_pfc_0_final(void) {
  unlink("__i0");
}
static void setup_memwrite_open_pfc_0_procfinal(void) {
  
}

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pfb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
static int test_memwrite_open_pfb8_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_memwrite_open_pfb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memwrite_open_pfb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pfb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pfb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pfb8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pfa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pfa8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
static void setup_memwrite_open_pfa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memwrite_open_pfa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pfa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pfa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pfa8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pf98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
static int test_memwrite_open_pf98_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_memwrite_open_pf98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memwrite_open_pf98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pf98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pf98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pf98_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pf88_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pf88_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pf88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_pf88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pf88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pf88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pf88_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pf70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pf70_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
static void setup_memwrite_open_pf70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_memwrite_open_pf70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pf70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pf70_0_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_pf70_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pf50_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pf50_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pf50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_pf50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pf50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pf50_0_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_pf50_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pf30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pf30_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pf30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_pf30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pf30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pf30_0_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_pf30_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pf10_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pf10_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pf10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_pf10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pf10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pf10_0_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_pf10_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pef0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
static int test_memwrite_open_pef0_0_1(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_memwrite_open_pef0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_pef0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pef0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pef0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pef0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_ped0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_ped0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_ped0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfa8_0_common
// static void setup_memwrite_open_ped0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_ped0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_ped0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_ped0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_peb_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
static int test_memwrite_open_peb_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_memwrite_open_peb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_peb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_peb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_peb_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_peb_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pe9_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pe9_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_pe9_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_pe9_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pe9_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pe9_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pe9_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pe0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
static int test_memwrite_open_pe0_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_memwrite_open_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_open_pfc_0_proc0
// static void setup_memwrite_open_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pe0_0_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
static int test_memwrite_open_pde_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_open_pde_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfc_0_1
// static void setup_memwrite_open_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
static void setup_memwrite_open_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_open_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pde_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pde_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pddc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pddc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
static void setup_memwrite_open_pddc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memwrite_open_pddc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
}
// static void setup_memwrite_open_pddc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
static void setup_memwrite_open_pddc_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memwrite_open_pddc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pddc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pddc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pddc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
static void setup_memwrite_open_pddc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_open_pddc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pddc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pddc_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pdd4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pdd4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pdd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pddc_0_common
// static void setup_memwrite_open_pdd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_memwrite_open_pddc_0_proc0
// static void setup_memwrite_open_pdd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pdd4_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pddc_0_final
// static void setup_memwrite_open_pdd4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pdd4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pdd4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pdd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_pdd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_open_pddc_1_proc0
// static void setup_memwrite_open_pdd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pdd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pdd4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pdcc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pdcc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pdcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_pdcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pdcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pdcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pdcc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pdc4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pdc4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pdc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_pdc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pdc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pdc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pdc4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pdb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pdb8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
static void setup_memwrite_open_pdb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_memwrite_open_pdb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_open_pddc_1_proc0
// static void setup_memwrite_open_pdb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pdb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pdb8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pda8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pda8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pda8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_open_pdb8_0_common
// static void setup_memwrite_open_pda8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_open_pddc_1_proc0
// static void setup_memwrite_open_pda8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pda8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pda8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pd98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pd98_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pd98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_open_pdb8_0_common
// static void setup_memwrite_open_pd98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_open_pddc_1_proc0
// static void setup_memwrite_open_pd98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pd98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pd98_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pd88_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pd88_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pd88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_open_pdb8_0_common
// static void setup_memwrite_open_pd88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_open_pddc_1_proc0
// static void setup_memwrite_open_pd88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pd88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pd88_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pd78_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pd78_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_pd78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pddc_0_common
// static void setup_memwrite_open_pd78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_memwrite_open_pddc_0_proc0
// static void setup_memwrite_open_pd78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pd78_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pddc_0_final
// static void setup_memwrite_open_pd78_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pd78_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pd78_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_pd78_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_pd78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_open_pddc_1_proc0
// static void setup_memwrite_open_pd78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pd78_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pd78_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pd68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pd68_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_pd68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pddc_0_common
// static void setup_memwrite_open_pd68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_memwrite_open_pddc_0_proc0
// static void setup_memwrite_open_pd68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pd68_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pddc_0_final
// static void setup_memwrite_open_pd68_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pd68_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pd68_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_pd68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_pd68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_open_pddc_1_proc0
// static void setup_memwrite_open_pd68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pd68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pd68_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pd58_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pd58_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_pd58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_pd58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pd58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pd58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pd58_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pd48_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pd48_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_pd48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_pd48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pd48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pd48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pd48_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pde_0_0
// static int test_memwrite_open_pd0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pe0_0_1
// static void setup_memwrite_open_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_open_pdb8_0_common
// static void setup_memwrite_open_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pce_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pce_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfc_0_1
static void setup_memwrite_open_pce_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memwrite_open_pce_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pce_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pce_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pcda_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pcda_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pcda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pddc_0_common
static void setup_memwrite_open_pcda_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_open_pcda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pcda_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pddc_0_final
// static void setup_memwrite_open_pcda_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pcd2_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pcd2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pcd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pddc_0_common
// static void setup_memwrite_open_pcd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memwrite_open_pcda_0_proc0
// static void setup_memwrite_open_pcd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pcd2_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pddc_0_final
// static void setup_memwrite_open_pcd2_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pccc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pccc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pccc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pce_0_common
// static void setup_memwrite_open_pccc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pccc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pccc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pccc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pcc4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pcc4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pcc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pce_0_common
// static void setup_memwrite_open_pcc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pcc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pcc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pcc4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pcb4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pcb4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
static void setup_memwrite_open_pcb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_open_pcb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pcb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pcb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pcb4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pca4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pca4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pca4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_open_pcb4_0_common
// static void setup_memwrite_open_pca4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pca4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pca4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pca4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pc94_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pc94_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pc94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_open_pcb4_0_common
// static void setup_memwrite_open_pc94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pc94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pc94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pc94_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pc84_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pc84_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pc84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_open_pcb4_0_common
// static void setup_memwrite_open_pc84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pc84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pc84_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pc84_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pc74_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pc74_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_pc74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pddc_0_common
// static void setup_memwrite_open_pc74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memwrite_open_pcda_0_proc0
// static void setup_memwrite_open_pc74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pc74_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pddc_0_final
// static void setup_memwrite_open_pc74_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pc64_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pc64_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_pc64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pddc_0_common
// static void setup_memwrite_open_pc64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memwrite_open_pcda_0_proc0
// static void setup_memwrite_open_pc64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pc64_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pddc_0_final
// static void setup_memwrite_open_pc64_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pc58_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pc58_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_pc58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pce_0_common
// static void setup_memwrite_open_pc58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pc58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pc58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pc58_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pc48_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pc48_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_pc48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pce_0_common
// static void setup_memwrite_open_pc48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pc48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pc48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pc48_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_open_pfc_0_0
// static int test_memwrite_open_pc0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pe0_0_1
// static void setup_memwrite_open_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_open_pcb4_0_common
// static void setup_memwrite_open_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pde_0_proc0
// static void setup_memwrite_open_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
static int test_memwrite_open_pb8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_open_pb8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfc_0_1
// static void setup_memwrite_open_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
static void setup_memwrite_open_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_open_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pb8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfc_0_1
// static void setup_memwrite_open_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
static void setup_memwrite_open_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_open_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pb70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pb70_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pb70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfb8_0_common
static void setup_memwrite_open_pb70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
// static void setup_memwrite_open_pb70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pb70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pb70_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pb70_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pb70_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pb70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfa8_0_common
// static void setup_memwrite_open_pb70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_pb70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pb70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pb70_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pb50_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pb50_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pb50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfb8_0_common
// static void setup_memwrite_open_pb50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
// }
// ^ See setup_memwrite_open_pb70_0_proc0
// static void setup_memwrite_open_pb50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pb50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pb50_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pb50_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pb50_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pb50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfb8_0_common
// static void setup_memwrite_open_pb50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_pb50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pb50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pb50_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pb3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pb3_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pb3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
static void setup_memwrite_open_pb3_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_memwrite_open_pb3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pb3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pb3_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pb3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pb3_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pb3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_pb3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_pb3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pb3_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pb3_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pb1_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pb1_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pb1_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_pb1_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2297000);
// }
// ^ See setup_memwrite_open_pb3_0_proc0
// static void setup_memwrite_open_pb1_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pb1_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pb1_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pb1_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pb1_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pb1_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_pb1_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_pb1_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pb1_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pb1_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pae_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pae_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
static void setup_memwrite_open_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_open_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x22f1000);
}
// static void setup_memwrite_open_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pae_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pae_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pae_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_pae_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pae_1_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_pae_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_paa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_paa_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_open_pae_0_common
// static void setup_memwrite_open_paa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x22f1000);
// }
// ^ See setup_memwrite_open_pae_0_proc0
// static void setup_memwrite_open_paa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_paa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_paa_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_paa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_paa_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_paa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_paa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_paa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_paa_1_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_paa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pa6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pa6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_open_pae_0_common
// static void setup_memwrite_open_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x22f1000);
// }
// ^ See setup_memwrite_open_pae_0_proc0
// static void setup_memwrite_open_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pa6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pa6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pa6_1_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_pa6_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pa2_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pa2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pa2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_open_pae_0_common
// static void setup_memwrite_open_pa2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x22f1000);
// }
// ^ See setup_memwrite_open_pae_0_proc0
// static void setup_memwrite_open_pa2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pa2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_pa2_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_pa2_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_pa2_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_pa2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_pa2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_pa2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_pa2_1_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_pa2_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p9e_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p9e_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfa8_0_common
static void setup_memwrite_open_p9e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x20ad000);
}
// static void setup_memwrite_open_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p9e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p9e_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p9e_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p9e_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_p9e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p9e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p9e_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p9a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p9a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x20ad000);
// }
// ^ See setup_memwrite_open_p9e_0_proc0
// static void setup_memwrite_open_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p9a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p9a_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfb8_0_common
// static void setup_memwrite_open_p9a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p96_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p96_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2297000);
// }
// ^ See setup_memwrite_open_pb3_0_proc0
// static void setup_memwrite_open_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p96_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p96_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p96_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p96_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_p96_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_p96_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_p96_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p96_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p96_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p92_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p92_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_p92_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_p92_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2297000);
// }
// ^ See setup_memwrite_open_pb3_0_proc0
// static void setup_memwrite_open_p92_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p92_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p92_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p92_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p92_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_p92_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_p92_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_p92_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p92_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p92_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p8_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pe0_0_1
// static void setup_memwrite_open_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_open_pdb8_0_common
// static void setup_memwrite_open_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_open_pb8_0_proc0
// static void setup_memwrite_open_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p8_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pe0_0_1
// static void setup_memwrite_open_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_open_pb8_1_proc0
// static void setup_memwrite_open_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p7_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p7_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfc_0_1
// static void setup_memwrite_open_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p7_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p6e_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p6e_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_p6e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfb8_0_common
// static void setup_memwrite_open_p6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p6e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p6e_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p6a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p6a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_p6a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfa8_0_common
// static void setup_memwrite_open_p6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p6a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p6a_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p66_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p66_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_p66_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_p66_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p66_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p66_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p66_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p62_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p62_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p62_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p5c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p5c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p5c_0_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p54_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p54_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pfb8_0_1
// static void setup_memwrite_open_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p54_0_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_p54_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p4c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p4c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p4c_0_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_p4c_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p44_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p44_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pf98_0_1
// static void setup_memwrite_open_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p44_0_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_p44_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p3c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p3c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfb8_0_common
// static void setup_memwrite_open_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p3c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p3c_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p34_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p34_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pef0_0_1
// static void setup_memwrite_open_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pfc_0_common
// static void setup_memwrite_open_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p34_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p2c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p2c_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p24_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p24_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_memwrite_open_peb_0_1
// static void setup_memwrite_open_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_open_pf98_0_common
// static void setup_memwrite_open_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_open_pfc_0_final
// static void setup_memwrite_open_p24_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal

/*
 * calls: memwrite open
 */
// static int test_memwrite_open_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_open_pb8_0_0
// static int test_memwrite_open_p0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_open_pe0_0_1
// static void setup_memwrite_open_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_open_pf70_0_common
// static void setup_memwrite_open_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_open_pfc_0_proc1
// static void setup_memwrite_open_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal
// static void setup_memwrite_open_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_open_pfc_0_procfinal


/*
 * calls: memwrite pipe
 */
static int test_memwrite_pipe_pfc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_pipe_pfc_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memwrite_pipe_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memwrite_pipe_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_pipe_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_pipe_pfc_0_final(void) {
  
}
static void setup_memwrite_pipe_pfc_0_procfinal(void) {
  
}

/*
 * calls: memwrite pipe
 */
// static int test_memwrite_pipe_pec_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pipe_pfc_0_0
// static int test_memwrite_pipe_pec_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
// static void setup_memwrite_pipe_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_common
// static void setup_memwrite_pipe_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pipe_pfc_0_proc0
// static void setup_memwrite_pipe_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_pec_0_final(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal
// static void setup_memwrite_pipe_pec_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal

/*
 * calls: memwrite pipe
 */
static int test_memwrite_pipe_pde_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_pipe_pde_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
static void setup_memwrite_pipe_pde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_pipe_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pipe_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
static void setup_memwrite_pipe_pde_0_final(void) {
  unlink("__i0");
}
// static void setup_memwrite_pipe_pde_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal

/*
 * calls: memwrite pipe
 */
// static int test_memwrite_pipe_pd6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pipe_pde_0_0
// static int test_memwrite_pipe_pd6_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
// static void setup_memwrite_pipe_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pipe_pde_0_common
// static void setup_memwrite_pipe_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pipe_pde_0_proc0
// static void setup_memwrite_pipe_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_pd6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pipe_pde_0_final
// static void setup_memwrite_pipe_pd6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal

/*
 * calls: memwrite pipe
 */
// static int test_memwrite_pipe_pce_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pipe_pfc_0_0
// static int test_memwrite_pipe_pce_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
static void setup_memwrite_pipe_pce_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_pipe_pce_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pipe_pde_0_proc0
// static void setup_memwrite_pipe_pce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_pce_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pipe_pde_0_final
// static void setup_memwrite_pipe_pce_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal

/*
 * calls: memwrite pipe
 */
// static int test_memwrite_pipe_pc6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pipe_pfc_0_0
// static int test_memwrite_pipe_pc6_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
// static void setup_memwrite_pipe_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pipe_pce_0_common
// static void setup_memwrite_pipe_pc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pipe_pde_0_proc0
// static void setup_memwrite_pipe_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_pc6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pipe_pde_0_final
// static void setup_memwrite_pipe_pc6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal

/*
 * calls: memwrite pipe
 */
static int test_memwrite_pipe_pb8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_pipe_pb8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
static void setup_memwrite_pipe_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pipe_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_pipe_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pipe_pde_0_final
// static void setup_memwrite_pipe_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal

/*
 * calls: memwrite pipe
 */
// static int test_memwrite_pipe_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pipe_pb8_0_0
// static int test_memwrite_pipe_pb8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
// static void setup_memwrite_pipe_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_common
static void setup_memwrite_pipe_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pipe_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_pb8_1_final(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal
// static void setup_memwrite_pipe_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal

/*
 * calls: memwrite pipe
 */
// static int test_memwrite_pipe_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pipe_pb8_0_0
// static int test_memwrite_pipe_p98_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
// static void setup_memwrite_pipe_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pipe_pb8_0_common
// static void setup_memwrite_pipe_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_memwrite_pipe_pb8_0_proc0
// static void setup_memwrite_pipe_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pipe_pde_0_final
// static void setup_memwrite_pipe_p98_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal

/*
 * calls: memwrite pipe
 */
// static int test_memwrite_pipe_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pipe_pb8_0_0
// static int test_memwrite_pipe_p98_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
// static void setup_memwrite_pipe_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_common
// static void setup_memwrite_pipe_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pipe_pb8_1_proc0
// static void setup_memwrite_pipe_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_p98_1_final(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal
// static void setup_memwrite_pipe_p98_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal

/*
 * calls: memwrite pipe
 */
// static int test_memwrite_pipe_p70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pipe_pb8_0_0
// static int test_memwrite_pipe_p70_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
// static void setup_memwrite_pipe_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_common
// static void setup_memwrite_pipe_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_p70_0_final(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal
// static void setup_memwrite_pipe_p70_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal

/*
 * calls: memwrite pipe
 */
// static int test_memwrite_pipe_p30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pipe_pb8_0_0
// static int test_memwrite_pipe_p30_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_pipe_pfc_0_1
// static void setup_memwrite_pipe_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_common
// static void setup_memwrite_pipe_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pipe_pfc_0_proc1
// static void setup_memwrite_pipe_p30_0_final(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal
// static void setup_memwrite_pipe_p30_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pipe_pfc_0_procfinal


/*
 * calls: memwrite pread
 */
static int test_memwrite_pread_pfc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_pread_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_pread_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_pread_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_pread_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_memwrite_pread_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_memwrite_pread_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pfc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pfc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
static void setup_memwrite_pread_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_pread_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pfa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
static int test_memwrite_pread_pfa_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_pread_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_pread_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_pread_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_pread_pfa_0_final(void) {
  unlink("__i0");
}
static void setup_memwrite_pread_pfa_0_procfinal(void) {
  
}

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pfa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pfa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pfa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pfa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_pread_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pfa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pfa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
static int test_memwrite_pread_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_pread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_pread_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pread_pfa_0_proc0
// static void setup_memwrite_pread_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pread_pfa_1_proc0
// static void setup_memwrite_pread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
static int test_memwrite_pread_pf0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_pread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memwrite_pread_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_pread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pf0_0_final(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal
// static void setup_memwrite_pread_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pec_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
static void setup_memwrite_pread_pec_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_pread_pec_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_pread_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pec_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pec_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
// static void setup_memwrite_pread_pec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pread_pec_0_proc0
static void setup_memwrite_pread_pec_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_pread_pec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pea_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pea_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pread_pf0_0_proc0
static void setup_memwrite_pread_pea_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pea_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pea_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pea_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pea_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_pea_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pread_pf0_0_proc0
static void setup_memwrite_pread_pea_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pea_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pea_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pe8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pe8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pread_pf0_0_proc0
// static void setup_memwrite_pread_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pe8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pe8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pread_pf0_0_proc0
// static void setup_memwrite_pread_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_1_proc1
// static void setup_memwrite_pread_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pe0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pe0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pf0_0_common
// static void setup_memwrite_pread_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pread_pf0_0_proc0
// static void setup_memwrite_pread_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pe0_0_final(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal
// static void setup_memwrite_pread_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
static int test_memwrite_pread_pde_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_pread_pde_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
static void setup_memwrite_pread_pde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_pread_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_pread_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pde_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pde_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pde_0_common
static void setup_memwrite_pread_pde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_pread_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pde_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdd_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pdd_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
static void setup_memwrite_pread_pdd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_pread_pdd_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_memwrite_pread_pdd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
static void setup_memwrite_pread_pdd_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memwrite_pread_pdd_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdd_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
static int test_memwrite_pread_pdd_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_pread_pdd_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pread_pdd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x20ad000);
}
// static void setup_memwrite_pread_pdd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pdd_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pdd_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdd_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pdd_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pdd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pdd_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
// static void setup_memwrite_pread_pdd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pdd_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pdd_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdd_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
static int test_memwrite_pread_pdd_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 31617024);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memwrite_pread_pdd_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pdd_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
}
// static void setup_memwrite_pread_pdd_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pdd_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pdd_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdd_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
static int test_memwrite_pread_pdd_4_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 36270080);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memwrite_pread_pdd_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pdd_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2297000);
}
// static void setup_memwrite_pread_pdd_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pdd_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pdd_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdd_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
static int test_memwrite_pread_pdd_5_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 5062656);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memwrite_pread_pdd_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pdd_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
}
// static void setup_memwrite_pread_pdd_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pdd_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pdd_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pdc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
static void setup_memwrite_pread_pdc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pread_pdc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_memwrite_pread_pdc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pdc0_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pdc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdc0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pdc0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
static void setup_memwrite_pread_pdc0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pread_pdc0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x1e29000);
}
// static void setup_memwrite_pread_pdc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pdc0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pdc0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdc0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pdc0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pdc0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
static void setup_memwrite_pread_pdc0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
}
// static void setup_memwrite_pread_pdc0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pdc0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pdc0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdc0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pdc0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pdc0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
static void setup_memwrite_pread_pdc0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9986048, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x986000);
}
// static void setup_memwrite_pread_pdc0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pdc0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pdc0_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pdc0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pdc0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pdc0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
static void setup_memwrite_pread_pdc0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x27000);
}
// static void setup_memwrite_pread_pdc0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pdc0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pdc0_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_pread_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pde_0_common
static void setup_memwrite_pread_pd6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_pread_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_0_proc1
// static void setup_memwrite_pread_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pde_0_common
// static void setup_memwrite_pread_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_pread_pd6_0_proc0
// static void setup_memwrite_pread_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_1_proc1
// static void setup_memwrite_pread_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd5_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pd5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pdd_0_common
static void setup_memwrite_pread_pd5_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
static void setup_memwrite_pread_pd5_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pd5_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pd5_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd5_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
static void setup_memwrite_pread_pd5_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_pread_pd5_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x1e28000);
}
// static void setup_memwrite_pread_pd5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_1_proc1
// static void setup_memwrite_pread_pd5_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pd5_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd5_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd5_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pd5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pd5_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e27000);
}
static void setup_memwrite_pread_pd5_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pd5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pd5_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd5_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd5_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 31617024);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pdd_3_1
// static void setup_memwrite_pread_pd5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pd5_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
}
static void setup_memwrite_pread_pd5_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pd5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pd5_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd5_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd5_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 36270080);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pdd_4_1
// static void setup_memwrite_pread_pd5_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pd5_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2297000);
}
static void setup_memwrite_pread_pd5_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pd5_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pd5_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd5_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd5_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5062656);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pdd_5_1
// static void setup_memwrite_pread_pd5_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pd5_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x4d4000);
}
// static void setup_memwrite_pread_pd5_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pd5_0_proc1
// static void setup_memwrite_pread_pd5_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pd5_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd40_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pd40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pdc0_0_common
// static void setup_memwrite_pread_pd40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x26000);
// }
// ^ See setup_memwrite_pread_pd5_0_proc0
// static void setup_memwrite_pread_pd40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pd5_2_proc1
// static void setup_memwrite_pread_pd40_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pd40_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd40_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
static int test_memwrite_pread_pd40_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 20480);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memwrite_pread_pd40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pdd_1_common
static void setup_memwrite_pread_pd40_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x8ef000);
}
static void setup_memwrite_pread_pd40_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pd40_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pd40_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd40_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd40_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pd40_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pd40_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1e28000);
// }
// ^ See setup_memwrite_pread_pd5_3_proc0
// static void setup_memwrite_pread_pd40_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pd5_2_proc1
// static void setup_memwrite_pread_pd40_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pd40_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd40_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd40_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pd40_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
static void setup_memwrite_pread_pd40_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x986000);
}
static void setup_memwrite_pread_pd40_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9986048, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pd40_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pd40_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pde_0_0
// static int test_memwrite_pread_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_pread_pd8_0_proc0
// static void setup_memwrite_pread_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pce_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pce_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
static void setup_memwrite_pread_pce_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_pread_pce_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pread_pce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_pce_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pce_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pce_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pce_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pce_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pce_0_common
static void setup_memwrite_pread_pce_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pread_pce_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_pce_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pce_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pcd_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pcd_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pcd_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pd5_1_common
static void setup_memwrite_pread_pcd_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_pread_pcd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pcd_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pcd_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pcd_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
static int test_memwrite_pread_pcd_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 5087232);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_pread_pcd_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pread_pcd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_pread_pcd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pcd_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pcd_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pcd_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
static int test_memwrite_pread_pcd_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memwrite_pread_pcd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
static void setup_memwrite_pread_pcd_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pread_pcd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pcd_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pcd_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pcd_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
static int test_memwrite_pread_pcd_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 31621120);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_memwrite_pread_pcd_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
static void setup_memwrite_pread_pcd_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31621120, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pread_pcd_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pcd_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pcd_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pcc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
static int test_memwrite_pread_pcc8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 1);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_pread_pcc8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pread_pcc8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_pread_pcc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pcc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pcc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pcc8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pcc8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pcc8_0_1
// static void setup_memwrite_pread_pcc8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pcc8_0_common
static void setup_memwrite_pread_pcc8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_pread_pcc8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pcc8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pcc8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pcc8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
static int test_memwrite_pread_pcc8_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 8192);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 1);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_pread_pcc8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pread_pcc8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x3000);
}
// static void setup_memwrite_pread_pcc8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pcc8_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pcc8_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pcc8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
static int test_memwrite_pread_pcc8_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 1);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_pread_pcc8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pread_pcc8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_memwrite_pread_pcc8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pcc8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pcc8_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pcc8_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pcc8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
static void setup_memwrite_pread_pcc8_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pread_pcc8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pread_pcc8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pcc8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pcc8_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
static void setup_memwrite_pread_pc8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pread_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pce_0_common
static void setup_memwrite_pread_pc6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pread_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_0_proc1
// static void setup_memwrite_pread_pc6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pc6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pc6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pce_0_common
// static void setup_memwrite_pread_pc6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_pc6_0_proc0
// static void setup_memwrite_pread_pc6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_1_proc1
// static void setup_memwrite_pread_pc6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pc6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc5_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pc5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pd5_1_common
static void setup_memwrite_pread_pc5_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_pread_pc5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_pc5_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pc5_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc5_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5087232);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pcd_1_1
// static void setup_memwrite_pread_pc5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pcd_1_common
// static void setup_memwrite_pread_pc5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memwrite_pread_pc5_0_proc0
static void setup_memwrite_pread_pc5_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pc5_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pdd_0_final
// static void setup_memwrite_pread_pc5_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc5_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc5_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pcd_2_1
// static void setup_memwrite_pread_pc5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pc5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_pc8_0_proc0
// static void setup_memwrite_pread_pc5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_pc5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pc5_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc5_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc5_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 31621120);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pcd_3_1
// static void setup_memwrite_pread_pc5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pc5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_pc8_0_proc0
static void setup_memwrite_pread_pc5_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31621120, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pc5_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pc5_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc48_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc48_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pcc8_0_1
// static void setup_memwrite_pread_pc48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pcc8_0_common
static void setup_memwrite_pread_pc48_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_pread_pc48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pd40_1_proc1
// static void setup_memwrite_pread_pc48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pc48_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc48_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc48_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pcc8_0_1
// static void setup_memwrite_pread_pc48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pcc8_0_common
// static void setup_memwrite_pread_pc48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_pread_pc48_0_proc0
static void setup_memwrite_pread_pc48_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pc48_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pc48_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc48_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc48_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pd40_1_1
static void setup_memwrite_pread_pc48_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pread_pc48_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
}
static void setup_memwrite_pread_pc48_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pread_pc48_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pc48_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc48_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc48_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pd40_1_1
// static void setup_memwrite_pread_pc48_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pc48_2_common
// static void setup_memwrite_pread_pc48_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x5000);
// }
// ^ See setup_memwrite_pread_pc48_2_proc0
// static void setup_memwrite_pread_pc48_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pd40_1_proc1
// static void setup_memwrite_pread_pc48_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pc48_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pread_pfc_0_0
// static int test_memwrite_pread_pc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_pc8_0_proc0
// static void setup_memwrite_pread_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
static int test_memwrite_pread_pb8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_pread_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
static void setup_memwrite_pread_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_pread_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
static void setup_memwrite_pread_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_pread_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
static void setup_memwrite_pread_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pread_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_pb8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pb8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
static void setup_memwrite_pread_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pread_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_pb8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_pb8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_pread_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pread_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_pread_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pb4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pread_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb4_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb4_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_pb4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pb4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_pread_pb4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pb4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pb4_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_memwrite_pread_pb4_0_proc0
// static void setup_memwrite_pread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pread_pb4_1_proc0
// static void setup_memwrite_pread_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
static void setup_memwrite_pread_pb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_memwrite_pread_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_pb4_4_proc0
// static void setup_memwrite_pread_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pb0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pb0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_pb0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_pb0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pread_pb4_3_proc0
// static void setup_memwrite_pread_pb0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pb0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pb0_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_pread_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_pa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pf0_0_common
static void setup_memwrite_pread_pa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pread_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_pa_1_final(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal
// static void setup_memwrite_pread_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
static void setup_memwrite_pread_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_pread_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_0_proc1
// static void setup_memwrite_pread_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p98_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
static void setup_memwrite_pread_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pread_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_0_proc1
// static void setup_memwrite_pread_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p98_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p98_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
// static void setup_memwrite_pread_p98_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_p98_0_proc0
// static void setup_memwrite_pread_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_1_proc1
// static void setup_memwrite_pread_p98_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_p98_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p98_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p98_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
// static void setup_memwrite_pread_p98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pread_p98_1_proc0
// static void setup_memwrite_pread_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_1_proc1
// static void setup_memwrite_pread_p98_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_p98_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p94_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p94_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
static void setup_memwrite_pread_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_pread_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p94_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p94_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p94_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pread_pa_1_proc0
// static void setup_memwrite_pread_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p94_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p94_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p94_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_p94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_p94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_pa_0_proc0
// static void setup_memwrite_pread_p94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_p94_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p94_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p94_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p94_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_p94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_p94_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_pa_0_proc0
// static void setup_memwrite_pread_p94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_1_proc1
// static void setup_memwrite_pread_p94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p94_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p94_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p94_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_p94_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_p94_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pread_pa_1_proc0
// static void setup_memwrite_pread_p94_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_1_proc1
// static void setup_memwrite_pread_p94_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p94_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_memwrite_pread_p94_0_proc0
// static void setup_memwrite_pread_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pread_pa_1_proc0
// static void setup_memwrite_pread_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p90_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p90_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_p90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pread_pa_1_proc0
// static void setup_memwrite_pread_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_1_proc1
// static void setup_memwrite_pread_p90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p90_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p90_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p90_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_p90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_p90_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_pa_0_proc0
// static void setup_memwrite_pread_p90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pd5_2_proc1
// static void setup_memwrite_pread_p90_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p90_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p90_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p90_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_p90_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_p90_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_pa_0_proc0
// static void setup_memwrite_pread_p90_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_1_proc1
// static void setup_memwrite_pread_p90_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p90_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pread_pa_0_proc0
// static void setup_memwrite_pread_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pf0_0_common
// static void setup_memwrite_pread_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pread_pa_1_proc0
// static void setup_memwrite_pread_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal
// static void setup_memwrite_pread_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p7_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
// static void setup_memwrite_pread_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_0_proc1
// static void setup_memwrite_pread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p7_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
// static void setup_memwrite_pread_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_1_proc1
// static void setup_memwrite_pread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p68_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_1_proc1
// static void setup_memwrite_pread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p60_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p60_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_1_proc1
// static void setup_memwrite_pread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pf0_0_common
// static void setup_memwrite_pread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p4_0_final(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal
// static void setup_memwrite_pread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p3_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
// static void setup_memwrite_pread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_0_proc1
// static void setup_memwrite_pread_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p3_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfc_0_1
// static void setup_memwrite_pread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pread_pfc_0_common
// static void setup_memwrite_pread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pfc_0_proc1
// static void setup_memwrite_pread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pread_pec_1_proc1
// static void setup_memwrite_pread_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_final
// static void setup_memwrite_pread_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pread_pfc_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p28_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p28_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pfa_0_1
// static void setup_memwrite_pread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pfa_0_common
// static void setup_memwrite_pread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_1_proc1
// static void setup_memwrite_pread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_0_proc1
// static void setup_memwrite_pread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p20_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p20_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf8_0_1
// static void setup_memwrite_pread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pread_pf8_0_common
// static void setup_memwrite_pread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pread_pea_1_proc1
// static void setup_memwrite_pread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pread_pfa_0_final
// static void setup_memwrite_pread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal

/*
 * calls: memwrite pread
 */
// static int test_memwrite_pread_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pread_pb8_0_0
// static int test_memwrite_pread_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_pread_pf0_0_1
// static void setup_memwrite_pread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pf0_0_common
// static void setup_memwrite_pread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pread_pfa_0_proc1
// static void setup_memwrite_pread_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal
// static void setup_memwrite_pread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pread_pfa_0_procfinal


/*
 * calls: memwrite pwrite
 */
static int test_memwrite_pwrite_pfc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_pwrite_pfc_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_pwrite_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_pwrite_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_memwrite_pwrite_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_memwrite_pwrite_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pfc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pfc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
static void setup_memwrite_pwrite_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_pwrite_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pfa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
static int test_memwrite_pwrite_pfa_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_pwrite_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_pwrite_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_pwrite_pfa_0_final(void) {
  unlink("__i0");
}
static void setup_memwrite_pwrite_pfa_0_procfinal(void) {
  
}

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pfa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pfa_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pfa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pfa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_pwrite_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pfa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pfa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pf8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
static void setup_memwrite_pwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_pwrite_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pf8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pf8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pwrite_pfa_1_proc0
// static void setup_memwrite_pwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
static int test_memwrite_pwrite_pf0_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memwrite_pwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_pwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pf0_0_final(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal
// static void setup_memwrite_pwrite_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pec_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pec_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
static void setup_memwrite_pwrite_pec_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_pwrite_pec_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_pwrite_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pec_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pec_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
// static void setup_memwrite_pwrite_pec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pwrite_pec_0_proc0
static void setup_memwrite_pwrite_pec_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_pwrite_pec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pea_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pea_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pwrite_pf0_0_proc0
static void setup_memwrite_pwrite_pea_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pea_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pea_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pea_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pea_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_pea_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pwrite_pf0_0_proc0
static void setup_memwrite_pwrite_pea_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pea_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pea_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pe8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pe8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pwrite_pf0_0_proc0
static void setup_memwrite_pwrite_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pe8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pe8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pwrite_pf0_0_proc0
// static void setup_memwrite_pwrite_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_1_proc1
// static void setup_memwrite_pwrite_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pe0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pe0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pf0_0_common
// static void setup_memwrite_pwrite_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_pwrite_pf0_0_proc0
// static void setup_memwrite_pwrite_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pe0_0_final(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal
// static void setup_memwrite_pwrite_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
static int test_memwrite_pwrite_pde_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_pwrite_pde_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
static void setup_memwrite_pwrite_pde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_pwrite_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pde_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pde_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pde_0_common
static void setup_memwrite_pwrite_pde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pde_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pdd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
static int test_memwrite_pwrite_pdd8_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pdd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pdd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_pwrite_pdd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
static void setup_memwrite_pwrite_pdd8_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memwrite_pwrite_pdd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pdd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pdd8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pdd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pdd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_pwrite_pdd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pdd8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pdd8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pdd8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
static int test_memwrite_pwrite_pdd8_2_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pdd8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pdd8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x9000);
}
// static void setup_memwrite_pwrite_pdd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pdd8_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pdd8_0_final
// static void setup_memwrite_pwrite_pdd8_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pdd8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pdd8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pdd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pdd8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_pwrite_pdd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pdd8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pdd8_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pdc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pdc0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pdc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pdd8_0_common
static void setup_memwrite_pwrite_pdc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_pwrite_pdc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pdc0_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pdd8_0_final
// static void setup_memwrite_pwrite_pdc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pdc0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
static int test_memwrite_pwrite_pdc0_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pdc0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pdc0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
}
// static void setup_memwrite_pwrite_pdc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pdc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pdc0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pdc0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pdc0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
static void setup_memwrite_pwrite_pdc0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pdc0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x1000);
}
// static void setup_memwrite_pwrite_pdc0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pdc0_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pdd8_0_final
// static void setup_memwrite_pwrite_pdc0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pdc0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pdc0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pdc0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pdc0_1_common
static void setup_memwrite_pwrite_pdc0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
}
// static void setup_memwrite_pwrite_pdc0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pdc0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pdc0_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd6_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pde_0_common
static void setup_memwrite_pwrite_pd6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_0_proc1
// static void setup_memwrite_pwrite_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd6_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pde_0_common
// static void setup_memwrite_pwrite_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pd6_0_proc0
// static void setup_memwrite_pwrite_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_1_proc1
// static void setup_memwrite_pwrite_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd58_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd58_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pdd8_0_1
// static void setup_memwrite_pwrite_pd58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pdd8_0_common
static void setup_memwrite_pwrite_pd58_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
static void setup_memwrite_pwrite_pd58_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pd58_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pdd8_0_final
// static void setup_memwrite_pwrite_pd58_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd58_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd58_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pd58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pd58_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
static void setup_memwrite_pwrite_pd58_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pd58_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pd58_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd58_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd58_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pdd8_2_1
// static void setup_memwrite_pwrite_pd58_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pdd8_2_common
static void setup_memwrite_pwrite_pd58_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x9000);
}
static void setup_memwrite_pwrite_pd58_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pd58_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pdd8_0_final
// static void setup_memwrite_pwrite_pd58_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd58_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd58_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pd58_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_pd58_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_pwrite_pd58_1_proc0
static void setup_memwrite_pwrite_pd58_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pd58_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pd58_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd40_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd40_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pd40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pdd8_0_common
// static void setup_memwrite_pwrite_pd40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memwrite_pwrite_pd58_0_proc0
// static void setup_memwrite_pwrite_pd40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pe8_0_proc1
// static void setup_memwrite_pwrite_pd40_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pdd8_0_final
// static void setup_memwrite_pwrite_pd40_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd40_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd40_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pdc0_1_1
// static void setup_memwrite_pwrite_pd40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pdc0_1_common
static void setup_memwrite_pwrite_pd40_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
}
static void setup_memwrite_pwrite_pd40_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pd40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pd40_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd40_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd40_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pdc0_1_1
// static void setup_memwrite_pwrite_pd40_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pdd8_2_common
static void setup_memwrite_pwrite_pd40_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x8000);
}
static void setup_memwrite_pwrite_pd40_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pd40_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pdd8_0_final
// static void setup_memwrite_pwrite_pd40_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd40_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd40_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pdc0_1_1
// static void setup_memwrite_pwrite_pd40_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pdc0_1_common
// static void setup_memwrite_pwrite_pd40_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x8000);
// }
// ^ See setup_memwrite_pwrite_pd40_1_proc0
// static void setup_memwrite_pwrite_pd40_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pd40_2_proc1
// static void setup_memwrite_pwrite_pd40_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pd40_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pde_0_0
// static int test_memwrite_pwrite_pd0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pd8_0_proc0
// static void setup_memwrite_pwrite_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pce_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pce_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
static void setup_memwrite_pwrite_pce_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_memwrite_pwrite_pce_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pde_0_proc0
// static void setup_memwrite_pwrite_pce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_pce_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pce_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pce_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pce_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pce_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pce_0_common
// static void setup_memwrite_pwrite_pce_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pde_1_proc0
// static void setup_memwrite_pwrite_pce_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_pce_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pce_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pcd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
static int test_memwrite_pwrite_pcd0_0_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pcd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pcd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x4000);
}
// static void setup_memwrite_pwrite_pcd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pcd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pcd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pcd0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
static int test_memwrite_pwrite_pcd0_1_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pcd0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pcd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
}
// static void setup_memwrite_pwrite_pcd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pcd0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pdd8_0_final
// static void setup_memwrite_pwrite_pcd0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pcd0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pcd0_2_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pcd0_0_1
// static void setup_memwrite_pwrite_pcd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pcd0_0_common
static void setup_memwrite_pwrite_pcd0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x4000);
}
// static void setup_memwrite_pwrite_pcd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pcd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pcd0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pcd0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pcd0_3_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pcd0_0_1
// static void setup_memwrite_pwrite_pcd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pcd0_0_common
static void setup_memwrite_pwrite_pcd0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x4000);
}
// static void setup_memwrite_pwrite_pcd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pcd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pcd0_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pcc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
static int test_memwrite_pwrite_pcc0_0_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pcc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pcc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_pwrite_pcc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pcc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pcc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pcc0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pcc0_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pcd0_1_1
static void setup_memwrite_pwrite_pcc0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pcc0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
}
// static void setup_memwrite_pwrite_pcc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pcc0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pdd8_0_final
// static void setup_memwrite_pwrite_pcc0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pcc0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
static int test_memwrite_pwrite_pcc0_2_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pcc0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pcc0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x3000);
}
// static void setup_memwrite_pwrite_pcc0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pcc0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pcc0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pcc0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pcc0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
static void setup_memwrite_pwrite_pcc0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pcc0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_pcc0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pcc0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pcc0_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pcc0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pcc0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pcc0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pcc0_3_common
static void setup_memwrite_pwrite_pcc0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_pcc0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pcc0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pcc0_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pc8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pd8_0_proc0
// static void setup_memwrite_pwrite_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pc6_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pce_0_common
// static void setup_memwrite_pwrite_pc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pd6_0_proc0
// static void setup_memwrite_pwrite_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_0_proc1
// static void setup_memwrite_pwrite_pc6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pc6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc6_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pc6_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pc6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pce_0_common
// static void setup_memwrite_pwrite_pc6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pd6_0_proc0
// static void setup_memwrite_pwrite_pc6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_1_proc1
// static void setup_memwrite_pwrite_pc6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pc6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc50_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
static int test_memwrite_pwrite_pc50_0_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pc50_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pc50_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
static void setup_memwrite_pwrite_pc50_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pc50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pc50_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc50_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pc50_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pcd0_1_1
// static void setup_memwrite_pwrite_pc50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pcd0_1_common
static void setup_memwrite_pwrite_pc50_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
}
// static void setup_memwrite_pwrite_pc50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pd58_3_proc1
// static void setup_memwrite_pwrite_pc50_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pdd8_0_final
// static void setup_memwrite_pwrite_pc50_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc50_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pc50_2_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pc50_0_1
// static void setup_memwrite_pwrite_pc50_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pc50_0_common
// static void setup_memwrite_pwrite_pc50_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x6000);
// }
// ^ See setup_memwrite_pwrite_pc50_0_proc0
// static void setup_memwrite_pwrite_pc50_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pd40_2_proc1
// static void setup_memwrite_pwrite_pc50_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pc50_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc40_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pc40_0_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pcc0_0_1
// static void setup_memwrite_pwrite_pc40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pcc0_0_common
// static void setup_memwrite_pwrite_pc40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_pwrite_pd58_1_proc0
// static void setup_memwrite_pwrite_pc40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pd40_1_proc1
// static void setup_memwrite_pwrite_pc40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pc40_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc40_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pc40_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pcd0_1_1
static void setup_memwrite_pwrite_pc40_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pc40_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
static void setup_memwrite_pwrite_pc40_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pc40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pc40_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc40_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
static int test_memwrite_pwrite_pc40_2_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_memwrite_pwrite_pc40_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_pwrite_pc40_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
}
static void setup_memwrite_pwrite_pc40_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_pc40_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pc40_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc40_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pc40_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pc40_2_1
// static void setup_memwrite_pwrite_pc40_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pc40_2_common
// static void setup_memwrite_pwrite_pc40_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x5000);
// }
// ^ See setup_memwrite_pwrite_pc40_2_proc0
// static void setup_memwrite_pwrite_pc40_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pd40_1_proc1
// static void setup_memwrite_pwrite_pc40_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pc40_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_pwrite_pfc_0_0
// static int test_memwrite_pwrite_pc0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pd8_0_proc0
// static void setup_memwrite_pwrite_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
static int test_memwrite_pwrite_pb8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_pwrite_pb8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
static void setup_memwrite_pwrite_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
static void setup_memwrite_pwrite_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb8_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
static void setup_memwrite_pwrite_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pwrite_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_pb8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pb8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb8_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
static void setup_memwrite_pwrite_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pwrite_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_pb8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_pb8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb4_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
// static void setup_memwrite_pwrite_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
// static void setup_memwrite_pwrite_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb4_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pwrite_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb4_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb4_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pb4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
// static void setup_memwrite_pwrite_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb4_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb4_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pb4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pwrite_pb4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb4_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb4_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb4_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pb4_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_pb4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb4_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
static void setup_memwrite_pwrite_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_memwrite_pwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
static void setup_memwrite_pwrite_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
// static void setup_memwrite_pwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pdd8_0_1
static void setup_memwrite_pwrite_pb0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_pwrite_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pwrite_pb4_4_proc0
// static void setup_memwrite_pwrite_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb0_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x704000);
// }
// ^ See setup_memwrite_pwrite_pb4_3_proc0
// static void setup_memwrite_pwrite_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb0_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_pb0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pwrite_pb4_4_proc0
// static void setup_memwrite_pwrite_pb0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb0_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pb0_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pb0_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_pb0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_pb0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pb4_5_proc0
// static void setup_memwrite_pwrite_pb0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pb0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pb0_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pa_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_pa_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pf0_0_common
static void setup_memwrite_pwrite_pa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pwrite_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_pa_1_final(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal
// static void setup_memwrite_pwrite_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p98_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
static void setup_memwrite_pwrite_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_pwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_0_proc1
// static void setup_memwrite_pwrite_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p98_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
static void setup_memwrite_pwrite_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_pwrite_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_0_proc1
// static void setup_memwrite_pwrite_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p98_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p98_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
// static void setup_memwrite_pwrite_p98_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_p98_0_proc0
// static void setup_memwrite_pwrite_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_1_proc1
// static void setup_memwrite_pwrite_p98_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_p98_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p98_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p98_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
// static void setup_memwrite_pwrite_p98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pwrite_p98_1_proc0
// static void setup_memwrite_pwrite_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_1_proc1
// static void setup_memwrite_pwrite_p98_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_p98_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p94_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p94_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
// static void setup_memwrite_pwrite_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_0_proc1
// static void setup_memwrite_pwrite_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p94_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p94_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p94_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
static void setup_memwrite_pwrite_p94_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
// static void setup_memwrite_pwrite_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9347072, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pc40_2_proc1
// static void setup_memwrite_pwrite_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p94_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p94_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p94_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_p94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pa_0_proc0
// static void setup_memwrite_pwrite_p94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pd58_3_proc1
// static void setup_memwrite_pwrite_p94_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p94_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p94_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p94_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_p94_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pwrite_pa_1_proc0
static void setup_memwrite_pwrite_p94_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 33169408, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_pwrite_p94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p94_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p94_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p94_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p94_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_p94_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pa_0_proc0
// static void setup_memwrite_pwrite_p94_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_1_proc1
// static void setup_memwrite_pwrite_p94_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p94_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p94_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p94_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p94_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_p94_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pwrite_pa_1_proc0
// static void setup_memwrite_pwrite_p94_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_1_proc1
// static void setup_memwrite_pwrite_p94_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p94_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p90_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
static void setup_memwrite_pwrite_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_memwrite_pwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pe8_0_proc1
// static void setup_memwrite_pwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p90_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x704000);
// }
// ^ See setup_memwrite_pwrite_p94_0_proc0
// static void setup_memwrite_pwrite_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pd58_1_proc1
// static void setup_memwrite_pwrite_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p90_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p90_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pdd8_0_1
// static void setup_memwrite_pwrite_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pb0_2_common
static void setup_memwrite_pwrite_p90_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_memwrite_pwrite_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_1_proc1
// static void setup_memwrite_pwrite_p90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p90_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p90_3_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p90_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_p90_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pwrite_pa_1_proc0
// static void setup_memwrite_pwrite_p90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pd40_1_proc1
// static void setup_memwrite_pwrite_p90_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p90_3_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p90_4_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p90_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p90_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_p90_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pwrite_pa_1_proc0
// static void setup_memwrite_pwrite_p90_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_1_proc1
// static void setup_memwrite_pwrite_p90_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p90_4_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p90_5_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p90_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p90_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_p90_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pa_0_proc0
// static void setup_memwrite_pwrite_p90_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_1_proc1
// static void setup_memwrite_pwrite_p90_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p90_5_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_pwrite_pa_0_proc0
// static void setup_memwrite_pwrite_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pf0_0_common
// static void setup_memwrite_pwrite_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_pwrite_pa_1_proc0
// static void setup_memwrite_pwrite_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal
// static void setup_memwrite_pwrite_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p7_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p7_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
// static void setup_memwrite_pwrite_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_0_proc1
// static void setup_memwrite_pwrite_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p7_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p7_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
// static void setup_memwrite_pwrite_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_1_proc1
// static void setup_memwrite_pwrite_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p68_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pd58_0_proc1
// static void setup_memwrite_pwrite_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p68_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p68_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_1_proc1
// static void setup_memwrite_pwrite_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p68_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p60_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pd58_1_proc1
// static void setup_memwrite_pwrite_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p60_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p60_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_1_proc1
// static void setup_memwrite_pwrite_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p60_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p4_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pf0_0_common
// static void setup_memwrite_pwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p4_0_final(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal
// static void setup_memwrite_pwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p3_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p3_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
// static void setup_memwrite_pwrite_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_0_proc1
// static void setup_memwrite_pwrite_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p3_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p3_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfc_0_1
// static void setup_memwrite_pwrite_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_pwrite_pfc_0_common
// static void setup_memwrite_pwrite_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pfc_0_proc1
// static void setup_memwrite_pwrite_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_pwrite_pec_1_proc1
// static void setup_memwrite_pwrite_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_final
// static void setup_memwrite_pwrite_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_pwrite_pfc_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p28_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_0_proc1
// static void setup_memwrite_pwrite_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p28_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p28_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pfa_0_common
// static void setup_memwrite_pwrite_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_1_proc1
// static void setup_memwrite_pwrite_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p28_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p20_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pe8_0_proc1
// static void setup_memwrite_pwrite_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p20_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p20_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pfa_0_1
// static void setup_memwrite_pwrite_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pf8_0_common
// static void setup_memwrite_pwrite_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_pwrite_pea_1_proc1
// static void setup_memwrite_pwrite_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_pwrite_pfa_0_final
// static void setup_memwrite_pwrite_p20_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal

/*
 * calls: memwrite pwrite
 */
// static int test_memwrite_pwrite_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_pwrite_pb8_0_0
// static int test_memwrite_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_memwrite_pwrite_pf0_0_1
// static void setup_memwrite_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pf0_0_common
// static void setup_memwrite_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_pwrite_pfa_0_proc1
// static void setup_memwrite_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal
// static void setup_memwrite_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_pwrite_pfa_0_procfinal


/*
 * calls: memwrite read
 */
static int test_memwrite_read_pfe_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_read_pfe_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_read_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_read_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_read_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_memwrite_read_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_memwrite_read_pfe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pfd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
static int test_memwrite_read_pfd8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_read_pfd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_read_pfd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_read_pfd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pfd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pfd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pfd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
static int test_memwrite_read_pfd0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_read_pfd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_read_pfd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_read_pfd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_read_pfd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pfd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pfc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
static int test_memwrite_read_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_read_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_memwrite_read_pfc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_read_pfd8_0_proc0
// static void setup_memwrite_read_pfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pfa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pfa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
static void setup_memwrite_read_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_read_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_read_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_read_pfa_0_final(void) {
  unlink("__i0");
}
static void setup_memwrite_read_pfa_0_procfinal(void) {
  
}

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pf8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
static void setup_memwrite_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_read_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_read_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
static void setup_memwrite_read_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memwrite_read_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pf0_0_final(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal
// static void setup_memwrite_read_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pee_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pee_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pee_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfe_0_common
static void setup_memwrite_read_pee_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_read_pee_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_read_pee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_ped8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_ped8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
// static void setup_memwrite_read_ped8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd8_0_common
// static void setup_memwrite_read_ped8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_read_pee_0_proc0
static void setup_memwrite_read_ped8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_read_ped8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_ped8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_ped0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_ped0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_ped0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd0_0_common
static void setup_memwrite_read_ped0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_read_ped0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_read_ped0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_ped0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pec_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfc_0_common
// static void setup_memwrite_read_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_read_pee_0_proc0
// static void setup_memwrite_read_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pea_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pea_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
// static void setup_memwrite_read_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_read_pf0_0_proc0
static void setup_memwrite_read_pea_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_read_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pea_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pe8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pe8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
// static void setup_memwrite_read_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_read_pf0_0_proc0
// static void setup_memwrite_read_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pe0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pe0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_read_pf0_0_common
// static void setup_memwrite_read_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_read_pf0_0_proc0
// static void setup_memwrite_read_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pe0_0_final(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal
// static void setup_memwrite_read_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
static int test_memwrite_read_pdf_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_read_pdf_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
static void setup_memwrite_read_pdf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_read_pdf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_read_pdf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pdf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pdf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pdec_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pdec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
static void setup_memwrite_read_pdec_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_read_pdec_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_read_pdec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pdec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pdec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pde8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pde8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pde8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pdec_0_common
static void setup_memwrite_read_pde8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_read_pde8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfd0_0_proc1
// static void setup_memwrite_read_pde8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pde8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pde0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pde0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
static void setup_memwrite_read_pde0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_read_pde0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_read_pde0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pde0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pde0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pdd_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pdd_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
static void setup_memwrite_read_pdd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_read_pdd_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_read_pdd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
static void setup_memwrite_read_pdd_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memwrite_read_pdd_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pdd_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pdd_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pdd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
static void setup_memwrite_read_pdd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_read_pdd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pdd_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pdd_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pdd_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pdd_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pdd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
static void setup_memwrite_read_pdd_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_read_pdd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pdd_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pdd_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pdc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pdc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
static void setup_memwrite_read_pdc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_read_pdc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_read_pdc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pdc0_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pdd_0_final
// static void setup_memwrite_read_pdc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pdc0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pdc0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
static void setup_memwrite_read_pdc0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_read_pdc0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
}
// static void setup_memwrite_read_pdc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pdc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pdc0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
static void setup_memwrite_read_pd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_read_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd7_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pd7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pdf_0_common
static void setup_memwrite_read_pd7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_read_pd7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pee_0_proc1
// static void setup_memwrite_read_pd7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pd7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd6c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd6c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
// static void setup_memwrite_read_pd6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pdec_0_common
static void setup_memwrite_read_pd6c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_read_pd6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_pd6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pd6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pd68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pdec_0_common
static void setup_memwrite_read_pd68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_read_pd68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped0_0_proc1
// static void setup_memwrite_read_pd68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pd68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pd60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pde0_0_common
// static void setup_memwrite_read_pd60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pd7_0_proc0
// static void setup_memwrite_read_pd60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_pd60_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pd60_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd5_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
static void setup_memwrite_read_pd5_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_read_pd5_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
static void setup_memwrite_read_pd5_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_read_pd5_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pdd_0_final
// static void setup_memwrite_read_pd5_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd5_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pd5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
// static void setup_memwrite_read_pd5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pd8_0_proc0
// static void setup_memwrite_read_pd5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pd5_0_proc1
// static void setup_memwrite_read_pd5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pd5_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd5_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd5_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pd5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
// static void setup_memwrite_read_pd5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pd8_0_proc0
// static void setup_memwrite_read_pd5_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_pd5_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pd5_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd40_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pd40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pdc0_0_common
// static void setup_memwrite_read_pd40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memwrite_read_pd5_0_proc0
static void setup_memwrite_read_pd40_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_read_pd40_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pdd_0_final
// static void setup_memwrite_read_pd40_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd40_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd40_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pd40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pdc0_1_common
static void setup_memwrite_read_pd40_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
}
static void setup_memwrite_read_pd40_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_read_pd40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pd40_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pdf_0_0
// static int test_memwrite_read_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
// static void setup_memwrite_read_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pd8_0_proc0
// static void setup_memwrite_read_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pcf_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pcf_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
static void setup_memwrite_read_pcf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_memwrite_read_pcf_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pdf_0_proc0
// static void setup_memwrite_read_pcf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pcf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pcf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pcec_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pcec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
static void setup_memwrite_read_pcec_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_read_pcec_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memwrite_read_pcec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pcec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pcec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pce8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pce8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pce8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pcec_0_common
static void setup_memwrite_read_pce8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memwrite_read_pce8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfd0_0_proc1
// static void setup_memwrite_read_pce8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pce8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pce0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pce0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
static void setup_memwrite_read_pce0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_memwrite_read_pce0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pde0_0_proc0
// static void setup_memwrite_read_pce0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pce0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pce0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pcd_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pcd_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
static void setup_memwrite_read_pcd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_memwrite_read_pcd_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memwrite_read_pdd_0_proc0
// static void setup_memwrite_read_pcd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pcd_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pdd_0_final
// static void setup_memwrite_read_pcd_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pcd_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pcd_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pcd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
static void setup_memwrite_read_pcd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 159744, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_read_pcd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pcd_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pcd_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pcc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
static int test_memwrite_read_pcc8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 1);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_memwrite_read_pcc8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_read_pcc8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_read_pcc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pcc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pcc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pcc8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pcc8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
static void setup_memwrite_read_pcc8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_read_pcc8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pdd_2_proc0
// static void setup_memwrite_read_pcc8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pcc8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pcc8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pc8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
// static void setup_memwrite_read_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pd8_0_proc0
// static void setup_memwrite_read_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pc7_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pc7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pc7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pcf_0_common
// static void setup_memwrite_read_pc7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pd7_0_proc0
// static void setup_memwrite_read_pc7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pee_0_proc1
// static void setup_memwrite_read_pc7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pc7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pc6c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pc6c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
// static void setup_memwrite_read_pc6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pcec_0_common
static void setup_memwrite_read_pc6c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memwrite_read_pc6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_pc6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pc6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pc68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pc68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pc68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pcec_0_common
static void setup_memwrite_read_pc68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memwrite_read_pc68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped0_0_proc1
// static void setup_memwrite_read_pc68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pc68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pc60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pc60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pc60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pce0_0_common
// static void setup_memwrite_read_pc60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pd7_0_proc0
// static void setup_memwrite_read_pc60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_pc60_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pc60_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pc5_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pc5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
static void setup_memwrite_read_pc5_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_read_pc5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memwrite_read_pd5_0_proc0
// static void setup_memwrite_read_pc5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pd5_0_proc1
// static void setup_memwrite_read_pc5_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pdd_0_final
// static void setup_memwrite_read_pc5_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pc5_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pc5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pc5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
// static void setup_memwrite_read_pc5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pd8_0_proc0
static void setup_memwrite_read_pc5_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 159744, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_read_pc5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pc5_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pc48_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pc48_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pcc8_0_1
// static void setup_memwrite_read_pc48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pcc8_0_common
static void setup_memwrite_read_pc48_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_read_pc48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_pc48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pc48_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pc48_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pc48_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pc48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pcc8_1_common
// static void setup_memwrite_read_pc48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pd8_0_proc0
// static void setup_memwrite_read_pc48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_pc48_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pc48_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_read_pfe_0_0
// static int test_memwrite_read_pc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
// static void setup_memwrite_read_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pd8_0_proc0
// static void setup_memwrite_read_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
static int test_memwrite_read_pbc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_read_pbc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfe_0_common
static void setup_memwrite_read_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_read_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pbc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfe_0_common
static void setup_memwrite_read_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_read_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pbb_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pbb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
// static void setup_memwrite_read_pbb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd8_0_common
static void setup_memwrite_read_pbb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_read_pbb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pbb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pbb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pbb_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pbb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
// static void setup_memwrite_read_pbb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd8_0_common
static void setup_memwrite_read_pbb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_read_pbb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pbb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pbb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pba_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pba_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pba_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd0_0_common
static void setup_memwrite_read_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x5000);
}
// static void setup_memwrite_read_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfd0_0_proc1
// static void setup_memwrite_read_pba_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pba_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pba_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pba_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pba_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd0_0_common
static void setup_memwrite_read_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_read_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfd0_0_proc1
// static void setup_memwrite_read_pba_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pba_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfc_0_common
// static void setup_memwrite_read_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_memwrite_read_pbb_0_proc0
// static void setup_memwrite_read_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfc_0_common
// static void setup_memwrite_read_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_read_pbb_1_proc0
// static void setup_memwrite_read_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pb4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pb4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
static void setup_memwrite_read_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_memwrite_read_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pb4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pb4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
static void setup_memwrite_read_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
// static void setup_memwrite_read_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pb4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pb4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
static void setup_memwrite_read_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_read_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
static void setup_memwrite_read_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_memwrite_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
static void setup_memwrite_read_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_read_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pb0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pb0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
static void setup_memwrite_read_pb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_read_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
static void setup_memwrite_read_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_read_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_pa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_read_pf0_0_common
static void setup_memwrite_read_pa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_read_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_pa_1_final(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal
// static void setup_memwrite_read_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p9c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfe_0_common
static void setup_memwrite_read_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_read_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pee_0_proc1
// static void setup_memwrite_read_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p9c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfe_0_common
static void setup_memwrite_read_p9c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_read_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pee_0_proc1
// static void setup_memwrite_read_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p9b_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p9b_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
// static void setup_memwrite_read_p9b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd8_0_common
static void setup_memwrite_read_p9b_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_read_p9b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_p9b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p9b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p9b_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p9b_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
// static void setup_memwrite_read_p9b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd8_0_common
// static void setup_memwrite_read_p9b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_read_p9c_1_proc0
// static void setup_memwrite_read_p9b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_p9b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p9b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p9a_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p9a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd0_0_common
static void setup_memwrite_read_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x5000);
}
// static void setup_memwrite_read_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped0_0_proc1
// static void setup_memwrite_read_p9a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p9a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p9a_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p9a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd8_0_common
static void setup_memwrite_read_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_read_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped0_0_proc1
// static void setup_memwrite_read_p9a_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p9a_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfc_0_common
// static void setup_memwrite_read_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_memwrite_read_p9b_0_proc0
// static void setup_memwrite_read_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p98_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfc_0_common
// static void setup_memwrite_read_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_read_p9c_1_proc0
// static void setup_memwrite_read_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p94_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p94_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
static void setup_memwrite_read_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_read_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p94_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p94_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p94_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
// static void setup_memwrite_read_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_read_pa_1_proc0
// static void setup_memwrite_read_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p94_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p94_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p94_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_p94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
// static void setup_memwrite_read_p94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pa_0_proc0
// static void setup_memwrite_read_p94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_p94_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p94_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
static void setup_memwrite_read_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_memwrite_read_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
// static void setup_memwrite_read_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pa_0_proc0
// static void setup_memwrite_read_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p90_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p90_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
// static void setup_memwrite_read_p90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_read_pa_1_proc0
// static void setup_memwrite_read_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_p90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p90_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
// static void setup_memwrite_read_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_read_pa_0_proc0
// static void setup_memwrite_read_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_read_pf0_0_common
// static void setup_memwrite_read_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_read_pa_1_proc0
// static void setup_memwrite_read_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal
// static void setup_memwrite_read_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p78_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfe_0_common
// static void setup_memwrite_read_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pee_0_proc1
// static void setup_memwrite_read_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p76_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
// static void setup_memwrite_read_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd8_0_common
// static void setup_memwrite_read_p76_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p74_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd0_0_common
// static void setup_memwrite_read_p74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped0_0_proc1
// static void setup_memwrite_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfd0_0_proc1
// static void setup_memwrite_read_p74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfc_0_common
// static void setup_memwrite_read_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
// static void setup_memwrite_read_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pd5_0_proc1
// static void setup_memwrite_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
// static void setup_memwrite_read_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_read_pf0_0_common
// static void setup_memwrite_read_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_p4_0_final(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal
// static void setup_memwrite_read_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p38_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfe_0_common
// static void setup_memwrite_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pee_0_proc1
// static void setup_memwrite_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p36_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd8_0_1
// static void setup_memwrite_read_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd8_0_common
// static void setup_memwrite_read_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p34_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfd0_0_common
// static void setup_memwrite_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfd0_0_proc1
// static void setup_memwrite_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped0_0_proc1
// static void setup_memwrite_read_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_read_pfc_0_common
// static void setup_memwrite_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_pfe_0_proc1
// static void setup_memwrite_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_read_ped8_0_proc1
// static void setup_memwrite_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_final
// static void setup_memwrite_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_read_pfe_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfd0_0_1
// static void setup_memwrite_read_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_read_pfa_0_common
// static void setup_memwrite_read_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfc_0_1
// static void setup_memwrite_read_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_read_pf8_0_common
// static void setup_memwrite_read_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_read_pea_0_proc1
// static void setup_memwrite_read_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_read_pfa_0_final
// static void setup_memwrite_read_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal

/*
 * calls: memwrite read
 */
// static int test_memwrite_read_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_read_pbc_0_0
// static int test_memwrite_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_memwrite_read_pfe_0_1
// static void setup_memwrite_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_read_pf0_0_common
// static void setup_memwrite_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_read_pfa_0_proc1
// static void setup_memwrite_read_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal
// static void setup_memwrite_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_read_pfa_0_procfinal


/*
 * calls: memwrite rename
 */
static int test_memwrite_rename_pf8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_rename_pf8_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memwrite_rename_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memwrite_rename_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_rename_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_rename_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_memwrite_rename_pf8_0_procfinal(void) {
  
}

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pf4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_rename_pf8_0_0
static int test_memwrite_rename_pf4_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memwrite_rename_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_memwrite_rename_pf4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_rename_pf8_0_proc0
// static void setup_memwrite_rename_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pf4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pf4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_rename_pf8_0_0
// static int test_memwrite_rename_pf0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
// static void setup_memwrite_rename_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf8_0_common
// static void setup_memwrite_rename_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_rename_pf8_0_proc0
// static void setup_memwrite_rename_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_rename_pf8_0_0
static int test_memwrite_rename_pe_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_memwrite_rename_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_memwrite_rename_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_rename_pf8_0_proc0
// static void setup_memwrite_rename_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pe_0_final(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal
// static void setup_memwrite_rename_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
static int test_memwrite_rename_pdc_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_rename_pdc_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf8_0_1
// static void setup_memwrite_rename_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf8_0_common
static void setup_memwrite_rename_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_rename_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pdc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pda_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pdc_0_0
// static int test_memwrite_rename_pda_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
static void setup_memwrite_rename_pda_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_memwrite_rename_pda_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x26000);
}
// static void setup_memwrite_rename_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
static void setup_memwrite_rename_pda_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memwrite_rename_pda_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pda_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pdc_0_0
// static int test_memwrite_rename_pda_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
static void setup_memwrite_rename_pda_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_memwrite_rename_pda_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_rename_pdc_0_proc0
// static void setup_memwrite_rename_pda_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pda_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pda_0_final
// static void setup_memwrite_rename_pda_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pda_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pdc_0_0
// static int test_memwrite_rename_pda_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
// static void setup_memwrite_rename_pda_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf4_0_common
// static void setup_memwrite_rename_pda_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_rename_pdc_0_proc0
// static void setup_memwrite_rename_pda_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pda_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pda_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pdc_0_0
// static int test_memwrite_rename_pd8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
// static void setup_memwrite_rename_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf8_0_common
// static void setup_memwrite_rename_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_rename_pdc_0_proc0
// static void setup_memwrite_rename_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pdc_0_0
// static int test_memwrite_rename_pd0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pe_0_1
static void setup_memwrite_rename_pd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_memwrite_rename_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_rename_pdc_0_proc0
// static void setup_memwrite_rename_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pcc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_rename_pf8_0_0
// static int test_memwrite_rename_pcc_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf8_0_1
static void setup_memwrite_rename_pcc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memwrite_rename_pcc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_rename_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pca_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_rename_pf8_0_0
// static int test_memwrite_rename_pca_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
static void setup_memwrite_rename_pca_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_memwrite_rename_pca_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_rename_pca_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pca_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pda_0_final
// static void setup_memwrite_rename_pca_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pca_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_rename_pf8_0_0
// static int test_memwrite_rename_pca_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
static void setup_memwrite_rename_pca_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_memwrite_rename_pca_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_rename_pcc_0_proc0
// static void setup_memwrite_rename_pca_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pca_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pda_0_final
// static void setup_memwrite_rename_pca_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pca_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_rename_pf8_0_0
// static int test_memwrite_rename_pca_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
static void setup_memwrite_rename_pca_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_memwrite_rename_pca_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_rename_pcc_0_proc0
// static void setup_memwrite_rename_pca_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pca_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pca_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_rename_pf8_0_0
// static int test_memwrite_rename_pc8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
// static void setup_memwrite_rename_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pcc_0_common
// static void setup_memwrite_rename_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_rename_pcc_0_proc0
// static void setup_memwrite_rename_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_rename_pf8_0_0
// static int test_memwrite_rename_pc0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pe_0_1
static void setup_memwrite_rename_pc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_rename_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_rename_pcc_0_proc0
// static void setup_memwrite_rename_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
static int test_memwrite_rename_pb_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_rename_pb_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf8_0_1
// static void setup_memwrite_rename_pb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf8_0_common
static void setup_memwrite_rename_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_rename_pb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pb_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pb_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pb_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_pb_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf8_0_1
// static void setup_memwrite_rename_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf8_0_common
static void setup_memwrite_rename_pb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_rename_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pb_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pb_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pa8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_pa8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
// static void setup_memwrite_rename_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf4_0_common
static void setup_memwrite_rename_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_rename_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pa8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_pa8_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
// static void setup_memwrite_rename_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf4_0_common
// static void setup_memwrite_rename_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_rename_pb_1_proc0
// static void setup_memwrite_rename_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pa0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_pa0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
// static void setup_memwrite_rename_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf8_0_common
// static void setup_memwrite_rename_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_rename_pb_0_proc0
// static void setup_memwrite_rename_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_pa0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_pa0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
// static void setup_memwrite_rename_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf8_0_common
// static void setup_memwrite_rename_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_rename_pb_1_proc0
// static void setup_memwrite_rename_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_p8_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pe_0_1
// static void setup_memwrite_rename_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_rename_pd0_0_common
// static void setup_memwrite_rename_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_rename_pb_0_proc0
// static void setup_memwrite_rename_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_p8_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pe_0_1
// static void setup_memwrite_rename_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pe_0_common
// static void setup_memwrite_rename_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_rename_pb_1_proc0
// static void setup_memwrite_rename_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal
// static void setup_memwrite_rename_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_p6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_p6_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf8_0_1
// static void setup_memwrite_rename_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf8_0_common
// static void setup_memwrite_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_p50_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_p50_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
// static void setup_memwrite_rename_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf4_0_common
// static void setup_memwrite_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_p4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pf4_0_1
// static void setup_memwrite_rename_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_rename_pf8_0_common
// static void setup_memwrite_rename_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_rename_pf8_0_final
// static void setup_memwrite_rename_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal

/*
 * calls: memwrite rename
 */
// static int test_memwrite_rename_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_rename_pb_0_0
// static int test_memwrite_rename_p0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_rename_pe_0_1
// static void setup_memwrite_rename_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pe_0_common
// static void setup_memwrite_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_rename_pf8_0_proc1
// static void setup_memwrite_rename_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal
// static void setup_memwrite_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_rename_pf8_0_procfinal


/*
 * calls: memwrite stat
 */
static int test_memwrite_stat_pf_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_stat_pf_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_memwrite_stat_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memwrite_stat_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_stat_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_stat_pf_0_final(void) {
  unlink("__i0");
}
static void setup_memwrite_stat_pf_0_procfinal(void) {
  
}

/*
 * calls: memwrite stat
 */
// static int test_memwrite_stat_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_stat_pf_0_0
static int test_memwrite_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_memwrite_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_memwrite_stat_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_stat_pf_0_proc0
// static void setup_memwrite_stat_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_pe_0_final(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal
// static void setup_memwrite_stat_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal

/*
 * calls: memwrite stat
 */
static int test_memwrite_stat_pd8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_stat_pd8_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memwrite_stat_pf_0_1
// static void setup_memwrite_stat_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_stat_pf_0_common
static void setup_memwrite_stat_pd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x26000);
}
// static void setup_memwrite_stat_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_stat_pf_0_final
// static void setup_memwrite_stat_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal

/*
 * calls: memwrite stat
 */
// static int test_memwrite_stat_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_stat_pd8_0_0
// static int test_memwrite_stat_pd0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memwrite_stat_pe_0_1
static void setup_memwrite_stat_pd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_memwrite_stat_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x26000);
// }
// ^ See setup_memwrite_stat_pd8_0_proc0
// static void setup_memwrite_stat_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_stat_pf_0_final
// static void setup_memwrite_stat_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal

/*
 * calls: memwrite stat
 */
// static int test_memwrite_stat_pc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_stat_pf_0_0
static int test_memwrite_stat_pc8_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_memwrite_stat_pc8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memwrite_stat_pc8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_stat_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_pc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_stat_pf_0_final
// static void setup_memwrite_stat_pc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal

/*
 * calls: memwrite stat
 */
// static int test_memwrite_stat_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_stat_pf_0_0
// static int test_memwrite_stat_pc0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memwrite_stat_pe_0_1
static void setup_memwrite_stat_pc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_stat_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_stat_pc8_0_proc0
// static void setup_memwrite_stat_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_stat_pf_0_final
// static void setup_memwrite_stat_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal

/*
 * calls: memwrite stat
 */
static int test_memwrite_stat_pa_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_stat_pa_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memwrite_stat_pf_0_1
// static void setup_memwrite_stat_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_stat_pf_0_common
static void setup_memwrite_stat_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_stat_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_stat_pf_0_final
// static void setup_memwrite_stat_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal

/*
 * calls: memwrite stat
 */
// static int test_memwrite_stat_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_stat_pa_0_0
// static int test_memwrite_stat_pa_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memwrite_stat_pf_0_1
// static void setup_memwrite_stat_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_stat_pf_0_common
static void setup_memwrite_stat_pa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_stat_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_stat_pf_0_final
// static void setup_memwrite_stat_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal

/*
 * calls: memwrite stat
 */
// static int test_memwrite_stat_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_stat_pa_0_0
// static int test_memwrite_stat_p8_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memwrite_stat_pe_0_1
// static void setup_memwrite_stat_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_stat_pd0_0_common
// static void setup_memwrite_stat_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_stat_pa_0_proc0
// static void setup_memwrite_stat_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_stat_pf_0_final
// static void setup_memwrite_stat_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal

/*
 * calls: memwrite stat
 */
// static int test_memwrite_stat_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_stat_pa_0_0
// static int test_memwrite_stat_p8_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memwrite_stat_pe_0_1
// static void setup_memwrite_stat_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pe_0_common
// static void setup_memwrite_stat_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_stat_pa_1_proc0
// static void setup_memwrite_stat_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal
// static void setup_memwrite_stat_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal

/*
 * calls: memwrite stat
 */
// static int test_memwrite_stat_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_stat_pa_0_0
// static int test_memwrite_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memwrite_stat_pf_0_1
// static void setup_memwrite_stat_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_stat_pf_0_common
// static void setup_memwrite_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_stat_pf_0_final
// static void setup_memwrite_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal

/*
 * calls: memwrite stat
 */
// static int test_memwrite_stat_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_stat_pa_0_0
// static int test_memwrite_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_memwrite_stat_pe_0_1
// static void setup_memwrite_stat_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pe_0_common
// static void setup_memwrite_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_stat_pf_0_proc1
// static void setup_memwrite_stat_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal
// static void setup_memwrite_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_stat_pf_0_procfinal


/*
 * calls: memwrite unlink
 */
static int test_memwrite_unlink_pf0_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_unlink_pf0_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_memwrite_unlink_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memwrite_unlink_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_unlink_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_unlink_pf0_0_final(void) {
  unlink("__i0");
}
static void setup_memwrite_unlink_pf0_0_procfinal(void) {
  
}

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_pe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_unlink_pf0_0_0
static int test_memwrite_unlink_pe_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_memwrite_unlink_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_memwrite_unlink_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_unlink_pf0_0_proc0
// static void setup_memwrite_unlink_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_pe_0_final(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal
// static void setup_memwrite_unlink_pe_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
static int test_memwrite_unlink_pd8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_unlink_pd8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pf0_0_1
static void setup_memwrite_unlink_pd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_memwrite_unlink_pd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_unlink_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
static void setup_memwrite_unlink_pd8_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memwrite_unlink_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_pd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_unlink_pd8_0_0
// static int test_memwrite_unlink_pd8_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pf0_0_1
// static void setup_memwrite_unlink_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_unlink_pf0_0_common
static void setup_memwrite_unlink_pd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_unlink_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_pd8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_unlink_pf0_0_final
// static void setup_memwrite_unlink_pd8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_unlink_pd8_0_0
// static int test_memwrite_unlink_pd0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pe_0_1
static void setup_memwrite_unlink_pd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_memwrite_unlink_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_unlink_pd8_1_proc0
// static void setup_memwrite_unlink_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_unlink_pf0_0_final
// static void setup_memwrite_unlink_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_pc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_unlink_pf0_0_0
// static int test_memwrite_unlink_pc8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pf0_0_1
static void setup_memwrite_unlink_pc8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memwrite_unlink_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memwrite_unlink_pd8_0_proc0
// static void setup_memwrite_unlink_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_pc8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_unlink_pd8_0_final
// static void setup_memwrite_unlink_pc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_pc8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_unlink_pf0_0_0
// static int test_memwrite_unlink_pc8_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pf0_0_1
static void setup_memwrite_unlink_pc8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_memwrite_unlink_pc8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_unlink_pd8_1_proc0
// static void setup_memwrite_unlink_pc8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_pc8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_unlink_pf0_0_final
// static void setup_memwrite_unlink_pc8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_unlink_pf0_0_0
// static int test_memwrite_unlink_pc0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pe_0_1
static void setup_memwrite_unlink_pc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_unlink_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_unlink_pd8_1_proc0
// static void setup_memwrite_unlink_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_unlink_pf0_0_final
// static void setup_memwrite_unlink_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
static int test_memwrite_unlink_pa_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_unlink_pa_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pf0_0_1
// static void setup_memwrite_unlink_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_unlink_pf0_0_common
static void setup_memwrite_unlink_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_unlink_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_unlink_pf0_0_final
// static void setup_memwrite_unlink_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_unlink_pa_0_0
// static int test_memwrite_unlink_pa_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pf0_0_1
// static void setup_memwrite_unlink_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_unlink_pf0_0_common
static void setup_memwrite_unlink_pa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_unlink_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_unlink_pf0_0_final
// static void setup_memwrite_unlink_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_unlink_pa_0_0
// static int test_memwrite_unlink_p8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pe_0_1
// static void setup_memwrite_unlink_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_unlink_pd0_0_common
static void setup_memwrite_unlink_p8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_unlink_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_unlink_pf0_0_final
// static void setup_memwrite_unlink_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_unlink_pa_0_0
// static int test_memwrite_unlink_p8_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pe_0_1
// static void setup_memwrite_unlink_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pe_0_common
// static void setup_memwrite_unlink_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_unlink_pa_1_proc0
// static void setup_memwrite_unlink_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal
// static void setup_memwrite_unlink_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_unlink_pa_0_0
// static int test_memwrite_unlink_p4_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pf0_0_1
// static void setup_memwrite_unlink_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_memwrite_unlink_pf0_0_common
// static void setup_memwrite_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_unlink_pf0_0_final
// static void setup_memwrite_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal

/*
 * calls: memwrite unlink
 */
// static int test_memwrite_unlink_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_unlink_pa_0_0
// static int test_memwrite_unlink_p0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_memwrite_unlink_pe_0_1
// static void setup_memwrite_unlink_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pe_0_common
// static void setup_memwrite_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_unlink_pf0_0_proc1
// static void setup_memwrite_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal
// static void setup_memwrite_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_unlink_pf0_0_procfinal


/*
 * calls: memwrite write
 */
static int test_memwrite_write_pff_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 0);
  expect_result("r", r, 0);
  return r;
}
static int test_memwrite_write_pff_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_memwrite_write_pff_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_write_pff_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_write_pff_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_memwrite_write_pff_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_memwrite_write_pff_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pfe_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
static int test_memwrite_write_pfe_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_memwrite_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_write_pfe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pfe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pfc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
static int test_memwrite_write_pfc_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_memwrite_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_write_pfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pfa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pfa_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
static void setup_memwrite_write_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_memwrite_write_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_write_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_memwrite_write_pfa_0_final(void) {
  unlink("__i0");
}
static void setup_memwrite_write_pfa_0_procfinal(void) {
  
}

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pf8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
static void setup_memwrite_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_write_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_write_pfa_0_proc0
// static void setup_memwrite_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
static void setup_memwrite_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_memwrite_write_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_memwrite_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pf0_0_final(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal
// static void setup_memwrite_write_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pef_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pef_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
// static void setup_memwrite_write_pef_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pff_0_common
static void setup_memwrite_write_pef_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_write_pef_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_write_pef_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pef_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pee_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pee_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pee_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfe_0_common
static void setup_memwrite_write_pee_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
static void setup_memwrite_write_pee_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_write_pee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pec_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pec_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfc_0_common
// static void setup_memwrite_write_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_write_pee_0_proc0
static void setup_memwrite_write_pec_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_memwrite_write_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pea_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pea_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
// static void setup_memwrite_write_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_write_pf0_0_proc0
static void setup_memwrite_write_pea_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_write_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pea_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pe8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pe8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_write_pf0_0_proc0
// static void setup_memwrite_write_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pe0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pe0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_write_pf0_0_common
// static void setup_memwrite_write_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_memwrite_write_pf0_0_proc0
// static void setup_memwrite_write_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pe0_0_final(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal
// static void setup_memwrite_write_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
static int test_memwrite_write_pdf8_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 7);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_write_pdf8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
static void setup_memwrite_write_pdf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_memwrite_write_pdf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_write_pdf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pff_0_proc1
// static void setup_memwrite_write_pdf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pdf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pdf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pdf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pdf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pdf8_0_common
static void setup_memwrite_write_pdf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_write_pdf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_pdf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pdf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pde_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pde_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pdf8_0_common
static void setup_memwrite_write_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_write_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pdd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pdd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
static void setup_memwrite_write_pdd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_write_pdd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_write_pdd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
static void setup_memwrite_write_pdd8_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_memwrite_write_pdd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pdd8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pdd8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pdd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
static void setup_memwrite_write_pdd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_write_pdd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pdd8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pdd8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pdc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pdc0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
static void setup_memwrite_write_pdc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_write_pdc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_memwrite_write_pdc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pdc0_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pdd8_0_final
// static void setup_memwrite_write_pdc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pdc0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pdc0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
static void setup_memwrite_write_pdc0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_write_pdc0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
}
// static void setup_memwrite_write_pdc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pdc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pdc0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pd8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
static void setup_memwrite_write_pd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pd8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pd78_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pd78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
// static void setup_memwrite_write_pd78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pdf8_0_common
static void setup_memwrite_write_pd78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_write_pd78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pef_0_proc1
// static void setup_memwrite_write_pd78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pd78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pd70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pd70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pd70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pdf8_0_common
static void setup_memwrite_write_pd70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_write_pd70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pee_0_proc1
// static void setup_memwrite_write_pd70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pd70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pd6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pd6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pdf8_0_common
// static void setup_memwrite_write_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pd70_0_proc0
// static void setup_memwrite_write_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pec_0_proc1
// static void setup_memwrite_write_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pd58_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pd58_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pd58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pdd8_0_common
static void setup_memwrite_write_pd58_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
static void setup_memwrite_write_pd58_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_write_pd58_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pdd8_0_final
// static void setup_memwrite_write_pd58_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pd58_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pd58_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pd58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
static void setup_memwrite_write_pd58_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_memwrite_write_pd58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_pd58_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pd58_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pd40_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pd40_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pd40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pdc0_0_common
// static void setup_memwrite_write_pd40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_memwrite_write_pd58_0_proc0
static void setup_memwrite_write_pd40_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_write_pd40_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pdd8_0_final
// static void setup_memwrite_write_pd40_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pd40_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pd40_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pd40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pdc0_1_common
static void setup_memwrite_write_pd40_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x8000);
}
static void setup_memwrite_write_pd40_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_write_pd40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pd40_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 7);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pdf8_0_0
// static int test_memwrite_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
// static void setup_memwrite_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pd8_0_proc0
// static void setup_memwrite_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pcf8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pcf8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
static void setup_memwrite_write_pcf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_memwrite_write_pcf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pdf8_0_proc0
// static void setup_memwrite_write_pcf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pff_0_proc1
// static void setup_memwrite_write_pcf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pcf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pcf0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pcf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
static void setup_memwrite_write_pcf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_memwrite_write_pcf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pdf0_0_proc0
// static void setup_memwrite_write_pcf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_pcf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pcf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pce_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pce_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pce_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pcf0_0_common
// static void setup_memwrite_write_pce_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pde_0_proc0
// static void setup_memwrite_write_pce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_pce_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pce_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pcd0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
static int test_memwrite_write_pcd0_0_1(void) {
  ssize_t r = write(10, dataval1, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_memwrite_write_pcd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_write_pcd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x6000);
}
// static void setup_memwrite_write_pcd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pcd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pcd0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pcd0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pcd0_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pcd0_0_1
static void setup_memwrite_write_pcd0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_write_pcd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x4000);
}
// static void setup_memwrite_write_pcd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pcd0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pdd8_0_final
// static void setup_memwrite_write_pcd0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pcc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pcc0_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pcd0_0_1
static void setup_memwrite_write_pcc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_write_pcc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_write_pdd8_1_proc0
// static void setup_memwrite_write_pcc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pcc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pcc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pcc0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pcc0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
static void setup_memwrite_write_pcc0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_memwrite_write_pcc0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_memwrite_write_pcc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pcc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pcc0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pc8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pc8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pd8_0_proc0
// static void setup_memwrite_write_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pc8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pc8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pc78_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pc78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
// static void setup_memwrite_write_pc78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pcf8_0_common
// static void setup_memwrite_write_pc78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pd78_0_proc0
// static void setup_memwrite_write_pc78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pef_0_proc1
// static void setup_memwrite_write_pc78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pc78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pc70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pc70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pc70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pcf0_0_common
// static void setup_memwrite_write_pc70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pd70_0_proc0
// static void setup_memwrite_write_pc70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pee_0_proc1
// static void setup_memwrite_write_pc70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pc70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pc6_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pc6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pcf0_0_common
// static void setup_memwrite_write_pc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pd70_0_proc0
// static void setup_memwrite_write_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pec_0_proc1
// static void setup_memwrite_write_pc6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pc6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pc50_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pc50_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pcd0_0_1
static void setup_memwrite_write_pc50_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_memwrite_write_pc50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pd8_0_proc0
// static void setup_memwrite_write_pc50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pd58_0_proc1
// static void setup_memwrite_write_pc50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pc50_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pc50_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pc50_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pcd0_0_1
// static void setup_memwrite_write_pc50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pcd0_1_common
static void setup_memwrite_write_pc50_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i1", 0x4000);
}
static void setup_memwrite_write_pc50_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_memwrite_write_pc50_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pdd8_0_final
// static void setup_memwrite_write_pc50_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pc40_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pc40_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pcd0_0_1
// static void setup_memwrite_write_pc40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pcc0_0_common
// static void setup_memwrite_write_pc40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1000);
// }
// ^ See setup_memwrite_write_pd58_1_proc0
// static void setup_memwrite_write_pc40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_pc40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pc40_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pc40_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pc40_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pc40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pcc0_1_common
// static void setup_memwrite_write_pc40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pd8_0_proc0
// static void setup_memwrite_write_pc40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_pc40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pc40_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pc0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 0);
//   expect_result("r", r, 0);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_0
// static int test_memwrite_write_pc0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pd8_0_proc0
// static void setup_memwrite_write_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
static int test_memwrite_write_pbe_0_0(void) {
  char* p = (char*) 0x12345600000UL;
  int signal, r = 0;
  pf_active = 1;
  if ((signal = sigsetjmp(pf_jmpbuf, 1)))
    r = -1;
  else
    *p = 0;
  pf_active = 0;
  expect_result("signal", signal, 11);
  expect_result("r", r, -1);
  return r;
}
// static int test_memwrite_write_pbe_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
// static void setup_memwrite_write_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pff_0_common
static void setup_memwrite_write_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_write_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pff_0_proc1
// static void setup_memwrite_write_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pbe_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pbe_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
// static void setup_memwrite_write_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pff_0_common
static void setup_memwrite_write_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_write_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pff_0_proc1
// static void setup_memwrite_write_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pbc_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pbc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfe_0_common
static void setup_memwrite_write_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pbc_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pbc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfe_0_common
static void setup_memwrite_write_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_write_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pb8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pb8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfc_0_common
static void setup_memwrite_write_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pb8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pb8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfc_0_common
static void setup_memwrite_write_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_write_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pb4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pb4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
static void setup_memwrite_write_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_memwrite_write_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pb4_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pb4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
static void setup_memwrite_write_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_write_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pb4_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pb4_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
static void setup_memwrite_write_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_write_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pb0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2297000);
// }
// ^ See setup_memwrite_write_pb4_0_proc0
// static void setup_memwrite_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pb0_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pb0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pb4_1_proc0
// static void setup_memwrite_write_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pb0_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pb0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_write_pb4_2_proc0
// static void setup_memwrite_write_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pa_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pa_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
static void setup_memwrite_write_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_write_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_pa_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_pa_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_pa_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_write_pf0_0_common
static void setup_memwrite_write_pa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_write_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_pa_1_final(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal
// static void setup_memwrite_write_pa_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p9e_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p9e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
// static void setup_memwrite_write_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pff_0_common
static void setup_memwrite_write_p9e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_write_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pef_0_proc1
// static void setup_memwrite_write_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p9e_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p9e_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
// static void setup_memwrite_write_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pff_0_common
static void setup_memwrite_write_p9e_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_write_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pef_0_proc1
// static void setup_memwrite_write_p9e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p9e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p9c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p9c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfe_0_common
static void setup_memwrite_write_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_memwrite_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pee_0_proc1
// static void setup_memwrite_write_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p9c_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p9c_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfe_0_common
static void setup_memwrite_write_p9c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_memwrite_write_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pee_0_proc1
// static void setup_memwrite_write_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p98_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p98_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfc_0_common
static void setup_memwrite_write_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_memwrite_write_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pec_0_proc1
// static void setup_memwrite_write_p98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p98_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p98_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfc_0_common
// static void setup_memwrite_write_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_write_p9c_1_proc0
// static void setup_memwrite_write_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pec_0_proc1
// static void setup_memwrite_write_p98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p94_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p94_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
static void setup_memwrite_write_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_memwrite_write_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p94_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p94_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p94_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
// static void setup_memwrite_write_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pa_0_proc0
// static void setup_memwrite_write_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_p94_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p94_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p94_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p94_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
// static void setup_memwrite_write_p94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_write_pa_1_proc0
// static void setup_memwrite_write_p94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_p94_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p94_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p90_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p90_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2297000);
// }
// ^ See setup_memwrite_write_p94_0_proc0
// static void setup_memwrite_write_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p90_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p90_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p90_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pa_0_proc0
// static void setup_memwrite_write_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p90_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p90_2_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p90_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_p90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_write_pa_1_proc0
// static void setup_memwrite_write_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_p90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p90_2_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p8_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
// static void setup_memwrite_write_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_memwrite_write_pa_0_proc0
// static void setup_memwrite_write_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p8_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p8_1_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_write_pf0_0_common
// static void setup_memwrite_write_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_memwrite_write_pa_1_proc0
// static void setup_memwrite_write_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_p8_1_final(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal
// static void setup_memwrite_write_p8_1_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p7c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p7c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
// static void setup_memwrite_write_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pff_0_common
// static void setup_memwrite_write_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pef_0_proc1
// static void setup_memwrite_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pff_0_proc1
// static void setup_memwrite_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p78_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfe_0_common
// static void setup_memwrite_write_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pee_0_proc1
// static void setup_memwrite_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p70_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfc_0_common
// static void setup_memwrite_write_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pec_0_proc1
// static void setup_memwrite_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p68_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p68_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
// static void setup_memwrite_write_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p60_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p60_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p4_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_write_pf0_0_common
// static void setup_memwrite_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_p4_0_final(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal
// static void setup_memwrite_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p3c_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pff_0_1
// static void setup_memwrite_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pff_0_common
// static void setup_memwrite_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pff_0_proc1
// static void setup_memwrite_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pef_0_proc1
// static void setup_memwrite_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p38_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfe_0_common
// static void setup_memwrite_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pee_0_proc1
// static void setup_memwrite_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p30_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_memwrite_write_pfc_0_common
// static void setup_memwrite_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pfe_0_proc1
// static void setup_memwrite_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_memwrite_write_pec_0_proc1
// static void setup_memwrite_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_final
// static void setup_memwrite_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_memwrite_write_pff_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p28_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_memwrite_write_pfa_0_common
// static void setup_memwrite_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p20_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfe_0_1
// static void setup_memwrite_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_memwrite_write_pf8_0_common
// static void setup_memwrite_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_memwrite_write_pea_0_proc1
// static void setup_memwrite_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_memwrite_write_pfa_0_final
// static void setup_memwrite_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal

/*
 * calls: memwrite write
 */
// static int test_memwrite_write_p0_0_0(void) {
//   char* p = (char*) 0x12345600000UL;
//   int signal, r = 0;
//   pf_active = 1;
//   if ((signal = sigsetjmp(pf_jmpbuf, 1)))
//     r = -1;
//   else
//     *p = 0;
//   pf_active = 0;
//   expect_result("signal", signal, 11);
//   expect_result("r", r, -1);
//   return r;
// }
// ^ See test_memwrite_write_pbe_0_0
// static int test_memwrite_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_memwrite_write_pfc_0_1
// static void setup_memwrite_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_memwrite_write_pf0_0_common
// static void setup_memwrite_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_memwrite_write_pfa_0_proc1
// static void setup_memwrite_write_p0_0_final(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal
// static void setup_memwrite_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_memwrite_write_pfa_0_procfinal


/*
 * calls: mmap mmap
 */
static int test_mmap_mmap_pf8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_mmap_pf8_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
static void setup_mmap_mmap_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mmap_mmap_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_mmap_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_mmap_pf8_0_final(void) {
  
}
static void setup_mmap_mmap_pf8_0_procfinal(void) {
  
}

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
static int test_mmap_mmap_pf8_2_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_mmap_pf8_2_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_mmap_mmap_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_2_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_3_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
static void setup_mmap_mmap_pf8_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mmap_mmap_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
static void setup_mmap_mmap_pf8_4_final(void) {
  unlink("__i0");
}
// static void setup_mmap_mmap_pf8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pf8_6_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_mmap_mmap_pf8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_6_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_5_proc0
// static void setup_mmap_mmap_pf8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_4_proc0
// static void setup_mmap_mmap_pf8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pf8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_pf8_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_4_proc0
// static void setup_mmap_mmap_pf8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_pf8_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_pf8_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_4_proc0
// static void setup_mmap_mmap_pf8_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_pf8_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_16_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_pf8_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_pf8_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
static void setup_mmap_mmap_pf8_17_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf8_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_17_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_17_proc0
// static void setup_mmap_mmap_pf8_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_18_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
static void setup_mmap_mmap_pf8_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf8_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_19_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_20_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf8_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_20_proc0
// static void setup_mmap_mmap_pf8_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_22_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
static void setup_mmap_mmap_pf8_23_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf8_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_23_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_22_proc0
// static void setup_mmap_mmap_pf8_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_25_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_23_proc0
// static void setup_mmap_mmap_pf8_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_25_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_25_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_26_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_26_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_26_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_27_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_27_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_27_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_28_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_28_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf8_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_28_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_29_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_27_proc0
// static void setup_mmap_mmap_pf8_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_29_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_29_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_30_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_28_proc0
// static void setup_mmap_mmap_pf8_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_31_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
static void setup_mmap_mmap_pf8_31_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pf8_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_31_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_31_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_32_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_32_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_32_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_32_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_33_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
static void setup_mmap_mmap_pf8_33_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pf8_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_33_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_33_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_34_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_34_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_19_proc0
// static void setup_mmap_mmap_pf8_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_34_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_34_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_35_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_35_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_35_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_36_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_26_proc0
// static void setup_mmap_mmap_pf8_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_37_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_37_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_38_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_38_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_39_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_39_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_40_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_40_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_40_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf8_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_40_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_40_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_41_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_41_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
static void setup_mmap_mmap_pf8_41_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf8_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_41_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_41_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_42_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_42_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
static void setup_mmap_mmap_pf8_42_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf8_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_42_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_42_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_43_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_43_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_43_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf8_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_43_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_43_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_44_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_44_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
static void setup_mmap_mmap_pf8_44_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf8_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_44_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_44_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_45_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_45_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf8_45_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf8_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_45_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_45_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_46_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_46_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pf8_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_46_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_pf8_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_46_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_46_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_47_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_47_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pf8_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_pf8_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_47_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_47_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_48_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_48_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pf8_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_48_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_pf8_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_48_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_48_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_49_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_49_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_49_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_pf8_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_49_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_49_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_50_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_50_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_50_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_pf8_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_50_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_50_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_51_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_51_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_51_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_pf8_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_51_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_51_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_52_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_52_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_52_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_35_proc0
// static void setup_mmap_mmap_pf8_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_52_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_52_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_53_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_53_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_53_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_37_proc0
// static void setup_mmap_mmap_pf8_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_53_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_53_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_54_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_54_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_54_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_38_proc0
// static void setup_mmap_mmap_pf8_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_54_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_54_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_55_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_55_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_55_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_19_proc0
// static void setup_mmap_mmap_pf8_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_55_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_55_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_56_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_56_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_42_proc0
// static void setup_mmap_mmap_pf8_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_56_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_56_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_57_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_57_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_57_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_43_proc0
// static void setup_mmap_mmap_pf8_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_57_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_57_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_58_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_58_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_39_proc0
// static void setup_mmap_mmap_pf8_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_58_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_58_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_59_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_59_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_59_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_40_proc0
// static void setup_mmap_mmap_pf8_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_59_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_59_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_60_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_60_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_60_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_60_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_41_proc0
// static void setup_mmap_mmap_pf8_60_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_60_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_60_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_61_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_61_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_61_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_61_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_44_proc0
// static void setup_mmap_mmap_pf8_61_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_61_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_61_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_62_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_62_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_1
// static void setup_mmap_mmap_pf8_62_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_62_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_45_proc0
// static void setup_mmap_mmap_pf8_62_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_62_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_62_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_63_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_63_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_63_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_63_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_pf8_63_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_63_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_63_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_64_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_64_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_64_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_64_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_pf8_64_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_64_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_64_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_65_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_65_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_65_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_65_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_pf8_65_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_65_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_65_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_66_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_66_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_66_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_66_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_26_proc0
// static void setup_mmap_mmap_pf8_66_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_66_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_66_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_67_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_67_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_67_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_67_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_37_proc0
// static void setup_mmap_mmap_pf8_67_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_67_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_67_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_68_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_68_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_68_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_68_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_45_proc0
// static void setup_mmap_mmap_pf8_68_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_68_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_68_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_69_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_69_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_69_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_69_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_43_proc0
// static void setup_mmap_mmap_pf8_69_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_69_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_69_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_70_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_70_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_70_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_70_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_35_proc0
// static void setup_mmap_mmap_pf8_70_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_70_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_70_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_71_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_71_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_71_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_71_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_41_proc0
// static void setup_mmap_mmap_pf8_71_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_71_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_71_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_72_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_72_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_72_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_72_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_44_proc0
// static void setup_mmap_mmap_pf8_72_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_72_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_72_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_73_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_73_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_73_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_73_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_39_proc0
// static void setup_mmap_mmap_pf8_73_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_73_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_73_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_74_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_74_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_74_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_74_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_40_proc0
// static void setup_mmap_mmap_pf8_74_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_74_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_74_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_75_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_75_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_75_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_75_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_42_proc0
// static void setup_mmap_mmap_pf8_75_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_75_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_75_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_76_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf8_76_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_76_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_76_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_38_proc0
// static void setup_mmap_mmap_pf8_76_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_76_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_76_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_77_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_77_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_77_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_77_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_pf8_77_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_77_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_77_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_78_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_78_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_78_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_78_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_pf8_78_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_78_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_78_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_79_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_79_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_79_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_79_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_pf8_79_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_79_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_79_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_80_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_80_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_80_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_80_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_26_proc0
// static void setup_mmap_mmap_pf8_80_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_80_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_80_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_81_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_81_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_81_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_81_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_37_proc0
// static void setup_mmap_mmap_pf8_81_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_81_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_81_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_82_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_82_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_82_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_82_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_42_proc0
// static void setup_mmap_mmap_pf8_82_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_82_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_82_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_83_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_83_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_83_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_83_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_43_proc0
// static void setup_mmap_mmap_pf8_83_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_83_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_83_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_84_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_84_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_84_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_84_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_45_proc0
// static void setup_mmap_mmap_pf8_84_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_84_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_84_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_85_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_85_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_85_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_85_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_19_proc0
// static void setup_mmap_mmap_pf8_85_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_85_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_85_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_86_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_86_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_86_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_86_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_35_proc0
// static void setup_mmap_mmap_pf8_86_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_86_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_86_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_87_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_87_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_87_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_87_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_44_proc0
// static void setup_mmap_mmap_pf8_87_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_87_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_87_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_88_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_88_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_88_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_88_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_39_proc0
// static void setup_mmap_mmap_pf8_88_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_88_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_88_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_89_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_89_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_89_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_89_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_40_proc0
// static void setup_mmap_mmap_pf8_89_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_89_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_89_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_90_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_90_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_90_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_90_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_38_proc0
// static void setup_mmap_mmap_pf8_90_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_90_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_90_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_91_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_91_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_6_1
// static void setup_mmap_mmap_pf8_91_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_91_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_41_proc0
// static void setup_mmap_mmap_pf8_91_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_91_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_91_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_92_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_92_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_pf8_92_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_92_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_pf8_92_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_92_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_92_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_93_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_93_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_pf8_93_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pf8_93_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_pf8_93_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_93_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf8_93_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf8_94_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pf8_94_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_pf8_94_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf8_94_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_pf8_94_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf8_94_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf8_94_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pf6_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
static void setup_mmap_mmap_pf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_mmap_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_mmap_pf6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_mmap_pf6_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_mmap_pf6_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pf6_1_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_mmap_mmap_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pf6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf6_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf6_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_pf6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pf6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pf6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf6_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf6_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_pf6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pf6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pf6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf6_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf6_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_pf6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pf6_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pf6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf6_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf6_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pf4_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_mmap_mmap_pf4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_mmap_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
static void setup_mmap_mmap_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_mmap_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_mmap_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
static void setup_mmap_mmap_pf4_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_mmap_pf4_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pf4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf4_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_14_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_14_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf4_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_16_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf4_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_17_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_18_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_18_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_20_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_21_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_22_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_23_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_23_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_23_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_24_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_24_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_24_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_25_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_25_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_25_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_25_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_26_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_26_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_26_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_27_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_27_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_27_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_28_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_28_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_28_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_28_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_29_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_29_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pf4_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_29_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_29_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_30_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_30_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_31_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_31_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_31_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_31_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_32_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_32_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_32_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_32_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_33_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_33_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_33_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_33_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_34_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_34_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_34_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_34_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_35_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_35_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_35_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_36_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_36_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_37_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_37_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_38_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_38_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_39_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_39_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_40_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_40_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_40_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_40_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_40_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_41_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_41_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_41_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_41_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_41_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_42_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_42_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_42_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_42_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_42_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_43_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_43_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_43_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_43_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_43_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_44_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_44_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_44_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_44_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_44_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_45_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_45_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_45_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_45_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_45_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_46_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_46_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_46_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pf4_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_46_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_46_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_47_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_47_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_47_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pf4_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_47_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_47_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_48_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_48_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf4_48_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pf4_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_48_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_48_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_49_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_49_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_49_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pf4_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_49_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_49_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_50_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_50_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_50_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pf4_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_50_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_50_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_51_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_51_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_51_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pf4_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_51_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_51_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_52_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_52_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_52_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_52_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_52_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_53_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_53_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_53_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_53_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_53_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_54_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_54_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_54_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_54_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_54_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_55_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_55_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_55_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_55_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_55_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_56_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_56_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_56_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_56_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_56_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_57_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_57_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_57_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_57_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_57_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_58_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_58_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_58_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_58_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_58_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_59_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_59_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_59_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_59_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_59_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_60_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_60_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_60_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_60_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_60_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_60_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_60_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_61_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_61_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_61_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_61_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_61_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_61_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_61_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_62_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_62_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_62_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_62_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_62_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_62_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_62_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_63_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_63_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_63_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_63_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_63_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_63_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_63_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_64_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_64_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_64_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_64_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_64_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_64_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_64_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_65_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_65_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_65_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_65_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_65_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_65_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_65_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_66_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_66_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_66_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_66_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_66_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_66_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_66_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_67_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_67_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_67_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_67_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_67_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_67_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_67_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_68_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_68_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_68_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_68_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_68_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_68_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_68_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_69_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_69_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_69_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_69_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_69_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_69_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_69_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_70_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_70_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_70_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_70_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pf4_70_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_70_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_70_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_71_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_71_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_71_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_71_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_71_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_71_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_71_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_72_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_72_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_72_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_72_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_72_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_72_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_72_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_73_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_73_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_73_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pf4_73_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pf4_73_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pf4_73_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pf4_73_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf4_74_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pf4_74_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pf4_74_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pf4_74_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pf4_74_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf4_74_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf4_74_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pf0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_mmap_mmap_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf0_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pf0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pf0_1_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_mmap_mmap_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_mmap_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pec_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_mmap_mmap_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pec_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pec_2_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_mmap_mmap_pec_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_2_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pec_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pec_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_3_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pec_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pec_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pec_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_pec_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pec_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pec_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pec_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_pec_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_5_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pec_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pec_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pec_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_pec_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pec_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pec_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pec_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_pec_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_7_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pec_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pec_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pec_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_pec_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pec_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pec_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pec_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_pec_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_9_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pec_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pec_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pec_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_pec_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pec_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pec_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pec_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_pec_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_11_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pec_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pec_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pec_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_pec_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pec_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pec_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pec_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_pec_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_13_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pec_14_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pec_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pec_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_pec_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pec_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pec_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pec_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_pec_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_15_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pec_16_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pec_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pec_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_pec_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pec_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pec_17_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pec_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_pec_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_17_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pec_18_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pec_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pec_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_pec_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pec_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pec_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static int test_mmap_mmap_pec_19_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pec_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pec_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_pec_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pec_19_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pec_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pe6_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_mmap_mmap_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pe6_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static void setup_mmap_mmap_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_1_proc0
// static void setup_mmap_mmap_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe6_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe6_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_pe6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pe6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_pe6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe6_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe6_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_pe6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pe6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_3_proc0
// static void setup_mmap_mmap_pe6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe6_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe6_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_pe6_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pe6_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_4_proc0
// static void setup_mmap_mmap_pe6_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe6_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe6_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pe50_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_mmap_mmap_pe50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pe50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_pe50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_pe50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pe50_2_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_mmap_mmap_pe50_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_pe50_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_3_proc0
// static void setup_mmap_mmap_pe50_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_3_proc0
// static void setup_mmap_mmap_pe50_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_pe50_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pe50_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_11_proc0
// static void setup_mmap_mmap_pe50_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_mmap_pe50_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_pe50_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pe50_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_11_proc0
// static void setup_mmap_mmap_pe50_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_47_proc0
// static void setup_mmap_mmap_pe50_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_13_proc0
// static void setup_mmap_mmap_pe50_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_14_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_49_proc0
// static void setup_mmap_mmap_pe50_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pe50_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_16_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_14_proc0
// static void setup_mmap_mmap_pe50_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_16_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_16_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_17_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_17_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pe50_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_18_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_50_proc0
// static void setup_mmap_mmap_pe50_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_18_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_18_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_19_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pe50_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_20_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_51_proc0
// static void setup_mmap_mmap_pe50_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_20_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_20_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_21_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_47_proc0
// static void setup_mmap_mmap_pe50_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_22_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_13_proc0
// static void setup_mmap_mmap_pe50_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_23_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_49_proc0
// static void setup_mmap_mmap_pe50_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_24_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_pe50_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_25_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_14_proc0
// static void setup_mmap_mmap_pe50_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_25_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_25_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_26_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_pe50_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_26_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_27_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_50_proc0
// static void setup_mmap_mmap_pe50_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_27_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_27_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_28_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_28_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_pe50_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_28_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_29_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_51_proc0
// static void setup_mmap_mmap_pe50_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_29_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_29_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_30_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_30_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_mmap_pe50_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_31_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_31_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pe50_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_31_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_31_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_32_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pe50_32_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pe50_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_32_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_32_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_33_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_pe50_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_33_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_33_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_34_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_34_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_pe50_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_34_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_34_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_35_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_pe50_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_35_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_35_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_36_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_36_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pe50_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_37_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_37_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pe50_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_38_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_38_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pe50_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_39_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_39_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pe50_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_40_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_40_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_40_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pe50_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_40_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_40_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_41_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_41_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_41_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pe50_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_41_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_41_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_42_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_42_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_42_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pe50_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_42_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_42_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_43_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_43_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pe50_43_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pe50_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_43_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_43_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_44_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_44_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pe50_44_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pe50_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_44_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_44_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_45_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_45_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_pe50_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_45_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_45_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_46_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_46_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pe50_46_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pe50_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_46_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_46_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_47_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_47_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pe50_47_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pe50_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_47_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_47_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_48_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_48_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_48_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_pe50_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_48_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_48_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_49_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_49_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pe50_49_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pe50_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_49_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_49_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_50_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_50_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pe50_50_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pe50_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_50_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_50_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_51_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_51_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_51_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_pe50_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_51_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_51_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_52_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_52_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pe50_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pe50_52_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pe50_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_52_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_52_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_53_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_53_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_53_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_31_proc0
// static void setup_mmap_mmap_pe50_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_53_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_53_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_54_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_54_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_54_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_36_proc0
// static void setup_mmap_mmap_pe50_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_54_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_54_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_55_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_55_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_55_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_39_proc0
// static void setup_mmap_mmap_pe50_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_55_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_55_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_56_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_56_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_37_proc0
// static void setup_mmap_mmap_pe50_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_56_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_56_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_57_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_57_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_57_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_38_proc0
// static void setup_mmap_mmap_pe50_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_57_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_57_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_58_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_58_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_40_proc0
// static void setup_mmap_mmap_pe50_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_58_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_58_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_59_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_59_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_59_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_pe50_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_59_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_59_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_60_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_60_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_60_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_60_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_42_proc0
// static void setup_mmap_mmap_pe50_60_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_60_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_60_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_61_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_61_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_61_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_61_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_43_proc0
// static void setup_mmap_mmap_pe50_61_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_61_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_61_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_62_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_62_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_62_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_62_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_44_proc0
// static void setup_mmap_mmap_pe50_62_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_62_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_62_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_63_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_63_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_63_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_63_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_47_proc0
// static void setup_mmap_mmap_pe50_63_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_63_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_63_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_64_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_64_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_64_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_64_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_pe50_64_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_64_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_64_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_65_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_65_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_65_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_65_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_49_proc0
// static void setup_mmap_mmap_pe50_65_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_65_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_65_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_66_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_66_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_66_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_66_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_50_proc0
// static void setup_mmap_mmap_pe50_66_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_66_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_66_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_67_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_67_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_67_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_67_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_pe50_67_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_67_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_67_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_68_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_68_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_68_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_68_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_46_proc0
// static void setup_mmap_mmap_pe50_68_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_68_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_68_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_69_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_69_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_69_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pe50_69_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_pe50_69_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe50_69_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe50_69_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe50_70_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pe50_70_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pe50_70_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pe50_70_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_52_proc0
// static void setup_mmap_mmap_pe50_70_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pe50_70_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pe50_70_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pe0_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_mmap_mmap_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe0_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pe0_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_mmap_mmap_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pd8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pd8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pd8_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pd6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pd6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pd6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pd6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
static void setup_mmap_mmap_pd6_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pd6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pd6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pd4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pd4_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_mmap_mmap_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pd0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pd0_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pcc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pcc_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pcc_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pcc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pcc_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pcc_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pcc_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pc6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pc6_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pc6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pc6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pc6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pc6_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_pc6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pc6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pc6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pc6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pc6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pc50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pc50_0_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_mmap_mmap_pc50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pc50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pc50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pc50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pc50_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pc50_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
static int test_mmap_mmap_pc50_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static void setup_mmap_mmap_pc50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pc50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pc50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pc50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pc50_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static int test_mmap_mmap_pc0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pc0_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbe_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbe_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
static int test_mmap_mmap_pbe_1_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_mmap_mmap_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbe_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbe_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pbe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbe_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pbe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbe_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbe_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbe_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_pbe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbe_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pbe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbd8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbd8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_pbd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pbd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbd8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbd8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_pbd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pbd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbd8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbd8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_pbd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbd8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pbd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbd8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbd8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_pbd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pbd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbd8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbd8_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_pbd8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbd8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pbd8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbd8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbd8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbd8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbd8_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_pbd8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbd8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pbd8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbd8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbd8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
static int test_mmap_mmap_pbd0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_mmap_mmap_pbd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pbd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_pbd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbd0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbd0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pbd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pbd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pbd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pbb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pbb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
static int test_mmap_mmap_pbb0_1_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_mmap_mmap_pbb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pbb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
static int test_mmap_mmap_pbb0_2_1(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
  
  return xerrno(r);
}
// static void setup_mmap_mmap_pbb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pbb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pbb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pbb0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pbb0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pbb0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_3_proc0
// static void setup_mmap_mmap_pbb0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_6_proc0
// static void setup_mmap_mmap_pbb0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pbb0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_44_proc0
// static void setup_mmap_mmap_pbb0_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_pbb0_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_44_proc0
// static void setup_mmap_mmap_pbb0_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_12_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_12_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pbb0_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_13_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_13_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_14_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbb0_13_proc0
// static void setup_mmap_mmap_pbb0_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_14_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_14_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pbb0_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_15_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_15_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_16_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_15_proc0
// static void setup_mmap_mmap_pbb0_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_16_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_16_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_17_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_50_proc0
// static void setup_mmap_mmap_pbb0_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_17_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_17_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_18_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pbb0_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_18_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_18_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_19_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pbb0_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_19_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_19_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_20_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_20_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pbb0_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_20_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_20_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_21_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_50_proc0
// static void setup_mmap_mmap_pbb0_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_21_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_21_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_22_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_18_proc0
// static void setup_mmap_mmap_pbb0_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_22_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_22_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_23_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_19_proc0
// static void setup_mmap_mmap_pbb0_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_23_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_23_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_24_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_20_proc0
// static void setup_mmap_mmap_pbb0_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_24_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_24_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_25_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_46_proc0
// static void setup_mmap_mmap_pbb0_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_25_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_25_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_26_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_26_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pbb0_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_26_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_26_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_27_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_52_proc0
// static void setup_mmap_mmap_pbb0_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_27_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_27_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_28_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_28_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pbb0_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_28_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_28_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_29_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_46_proc0
// static void setup_mmap_mmap_pbb0_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_29_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_29_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_30_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_26_proc0
// static void setup_mmap_mmap_pbb0_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_30_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_30_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_31_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_52_proc0
// static void setup_mmap_mmap_pbb0_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_31_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_31_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_32_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_28_proc0
// static void setup_mmap_mmap_pbb0_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_32_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_32_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_33_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_33_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pbb0_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_33_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_33_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_34_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_34_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pbb0_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_34_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_34_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_35_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_35_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pbb0_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_35_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_35_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_36_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_34_proc0
// static void setup_mmap_mmap_pbb0_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_36_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_36_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_37_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_35_proc0
// static void setup_mmap_mmap_pbb0_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_37_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_37_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_38_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_38_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pbb0_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_38_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_38_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_39_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_33_proc0
// static void setup_mmap_mmap_pbb0_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_39_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_39_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_40_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_40_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_40_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_38_proc0
// static void setup_mmap_mmap_pbb0_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_40_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_40_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_41_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_41_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_41_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pbb0_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_41_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_41_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_42_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_42_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_42_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pbb0_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_42_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_42_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_43_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_43_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_43_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pbb0_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_43_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_43_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_44_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_44_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_44_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_1_proc0
// static void setup_mmap_mmap_pbb0_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_44_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_44_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_45_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_45_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_45_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pbb0_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_45_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_45_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_46_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_46_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_46_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pbb0_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_46_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_46_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_47_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_47_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_47_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pbb0_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_47_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_47_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_48_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_48_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pbb0_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_pbb0_48_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pbb0_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_48_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_48_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_49_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_49_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_49_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_0_proc0
// static void setup_mmap_mmap_pbb0_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_49_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_49_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_50_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_50_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_50_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_9_proc0
// static void setup_mmap_mmap_pbb0_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_50_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_50_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_51_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_51_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_51_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_42_proc0
// static void setup_mmap_mmap_pbb0_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_51_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_51_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_52_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_52_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_52_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_41_proc0
// static void setup_mmap_mmap_pbb0_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_52_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_52_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_53_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_53_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_53_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_43_proc0
// static void setup_mmap_mmap_pbb0_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_53_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_53_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_54_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_54_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_54_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_1_proc0
// static void setup_mmap_mmap_pbb0_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_54_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_54_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_55_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_55_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_55_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_45_proc0
// static void setup_mmap_mmap_pbb0_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_55_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_55_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_56_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_56_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_46_proc0
// static void setup_mmap_mmap_pbb0_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_56_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_56_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_57_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_57_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_57_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_47_proc0
// static void setup_mmap_mmap_pbb0_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_57_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_57_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pbb0_58_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pbb0_58_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pbb0_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pbb0_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_48_proc0
// static void setup_mmap_mmap_pbb0_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pbb0_58_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pbb0_58_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb98_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb98_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_pb98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_0_proc0
// static void setup_mmap_mmap_pb98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb98_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb98_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_pb98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_1_proc0
// static void setup_mmap_mmap_pb98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb98_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb98_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_pb98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb98_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_4_proc0
// static void setup_mmap_mmap_pb98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb98_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb98_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb98_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb98_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_pb98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_2_proc0
// static void setup_mmap_mmap_pb98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb98_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb98_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb98_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb98_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_pb98_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb98_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb98_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb98_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb98_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb98_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb98_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_pb98_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb98_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb98_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb98_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb98_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_pb94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_pb94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd0_1_proc0
// static void setup_mmap_mmap_pb94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd0_1_proc0
// static void setup_mmap_mmap_pb94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_11_proc0
// static void setup_mmap_mmap_pb94_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pb94_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pb94_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_11_proc0
// static void setup_mmap_mmap_pb94_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pb94_5_proc0
// static void setup_mmap_mmap_pb94_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_pb94_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_43_proc0
// static void setup_mmap_mmap_pb94_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_pb94_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_43_proc0
// static void setup_mmap_mmap_pb94_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbb0_13_proc0
// static void setup_mmap_mmap_pb94_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_12_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_12_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbb0_13_proc0
// static void setup_mmap_mmap_pb94_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_13_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_13_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_14_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pb94_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pb94_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_14_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_14_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pb94_14_proc0
// static void setup_mmap_mmap_pb94_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_15_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_15_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_16_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_44_proc0
// static void setup_mmap_mmap_pb94_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_16_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_16_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_17_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_50_proc0
// static void setup_mmap_mmap_pb94_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_17_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_17_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_18_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_46_proc0
// static void setup_mmap_mmap_pb94_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_18_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_18_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_19_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_14_proc0
// static void setup_mmap_mmap_pb94_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_19_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_19_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_20_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_49_proc0
// static void setup_mmap_mmap_pb94_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_20_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_20_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_21_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_50_proc0
// static void setup_mmap_mmap_pb94_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_21_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_21_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_22_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_51_proc0
// static void setup_mmap_mmap_pb94_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_22_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_22_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_23_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_52_proc0
// static void setup_mmap_mmap_pb94_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_23_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_23_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_24_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_15_proc0
// static void setup_mmap_mmap_pb94_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_24_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_24_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_25_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pb94_25_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pb94_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_25_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_25_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_26_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pb94_26_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pb94_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_26_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_26_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_27_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_19_proc0
// static void setup_mmap_mmap_pb94_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_27_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_27_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_28_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pb94_28_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pb94_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_28_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_28_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_29_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_33_proc0
// static void setup_mmap_mmap_pb94_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_29_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_29_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_30_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pb94_30_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pb94_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_30_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_30_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_31_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pb94_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_38_proc0
// static void setup_mmap_mmap_pb94_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_31_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_31_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_32_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_44_proc0
// static void setup_mmap_mmap_pb94_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_32_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_32_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_33_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_50_proc0
// static void setup_mmap_mmap_pb94_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_33_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_33_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_34_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_34_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_46_proc0
// static void setup_mmap_mmap_pb94_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_34_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_34_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_35_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_14_proc0
// static void setup_mmap_mmap_pb94_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_35_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_35_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_36_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_49_proc0
// static void setup_mmap_mmap_pb94_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_36_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_36_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_37_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_50_proc0
// static void setup_mmap_mmap_pb94_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_37_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_37_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_38_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_51_proc0
// static void setup_mmap_mmap_pb94_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_38_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_38_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_39_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_52_proc0
// static void setup_mmap_mmap_pb94_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_39_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_39_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_40_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_40_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_40_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_15_proc0
// static void setup_mmap_mmap_pb94_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_40_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_40_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_41_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_41_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_41_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pb94_25_proc0
// static void setup_mmap_mmap_pb94_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_41_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_41_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_42_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_42_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_42_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pb94_26_proc0
// static void setup_mmap_mmap_pb94_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_42_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_42_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_43_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_43_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_43_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_19_proc0
// static void setup_mmap_mmap_pb94_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_43_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_43_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_44_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_44_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_44_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pb94_28_proc0
// static void setup_mmap_mmap_pb94_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_44_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_44_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_45_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_45_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_33_proc0
// static void setup_mmap_mmap_pb94_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_45_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_45_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_46_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_46_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_46_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pb94_30_proc0
// static void setup_mmap_mmap_pb94_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_46_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_46_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb94_47_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb94_47_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pb94_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb94_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_38_proc0
// static void setup_mmap_mmap_pb94_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb94_47_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb94_47_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb8_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb8_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb6_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb58_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb58_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_pb58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb58_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb58_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb58_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb58_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_pb58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb58_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb58_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb58_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb58_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_pb58_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb58_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb58_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb58_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb58_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb58_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb58_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_pb58_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb58_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb58_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb58_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb58_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb50_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pb50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
static void setup_mmap_mmap_pb50_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pb50_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb50_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb50_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb50_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pb50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_pb50_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb50_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb30_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb30_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pb30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb30_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb30_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pb30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb30_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb30_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pb30_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb30_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb30_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb30_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb30_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb30_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb30_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pb30_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb30_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb30_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb30_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb30_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb18_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_pb18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb18_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_pb18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb18_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb18_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_pb18_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb18_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb18_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb18_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb18_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb18_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb18_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_pb18_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb18_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb18_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb18_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb18_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb14_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb14_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pb14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_pb14_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb14_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb14_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb14_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pb14_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb14_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb14_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_pb14_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb14_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb14_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb14_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pb14_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb14_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
static void setup_mmap_mmap_pb14_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pb14_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb14_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb14_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb14_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pb14_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb14_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb14_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_pb14_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb14_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb14_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb14_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pb14_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb14_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb14_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_pb14_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb14_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb14_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb14_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pb14_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb14_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb14_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_pb14_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb14_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb14_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb14_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pb14_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb14_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb14_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_pb14_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb14_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb14_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb14_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pb14_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pb14_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb14_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_pb14_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb14_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static int test_mmap_mmap_pb0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
static int test_mmap_mmap_pae_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_mmap_mmap_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_mmap_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pae_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_6_proc0
// static void setup_mmap_mmap_pae_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pae_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_7_proc0
// static void setup_mmap_mmap_pae_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pae_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_21_proc0
// static void setup_mmap_mmap_pae_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_14_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_14_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pae_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_19_proc0
// static void setup_mmap_mmap_pae_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pae_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_20_proc0
// static void setup_mmap_mmap_pae_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_17_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_18_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_18_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_20_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_21_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_22_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_23_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_pae_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_25_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_25_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_25_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_25_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_26_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_26_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_26_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_26_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_27_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_27_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_27_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_28_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_28_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_28_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_28_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_29_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pae_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_29_proc0
// static void setup_mmap_mmap_pae_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_29_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_29_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_30_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_30_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_31_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pae_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_31_proc0
// static void setup_mmap_mmap_pae_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_31_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_31_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_32_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_32_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pae_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_32_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_32_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_33_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_33_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_33_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_33_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_34_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_34_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pae_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_34_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_34_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_35_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_35_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_35_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_36_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_36_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pae_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_37_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_37_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pae_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_38_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_38_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_39_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_39_proc0
// static void setup_mmap_mmap_pae_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_40_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_40_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_40_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_40_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_40_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_41_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_41_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_41_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_41_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_41_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_42_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_42_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_42_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_42_proc0
// static void setup_mmap_mmap_pae_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_42_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_42_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_43_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_43_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_43_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_43_proc0
// static void setup_mmap_mmap_pae_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_43_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_43_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_44_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_44_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_44_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pae_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_44_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_44_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_45_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_45_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_45_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pae_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_45_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_45_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_46_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_46_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_46_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_46_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_46_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_47_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_47_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_47_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pae_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_47_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_47_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_48_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_48_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_48_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pae_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_48_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_48_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_49_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_49_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_49_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pae_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_49_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_49_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_50_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_50_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_50_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_50_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_50_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_51_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_51_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_51_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_51_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_51_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_52_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_52_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_52_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_52_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_52_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_53_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_53_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_53_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_53_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_53_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_54_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_54_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_54_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pae_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_54_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_54_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_55_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_55_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pae_55_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_55_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_55_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_56_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_56_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_pae_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_56_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_56_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_57_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_57_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_57_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pae_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_57_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_57_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_58_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_58_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_pae_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_58_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_58_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_59_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_59_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_59_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pae_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_59_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_59_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_60_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_60_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_60_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_60_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_60_proc0
// static void setup_mmap_mmap_pae_60_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_60_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_60_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_61_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_61_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_61_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_61_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_61_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_61_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_61_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_62_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_62_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_62_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_62_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_62_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_62_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_62_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_63_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_63_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_63_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_63_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_74_proc0
// static void setup_mmap_mmap_pae_63_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_63_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_63_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_64_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_64_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_64_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_64_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_66_proc0
// static void setup_mmap_mmap_pae_64_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_64_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_64_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_65_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_65_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_65_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_65_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_63_proc0
// static void setup_mmap_mmap_pae_65_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_65_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_65_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_66_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_66_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_66_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_66_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pae_66_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_66_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_66_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_67_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_67_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_67_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_67_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_67_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_67_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_67_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_68_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_68_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_68_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_68_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_68_proc0
// static void setup_mmap_mmap_pae_68_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_68_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_68_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_69_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_69_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_69_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_69_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_69_proc0
// static void setup_mmap_mmap_pae_69_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_69_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_69_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_70_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_70_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_70_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_70_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pae_70_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_70_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_70_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_71_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_71_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_71_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_71_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_71_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_71_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_71_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_72_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_72_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_72_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pae_72_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_62_proc0
// static void setup_mmap_mmap_pae_72_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pae_72_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pae_72_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_73_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_73_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_73_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_73_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pae_73_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_73_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_73_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pae_74_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pae_74_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pae_0_1
// static void setup_mmap_mmap_pae_74_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pae_74_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pae_74_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pae_74_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pae_74_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_pad8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pad8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_pad8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pad8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pad8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_pad8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_pad8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mmap_pad8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pad8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pad8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
static void setup_mmap_mmap_pad0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_mmap_pad0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_mmap_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
static void setup_mmap_mmap_pad0_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_mmap_mmap_pad0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
static int test_mmap_mmap_pad0_1_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_mmap_mmap_pad0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_pad0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
static int test_mmap_mmap_pad0_2_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_mmap_pad0_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_pad0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_pad0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
  init_map_file(0x12345601000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_mmap_pad0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_5_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_5_proc0
// static void setup_mmap_mmap_pad0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_6_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_7_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_8_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_7_proc0
// static void setup_mmap_mmap_pad0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_9_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_8_proc0
// static void setup_mmap_mmap_pad0_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_10_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_11_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_12_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
  init_map_file(0x12345601000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_13_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_4_proc0
// static void setup_mmap_mmap_pad0_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_14_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_11_proc0
// static void setup_mmap_mmap_pad0_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_15_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_12_proc0
// static void setup_mmap_mmap_pad0_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_16_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_13_proc0
// static void setup_mmap_mmap_pad0_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_17_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_5_proc0
// static void setup_mmap_mmap_pad0_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_18_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_4_proc0
// static void setup_mmap_mmap_pad0_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_19_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_11_proc0
// static void setup_mmap_mmap_pad0_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_20_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_12_proc0
// static void setup_mmap_mmap_pad0_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_21_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_5_proc0
// static void setup_mmap_mmap_pad0_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_22_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_11_proc0
// static void setup_mmap_mmap_pad0_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_23_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_12_proc0
// static void setup_mmap_mmap_pad0_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_24_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_25_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_7_proc0
// static void setup_mmap_mmap_pad0_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_25_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_25_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_26_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_8_proc0
// static void setup_mmap_mmap_pad0_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_26_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_26_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_27_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_4_proc0
// static void setup_mmap_mmap_pad0_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_27_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_27_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_28_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_28_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_7_proc0
// static void setup_mmap_mmap_pad0_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_28_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_28_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_29_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_8_proc0
// static void setup_mmap_mmap_pad0_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_29_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_29_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_30_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_13_proc0
// static void setup_mmap_mmap_pad0_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_30_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_31_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_13_proc0
// static void setup_mmap_mmap_pad0_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_31_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_31_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_32_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_pad0_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_32_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_32_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_33_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_pad0_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_33_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_33_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_34_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_34_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_pad0_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_34_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_34_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_35_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_pad0_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_35_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_36_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_pad0_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_37_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_pad0_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_38_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_pad0_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_39_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_pad0_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_40_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_40_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_40_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_pad0_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_40_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_40_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_41_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_41_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_41_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_pad0_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_41_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_41_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_42_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
static int test_mmap_mmap_pad0_42_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_mmap_mmap_pad0_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_42_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_pad0_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_42_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_42_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_43_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_43_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_43_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_pad0_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_43_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_43_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_44_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_44_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_44_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_6_proc0
// static void setup_mmap_mmap_pad0_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_44_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_44_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_45_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_45_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pad0_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_45_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_45_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_46_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_46_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_46_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_pad0_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_46_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_46_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_47_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_47_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pad0_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_47_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_47_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_48_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_48_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_48_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_pad0_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_48_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_48_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_49_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_49_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_49_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pad0_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_49_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_49_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_50_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_50_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_50_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_pad0_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_50_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_50_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_51_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_51_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_51_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pad0_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_51_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_51_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_52_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_52_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_52_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_pad0_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_52_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_52_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_53_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_53_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_53_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_7_proc0
// static void setup_mmap_mmap_pad0_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_53_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_53_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_54_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_54_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_54_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pad0_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_54_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_54_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_55_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_55_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_55_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_7_proc0
// static void setup_mmap_mmap_pad0_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_55_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_55_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_56_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_56_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_54_proc0
// static void setup_mmap_mmap_pad0_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_56_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_56_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_57_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_57_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_57_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pad0_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_57_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_57_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_58_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_58_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_6_proc0
// static void setup_mmap_mmap_pad0_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_58_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_58_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_59_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_59_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_59_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_57_proc0
// static void setup_mmap_mmap_pad0_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_59_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_59_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_60_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_60_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_60_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_60_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_6_proc0
// static void setup_mmap_mmap_pad0_60_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_60_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_60_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_61_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_61_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_61_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_61_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_57_proc0
// static void setup_mmap_mmap_pad0_61_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_61_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_61_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_62_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_62_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_62_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_62_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_6_proc0
// static void setup_mmap_mmap_pad0_62_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_62_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_62_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_63_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_63_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_63_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_63_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_57_proc0
// static void setup_mmap_mmap_pad0_63_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_63_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_63_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_64_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_64_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_64_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_64_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pad0_64_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_64_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_64_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_65_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_65_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_65_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_65_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_pad0_65_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_65_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_65_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_66_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_66_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_66_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_66_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pad0_66_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_66_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_66_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_67_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_67_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_67_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_67_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_pad0_67_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_67_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_67_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_68_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
static int test_mmap_mmap_pad0_68_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_mmap_mmap_pad0_68_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_68_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pad0_68_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_68_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_68_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_69_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_69_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_69_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_69_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_69_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_69_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_69_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_70_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_70_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_70_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_70_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_70_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_70_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_70_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_71_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_71_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_71_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_71_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pad0_71_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_71_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_71_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_72_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_72_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_72_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_72_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pad0_72_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_72_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_72_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_73_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_73_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_73_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_73_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_73_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_73_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_73_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_74_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_74_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_74_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_74_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_4_proc0
// static void setup_mmap_mmap_pad0_74_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_74_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_74_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_75_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_75_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_75_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_75_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pad0_75_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_75_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_75_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_76_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
static int test_mmap_mmap_pad0_76_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_mmap_mmap_pad0_76_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_76_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pad0_76_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_76_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_76_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_77_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_77_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_77_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_77_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_69_proc0
// static void setup_mmap_mmap_pad0_77_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_77_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_77_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_78_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_78_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_78_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_78_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_70_proc0
// static void setup_mmap_mmap_pad0_78_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_78_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_78_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_79_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_79_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_79_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_79_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_pad0_79_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_79_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_79_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_80_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_80_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_80_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_80_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pad0_80_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_80_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_80_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_81_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_81_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_81_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_81_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_69_proc0
// static void setup_mmap_mmap_pad0_81_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_81_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_81_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_82_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_82_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_82_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_82_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_70_proc0
// static void setup_mmap_mmap_pad0_82_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_82_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_82_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_83_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_83_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_83_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_83_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pad0_83_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_83_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_83_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_84_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_84_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_84_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_84_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pad0_84_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_84_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_84_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_85_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_85_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_85_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_85_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pad0_85_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_85_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_85_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_86_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_86_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_86_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_86_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_pad0_86_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_86_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_86_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_87_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_87_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_87_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_87_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_69_proc0
// static void setup_mmap_mmap_pad0_87_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_87_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_87_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_88_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_88_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_88_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_88_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_pad0_88_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_88_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_88_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_89_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_89_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_89_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_89_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_4_proc0
// static void setup_mmap_mmap_pad0_89_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_89_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_89_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_90_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_90_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_90_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_90_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_75_proc0
// static void setup_mmap_mmap_pad0_90_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_90_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_90_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_91_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_91_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_91_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_91_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
  init_map_file(0x12345601000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_91_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_91_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_91_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_92_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_92_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_92_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_92_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
  init_map_file(0x12345601000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_92_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_92_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_92_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_93_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_93_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_93_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_93_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_93_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_93_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_93_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_94_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_94_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_94_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_94_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_94_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_94_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_94_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_95_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_95_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_95_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_95_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_pad0_95_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_95_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_95_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_96_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_96_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_96_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_96_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_47_proc0
// static void setup_mmap_mmap_pad0_96_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_96_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_96_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_97_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_97_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_97_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_97_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_97_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_97_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_97_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_98_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_98_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_98_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_98_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
  init_map_file(0x12345601000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_98_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_98_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_98_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_99_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_99_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_99_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_99_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_23_proc0
// static void setup_mmap_mmap_pad0_99_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_99_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_99_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_100_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_100_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_100_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_100_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pad0_100_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_100_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_100_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_101_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_101_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_101_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_101_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_101_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_101_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_101_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_102_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_102_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_102_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_102_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_92_proc0
// static void setup_mmap_mmap_pad0_102_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_102_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_102_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_103_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_103_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_103_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_103_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_93_proc0
// static void setup_mmap_mmap_pad0_103_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_103_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_103_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_104_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_104_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_104_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_104_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_94_proc0
// static void setup_mmap_mmap_pad0_104_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_104_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_104_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_105_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_105_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_105_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_105_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_pad0_105_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_105_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_105_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_106_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_106_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_106_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_106_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_47_proc0
// static void setup_mmap_mmap_pad0_106_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_106_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_106_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_107_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_107_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_107_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_107_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_pad0_107_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_107_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_107_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_108_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_108_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_108_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_108_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_98_proc0
// static void setup_mmap_mmap_pad0_108_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_108_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_108_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_109_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_109_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_109_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_109_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_23_proc0
// static void setup_mmap_mmap_pad0_109_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_109_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_109_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_110_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_110_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_110_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_110_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_100_proc0
// static void setup_mmap_mmap_pad0_110_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_110_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_110_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_111_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_111_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_111_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_111_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_101_proc0
// static void setup_mmap_mmap_pad0_111_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_111_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_111_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_112_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_112_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_112_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_112_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_92_proc0
// static void setup_mmap_mmap_pad0_112_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_112_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_112_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_113_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_113_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_113_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_113_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_93_proc0
// static void setup_mmap_mmap_pad0_113_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_113_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_113_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_114_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_114_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_114_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_114_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_94_proc0
// static void setup_mmap_mmap_pad0_114_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_114_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_114_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_115_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_115_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_115_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_115_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_pad0_115_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_115_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_115_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_116_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_116_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_116_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_116_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_47_proc0
// static void setup_mmap_mmap_pad0_116_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_116_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_116_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_117_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_117_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_117_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_117_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_pad0_117_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_117_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_117_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_118_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_118_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_118_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_118_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_98_proc0
// static void setup_mmap_mmap_pad0_118_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_118_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_118_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_119_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_119_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_119_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_119_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_23_proc0
// static void setup_mmap_mmap_pad0_119_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_119_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_119_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_120_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_120_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_120_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_120_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_100_proc0
// static void setup_mmap_mmap_pad0_120_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_120_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_120_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_121_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_121_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_121_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_121_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_101_proc0
// static void setup_mmap_mmap_pad0_121_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_121_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_121_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_122_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_122_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_122_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_122_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_92_proc0
// static void setup_mmap_mmap_pad0_122_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_122_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_122_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_123_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_123_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_123_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_123_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_93_proc0
// static void setup_mmap_mmap_pad0_123_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_123_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_123_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_124_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_124_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_124_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_124_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_94_proc0
// static void setup_mmap_mmap_pad0_124_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_124_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_124_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_125_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_125_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_125_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_125_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_pad0_125_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_125_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_125_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_126_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_126_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_126_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_126_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_47_proc0
// static void setup_mmap_mmap_pad0_126_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_126_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_126_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_127_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_127_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_127_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_127_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_pad0_127_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_127_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_127_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_128_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_128_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_128_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_128_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_98_proc0
// static void setup_mmap_mmap_pad0_128_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_128_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_128_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_129_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_129_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_129_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_129_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_23_proc0
// static void setup_mmap_mmap_pad0_129_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_129_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_129_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_130_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_130_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_130_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_130_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_100_proc0
// static void setup_mmap_mmap_pad0_130_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_130_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_130_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_131_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_131_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_131_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_131_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_101_proc0
// static void setup_mmap_mmap_pad0_131_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_131_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_131_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_132_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_132_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_132_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_132_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_132_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_132_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_132_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_133_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_133_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_133_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_133_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_133_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_133_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_133_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_134_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_134_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_134_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_134_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_134_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_134_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_134_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_135_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_135_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_135_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_135_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_135_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_135_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_135_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_136_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_136_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_136_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_136_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_136_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_136_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_136_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_137_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_137_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_137_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_137_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_21_proc0
// static void setup_mmap_mmap_pad0_137_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_137_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_137_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_138_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_138_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_138_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_138_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_138_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_138_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_138_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_139_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_139_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_139_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_139_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_139_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_139_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_139_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_140_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_140_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_140_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_140_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_140_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_140_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_140_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_141_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_141_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_141_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_141_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_27_proc0
// static void setup_mmap_mmap_pad0_141_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_141_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_141_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_142_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_142_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_142_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_142_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_142_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_142_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_142_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_143_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_143_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_143_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_143_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_143_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_143_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_143_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_144_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_144_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_144_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_144_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_144_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_144_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_144_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_145_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_145_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_145_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_145_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_145_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_145_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_145_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_146_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_146_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_146_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_146_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_146_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_146_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_146_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_147_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_147_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_147_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_147_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_147_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_147_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_147_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_148_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_148_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_148_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_148_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_139_proc0
// static void setup_mmap_mmap_pad0_148_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_148_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_148_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_149_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_149_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_149_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_149_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_140_proc0
// static void setup_mmap_mmap_pad0_149_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_149_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_149_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_150_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_150_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_150_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_150_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_27_proc0
// static void setup_mmap_mmap_pad0_150_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_150_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_150_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_151_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_151_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_151_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_151_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_142_proc0
// static void setup_mmap_mmap_pad0_151_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_151_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_151_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_152_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_152_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_152_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_152_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_143_proc0
// static void setup_mmap_mmap_pad0_152_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_152_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_152_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_153_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_153_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_153_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_153_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_133_proc0
// static void setup_mmap_mmap_pad0_153_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_153_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_153_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_154_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_154_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_154_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_154_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_134_proc0
// static void setup_mmap_mmap_pad0_154_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_154_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_154_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_155_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_155_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_155_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_155_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_135_proc0
// static void setup_mmap_mmap_pad0_155_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_155_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_155_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_156_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_156_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_156_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_156_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_136_proc0
// static void setup_mmap_mmap_pad0_156_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_156_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_156_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_157_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_157_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_157_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_157_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_21_proc0
// static void setup_mmap_mmap_pad0_157_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_157_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_157_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_158_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_158_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_158_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_158_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_138_proc0
// static void setup_mmap_mmap_pad0_158_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_158_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_158_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_159_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_159_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_159_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_159_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_144_proc0
// static void setup_mmap_mmap_pad0_159_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_159_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_159_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_160_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_160_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_160_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_160_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_145_proc0
// static void setup_mmap_mmap_pad0_160_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_160_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_160_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_161_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_161_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_161_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_161_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_146_proc0
// static void setup_mmap_mmap_pad0_161_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_161_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_161_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_162_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_162_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_162_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_162_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_147_proc0
// static void setup_mmap_mmap_pad0_162_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_162_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_162_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_163_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_163_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_163_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_163_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_139_proc0
// static void setup_mmap_mmap_pad0_163_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_163_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_163_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_164_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_164_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_164_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_164_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_140_proc0
// static void setup_mmap_mmap_pad0_164_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_164_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_164_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_165_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_165_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_165_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_165_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_27_proc0
// static void setup_mmap_mmap_pad0_165_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_165_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_165_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_166_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_166_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_166_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_166_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_142_proc0
// static void setup_mmap_mmap_pad0_166_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_166_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_166_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_167_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_167_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_167_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_167_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_143_proc0
// static void setup_mmap_mmap_pad0_167_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_167_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_167_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_168_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_168_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_168_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_168_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_139_proc0
// static void setup_mmap_mmap_pad0_168_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_168_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_168_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_169_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_169_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_169_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_169_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_140_proc0
// static void setup_mmap_mmap_pad0_169_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_169_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_169_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_170_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_170_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_170_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_170_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_27_proc0
// static void setup_mmap_mmap_pad0_170_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_170_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_170_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_171_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_171_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_171_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_171_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_142_proc0
// static void setup_mmap_mmap_pad0_171_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_171_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_171_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_172_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_172_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_172_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_172_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_143_proc0
// static void setup_mmap_mmap_pad0_172_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_172_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_172_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_173_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_173_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_173_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_173_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_91_proc0
// static void setup_mmap_mmap_pad0_173_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_173_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_173_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_174_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_174_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_174_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_174_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_174_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_174_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_174_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_175_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_175_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_175_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_175_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_175_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_175_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_175_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_176_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_176_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_176_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_176_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pad0_176_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_176_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_176_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_177_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_177_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_177_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_177_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pad0_177_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_177_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_177_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_178_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_178_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_178_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_178_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_178_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_178_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_178_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_179_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_179_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_179_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_179_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_179_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_179_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_179_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_180_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_180_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_180_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_180_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_180_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_180_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_180_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_181_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_181_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_181_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_181_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_181_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_181_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_181_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_182_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_182_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_182_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_182_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_182_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_182_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_182_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_183_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_183_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_183_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_183_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_31_proc0
// static void setup_mmap_mmap_pad0_183_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_183_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_183_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_184_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_184_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_184_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_184_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_184_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_184_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_184_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_185_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_185_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_185_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_185_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
  init_map_file(0x12345601000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_185_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_185_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_185_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_186_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_186_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_186_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_186_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_38_proc0
// static void setup_mmap_mmap_pad0_186_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_186_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_186_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_187_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_187_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_187_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_187_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pad0_187_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_187_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_187_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_188_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_188_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_188_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_188_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_188_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_188_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_188_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_189_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_189_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_189_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_189_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_179_proc0
// static void setup_mmap_mmap_pad0_189_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_189_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_189_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_190_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_190_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_190_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_190_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_190_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_190_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_190_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_191_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_191_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_191_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_191_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_42_proc0
// static void setup_mmap_mmap_pad0_191_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_191_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_191_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_192_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_192_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_192_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_192_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_192_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_192_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_192_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_193_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_193_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_193_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_193_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_193_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_193_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_193_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_194_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_194_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_194_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_194_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_pad0_194_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_194_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_194_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_195_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_195_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_195_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_195_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_47_proc0
// static void setup_mmap_mmap_pad0_195_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_195_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_195_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_196_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_196_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_196_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_196_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_21_proc0
// static void setup_mmap_mmap_pad0_196_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_196_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_196_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_197_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_197_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_197_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_197_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pad0_197_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_197_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_197_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_198_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_198_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_198_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_198_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_91_proc0
// static void setup_mmap_mmap_pad0_198_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_198_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_198_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_199_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_199_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_199_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_199_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_174_proc0
// static void setup_mmap_mmap_pad0_199_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_199_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_199_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_200_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_200_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_200_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_200_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_175_proc0
// static void setup_mmap_mmap_pad0_200_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_200_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_200_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_201_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_201_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_201_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_201_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_176_proc0
// static void setup_mmap_mmap_pad0_201_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_201_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_201_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_202_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_202_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_202_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_202_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_177_proc0
// static void setup_mmap_mmap_pad0_202_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_202_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_202_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_203_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_203_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_203_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_203_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_178_proc0
// static void setup_mmap_mmap_pad0_203_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_203_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_203_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_204_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_204_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_204_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_204_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_180_proc0
// static void setup_mmap_mmap_pad0_204_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_204_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_204_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_205_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_205_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_205_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_205_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_181_proc0
// static void setup_mmap_mmap_pad0_205_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_205_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_205_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_206_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_206_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_206_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_206_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_182_proc0
// static void setup_mmap_mmap_pad0_206_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_206_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_206_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_207_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_207_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_207_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_207_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_31_proc0
// static void setup_mmap_mmap_pad0_207_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_207_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_207_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_208_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_208_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_208_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_208_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_184_proc0
// static void setup_mmap_mmap_pad0_208_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_208_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_208_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_209_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_209_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_209_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_209_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
  init_map_file(0x12345601000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_209_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_209_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_209_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_210_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_210_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_210_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_210_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
  init_map_file(0x12345601000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_210_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_210_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_210_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_211_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_211_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_211_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_211_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_39_proc0
// static void setup_mmap_mmap_pad0_211_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_211_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_211_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_212_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_212_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_212_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_212_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_file(0x12345601000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pad0_212_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_212_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_212_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_213_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_213_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_213_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_213_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_213_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_213_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_213_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_214_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_214_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_214_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_214_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_185_proc0
// static void setup_mmap_mmap_pad0_214_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_214_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_214_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_215_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_215_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_215_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_215_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_38_proc0
// static void setup_mmap_mmap_pad0_215_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_215_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_215_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_216_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_216_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_216_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_216_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_187_proc0
// static void setup_mmap_mmap_pad0_216_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_216_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_216_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_217_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_217_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_217_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_217_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_188_proc0
// static void setup_mmap_mmap_pad0_217_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_217_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_217_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_218_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_218_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_218_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_218_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_179_proc0
// static void setup_mmap_mmap_pad0_218_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_218_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_218_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_219_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_219_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_219_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_219_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_219_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_219_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_219_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_220_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_220_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_220_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_220_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_220_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_220_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_220_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_221_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_221_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_221_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_221_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_43_proc0
// static void setup_mmap_mmap_pad0_221_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_221_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_221_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_222_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_222_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_222_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
static void setup_mmap_mmap_pad0_222_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_222_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_222_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_222_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_223_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_223_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_223_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_223_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_223_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_223_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_223_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_224_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_224_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_224_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_224_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_190_proc0
// static void setup_mmap_mmap_pad0_224_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_224_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_224_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_225_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_225_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_225_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_225_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_42_proc0
// static void setup_mmap_mmap_pad0_225_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_225_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_225_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_226_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_226_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_226_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_226_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_192_proc0
// static void setup_mmap_mmap_pad0_226_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_226_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_226_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_227_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_227_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_227_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_227_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_193_proc0
// static void setup_mmap_mmap_pad0_227_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_227_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_227_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_228_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_228_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_228_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_228_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_209_proc0
// static void setup_mmap_mmap_pad0_228_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_228_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_228_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_229_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_229_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_229_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_229_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_210_proc0
// static void setup_mmap_mmap_pad0_229_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_229_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_229_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_230_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_230_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_230_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_230_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_39_proc0
// static void setup_mmap_mmap_pad0_230_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_230_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_230_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_231_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_231_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_231_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_231_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_212_proc0
// static void setup_mmap_mmap_pad0_231_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_231_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_231_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_232_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_232_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_232_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_232_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_213_proc0
// static void setup_mmap_mmap_pad0_232_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_232_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_232_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_233_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_233_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_233_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_233_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_185_proc0
// static void setup_mmap_mmap_pad0_233_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_233_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_233_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_234_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_234_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_234_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_234_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_38_proc0
// static void setup_mmap_mmap_pad0_234_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_234_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_234_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_235_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_235_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_235_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_235_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_187_proc0
// static void setup_mmap_mmap_pad0_235_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_235_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_235_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_236_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_236_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_236_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_236_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_188_proc0
// static void setup_mmap_mmap_pad0_236_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_236_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_236_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_237_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_237_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_237_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_237_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_219_proc0
// static void setup_mmap_mmap_pad0_237_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_237_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_237_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_238_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_238_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_238_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_238_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_220_proc0
// static void setup_mmap_mmap_pad0_238_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_238_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_238_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_239_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_239_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_239_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_239_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_43_proc0
// static void setup_mmap_mmap_pad0_239_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_239_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_239_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_240_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_240_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_240_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_240_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_222_proc0
// static void setup_mmap_mmap_pad0_240_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_240_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_240_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_241_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_241_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_241_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_241_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_223_proc0
// static void setup_mmap_mmap_pad0_241_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_241_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_241_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_242_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_242_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_242_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_242_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_190_proc0
// static void setup_mmap_mmap_pad0_242_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_242_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_242_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_243_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_243_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_243_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_243_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_42_proc0
// static void setup_mmap_mmap_pad0_243_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_243_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_243_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_244_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_244_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_244_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_244_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_192_proc0
// static void setup_mmap_mmap_pad0_244_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_244_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_244_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_245_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_245_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_245_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_245_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_193_proc0
// static void setup_mmap_mmap_pad0_245_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_245_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_245_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_246_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_246_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_246_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_246_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_91_proc0
// static void setup_mmap_mmap_pad0_246_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_246_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_246_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_247_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_247_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_247_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_247_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_185_proc0
// static void setup_mmap_mmap_pad0_247_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_247_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_247_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_248_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_248_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_248_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_248_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_38_proc0
// static void setup_mmap_mmap_pad0_248_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_248_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_248_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_249_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_249_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_249_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_249_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_file(0x12345601000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_187_proc0
// static void setup_mmap_mmap_pad0_249_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_249_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_249_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_250_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_250_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_250_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_250_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_188_proc0
// static void setup_mmap_mmap_pad0_250_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_250_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_250_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_251_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_251_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_251_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_251_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_179_proc0
// static void setup_mmap_mmap_pad0_251_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_251_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_251_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_252_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_252_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_252_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_252_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_190_proc0
// static void setup_mmap_mmap_pad0_252_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_252_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_252_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_253_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_253_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_253_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_253_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_42_proc0
// static void setup_mmap_mmap_pad0_253_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_253_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_253_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_254_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_254_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_254_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_254_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_192_proc0
// static void setup_mmap_mmap_pad0_254_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_254_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_254_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_255_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_255_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_255_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_255_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_193_proc0
// static void setup_mmap_mmap_pad0_255_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_255_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_255_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_256_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_256_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_256_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_256_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_pad0_256_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_256_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_256_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_257_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_257_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_257_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_257_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_47_proc0
// static void setup_mmap_mmap_pad0_257_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_257_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_257_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_258_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_258_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_258_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_258_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_21_proc0
// static void setup_mmap_mmap_pad0_258_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_258_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_258_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_259_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_259_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_259_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_259_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_197_proc0
// static void setup_mmap_mmap_pad0_259_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_259_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_259_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_260_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_260_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_260_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_260_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_132_proc0
// static void setup_mmap_mmap_pad0_260_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_260_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_260_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_261_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_261_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_261_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_261_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pad0_261_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_261_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_261_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_262_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_262_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_262_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_262_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pad0_262_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_262_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_262_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_263_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_263_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_263_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_263_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_pad0_263_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_263_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_263_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_264_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_264_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_264_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_264_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_pad0_264_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_264_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_264_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_265_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_265_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_265_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_265_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_pad0_265_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_265_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_265_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_266_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_266_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_266_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_266_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_266_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_266_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_266_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_267_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_267_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_267_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_267_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pad0_267_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_267_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_267_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_268_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_268_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_268_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_268_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pad0_268_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_268_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_268_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_269_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_269_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_269_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_269_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_pad0_269_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_269_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_269_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_270_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_270_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_270_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_270_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_pad0_270_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_270_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_270_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_271_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_271_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_271_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_271_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_pad0_271_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_271_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_271_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_272_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_272_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_272_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_272_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_272_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_272_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_272_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_273_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_273_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_273_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_273_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_273_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_273_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_273_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
static int test_mmap_mmap_pad0_274_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x1000UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_mmap_pad0_274_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_274_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_274_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i1", 0x0);
}
// static void setup_mmap_mmap_pad0_274_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_274_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_274_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_275_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
static int test_mmap_mmap_pad0_275_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x1e27000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
// static void setup_mmap_mmap_pad0_275_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_275_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i1", 0x1e27000);
}
// static void setup_mmap_mmap_pad0_275_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_275_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_275_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_276_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_276_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_276_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_276_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_pad0_276_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_276_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_276_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_277_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_277_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_277_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_277_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_262_proc0
// static void setup_mmap_mmap_pad0_277_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_277_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_277_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_278_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_278_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_278_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_278_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_pad0_278_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_278_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_278_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_279_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_279_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_279_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_279_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_pad0_279_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_279_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_279_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_280_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_280_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_280_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_280_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_268_proc0
// static void setup_mmap_mmap_pad0_280_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_280_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_280_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_281_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_281_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_281_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_281_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_pad0_281_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_281_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_281_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_282_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_282_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_282_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_282_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_282_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_282_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_282_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_283_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_283_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_283_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_283_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
  init_map_file(0x12345601000, 1, "__i1", 0x0);
}
// static void setup_mmap_mmap_pad0_283_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_283_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_283_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_284_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_284_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_284_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_284_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i1", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_284_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_284_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_284_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_285_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_285_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_285_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_285_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_213_proc0
// static void setup_mmap_mmap_pad0_285_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_285_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_285_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_286_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_286_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_286_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_286_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_147_proc0
// static void setup_mmap_mmap_pad0_286_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_286_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_286_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_287_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_287_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_287_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_287_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_223_proc0
// static void setup_mmap_mmap_pad0_287_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_287_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_287_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_288_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
static int test_mmap_mmap_pad0_288_1(void) {
  int* va = (int*) 0x12345601000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x4d4000UL);
  expect_result("r", r, 1250999406592);
  return xerrno(r);
}
static void setup_mmap_mmap_pad0_288_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_mmap_pad0_288_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i1", 0x4d4000);
}
// static void setup_mmap_mmap_pad0_288_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_288_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_288_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_289_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_289_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_289_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_289_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_289_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_289_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_289_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_290_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_290_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_290_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_290_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_290_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_290_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_290_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_291_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_291_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_291_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_291_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_291_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_291_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_291_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_292_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_292_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_292_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_292_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_292_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_292_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_292_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_293_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_293_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_293_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_293_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i1", 0x0);
}
// static void setup_mmap_mmap_pad0_293_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_293_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_293_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_294_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_294_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_294_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_294_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_294_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_294_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_294_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_295_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_295_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_295_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_295_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_295_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_295_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_295_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_296_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_296_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_296_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_296_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_296_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_296_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_296_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_297_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_297_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_297_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_297_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_297_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_297_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_297_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_298_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_298_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_298_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_298_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_298_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_298_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_298_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_299_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_299_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_299_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_299_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_299_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_299_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_299_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_300_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_300_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_300_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_300_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_300_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_300_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_300_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_301_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_301_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_301_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_301_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_301_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_301_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_301_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_302_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_302_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_302_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_302_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i1", 0x0);
}
// static void setup_mmap_mmap_pad0_302_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_302_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_302_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_303_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_303_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_303_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_303_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_303_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_303_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_303_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_304_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_304_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_304_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_304_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i1", 0x2000);
}
// static void setup_mmap_mmap_pad0_304_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_304_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_304_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_305_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_305_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_305_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_305_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i1", 0x0);
}
// static void setup_mmap_mmap_pad0_305_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_305_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_305_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_306_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_306_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_306_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_306_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_pad0_306_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_306_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_306_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_307_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_307_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_307_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_307_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_307_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_307_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_307_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_308_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_308_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_308_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_308_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_308_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_308_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_308_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_309_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_309_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_309_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_309_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mmap_pad0_309_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_309_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_309_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_310_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_310_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_310_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_pad0_310_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_310_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_310_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_310_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_311_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_311_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_311_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
static void setup_mmap_mmap_pad0_311_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mmap_pad0_311_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_311_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_311_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_312_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_312_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_312_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_312_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_272_proc0
// static void setup_mmap_mmap_pad0_312_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_312_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_312_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_313_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_313_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_313_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_313_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_273_proc0
// static void setup_mmap_mmap_pad0_313_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_313_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_313_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_314_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_314_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_314_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_314_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_274_proc0
// static void setup_mmap_mmap_pad0_314_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_314_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_314_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_315_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_315_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_315_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_315_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_289_proc0
// static void setup_mmap_mmap_pad0_315_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_315_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_315_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_316_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_316_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_316_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_316_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_295_proc0
// static void setup_mmap_mmap_pad0_316_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_316_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_316_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_317_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_317_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_317_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_317_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_296_proc0
// static void setup_mmap_mmap_pad0_317_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_317_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_317_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_318_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_318_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_318_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_318_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_266_proc0
// static void setup_mmap_mmap_pad0_318_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_318_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_318_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_319_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_319_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_319_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_319_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_290_proc0
// static void setup_mmap_mmap_pad0_319_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_319_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_319_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_320_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_320_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_320_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_320_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_291_proc0
// static void setup_mmap_mmap_pad0_320_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_320_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_320_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_321_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_321_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_321_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_321_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_292_proc0
// static void setup_mmap_mmap_pad0_321_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_321_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_321_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_322_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_322_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_322_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_322_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_293_proc0
// static void setup_mmap_mmap_pad0_322_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_322_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_322_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_323_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_323_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_323_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_323_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_294_proc0
// static void setup_mmap_mmap_pad0_323_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_323_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_323_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_324_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_324_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_324_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_324_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_297_proc0
// static void setup_mmap_mmap_pad0_324_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_324_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_324_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_325_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_325_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_325_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_325_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_298_proc0
// static void setup_mmap_mmap_pad0_325_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_325_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_325_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_326_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_326_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_326_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_326_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_299_proc0
// static void setup_mmap_mmap_pad0_326_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_326_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_326_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_327_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_327_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_327_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_327_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_300_proc0
// static void setup_mmap_mmap_pad0_327_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_327_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_327_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_328_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_328_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_328_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_328_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_301_proc0
// static void setup_mmap_mmap_pad0_328_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_328_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_328_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_329_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_329_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_329_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_329_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_302_proc0
// static void setup_mmap_mmap_pad0_329_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_329_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_329_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_330_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_330_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_330_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_330_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_303_proc0
// static void setup_mmap_mmap_pad0_330_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_330_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_330_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_331_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_331_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_331_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_331_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_304_proc0
// static void setup_mmap_mmap_pad0_331_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_331_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_331_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_332_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_332_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_332_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_332_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_305_proc0
// static void setup_mmap_mmap_pad0_332_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_332_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_332_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_333_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_333_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_333_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_333_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_306_proc0
// static void setup_mmap_mmap_pad0_333_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_333_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_333_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_334_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_334_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_334_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_334_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_307_proc0
// static void setup_mmap_mmap_pad0_334_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_334_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_334_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_335_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_335_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_335_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_335_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_308_proc0
// static void setup_mmap_mmap_pad0_335_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_335_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_335_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_336_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_336_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_336_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_336_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_309_proc0
// static void setup_mmap_mmap_pad0_336_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_336_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_336_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_337_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_337_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_337_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_337_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_310_proc0
// static void setup_mmap_mmap_pad0_337_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_337_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_337_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_338_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_338_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_338_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_338_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_311_proc0
// static void setup_mmap_mmap_pad0_338_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_338_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_338_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_339_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_339_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_339_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_339_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_pad0_339_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_339_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_339_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_340_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_340_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_340_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_340_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_262_proc0
// static void setup_mmap_mmap_pad0_340_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_340_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_340_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_341_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_341_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_341_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_341_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_pad0_341_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_341_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_341_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_342_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_342_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_342_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_342_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_pad0_342_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_342_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_342_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_343_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_343_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_343_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_343_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_268_proc0
// static void setup_mmap_mmap_pad0_343_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_343_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_343_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_344_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_344_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_344_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_344_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_pad0_344_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_344_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_344_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_345_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_345_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_345_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_345_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_132_proc0
// static void setup_mmap_mmap_pad0_345_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_345_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_345_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_346_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_346_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_346_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_346_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_272_proc0
// static void setup_mmap_mmap_pad0_346_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_346_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_346_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_347_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_347_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_347_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_347_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_273_proc0
// static void setup_mmap_mmap_pad0_347_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_347_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_347_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_348_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_348_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_348_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_348_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_274_proc0
// static void setup_mmap_mmap_pad0_348_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_348_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_348_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_349_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_349_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_349_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_349_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_289_proc0
// static void setup_mmap_mmap_pad0_349_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_349_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_349_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_350_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_350_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_350_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_350_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_295_proc0
// static void setup_mmap_mmap_pad0_350_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_350_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_350_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_351_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_351_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_351_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_351_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_296_proc0
// static void setup_mmap_mmap_pad0_351_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_351_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_351_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_352_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_352_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_352_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_352_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_266_proc0
// static void setup_mmap_mmap_pad0_352_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_352_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_352_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_353_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_353_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_353_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_353_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_290_proc0
// static void setup_mmap_mmap_pad0_353_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_353_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_353_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_354_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_354_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_354_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_354_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_291_proc0
// static void setup_mmap_mmap_pad0_354_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_354_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_354_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_355_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_355_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_355_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_355_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_292_proc0
// static void setup_mmap_mmap_pad0_355_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_355_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_355_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_356_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_356_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_356_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_356_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_293_proc0
// static void setup_mmap_mmap_pad0_356_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_356_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_356_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_357_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_357_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_357_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_357_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_294_proc0
// static void setup_mmap_mmap_pad0_357_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_357_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_357_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_358_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_358_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_358_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_358_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_297_proc0
// static void setup_mmap_mmap_pad0_358_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_358_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_358_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_359_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_359_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_359_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_359_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_298_proc0
// static void setup_mmap_mmap_pad0_359_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_359_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_359_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_360_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_360_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_360_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_360_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_299_proc0
// static void setup_mmap_mmap_pad0_360_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_360_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_360_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_361_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_361_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_361_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_361_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_300_proc0
// static void setup_mmap_mmap_pad0_361_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_361_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_361_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_362_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_362_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_362_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_362_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_301_proc0
// static void setup_mmap_mmap_pad0_362_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_362_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_362_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_363_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_363_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_363_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_363_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_302_proc0
// static void setup_mmap_mmap_pad0_363_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_363_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_363_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_364_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_364_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_364_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_364_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_303_proc0
// static void setup_mmap_mmap_pad0_364_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_364_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_364_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_365_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_365_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_365_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_365_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_304_proc0
// static void setup_mmap_mmap_pad0_365_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_365_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_365_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_366_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_366_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_366_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_366_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_305_proc0
// static void setup_mmap_mmap_pad0_366_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_366_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_366_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_367_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_367_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_367_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_367_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_306_proc0
// static void setup_mmap_mmap_pad0_367_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_367_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_367_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_368_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_368_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_368_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_368_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_307_proc0
// static void setup_mmap_mmap_pad0_368_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_368_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_368_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_369_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_369_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_369_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_369_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_308_proc0
// static void setup_mmap_mmap_pad0_369_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_369_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_369_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_370_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_370_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_370_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_370_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_309_proc0
// static void setup_mmap_mmap_pad0_370_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_370_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_370_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_371_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_371_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf4_0_1
// static void setup_mmap_mmap_pad0_371_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_371_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_310_proc0
// static void setup_mmap_mmap_pad0_371_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_371_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_371_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_372_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_372_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_68_1
// static void setup_mmap_mmap_pad0_372_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_372_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_311_proc0
// static void setup_mmap_mmap_pad0_372_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_372_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_372_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_373_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_373_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_373_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_373_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_pad0_373_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_373_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_373_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_374_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_374_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_374_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_374_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_262_proc0
// static void setup_mmap_mmap_pad0_374_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_374_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_374_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_375_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_375_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_375_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_375_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_pad0_375_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_375_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_375_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_376_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_376_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_376_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_376_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_pad0_376_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_376_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_376_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_377_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_377_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_377_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_377_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_268_proc0
// static void setup_mmap_mmap_pad0_377_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_377_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_377_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_378_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_378_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_378_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_378_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_pad0_378_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_378_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_378_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_379_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_379_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_379_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_379_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_295_proc0
// static void setup_mmap_mmap_pad0_379_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_379_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_379_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_380_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_380_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_380_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_380_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_282_proc0
// static void setup_mmap_mmap_pad0_380_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_380_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_380_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_381_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_381_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_381_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_381_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_147_proc0
// static void setup_mmap_mmap_pad0_381_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_381_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_381_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_382_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_382_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_382_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_382_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
//   init_map_file(0x12345601000, 1, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_283_proc0
// static void setup_mmap_mmap_pad0_382_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_382_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_382_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_383_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_383_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_383_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_383_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_213_proc0
// static void setup_mmap_mmap_pad0_383_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_383_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_383_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_384_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_384_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_384_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_384_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_284_proc0
// static void setup_mmap_mmap_pad0_384_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_384_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_384_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_385_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_385_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_385_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_385_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_223_proc0
// static void setup_mmap_mmap_pad0_385_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_385_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_385_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_386_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_386_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_386_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_386_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_272_proc0
// static void setup_mmap_mmap_pad0_386_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_386_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_386_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_387_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_387_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_387_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_387_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_273_proc0
// static void setup_mmap_mmap_pad0_387_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_387_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_387_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_388_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_388_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_388_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_388_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_274_proc0
// static void setup_mmap_mmap_pad0_388_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_388_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_388_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_389_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_389_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_389_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_389_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_289_proc0
// static void setup_mmap_mmap_pad0_389_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_389_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_389_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_390_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_390_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_390_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_390_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_290_proc0
// static void setup_mmap_mmap_pad0_390_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_390_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_390_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_391_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_391_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_391_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_391_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_291_proc0
// static void setup_mmap_mmap_pad0_391_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_391_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_391_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_392_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_392_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_392_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_392_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_292_proc0
// static void setup_mmap_mmap_pad0_392_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_392_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_392_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_393_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_393_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_393_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_393_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_293_proc0
// static void setup_mmap_mmap_pad0_393_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_393_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_393_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_394_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_394_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_394_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_394_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_294_proc0
// static void setup_mmap_mmap_pad0_394_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_394_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_394_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_395_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_395_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_395_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_395_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_296_proc0
// static void setup_mmap_mmap_pad0_395_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_395_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_395_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_396_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_396_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_396_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_396_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_297_proc0
// static void setup_mmap_mmap_pad0_396_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_396_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_396_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_397_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_397_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_397_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_397_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_298_proc0
// static void setup_mmap_mmap_pad0_397_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_397_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_397_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_398_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_398_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_398_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_398_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_266_proc0
// static void setup_mmap_mmap_pad0_398_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_398_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_398_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_399_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_399_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_399_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_399_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_299_proc0
// static void setup_mmap_mmap_pad0_399_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_399_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_399_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_400_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_400_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_400_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_400_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_300_proc0
// static void setup_mmap_mmap_pad0_400_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_400_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_400_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_401_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_401_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_401_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_401_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_301_proc0
// static void setup_mmap_mmap_pad0_401_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_401_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_401_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_402_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_402_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_402_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_402_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_302_proc0
// static void setup_mmap_mmap_pad0_402_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_402_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_402_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_403_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_403_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_403_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_403_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_303_proc0
// static void setup_mmap_mmap_pad0_403_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_403_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_403_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_404_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_404_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_404_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_404_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_304_proc0
// static void setup_mmap_mmap_pad0_404_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_404_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_404_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_405_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_405_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_405_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_405_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_305_proc0
// static void setup_mmap_mmap_pad0_405_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_405_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_405_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_406_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_406_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_406_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_406_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_306_proc0
// static void setup_mmap_mmap_pad0_406_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_406_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_406_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_407_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_407_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_407_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_407_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_307_proc0
// static void setup_mmap_mmap_pad0_407_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_407_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_407_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_408_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_408_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_408_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_408_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_308_proc0
// static void setup_mmap_mmap_pad0_408_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_408_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_408_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_409_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_409_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_409_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_409_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_309_proc0
// static void setup_mmap_mmap_pad0_409_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_409_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_409_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_410_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_410_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_1_1
// static void setup_mmap_mmap_pad0_410_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_pad0_410_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_310_proc0
// static void setup_mmap_mmap_pad0_410_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_410_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_pad0_410_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_411_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_411_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999406592);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_76_1
// static void setup_mmap_mmap_pad0_411_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pad0_411_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_311_proc0
// static void setup_mmap_mmap_pad0_411_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_411_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_411_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_412_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_412_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_412_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_412_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_42_proc0
// static void setup_mmap_mmap_pad0_412_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_412_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_412_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_413_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_413_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_413_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_413_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_pad0_413_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_413_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_413_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_414_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_414_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_414_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_414_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_pad0_414_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_414_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_414_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_415_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_415_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_415_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_415_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_pad0_415_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_415_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_415_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_416_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_416_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_416_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_416_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_47_proc0
// static void setup_mmap_mmap_pad0_416_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_416_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_416_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_417_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_417_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_417_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_417_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_pad0_417_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_417_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_417_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_418_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_418_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_418_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_418_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_pad0_418_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_418_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_418_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_419_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_419_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_419_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_419_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_pad0_419_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_419_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_419_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_420_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_420_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_420_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_420_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_pad0_420_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_420_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_420_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_421_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_421_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_pad0_421_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_421_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_pad0_421_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_421_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_421_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_422_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_422_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_422_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_422_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_49_proc0
// static void setup_mmap_mmap_pad0_422_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_422_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_422_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_423_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pad0_423_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pad0_423_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_423_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_pad0_423_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_423_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_423_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_424_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_424_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_424_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_424_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_42_proc0
// static void setup_mmap_mmap_pad0_424_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_424_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_424_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_425_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_425_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_425_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_425_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_pad0_425_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_425_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_425_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_426_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_426_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_426_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_426_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_pad0_426_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_426_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_426_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_427_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_427_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_427_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_427_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_pad0_427_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_427_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_427_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_428_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_428_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_428_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_428_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_47_proc0
// static void setup_mmap_mmap_pad0_428_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_428_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_428_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_429_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_429_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_429_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_429_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_pad0_429_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_429_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_429_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_430_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_430_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_430_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_430_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_pad0_430_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_430_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_430_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_431_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_431_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_431_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_431_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_pad0_431_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_431_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_431_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_432_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_432_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_432_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_432_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_pad0_432_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_432_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_432_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_433_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_433_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_pad0_433_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_433_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_pad0_433_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_433_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_433_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_434_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_434_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_434_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_434_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_49_proc0
// static void setup_mmap_mmap_pad0_434_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_434_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_434_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pad0_435_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pad0_435_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_pad0_435_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pad0_435_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_pad0_435_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pad0_435_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pad0_435_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pac_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pac_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pac_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pab0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_pab0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pab0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pab0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_4_proc0
// static void setup_mmap_mmap_pab0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_4_proc0
// static void setup_mmap_mmap_pab0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pab0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_pab0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pab0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pab0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pab0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pab0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_8_proc0
// static void setup_mmap_mmap_pab0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pab0_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pab0_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_pab0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pab0_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_pab0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pab0_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pab0_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_pab0_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pab0_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_8_proc0
// static void setup_mmap_mmap_pab0_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pab0_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pab0_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_47_proc0
// static void setup_mmap_mmap_pab0_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_21_proc0
// static void setup_mmap_mmap_pab0_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_14_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_49_proc0
// static void setup_mmap_mmap_pab0_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_21_proc0
// static void setup_mmap_mmap_pab0_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_16_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_47_proc0
// static void setup_mmap_mmap_pab0_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_17_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_49_proc0
// static void setup_mmap_mmap_pab0_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_18_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_pab0_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_19_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pab0_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_57_proc0
// static void setup_mmap_mmap_pab0_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pab0_19_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pab0_19_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_20_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_pab0_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_21_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pab0_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_26_proc0
// static void setup_mmap_mmap_pab0_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pab0_21_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pab0_21_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_22_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_pab0_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_23_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_pab0_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pab0_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_59_proc0
// static void setup_mmap_mmap_pab0_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pab0_23_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pab0_23_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_24_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_pab0_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_25_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pab0_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_26_proc0
// static void setup_mmap_mmap_pab0_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pab0_25_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pab0_25_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_26_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_pab0_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_26_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_27_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pab0_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_57_proc0
// static void setup_mmap_mmap_pab0_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pab0_27_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pab0_27_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_28_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pab0_28_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_pab0_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pab0_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pab0_28_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pab0_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pab0_29_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_pab0_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pab0_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_59_proc0
// static void setup_mmap_mmap_pab0_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pab0_29_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pab0_29_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa98_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa98_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_pa98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pa98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_pa98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pa98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pa98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa98_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa98_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_pa98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pa98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pad8_1_proc0
// static void setup_mmap_mmap_pa98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_pa98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pa98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
static void setup_mmap_mmap_pa94_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mmap_mmap_pa94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_pa94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
static void setup_mmap_mmap_pa94_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_mmap_mmap_pa94_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pa94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_pa94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pa94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_pa94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pa94_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_pa94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pa94_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
static void setup_mmap_mmap_pa94_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pa94_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pa94_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pa94_4_proc0
// static void setup_mmap_mmap_pa94_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_5_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pa94_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pa94_4_proc0
// static void setup_mmap_mmap_pa94_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_6_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pa94_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pa94_4_proc0
// static void setup_mmap_mmap_pa94_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_7_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa94_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa94_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa94_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_pa94_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa94_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa94_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa94_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_pa94_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa94_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa94_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa94_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa94_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_14_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa94_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_pa94_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa94_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_pa94_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_16_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pa94_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
static void setup_mmap_mmap_pa94_16_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_pa94_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_16_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_17_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa94_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_pa94_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_18_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pa94_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pa94_16_proc0
// static void setup_mmap_mmap_pa94_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_18_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_19_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa94_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_pa94_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_20_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pa94_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pa94_16_proc0
// static void setup_mmap_mmap_pa94_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_20_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_21_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa94_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_pa94_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_22_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pa94_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pa94_16_proc0
// static void setup_mmap_mmap_pa94_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_22_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_23_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa94_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_pa94_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_24_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pa94_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_pa94_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_24_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_25_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa94_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_pa94_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_25_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_25_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_26_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pa94_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_pa94_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_26_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_26_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_27_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa94_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_pa94_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_27_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_28_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pa94_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_28_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_pa94_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_28_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_28_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_29_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa94_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_pa94_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_29_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_29_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_30_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_pa94_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_pa94_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_30_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_31_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa94_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_pa94_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_31_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_31_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_32_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pa94_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_pa94_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_32_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_32_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_33_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa94_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_pa94_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_33_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_33_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_34_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pa94_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_34_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_pa94_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_34_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_34_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa94_35_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa94_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_pa94_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_35_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_36_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pa94_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_pa94_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_36_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_37_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa94_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_pa94_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_38_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_pa94_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pa94_0_common
// static void setup_mmap_mmap_pa94_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_pa94_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_38_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_mmap_mmap_pa94_0_final
// static void setup_mmap_mmap_pa94_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa94_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static int test_mmap_mmap_pa94_39_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa94_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa94_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_pa94_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa94_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa94_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa8_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa6_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa58_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa58_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_pa58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pa58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_pa58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pa58_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pa58_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa58_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa58_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_pa58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pa58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_pa58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pa58_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pa58_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa50_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_pa50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pa50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pa50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pa50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa50_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa30_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa30_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_pa30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa30_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa30_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa30_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_pa30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_pa30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa30_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa30_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa18_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa18_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_pa18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pa18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_pa18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_pa18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pa18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa18_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa18_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_pa18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_pa18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_pa18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_pa18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_pa18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa14_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa14_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pa14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pa14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pa14_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa14_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa14_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa14_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa14_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pa14_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pa14_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pa14_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa14_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa14_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa14_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_pa14_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pa14_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa14_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa14_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa14_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa14_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa14_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_pa14_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pa14_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa14_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_pa14_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa14_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static int test_mmap_mmap_pa0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p9c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p9c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p9c_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p9c_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p9c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p9c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p9c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p9c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p9b_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p9b_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p9b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p9b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_1_proc0
// static void setup_mmap_mmap_p9b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p9b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p9b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p9b_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p9b_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p9b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p9b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_4_proc0
// static void setup_mmap_mmap_p9b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p9b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p9b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p9a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p9a_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p98_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p98_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p98_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p98_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p98_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p98_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p98_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p98_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p96_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p96_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p96_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p96_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p96_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p96_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p96_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p96_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p96_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_p96_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p96_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p96_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_p96_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_5_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p96_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p96_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_p96_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p96_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p96_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_p96_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_7_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p96_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p96_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_36_proc0
// static void setup_mmap_mmap_p96_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p96_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_38_proc0
// static void setup_mmap_mmap_p96_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p96_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_39_proc0
// static void setup_mmap_mmap_p96_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p96_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_40_proc0
// static void setup_mmap_mmap_p96_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p96_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_p96_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p96_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p96_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_p96_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_13_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p96_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_14_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p96_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_p96_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p96_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p96_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_p96_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_15_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p96_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_16_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p96_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_36_proc0
// static void setup_mmap_mmap_p96_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_17_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p96_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_38_proc0
// static void setup_mmap_mmap_p96_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_18_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p96_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_39_proc0
// static void setup_mmap_mmap_p96_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p96_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p96_19_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p96_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p96_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_40_proc0
// static void setup_mmap_mmap_p96_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p96_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p96_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p93_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p93_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p93_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p93_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_1_proc0
// static void setup_mmap_mmap_p93_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p93_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p93_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p93_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p93_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p93_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p93_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_4_proc0
// static void setup_mmap_mmap_p93_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p93_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p93_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p928_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p928_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p928_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p928_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_3_proc0
// static void setup_mmap_mmap_p928_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_3_proc0
// static void setup_mmap_mmap_p928_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_31_proc0
// static void setup_mmap_mmap_p928_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_31_proc0
// static void setup_mmap_mmap_p928_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_36_proc0
// static void setup_mmap_mmap_p928_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_47_proc0
// static void setup_mmap_mmap_p928_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_39_proc0
// static void setup_mmap_mmap_p928_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_13_proc0
// static void setup_mmap_mmap_p928_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_37_proc0
// static void setup_mmap_mmap_p928_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_38_proc0
// static void setup_mmap_mmap_p928_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_14_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_49_proc0
// static void setup_mmap_mmap_p928_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p928_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_40_proc0
// static void setup_mmap_mmap_p928_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_16_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_36_proc0
// static void setup_mmap_mmap_p928_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_17_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_13_proc0
// static void setup_mmap_mmap_p928_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_18_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_37_proc0
// static void setup_mmap_mmap_p928_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_19_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_38_proc0
// static void setup_mmap_mmap_p928_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_20_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_47_proc0
// static void setup_mmap_mmap_p928_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_21_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_39_proc0
// static void setup_mmap_mmap_p928_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_22_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_49_proc0
// static void setup_mmap_mmap_p928_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p928_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p928_23_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p928_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p928_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_40_proc0
// static void setup_mmap_mmap_p928_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p928_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p928_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p90_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p90_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p90_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p90_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p90_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p90_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p90_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p90_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p8c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p8c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p8c_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p8b_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p8b_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p8b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p8b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p8b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p8b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p8b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p8b_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p8b_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p8b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p8b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p8b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p8b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p8b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p8a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p8a_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p88_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p88_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p88_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p88_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p86_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p86_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p86_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p86_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p86_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p86_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p86_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p86_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p86_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p86_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p86_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p86_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p86_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p86_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p83_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p83_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p83_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p83_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p83_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p83_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p83_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p83_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p83_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p83_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p83_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p83_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p83_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p83_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p828_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p828_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p828_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p828_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p828_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p828_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p828_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p828_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p828_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p828_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p828_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p828_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p828_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p828_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p828_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p828_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p828_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p828_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p828_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p828_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p828_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p828_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p828_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p828_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p828_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p828_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p828_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p828_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p80_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static int test_mmap_mmap_p80_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p80_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p80_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p7c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p7c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_p7c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p7c_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p7c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_2_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p7c_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_p7c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_3_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p7c_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p7c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p7c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_p7c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p7c_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p7c_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p7c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_p7c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_5_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p7c_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p7c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p7c_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_p7c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p7c_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p7c_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p7c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_p7c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_7_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p7c_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p7c_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p7c_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_p7c_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p7c_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p7c_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p7c_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p7c_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_p7c_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p7c_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p7c_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p7c_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_p7c_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_10_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p7c_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p7c_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_p7c_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_11_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p7c_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_p7c_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p7c_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_p7c_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p7c_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p7c_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_p7c_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p7c_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_p7c_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p7c_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p7c_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_p7c_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_p7c_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_14_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p7c_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_p7c_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_p7c_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_15_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_16_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p7c_16_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_p7c_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p7c_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_p7c_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p7c_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_17_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p7c_17_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_p7c_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_p7c_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_17_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_18_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p7c_18_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_p7c_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p7c_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_p7c_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p7c_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p7c_19_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p7c_19_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_2_1
// static void setup_mmap_mmap_p7c_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p7c_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_p7c_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p7c_19_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p7c_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p770_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p770_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_1_proc0
// static void setup_mmap_mmap_p770_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_p770_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p770_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_9_proc0
// static void setup_mmap_mmap_p770_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_p770_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p770_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p770_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_1_proc0
// static void setup_mmap_mmap_p770_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p770_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p770_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_3_proc0
// static void setup_mmap_mmap_p770_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_2_proc0
// static void setup_mmap_mmap_p770_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_5_proc0
// static void setup_mmap_mmap_p770_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_4_proc0
// static void setup_mmap_mmap_p770_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_12_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_12_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_4_proc0
// static void setup_mmap_mmap_p770_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_13_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_13_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_p770_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_14_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_14_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_14_proc0
// static void setup_mmap_mmap_p770_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_15_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_15_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_16_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_16_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_3_proc0
// static void setup_mmap_mmap_p770_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_16_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_16_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_17_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_17_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_45_proc0
// static void setup_mmap_mmap_p770_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_17_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_17_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_18_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_18_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mmap_p770_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_18_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_18_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_19_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_19_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_3_proc0
// static void setup_mmap_mmap_p770_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_19_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_19_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_20_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_20_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_18_proc0
// static void setup_mmap_mmap_p770_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_20_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_20_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_21_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_21_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_21_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_p770_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_21_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_21_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_22_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_22_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_22_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_p770_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_22_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_22_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_23_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_23_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_23_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_p770_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_23_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_23_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_24_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_24_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_41_proc0
// static void setup_mmap_mmap_p770_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_24_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_24_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_25_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_25_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_25_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_p770_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_25_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_25_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_26_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_26_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_42_proc0
// static void setup_mmap_mmap_p770_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_26_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_26_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_27_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_27_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_27_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_p770_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_27_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_27_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_28_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_28_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_28_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_43_proc0
// static void setup_mmap_mmap_p770_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_28_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_28_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_29_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_29_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_29_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_p770_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_29_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_29_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_30_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_30_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_22_proc0
// static void setup_mmap_mmap_p770_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_30_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_30_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_31_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_31_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_21_proc0
// static void setup_mmap_mmap_p770_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_31_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_31_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_32_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_32_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_23_proc0
// static void setup_mmap_mmap_p770_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_32_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_32_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_33_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_33_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_41_proc0
// static void setup_mmap_mmap_p770_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_33_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_33_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_34_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_34_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_34_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_25_proc0
// static void setup_mmap_mmap_p770_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_34_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_34_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_35_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_35_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_42_proc0
// static void setup_mmap_mmap_p770_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_35_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_35_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_36_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_36_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_27_proc0
// static void setup_mmap_mmap_p770_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_36_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_36_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_37_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_37_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_43_proc0
// static void setup_mmap_mmap_p770_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_37_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_37_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_38_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_38_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_29_proc0
// static void setup_mmap_mmap_p770_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_38_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_38_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_39_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_39_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_39_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_p770_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_39_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_39_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_40_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_40_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_40_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_p770_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_40_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_40_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_41_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_41_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_41_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_p770_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_41_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_41_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_42_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_42_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_42_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_40_proc0
// static void setup_mmap_mmap_p770_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_42_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_42_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_43_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_43_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_43_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_39_proc0
// static void setup_mmap_mmap_p770_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_43_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_43_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_44_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_44_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_44_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_41_proc0
// static void setup_mmap_mmap_p770_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_44_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_44_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_45_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_45_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_47_proc0
// static void setup_mmap_mmap_p770_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_45_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_45_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_46_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_46_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_46_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_p770_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_46_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_46_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_47_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_47_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_46_proc0
// static void setup_mmap_mmap_p770_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_47_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_47_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_48_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_48_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_48_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mmap_p770_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_48_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_48_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_49_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_49_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_49_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_48_proc0
// static void setup_mmap_mmap_p770_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_49_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_49_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_50_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p770_50_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
static void setup_mmap_mmap_p770_50_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_p770_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_50_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_50_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_51_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_51_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_51_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pbb0_46_proc0
// static void setup_mmap_mmap_p770_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_51_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_51_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_52_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_52_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_52_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_48_proc0
// static void setup_mmap_mmap_p770_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_52_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_52_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_53_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_53_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_53_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pbb0_47_proc0
// static void setup_mmap_mmap_p770_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_53_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_53_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_54_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_54_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_54_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_46_proc0
// static void setup_mmap_mmap_p770_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_54_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_54_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_55_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_55_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_55_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pbb0_48_proc0
// static void setup_mmap_mmap_p770_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_55_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_55_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p770_56_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p770_56_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p770_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p770_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_50_proc0
// static void setup_mmap_mmap_p770_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p770_56_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p770_56_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p750_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p750_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p750_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p750_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p750_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p750_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_3_proc0
// static void setup_mmap_mmap_p750_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_3_proc0
// static void setup_mmap_mmap_p750_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_3_proc0
// static void setup_mmap_mmap_p750_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_3_proc0
// static void setup_mmap_mmap_p750_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p750_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p750_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_11_proc0
// static void setup_mmap_mmap_p750_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p750_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p750_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_13_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_13_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p750_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_11_proc0
// static void setup_mmap_mmap_p750_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_15_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_15_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_16_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_16_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p750_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_17_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_17_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p750_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_17_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_17_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_18_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_18_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p750_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_19_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_19_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p750_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_19_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_19_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_20_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_20_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p750_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_21_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_21_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_11_proc0
// static void setup_mmap_mmap_p750_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_21_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_21_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_22_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_22_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p750_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_23_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_23_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_11_proc0
// static void setup_mmap_mmap_p750_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_23_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_23_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_24_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_24_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p750_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_p750_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_25_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_25_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_47_proc0
// static void setup_mmap_mmap_p750_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_25_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_25_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_26_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_26_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_50_proc0
// static void setup_mmap_mmap_p750_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_26_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_26_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_27_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_27_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p750_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_p750_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_27_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_28_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_28_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_28_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_47_proc0
// static void setup_mmap_mmap_p750_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_28_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_29_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_29_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_50_proc0
// static void setup_mmap_mmap_p750_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_29_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_29_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_30_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_30_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p750_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_p750_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_31_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_31_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_47_proc0
// static void setup_mmap_mmap_p750_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_31_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_31_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_32_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_32_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p750_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_p750_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_32_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_32_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_33_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_33_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_47_proc0
// static void setup_mmap_mmap_p750_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_33_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_33_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_34_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_34_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_34_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_50_proc0
// static void setup_mmap_mmap_p750_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_34_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_34_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_35_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_35_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_50_proc0
// static void setup_mmap_mmap_p750_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_35_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_35_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_36_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_36_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p750_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_p750_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_37_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_37_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_13_proc0
// static void setup_mmap_mmap_p750_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_38_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_38_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p750_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_p750_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_39_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_39_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_49_proc0
// static void setup_mmap_mmap_p750_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_40_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_40_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_40_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_14_proc0
// static void setup_mmap_mmap_p750_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_40_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_40_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_41_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_41_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_41_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_51_proc0
// static void setup_mmap_mmap_p750_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_41_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_41_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_42_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_42_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p750_42_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_p750_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_42_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_42_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_43_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_43_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_43_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_13_proc0
// static void setup_mmap_mmap_p750_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_43_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_43_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_44_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_44_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p750_44_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_p750_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_44_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_44_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_45_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_45_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_49_proc0
// static void setup_mmap_mmap_p750_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_45_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_45_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_46_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_46_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_46_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_14_proc0
// static void setup_mmap_mmap_p750_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_46_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_46_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_47_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p750_47_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_51_proc0
// static void setup_mmap_mmap_p750_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_47_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_47_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_48_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_48_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p750_48_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_p750_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_48_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_48_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_49_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_49_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_49_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_13_proc0
// static void setup_mmap_mmap_p750_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_49_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_49_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_50_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_50_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_50_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_49_proc0
// static void setup_mmap_mmap_p750_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_50_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_50_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_51_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_51_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_51_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_13_proc0
// static void setup_mmap_mmap_p750_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_51_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_51_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_52_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_52_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_52_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_49_proc0
// static void setup_mmap_mmap_p750_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_52_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_52_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_53_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_53_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_53_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_14_proc0
// static void setup_mmap_mmap_p750_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_53_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_53_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_54_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_54_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_54_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_p750_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_54_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_54_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_55_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_55_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p750_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_55_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_51_proc0
// static void setup_mmap_mmap_p750_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_55_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_55_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_56_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_56_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_p750_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_56_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_56_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_57_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_57_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_57_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_14_proc0
// static void setup_mmap_mmap_p750_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_57_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_57_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_58_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_58_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p750_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_p750_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p750_58_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p750_58_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p750_59_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p750_59_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p750_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p750_59_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_51_proc0
// static void setup_mmap_mmap_p750_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p750_59_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p750_59_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p72_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p72_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p72_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p72_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p72_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p72_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p72_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p72_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p72_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_p72_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p72_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p72_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_p72_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p72_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p72_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p72_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_p72_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_4_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p72_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p72_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p72_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p72_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_p72_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_5_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p72_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p72_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p72_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p72_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p72_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p72_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p72_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p72_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p72_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p72_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p72_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p72_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p72_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p72_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p72_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p72_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_10_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p72_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p72_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p72_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_9_proc0
// static void setup_mmap_mmap_p72_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p72_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p72_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf8_32_proc0
// static void setup_mmap_mmap_p72_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p72_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p72_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p72_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf8_31_proc0
// static void setup_mmap_mmap_p72_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_13_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p72_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p72_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p72_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p72_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf8_33_proc0
// static void setup_mmap_mmap_p72_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_14_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p72_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p72_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p72_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p72_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_16_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p72_16_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p72_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p72_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_17_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p72_17_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p72_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p72_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_18_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p72_18_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p72_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p72_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p72_19_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p72_19_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p72_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p72_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p72_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p72_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p72_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p6e_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p6e_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p6e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p6e_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p6e_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p6e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p6e_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p6e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p6e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p6e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p6e_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p6e_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p6e_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p6e_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p6e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p6e_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p6e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p6e_2_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p6e_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p6e_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p6e_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p6e_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p6e_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p6e_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p6e_3_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p6e_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p670_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p670_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p670_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p670_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p670_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p670_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p670_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p670_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p670_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p670_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p670_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_1_proc0
// static void setup_mmap_mmap_p670_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p670_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p670_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p670_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p670_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p670_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p670_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p670_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p670_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p670_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p670_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p670_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p670_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p670_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p670_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p670_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p670_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p670_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p670_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p670_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p670_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p670_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p670_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p670_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p670_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p670_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p670_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p670_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_1_proc0
// static void setup_mmap_mmap_p670_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p670_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p670_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p670_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p670_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p670_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p670_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_3_proc0
// static void setup_mmap_mmap_p670_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p670_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p670_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p670_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p670_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p670_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p670_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_4_proc0
// static void setup_mmap_mmap_p670_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p670_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p670_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p670_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p670_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p670_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p670_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_4_proc0
// static void setup_mmap_mmap_p670_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p670_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p670_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p670_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p670_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p670_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p670_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_3_proc0
// static void setup_mmap_mmap_p670_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p670_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p670_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p658_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p658_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p658_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p658_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p658_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p658_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p658_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p658_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p658_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p658_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p658_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p658_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p658_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p658_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p658_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p658_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p658_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p658_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p658_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p658_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p658_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p658_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p658_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p658_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p658_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p658_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p658_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_p658_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p658_13_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p658_13_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_14_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p658_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p658_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_16_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p658_16_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p658_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_p658_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p658_16_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p658_16_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_17_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_17_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p658_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_18_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_18_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p658_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_19_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_19_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p658_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_20_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_20_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p658_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p658_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p658_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p658_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_21_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_21_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p658_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p658_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_p658_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p658_21_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p658_21_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p658_22_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p658_22_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p658_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p658_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_p658_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p658_22_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p658_22_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p62_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p62_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p62_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p62_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p62_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p62_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_p62_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p62_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p62_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p62_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p62_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p62_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p62_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p62_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p62_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p62_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p62_2_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p62_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p62_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p62_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_p62_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p62_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p62_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p62_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p62_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p5c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p5c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p5c_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p5c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p5c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p5c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p5c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p5c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p5c_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p5c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p570_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p570_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p570_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p570_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p570_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p570_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p570_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p570_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p570_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p570_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p570_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p570_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p570_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p570_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p570_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p570_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p570_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p570_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p570_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p570_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p570_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p570_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p570_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p570_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p570_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p570_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p570_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p570_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p550_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p550_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p550_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p550_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p550_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p550_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p550_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p550_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p550_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p550_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p550_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p550_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p550_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p550_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p52_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p52_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p52_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p52_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p52_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p52_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p52_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p52_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p52_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p52_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p52_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p52_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p52_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p52_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p4e_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p4e_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p4e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p4e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p4e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p4e_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p4e_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p4e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p4e_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p4e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p4e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p4e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p4e_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p4e_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p4e_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p4e_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p4e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p4e_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p4e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p4e_2_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p4e_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p4e_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p4e_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p4e_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p4e_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p4e_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p4e_3_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p4e_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p470_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p470_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p470_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p470_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p470_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p470_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p470_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p470_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p470_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p470_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p470_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p470_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p470_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p470_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p470_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p470_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p470_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p470_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p470_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p470_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p470_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p470_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p470_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p470_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p470_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p470_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p470_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p470_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p458_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p458_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p458_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p458_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p458_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p458_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p458_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p458_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p458_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p458_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p458_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p458_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p458_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p458_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p458_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p458_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p458_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p458_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p458_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p458_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p458_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p458_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p458_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p458_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p458_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p458_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p458_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p458_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p42_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static int test_mmap_mmap_p42_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p42_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p42_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p42_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p42_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p42_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p42_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static int test_mmap_mmap_p42_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p42_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p42_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p42_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p42_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p42_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3e_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3e_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p3e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p3e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3e_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p3e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p3e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3e_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3e_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p3e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3e_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p3e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3e_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3e_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3e_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3e_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p3e_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3e_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p3e_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3e_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3e_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3d8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3d8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p3d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_0_proc0
// static void setup_mmap_mmap_p3d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3d8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3d8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p3d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_1_proc0
// static void setup_mmap_mmap_p3d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3d8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3d8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3d8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3d8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p3d8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3d8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_4_proc0
// static void setup_mmap_mmap_p3d8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3d8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3d8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3d8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3d8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p3d8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3d8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_2_proc0
// static void setup_mmap_mmap_p3d8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3d8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3d8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3d8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3d8_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p3d8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3d8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p3d8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3d8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3d8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3d8_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3d8_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p3d8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3d8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p3d8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3d8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3d8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3d0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3d0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p3d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p3d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p3d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3d0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3d0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p3d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p3d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd0_1_proc0
// static void setup_mmap_mmap_p3d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p3c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p3c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p3b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p3b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p3b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p3b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p3b0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p3b0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p3b0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p3b0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p3b0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p3b0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p3b0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_1_proc0
// static void setup_mmap_mmap_p3b0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p3b0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbb0_13_proc0
// static void setup_mmap_mmap_p3b0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p3b0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_0_proc0
// static void setup_mmap_mmap_p3b0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p3b0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_p3b0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p3b0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_1_proc0
// static void setup_mmap_mmap_p3b0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p3b0_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p3b0_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p3b0_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p3b0_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbb0_13_proc0
// static void setup_mmap_mmap_p3b0_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p3b0_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p3b0_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p398_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p398_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p398_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p398_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_0_proc0
// static void setup_mmap_mmap_p398_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p398_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p398_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p398_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p398_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p398_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p398_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_1_proc0
// static void setup_mmap_mmap_p398_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p398_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p398_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p398_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p398_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p398_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p398_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_2_proc0
// static void setup_mmap_mmap_p398_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p398_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p398_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p398_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p398_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p398_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p398_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p398_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p398_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p398_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p398_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p398_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p398_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p398_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd8_4_proc0
// static void setup_mmap_mmap_p398_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p398_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p398_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p398_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p398_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p398_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p398_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p398_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p398_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p398_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p394_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p394_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p394_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p394_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p394_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p394_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p394_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p394_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p394_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p394_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p394_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf4_5_proc0
// static void setup_mmap_mmap_p394_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p394_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p394_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p394_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p394_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p394_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p394_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd0_1_proc0
// static void setup_mmap_mmap_p394_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p394_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p394_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p394_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p394_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p394_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p394_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbd0_1_proc0
// static void setup_mmap_mmap_p394_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p394_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p394_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p394_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p394_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p394_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p394_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_p394_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p394_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p394_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p394_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p394_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p394_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p394_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbb0_13_proc0
// static void setup_mmap_mmap_p394_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p394_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p394_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p394_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p394_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p394_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p394_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pe50_32_proc0
// static void setup_mmap_mmap_p394_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p394_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p394_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p394_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p394_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p394_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p394_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pbb0_13_proc0
// static void setup_mmap_mmap_p394_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p394_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p394_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p38_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p38_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p38_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p38_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p36_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p36_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p36_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p36_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p36_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p36_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p36_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p36_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p36_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p358_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p358_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p358_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p358_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p358_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p358_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p358_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p358_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p358_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p358_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p358_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p358_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p358_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p358_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p358_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p358_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p358_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p358_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p358_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p358_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p358_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p358_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p358_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p358_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p358_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p358_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p358_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p358_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p350_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p350_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p350_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p350_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p350_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p350_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p350_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p350_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p350_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p350_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p350_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p350_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p350_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p350_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p34_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p34_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p34_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p34_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p34_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p34_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p34_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p34_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p34_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p330_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p330_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p330_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p330_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p330_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p330_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p330_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p330_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p330_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p330_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p330_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p330_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p330_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p330_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p330_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p330_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p330_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p330_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p330_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p330_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p330_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p330_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p330_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p330_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p330_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p330_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p330_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p330_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p318_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p318_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p318_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p318_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p318_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p318_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p318_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p318_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p318_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p318_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p318_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p318_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p318_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p318_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p318_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p318_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p318_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p318_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p318_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p318_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p318_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p318_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p318_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p318_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p318_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p318_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p318_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p318_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p314_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p314_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p314_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p314_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p314_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p314_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p314_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p314_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p314_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p314_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p314_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p314_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p314_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p314_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p314_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p314_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p314_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p314_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p314_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p314_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p314_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p314_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p314_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p314_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p314_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p314_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p314_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p314_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p314_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p314_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p314_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p314_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p314_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p314_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p314_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p314_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p314_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p314_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p314_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p314_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p314_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p314_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p314_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p314_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p314_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p314_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p314_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p314_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p314_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p314_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p314_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p314_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p314_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p314_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p314_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p314_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p30_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static int test_mmap_mmap_p30_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p2f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p2f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
static int test_mmap_mmap_p2f0_2_1(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static void setup_mmap_mmap_p2f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p2f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p2f0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p2f0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_4_proc0
// static void setup_mmap_mmap_p2f0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_4_proc0
// static void setup_mmap_mmap_p2f0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_4_proc0
// static void setup_mmap_mmap_p2f0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_4_proc0
// static void setup_mmap_mmap_p2f0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p2f0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p2f0_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_8_proc0
// static void setup_mmap_mmap_p2f0_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p2f0_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p2f0_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_13_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_13_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p2f0_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_8_proc0
// static void setup_mmap_mmap_p2f0_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_15_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_15_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_16_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_16_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p2f0_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_17_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_17_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p2f0_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_17_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_17_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_18_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_18_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p2f0_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_19_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_19_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p2f0_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_19_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_19_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_20_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_20_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p2f0_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_21_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_21_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_8_proc0
// static void setup_mmap_mmap_p2f0_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_21_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_21_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_22_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_22_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p2f0_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_23_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_23_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_8_proc0
// static void setup_mmap_mmap_p2f0_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_23_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_23_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_24_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_24_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2f0_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_25_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_25_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p2f0_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_25_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_25_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_26_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_26_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_p2f0_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_26_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_27_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_27_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_75_proc0
// static void setup_mmap_mmap_p2f0_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_27_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_28_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_28_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_p2f0_28_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_p2f0_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_28_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_28_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_29_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_29_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p2f0_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_29_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_29_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_30_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_30_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2f0_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_31_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_31_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p2f0_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_31_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_31_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_32_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_32_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_p2f0_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_32_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_32_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_33_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_33_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_75_proc0
// static void setup_mmap_mmap_p2f0_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_33_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_33_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_34_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_34_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_34_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2f0_28_proc0
// static void setup_mmap_mmap_p2f0_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_34_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_34_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_35_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_35_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p2f0_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_35_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_36_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_36_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2f0_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_37_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_37_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_75_proc0
// static void setup_mmap_mmap_p2f0_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_38_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_38_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2f0_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_39_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_39_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_75_proc0
// static void setup_mmap_mmap_p2f0_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_40_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_40_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_40_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p2f0_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_40_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_40_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_41_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_41_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_41_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p2f0_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_41_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_41_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_42_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_42_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_42_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p2f0_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_42_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_42_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_43_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_43_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_43_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_p2f0_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_43_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_43_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_44_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_44_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_44_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2f0_28_proc0
// static void setup_mmap_mmap_p2f0_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_44_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_44_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_45_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_45_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_p2f0_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_45_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_45_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_46_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_46_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_46_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2f0_28_proc0
// static void setup_mmap_mmap_p2f0_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_46_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_46_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_47_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_47_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_p2f0_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_47_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_47_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_48_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_48_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_48_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_21_proc0
// static void setup_mmap_mmap_p2f0_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_48_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_48_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_49_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_49_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_49_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_197_proc0
// static void setup_mmap_mmap_p2f0_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_49_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_49_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_50_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_50_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_50_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_26_proc0
// static void setup_mmap_mmap_p2f0_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_50_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_50_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_51_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_51_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_p2f0_51_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_p2f0_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_51_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_51_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_52_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_52_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_52_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_p2f0_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_52_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_52_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_53_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_53_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_53_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_21_proc0
// static void setup_mmap_mmap_p2f0_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_53_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_53_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_54_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_54_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_54_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_197_proc0
// static void setup_mmap_mmap_p2f0_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_54_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_54_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_55_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_55_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_55_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_26_proc0
// static void setup_mmap_mmap_p2f0_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_55_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_55_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_56_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_56_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2f0_51_proc0
// static void setup_mmap_mmap_p2f0_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_56_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_56_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_57_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_57_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_57_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_p2f0_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_57_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_57_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_58_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_58_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_21_proc0
// static void setup_mmap_mmap_p2f0_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_58_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_58_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_59_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_59_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_59_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_197_proc0
// static void setup_mmap_mmap_p2f0_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_59_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_59_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_60_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_60_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_60_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_60_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_p2f0_60_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_60_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_60_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_61_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_61_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_61_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_61_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_21_proc0
// static void setup_mmap_mmap_p2f0_61_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_61_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_61_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_62_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_62_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_62_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_62_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_197_proc0
// static void setup_mmap_mmap_p2f0_62_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_62_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_62_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_63_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_63_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_63_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_63_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_26_proc0
// static void setup_mmap_mmap_p2f0_63_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_63_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_63_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_64_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_64_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_64_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_64_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2f0_51_proc0
// static void setup_mmap_mmap_p2f0_64_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_64_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_64_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_65_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_65_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_65_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_65_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_26_proc0
// static void setup_mmap_mmap_p2f0_65_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_65_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_65_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_66_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_66_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_66_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_66_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2f0_51_proc0
// static void setup_mmap_mmap_p2f0_66_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_66_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_66_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_67_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_67_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_67_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_67_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_p2f0_67_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_67_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_67_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_68_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_68_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_68_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_68_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_47_proc0
// static void setup_mmap_mmap_p2f0_68_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_68_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_68_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_69_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_69_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_69_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_69_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p2f0_69_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_69_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_69_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_70_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_70_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_70_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_70_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_p2f0_70_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_70_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_70_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_71_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_71_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_71_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_71_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_49_proc0
// static void setup_mmap_mmap_p2f0_71_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_71_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_71_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_72_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_72_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_72_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_72_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p2f0_72_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_72_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_72_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_73_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_73_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_73_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_73_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_57_proc0
// static void setup_mmap_mmap_p2f0_73_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_73_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_73_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_74_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_74_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_74_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_74_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_25_proc0
// static void setup_mmap_mmap_p2f0_74_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_74_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_74_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_75_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_75_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_75_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_75_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_59_proc0
// static void setup_mmap_mmap_p2f0_75_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_75_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_75_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_76_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_76_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_76_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_76_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_29_proc0
// static void setup_mmap_mmap_p2f0_76_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_76_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_76_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_77_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_77_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_77_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_77_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_p2f0_77_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_77_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_77_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_78_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_78_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_78_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_78_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_47_proc0
// static void setup_mmap_mmap_p2f0_78_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_78_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_78_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_79_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_79_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_79_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_79_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p2f0_79_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_79_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_79_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_80_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_80_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_80_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_80_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_p2f0_80_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_80_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_80_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_81_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_81_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_81_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_81_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_49_proc0
// static void setup_mmap_mmap_p2f0_81_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_81_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_81_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_82_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_82_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_82_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_82_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p2f0_82_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_82_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_82_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_83_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_83_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_83_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_83_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_57_proc0
// static void setup_mmap_mmap_p2f0_83_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_83_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_83_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_84_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_84_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_84_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_84_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_25_proc0
// static void setup_mmap_mmap_p2f0_84_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_84_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_84_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_85_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_85_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_85_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_85_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_59_proc0
// static void setup_mmap_mmap_p2f0_85_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_85_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_85_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_86_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_86_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_86_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_86_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_29_proc0
// static void setup_mmap_mmap_p2f0_86_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_86_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_86_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_87_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_87_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_87_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_87_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_p2f0_87_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_87_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_87_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_88_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_88_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_88_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_88_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_47_proc0
// static void setup_mmap_mmap_p2f0_88_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_88_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_88_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_89_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_89_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_89_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_89_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p2f0_89_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_89_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_89_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_90_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_90_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_90_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_90_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_p2f0_90_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_90_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_90_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_91_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_91_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_91_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_91_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_49_proc0
// static void setup_mmap_mmap_p2f0_91_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_91_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_91_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_92_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_92_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_92_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_92_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p2f0_92_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_92_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_92_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_93_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_93_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_93_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_93_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_57_proc0
// static void setup_mmap_mmap_p2f0_93_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_93_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_93_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_94_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_94_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_94_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_94_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_25_proc0
// static void setup_mmap_mmap_p2f0_94_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_94_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_94_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_95_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_95_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_95_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_95_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_59_proc0
// static void setup_mmap_mmap_p2f0_95_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_95_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_95_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_96_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_96_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_96_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_96_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_29_proc0
// static void setup_mmap_mmap_p2f0_96_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_96_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_96_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_97_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_97_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_97_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_97_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_p2f0_97_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_97_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_97_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_98_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_98_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_98_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_98_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_47_proc0
// static void setup_mmap_mmap_p2f0_98_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_98_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_98_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_99_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_99_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_99_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_99_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p2f0_99_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_99_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_99_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_100_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_100_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_100_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2f0_100_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_p2f0_100_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_100_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_100_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_101_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_101_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_101_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_101_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_49_proc0
// static void setup_mmap_mmap_p2f0_101_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_101_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_101_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_102_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_102_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_102_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_102_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p2f0_102_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_102_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_102_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_103_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_103_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_103_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_103_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_57_proc0
// static void setup_mmap_mmap_p2f0_103_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_103_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_103_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_104_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_104_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_104_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_104_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_25_proc0
// static void setup_mmap_mmap_p2f0_104_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_104_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_104_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_105_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_105_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_105_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_105_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_59_proc0
// static void setup_mmap_mmap_p2f0_105_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_105_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_105_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_106_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_106_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_106_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_106_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_29_proc0
// static void setup_mmap_mmap_p2f0_106_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_106_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_106_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_107_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_107_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_107_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_107_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p2f0_107_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_107_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_107_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_108_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_108_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_108_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_108_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p2f0_108_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_108_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_108_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_109_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_109_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_109_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_109_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_42_proc0
// static void setup_mmap_mmap_p2f0_109_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_109_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_109_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_110_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_110_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_110_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_110_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_5_proc0
// static void setup_mmap_mmap_p2f0_110_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_110_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_110_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_111_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_111_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_111_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_111_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_27_proc0
// static void setup_mmap_mmap_p2f0_111_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_111_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_111_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_112_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_112_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_112_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_112_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p2f0_112_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_112_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_112_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_113_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_113_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_113_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_113_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p2f0_113_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_113_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_113_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_114_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_114_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_114_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_114_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_42_proc0
// static void setup_mmap_mmap_p2f0_114_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_114_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_114_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_115_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_115_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_115_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_115_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_5_proc0
// static void setup_mmap_mmap_p2f0_115_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_115_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_115_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_116_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2f0_116_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_116_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_116_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_27_proc0
// static void setup_mmap_mmap_p2f0_116_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_116_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_116_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_117_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_117_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_117_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_117_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p2f0_117_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_117_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_117_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_118_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_118_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_118_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_118_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p2f0_118_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_118_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_118_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_119_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_119_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_119_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_119_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_42_proc0
// static void setup_mmap_mmap_p2f0_119_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_119_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_119_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_120_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_120_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_120_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_120_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_5_proc0
// static void setup_mmap_mmap_p2f0_120_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_120_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_120_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_121_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_121_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p2f0_121_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_121_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_27_proc0
// static void setup_mmap_mmap_p2f0_121_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_121_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_121_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_122_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_122_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_122_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_122_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p2f0_122_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_122_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_122_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_123_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_123_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_123_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_123_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p2f0_123_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_123_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_123_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_124_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_124_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_124_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2f0_124_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pe50_42_proc0
// static void setup_mmap_mmap_p2f0_124_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2f0_124_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2f0_124_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_125_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_125_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_125_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_125_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_5_proc0
// static void setup_mmap_mmap_p2f0_125_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_125_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_125_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2f0_126_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2f0_126_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_p2f0_2_1
// static void setup_mmap_mmap_p2f0_126_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2f0_126_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_27_proc0
// static void setup_mmap_mmap_p2f0_126_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2f0_126_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2f0_126_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p2dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_8_proc0
// static void setup_mmap_mmap_p2dc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pad8_1_proc0
// static void setup_mmap_mmap_p2dc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_p2dc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_p2dc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p2dc_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pad8_1_proc0
// static void setup_mmap_mmap_p2dc_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_8_proc0
// static void setup_mmap_mmap_p2dc_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2dc_3_proc0
// static void setup_mmap_mmap_p2dc_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p2dc_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p2dc_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_57_proc0
// static void setup_mmap_mmap_p2dc_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_26_proc0
// static void setup_mmap_mmap_p2dc_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_59_proc0
// static void setup_mmap_mmap_p2dc_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_12_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_12_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2f0_28_proc0
// static void setup_mmap_mmap_p2dc_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_13_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_13_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_5_proc0
// static void setup_mmap_mmap_p2dc_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_14_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_14_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2f0_51_proc0
// static void setup_mmap_mmap_p2dc_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_15_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_15_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_16_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_16_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_27_proc0
// static void setup_mmap_mmap_p2dc_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_16_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_16_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_17_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_17_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_25_proc0
// static void setup_mmap_mmap_p2dc_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_17_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_17_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_18_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_18_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_29_proc0
// static void setup_mmap_mmap_p2dc_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_18_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_18_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_19_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_19_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2f0_28_proc0
// static void setup_mmap_mmap_p2dc_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_19_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_19_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_20_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_20_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_5_proc0
// static void setup_mmap_mmap_p2dc_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_20_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_20_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_21_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_21_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_26_proc0
// static void setup_mmap_mmap_p2dc_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_21_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_21_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_22_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_22_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2f0_51_proc0
// static void setup_mmap_mmap_p2dc_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_22_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_22_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_23_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_23_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_27_proc0
// static void setup_mmap_mmap_p2dc_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_23_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_23_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_24_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_24_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_57_proc0
// static void setup_mmap_mmap_p2dc_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_24_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_24_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_25_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_25_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_25_proc0
// static void setup_mmap_mmap_p2dc_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_25_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_25_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_26_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_26_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_59_proc0
// static void setup_mmap_mmap_p2dc_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_26_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_26_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_27_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_27_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_29_proc0
// static void setup_mmap_mmap_p2dc_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_27_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_27_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_28_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_28_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_28_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_3_proc0
// static void setup_mmap_mmap_p2dc_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_28_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_28_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_29_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_29_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_p2dc_29_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mmap_mmap_p2dc_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_29_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_29_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_30_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_30_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_18_proc0
// static void setup_mmap_mmap_p2dc_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_30_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_30_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_31_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_31_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_p2dc_31_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_p2dc_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_31_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_31_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_32_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_32_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_p2dc_32_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mmap_mmap_p2dc_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_32_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_32_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_33_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_33_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_48_proc0
// static void setup_mmap_mmap_p2dc_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_33_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_33_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_34_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_34_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_p2dc_34_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mmap_p2dc_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_34_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_34_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_35_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_35_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_46_proc0
// static void setup_mmap_mmap_p2dc_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_35_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_35_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_36_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_36_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
static void setup_mmap_mmap_p2dc_36_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mmap_p2dc_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_36_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_36_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_37_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2dc_37_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_50_proc0
// static void setup_mmap_mmap_p2dc_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_37_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_37_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_38_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_38_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_3_proc0
// static void setup_mmap_mmap_p2dc_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_38_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_38_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_39_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_39_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2dc_29_proc0
// static void setup_mmap_mmap_p2dc_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_39_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_39_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_40_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_40_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_40_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_18_proc0
// static void setup_mmap_mmap_p2dc_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_40_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_40_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_41_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_41_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_41_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p2dc_34_proc0
// static void setup_mmap_mmap_p2dc_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_41_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_41_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_42_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_42_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_42_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_p770_46_proc0
// static void setup_mmap_mmap_p2dc_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_42_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_42_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_43_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_43_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_43_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2dc_31_proc0
// static void setup_mmap_mmap_p2dc_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_43_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_43_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_44_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_44_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_44_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_p2dc_32_proc0
// static void setup_mmap_mmap_p2dc_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_44_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_44_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_45_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_45_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_p770_48_proc0
// static void setup_mmap_mmap_p2dc_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_45_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_45_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_46_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_46_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_46_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p2dc_36_proc0
// static void setup_mmap_mmap_p2dc_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_46_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_46_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2dc_47_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2dc_47_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p2dc_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2dc_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_p770_50_proc0
// static void setup_mmap_mmap_p2dc_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2dc_47_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2dc_47_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_p2d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_p2d4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_p2d4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_p2d4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_11_proc0
// static void setup_mmap_mmap_p2d4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_11_proc0
// static void setup_mmap_mmap_p2d4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_5_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_11_proc0
// static void setup_mmap_mmap_p2d4_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_6_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_11_proc0
// static void setup_mmap_mmap_p2d4_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_7_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p2d4_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p2d4_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p2d4_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p2d4_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p2d4_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p2d4_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p2d4_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pf4_9_proc0
// static void setup_mmap_mmap_p2d4_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_16_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_16_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p2d4_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2d4_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_17_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_17_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p2d4_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2d4_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_18_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_18_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p2d4_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p2d4_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_19_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_19_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p2d4_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p2d4_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_20_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_20_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_5_proc0
// static void setup_mmap_mmap_p2d4_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_20_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_21_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_21_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p2d4_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_22_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_22_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_p2d4_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2d4_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_23_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_23_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_12_proc0
// static void setup_mmap_mmap_p2d4_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_23_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_24_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_24_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_p2d4_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_25_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_25_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_p2d4_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p2d4_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_25_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_25_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_26_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_26_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_5_proc0
// static void setup_mmap_mmap_p2d4_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_26_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_26_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_27_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_27_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p2d4_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_27_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_28_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_28_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_p2d4_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_28_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2d4_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_28_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_29_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_29_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_12_proc0
// static void setup_mmap_mmap_p2d4_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_29_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_29_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_30_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_30_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_41_proc0
// static void setup_mmap_mmap_p2d4_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_31_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_31_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_p2d4_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p2d4_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_31_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_31_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_32_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_32_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_p2d4_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_32_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_32_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_33_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_33_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_262_proc0
// static void setup_mmap_mmap_p2d4_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_33_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_33_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_34_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_34_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_34_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_p2d4_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_34_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_34_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_35_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_35_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p2d4_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p2d4_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_35_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_36_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_36_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_93_proc0
// static void setup_mmap_mmap_p2d4_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_36_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_37_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_37_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_p2d4_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_38_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_38_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p2d4_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p2d4_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_39_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_39_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_p2d4_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_39_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_40_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_40_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_40_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_p2d4_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_40_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_40_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_41_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_41_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p2d4_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_41_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p2d4_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_41_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_41_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_42_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_42_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_42_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_93_proc0
// static void setup_mmap_mmap_p2d4_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_42_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_42_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_43_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_43_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_43_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_94_proc0
// static void setup_mmap_mmap_p2d4_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_43_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_43_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_44_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_44_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
static void setup_mmap_mmap_p2d4_44_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i1", 0x0);
}
// static void setup_mmap_mmap_p2d4_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_44_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_44_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_45_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_45_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_p2d4_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_45_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_45_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_46_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_46_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_46_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_47_proc0
// static void setup_mmap_mmap_p2d4_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_46_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_46_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_47_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_47_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_p2d4_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_47_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_47_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_48_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_48_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_p2d4_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_48_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p2d4_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_48_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_48_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_49_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_49_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_49_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_p2d4_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_49_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_49_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_50_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_50_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_50_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_p2d4_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_50_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_50_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_51_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_51_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_51_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_262_proc0
// static void setup_mmap_mmap_p2d4_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_51_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_51_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_52_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_52_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_52_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_p2d4_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_52_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_52_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_53_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_53_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_p2d4_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_53_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p2d4_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_53_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_53_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_54_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_54_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_54_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_p2d4_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_54_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_54_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_55_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_55_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_55_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_p2d4_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_55_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_55_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_56_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_56_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_268_proc0
// static void setup_mmap_mmap_p2d4_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_56_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_56_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_57_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_57_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_57_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_p2d4_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_57_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_57_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_58_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2d4_58_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_p2d4_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p2d4_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_58_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_58_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_59_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_59_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_59_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_p2d4_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_59_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_59_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_60_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_60_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_60_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_60_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_262_proc0
// static void setup_mmap_mmap_p2d4_60_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_60_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_60_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_61_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_61_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_61_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_61_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_p2d4_61_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_61_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_61_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_62_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_62_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p2d4_62_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_62_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p2d4_62_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_62_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_62_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_63_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_63_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_63_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_63_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_93_proc0
// static void setup_mmap_mmap_p2d4_63_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_63_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_63_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_64_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_64_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_64_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_64_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_p2d4_64_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_64_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_64_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_65_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_65_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p2d4_65_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_65_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p2d4_65_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_65_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_65_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_66_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_66_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_66_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_66_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_p2d4_66_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_66_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_66_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_67_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_67_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p2d4_67_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_67_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_p2d4_67_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_67_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_67_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_68_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_68_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p2d4_68_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_68_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p2d4_68_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_68_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_68_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_69_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_69_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_69_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_69_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_93_proc0
// static void setup_mmap_mmap_p2d4_69_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_69_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_69_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_70_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_70_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_70_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_70_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_94_proc0
// static void setup_mmap_mmap_p2d4_70_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_70_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_70_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_71_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_71_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_71_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_71_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i1", 0x0);
// }
// ^ See setup_mmap_mmap_p2d4_44_proc0
// static void setup_mmap_mmap_p2d4_71_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_71_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_71_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_72_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_72_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_72_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_72_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_15_proc0
// static void setup_mmap_mmap_p2d4_72_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_72_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_72_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_73_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_73_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_73_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_73_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pe50_47_proc0
// static void setup_mmap_mmap_p2d4_73_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_73_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_73_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_74_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_74_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_74_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_74_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pf4_12_proc0
// static void setup_mmap_mmap_p2d4_74_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_74_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_74_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_75_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_75_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_p2d4_75_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_75_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p2d4_75_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_75_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_75_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_76_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_76_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_76_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_76_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_261_proc0
// static void setup_mmap_mmap_p2d4_76_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_76_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_76_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_77_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_77_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_77_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_77_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pe50_17_proc0
// static void setup_mmap_mmap_p2d4_77_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_77_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_77_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_78_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_78_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_78_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_78_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_262_proc0
// static void setup_mmap_mmap_p2d4_78_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_78_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_78_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_79_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_79_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_79_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_79_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pf4_46_proc0
// static void setup_mmap_mmap_p2d4_79_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_79_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_79_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_80_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_80_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_p2d4_80_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_80_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p2d4_80_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_80_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_80_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_81_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_81_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_81_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_81_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_267_proc0
// static void setup_mmap_mmap_p2d4_81_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_81_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_81_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_82_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_82_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_82_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_82_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pe50_19_proc0
// static void setup_mmap_mmap_p2d4_82_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_82_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_82_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_83_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_83_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_83_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p2d4_83_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_268_proc0
// static void setup_mmap_mmap_p2d4_83_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_83_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p2d4_83_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_84_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_84_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_42_1
// static void setup_mmap_mmap_p2d4_84_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2d4_84_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pf4_48_proc0
// static void setup_mmap_mmap_p2d4_84_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_84_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_84_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2d4_85_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2d4_85_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pad0_2_0
// static void setup_mmap_mmap_p2d4_85_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2d4_85_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p2d4_85_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2d4_85_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2d4_85_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p2c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_4_proc0
// static void setup_mmap_mmap_p2c8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p2c8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_4_proc0
// static void setup_mmap_mmap_p2c8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2c8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2c8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_75_proc0
// static void setup_mmap_mmap_p2c8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_75_proc0
// static void setup_mmap_mmap_p2c8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p2c8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_47_proc0
// static void setup_mmap_mmap_p2c8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p2c8_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_21_proc0
// static void setup_mmap_mmap_p2c8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_197_proc0
// static void setup_mmap_mmap_p2c8_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p2c8_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_49_proc0
// static void setup_mmap_mmap_p2c8_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2c8_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p2c8_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_16_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_16_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_73_proc0
// static void setup_mmap_mmap_p2c8_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_17_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_17_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pae_21_proc0
// static void setup_mmap_mmap_p2c8_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_18_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_18_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mmap_mmap_pad0_197_proc0
// static void setup_mmap_mmap_p2c8_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_19_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_19_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mmap_pad0_97_proc0
// static void setup_mmap_mmap_p2c8_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_20_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_20_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pae_47_proc0
// static void setup_mmap_mmap_p2c8_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_21_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_21_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mmap_pad0_265_proc0
// static void setup_mmap_mmap_p2c8_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_22_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_22_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pae_49_proc0
// static void setup_mmap_mmap_p2c8_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2c8_23_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2c8_23_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p2c8_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2c8_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mmap_pad0_271_proc0
// static void setup_mmap_mmap_p2c8_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2c8_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2c8_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p2b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p2b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p2b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p2b8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p2b8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p2b8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2b8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p2b8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2b8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2b8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p2b8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2b8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p2b8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2b8_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2b8_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p2b8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_9_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2b8_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p2b8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2b8_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2b8_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_10_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_8_proc0
// static void setup_mmap_mmap_p2b8_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_11_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2b8_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p2b8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2b8_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2b8_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_12_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2b8_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_13_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p2b8_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_14_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2b8_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_15_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2b8_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p2b8_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2b8_15_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2b8_15_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_16_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p2b8_16_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2b8_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p2b8_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2b8_16_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2b8_16_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_17_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_17_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p2b8_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_18_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_18_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2b8_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_19_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_19_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p2b8_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2b8_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p2b8_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2b8_19_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2b8_19_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_20_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_20_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_0_proc0
// static void setup_mmap_mmap_p2b8_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_21_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_21_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p2b8_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p2b8_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p2b8_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p2b8_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p2b8_22_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p2b8_22_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p2b8_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p2b8_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p2b8_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p2b8_22_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p2b8_22_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p29c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p29c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p29c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p29c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p29c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p29c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p29c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p29c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p29c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p29c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p29c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pad8_1_proc0
// static void setup_mmap_mmap_p29c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p29c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p29c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p29c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p29c_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p29c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p29c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pae_5_proc0
// static void setup_mmap_mmap_p29c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p29c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p29c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p29c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p29c_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p29c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p29c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pad8_1_proc0
// static void setup_mmap_mmap_p29c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p29c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p29c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p29c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p29c_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p29c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p29c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p29c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p29c_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p29c_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p29c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p29c_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p29c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p29c_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_2_proc0
// static void setup_mmap_mmap_p29c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p29c_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p29c_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p29c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p29c_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p29c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p29c_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_3_proc0
// static void setup_mmap_mmap_p29c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p29c_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p29c_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p29c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p29c_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p29c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p29c_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_3_proc0
// static void setup_mmap_mmap_p29c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p29c_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p29c_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p296_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p296_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p296_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p296_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_p296_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p296_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p296_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p296_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p296_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p296_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p296_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_p296_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p296_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p296_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p296_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p296_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p296_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p296_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_p296_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p296_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p296_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p296_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p296_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p296_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p296_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_proc0
// static void setup_mmap_mmap_p296_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p296_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p296_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p296_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p296_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p296_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p296_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p296_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p296_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p296_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p296_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p296_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p296_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p296_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p296_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p296_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p296_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p296_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p296_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p296_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p296_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p296_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p296_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p296_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p296_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p296_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p296_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_0_common
// static void setup_mmap_mmap_p296_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pad0_5_proc0
// static void setup_mmap_mmap_p296_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p296_7_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pad0_0_final
// static void setup_mmap_mmap_p296_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p296_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p296_8_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p296_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p296_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p296_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p296_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p296_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p288_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p288_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_p288_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p288_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p288_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p288_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p288_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p288_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p288_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_p288_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p288_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p288_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p288_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p288_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p288_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p288_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_p288_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p288_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p288_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p288_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p288_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p288_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p288_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_p288_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p288_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p288_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p288_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p288_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p270_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p270_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p270_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p270_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p270_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p270_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p270_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p270_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p270_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p270_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p270_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p270_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p270_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p270_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p25c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p25c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p25c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p25c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p25c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p25c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p25c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p25c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p25c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p25c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p25c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p25c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p25c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p25c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p25c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p25c_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p25c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p25c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p25c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p25c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p25c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p25c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p25c_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p25c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p25c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p25c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p25c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p25c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p25c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p25c_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p25c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p25c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p25c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p25c_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p25c_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p25c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p25c_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p25c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p25c_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p25c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p25c_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p25c_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p25c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p25c_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p25c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p25c_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p25c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p25c_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p25c_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p25c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p25c_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p25c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p25c_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p25c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p25c_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p25c_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p254_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p254_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p254_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p254_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p254_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p254_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p254_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p254_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p254_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p254_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p254_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p254_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p254_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p254_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p254_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p254_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p254_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p254_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p254_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p254_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p254_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p254_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p254_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p254_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p254_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p254_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p254_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p254_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p248_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p248_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p248_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p248_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p248_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p248_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p248_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p248_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p248_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p248_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p248_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p248_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p248_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p248_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p248_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p248_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p248_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p248_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p248_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p248_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p248_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p248_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p248_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p248_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p248_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p248_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p248_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p248_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p238_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p238_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p238_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p238_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p238_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p238_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p238_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p238_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p238_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p238_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p238_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p238_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p238_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p238_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p238_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p238_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p238_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p238_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p238_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p238_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p238_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p238_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p238_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p238_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p238_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p238_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p238_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p238_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p21c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p21c_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p21c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p21c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p21c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p21c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p21c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p21c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p21c_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p21c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p21c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p21c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p21c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p21c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p21c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p21c_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p21c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p21c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p21c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p21c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p21c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p21c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p21c_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p21c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p21c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb50_0_proc1
// static void setup_mmap_mmap_p21c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p21c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p21c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p21c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p21c_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p21c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p21c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p21c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p21c_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p21c_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p21c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p21c_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p21c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p21c_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p21c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p21c_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p21c_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p21c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p21c_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p21c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p21c_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p21c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p21c_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p21c_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p21c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p21c_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p21c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf4_5_common
// static void setup_mmap_mmap_p21c_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pb14_2_proc1
// static void setup_mmap_mmap_p21c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p21c_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p21c_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p216_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p216_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p216_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p216_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p216_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p216_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p216_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p216_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p216_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p216_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p216_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p216_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p216_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p216_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p216_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p216_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p216_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p216_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p216_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p216_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p216_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p216_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p216_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p216_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p216_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p216_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p216_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p216_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p216_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p216_4_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p216_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p216_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p216_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p216_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p216_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p216_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p216_5_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p216_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p216_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p216_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p216_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p216_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p216_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p216_6_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p216_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p216_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p216_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p216_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p216_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p216_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p216_7_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p216_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p216_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p216_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p216_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p216_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p208_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p208_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p208_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p208_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p208_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p208_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p208_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p208_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p208_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p208_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p208_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p208_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p208_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p208_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p208_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static int test_mmap_mmap_p208_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p208_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p208_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p208_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p208_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p208_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p208_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static int test_mmap_mmap_p208_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p208_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p208_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p208_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p208_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p208_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p1c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p1c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p1c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p1c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p1c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p1c_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p1c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p1c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p1c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbe_1_1
// static void setup_mmap_mmap_p1c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p1c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p1c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p1c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p1c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p1b_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p1b_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p1b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p1b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_1_proc0
// static void setup_mmap_mmap_p1b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p1b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p1b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p1b_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p1b_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_1_1
// static void setup_mmap_mmap_p1b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p1b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_4_proc0
// static void setup_mmap_mmap_p1b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p1b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p1b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p1a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p1a_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbd0_0_1
// static void setup_mmap_mmap_p1a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p1a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p1a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p1a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p1a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p18_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p18_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_1_1
// static void setup_mmap_mmap_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p18_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p18_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p18_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p18_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p18_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p18_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p16_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p16_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p16_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p16_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p16_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p16_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p16_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p16_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p16_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p16_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p16_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p16_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p16_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p16_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p16_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p16_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_1_1
// static void setup_mmap_mmap_p16_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p16_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p16_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p16_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p16_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p16_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p16_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pbb0_2_1
// static void setup_mmap_mmap_p16_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf8_4_common
// static void setup_mmap_mmap_p16_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p16_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p16_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p16_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p13_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p13_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p13_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p13_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_1_proc0
// static void setup_mmap_mmap_p13_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p13_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p13_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p13_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p13_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_1_1
// static void setup_mmap_mmap_p13_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p13_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_4_proc0
// static void setup_mmap_mmap_p13_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p13_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p13_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p128_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p128_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p128_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p128_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p128_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p128_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p128_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p128_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p128_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p128_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p128_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_proc0
// static void setup_mmap_mmap_p128_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p128_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p128_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p128_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p128_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_0_1
// static void setup_mmap_mmap_p128_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p128_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p128_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p128_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p128_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p128_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p128_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 11, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe50_2_1
// static void setup_mmap_mmap_p128_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p128_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pe50_30_proc0
// static void setup_mmap_mmap_p128_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p128_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p128_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p10_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p10_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 11, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_1_1
// static void setup_mmap_mmap_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p10_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p10_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p10_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p10_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p10_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p10_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p0c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p0c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf8_0_0
// static void setup_mmap_mmap_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p0c_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p0c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p0b_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p0b_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p0b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p0b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p0b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p0b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p0b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p0b_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p0b_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf6_0_1
// static void setup_mmap_mmap_p0b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p0b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p0b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p0b_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p0b_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p0a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p0a_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pd4_0_1
// static void setup_mmap_mmap_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p08_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p08_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pf0_0_1
// static void setup_mmap_mmap_p08_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p08_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p08_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p08_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p08_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p06_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p06_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_0_1
// static void setup_mmap_mmap_p06_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p06_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p06_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p06_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p06_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p06_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p06_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pec_2_1
// static void setup_mmap_mmap_p06_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p06_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p06_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p06_1_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p06_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p03_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p03_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p03_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p03_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p03_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc0
// static void setup_mmap_mmap_p03_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p03_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p03_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p03_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe6_0_1
// static void setup_mmap_mmap_p03_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mmap_pf6_0_common
// static void setup_mmap_mmap_p03_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pf6_0_proc1
// static void setup_mmap_mmap_p03_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mmap_pd6_1_proc1
// static void setup_mmap_mmap_p03_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_final
// static void setup_mmap_mmap_p03_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mmap_pf6_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p028_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p028_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p028_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p028_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p028_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p028_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p028_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p028_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p028_1_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p028_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p028_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p028_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pae_1_proc0
// static void setup_mmap_mmap_p028_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p028_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p028_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p028_2_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_0_1
// static void setup_mmap_mmap_p028_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p028_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p028_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p028_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p028_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p028_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p028_3_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pc50_1_1
// static void setup_mmap_mmap_p028_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf4_1_common
// static void setup_mmap_mmap_p028_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p028_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mmap_pf0_1_proc0
// static void setup_mmap_mmap_p028_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mmap_pf8_4_final
// static void setup_mmap_mmap_p028_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal

/*
 * calls: mmap mmap
 */
// static int test_mmap_mmap_p00_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static int test_mmap_mmap_p00_0_1(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mmap_pe0_0_1
// static void setup_mmap_mmap_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_common
// static void setup_mmap_mmap_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mmap_pf8_0_proc1
// static void setup_mmap_mmap_p00_0_final(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal
// static void setup_mmap_mmap_p00_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mmap_pf8_0_procfinal


/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_pf8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_mprotect_pf8_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mmap_mprotect_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mmap_mprotect_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mmap_mprotect_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_mprotect_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_mmap_mprotect_pf8_0_procfinal(void) {
  
}

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
static int test_mmap_mprotect_pf8_2_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_mmap_mprotect_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_1_proc0
// static void setup_mmap_mprotect_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_pf8_4_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_mprotect_pf8_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_1_proc0
// static void setup_mmap_mprotect_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_3_proc0
// static void setup_mmap_mprotect_pf8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_1_proc0
// static void setup_mmap_mprotect_pf8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_3_proc0
// static void setup_mmap_mprotect_pf8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_3_proc0
// static void setup_mmap_mprotect_pf8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
static void setup_mmap_mprotect_pf8_9_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mmap_mprotect_pf8_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pf8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_9_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pf8_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pf8_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_0_proc0
// static void setup_mmap_mprotect_pf8_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_10_proc0
// static void setup_mmap_mprotect_pf8_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_12_proc0
// static void setup_mmap_mprotect_pf8_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_13_proc0
// static void setup_mmap_mprotect_pf8_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pf8_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_20_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pf8_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_11_proc0
// static void setup_mmap_mprotect_pf8_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_18_proc0
// static void setup_mmap_mprotect_pf8_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_19_proc0
// static void setup_mmap_mprotect_pf8_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_20_proc0
// static void setup_mmap_mprotect_pf8_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_25_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_0_proc0
// static void setup_mmap_mprotect_pf8_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_25_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_25_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_26_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_10_proc0
// static void setup_mmap_mprotect_pf8_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_26_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_27_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_11_proc0
// static void setup_mmap_mprotect_pf8_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_27_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_28_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_28_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_12_proc0
// static void setup_mmap_mprotect_pf8_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_28_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_29_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_13_proc0
// static void setup_mmap_mprotect_pf8_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_29_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_29_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_30_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_18_proc0
// static void setup_mmap_mprotect_pf8_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_31_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_19_proc0
// static void setup_mmap_mprotect_pf8_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_31_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_31_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_32_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_20_proc0
// static void setup_mmap_mprotect_pf8_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_32_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_32_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_33_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_33_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_0_proc0
// static void setup_mmap_mprotect_pf8_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_33_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_33_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_34_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_34_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_10_proc0
// static void setup_mmap_mprotect_pf8_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_34_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_34_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_35_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_35_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_11_proc0
// static void setup_mmap_mprotect_pf8_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_35_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_36_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_12_proc0
// static void setup_mmap_mprotect_pf8_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_37_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_13_proc0
// static void setup_mmap_mprotect_pf8_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_38_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_18_proc0
// static void setup_mmap_mprotect_pf8_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_39_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_19_proc0
// static void setup_mmap_mprotect_pf8_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_40_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_40_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_40_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_20_proc0
// static void setup_mmap_mprotect_pf8_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_40_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_40_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_41_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
static int test_mmap_mprotect_pf8_41_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_mmap_mprotect_pf8_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_41_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_41_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_41_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_42_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
static int test_mmap_mprotect_pf8_42_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_mmap_mprotect_pf8_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_42_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_pf8_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_42_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_42_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_43_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_43_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pf8_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_43_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_43_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_43_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_44_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_44_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_pf8_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_44_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_pf8_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_44_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_44_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_45_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_45_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
static void setup_mmap_mprotect_pf8_45_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mprotect_pf8_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_45_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_45_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_46_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_46_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
static void setup_mmap_mprotect_pf8_46_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mprotect_pf8_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_46_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_46_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_47_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_47_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_45_proc0
// static void setup_mmap_mprotect_pf8_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_47_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_47_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_48_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_48_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_48_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_46_proc0
// static void setup_mmap_mprotect_pf8_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_48_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_48_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_49_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_49_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_49_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_45_proc0
// static void setup_mmap_mprotect_pf8_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_49_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_49_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_50_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_50_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_50_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_46_proc0
// static void setup_mmap_mprotect_pf8_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_50_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_50_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_51_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_51_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_51_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_45_proc0
// static void setup_mmap_mprotect_pf8_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_51_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_51_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_52_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_52_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_52_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_46_proc0
// static void setup_mmap_mprotect_pf8_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_52_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_52_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_53_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_53_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
static void setup_mmap_mprotect_pf8_53_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pf8_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_53_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_53_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_54_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_54_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
static void setup_mmap_mprotect_pf8_54_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pf8_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_54_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_54_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_55_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_55_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
static void setup_mmap_mprotect_pf8_55_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pf8_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_55_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_55_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_56_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_56_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_9_proc0
// static void setup_mmap_mprotect_pf8_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_56_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_56_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_57_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_57_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_57_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_57_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_57_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_58_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_58_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_53_proc0
// static void setup_mmap_mprotect_pf8_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_58_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_58_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_59_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_59_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_59_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_54_proc0
// static void setup_mmap_mprotect_pf8_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_59_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_59_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_60_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_60_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_60_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_60_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_60_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_60_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_60_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_61_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_61_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_61_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_61_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_61_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_61_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_61_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_62_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_62_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_62_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_62_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_55_proc0
// static void setup_mmap_mprotect_pf8_62_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_62_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_62_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_63_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_63_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pf8_63_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pf8_63_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pf8_63_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_63_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_63_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_64_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_64_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_64_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_64_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_9_proc0
// static void setup_mmap_mprotect_pf8_64_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_64_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_64_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_65_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_65_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_65_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_65_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_57_proc0
// static void setup_mmap_mprotect_pf8_65_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_65_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_65_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_66_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_66_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_66_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_66_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_53_proc0
// static void setup_mmap_mprotect_pf8_66_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_66_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_66_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_67_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_67_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_67_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_67_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_54_proc0
// static void setup_mmap_mprotect_pf8_67_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_67_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_67_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_68_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_68_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_68_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_68_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_60_proc0
// static void setup_mmap_mprotect_pf8_68_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_68_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_68_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_69_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_69_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_69_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_69_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_61_proc0
// static void setup_mmap_mprotect_pf8_69_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_69_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_69_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_70_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_70_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_70_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_70_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_55_proc0
// static void setup_mmap_mprotect_pf8_70_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_70_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_70_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_71_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_71_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_71_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pf8_71_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_63_proc0
// static void setup_mmap_mprotect_pf8_71_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_71_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pf8_71_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_72_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_72_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_72_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_72_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_9_proc0
// static void setup_mmap_mprotect_pf8_72_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_72_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_72_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_73_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_73_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_73_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_73_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_53_proc0
// static void setup_mmap_mprotect_pf8_73_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_73_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_73_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_74_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_74_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_74_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_74_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_54_proc0
// static void setup_mmap_mprotect_pf8_74_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_74_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_74_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_75_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_75_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pf8_75_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_75_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_55_proc0
// static void setup_mmap_mprotect_pf8_75_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_75_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_75_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_76_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_76_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pf8_76_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
static void setup_mmap_mprotect_pf8_76_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pf8_76_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_76_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_76_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_77_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pf8_77_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pf8_77_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
static void setup_mmap_mprotect_pf8_77_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pf8_77_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_77_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_77_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_78_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_78_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_pf8_78_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_78_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_pf8_78_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_78_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_78_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pf8_79_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_4_0
// static int test_mmap_mprotect_pf8_79_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_pf8_79_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pf8_79_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_pf8_79_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pf8_79_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pf8_79_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
static int test_mmap_mprotect_pe0_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_mmap_mprotect_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pe0_0_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pe0_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pe0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pe0_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pe0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pe0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pe0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pe0_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pe0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pe0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_pe0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pe0_3_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pe0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pe0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pe0_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pe0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pe0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_pe0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pe0_4_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pe0_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pd0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pd0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pd0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_pd0_1_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pd0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pd0_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_pd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pd0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pd0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
// static int test_mmap_mprotect_pd0_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_pd0_3_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pd0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_0
static int test_mmap_mprotect_pc0_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_mmap_mprotect_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pc0_0_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_pbc_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_mprotect_pbc_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
static void setup_mmap_mprotect_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_mprotect_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mmap_mprotect_pbc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_mprotect_pbc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_mprotect_pbc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pbc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pbc_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pbc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pbc_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pbc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pbc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pbc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pbc_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pbc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pbc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pbc_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pbc_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pbc_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pbc_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pbc_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pbc_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pbc_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pbc_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pbc_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pbc_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pbc_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mprotect_pbc_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pbc_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pbc_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pbc_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pbc_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pbc_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pbc_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mprotect_pbc_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pbc_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pbc_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pbc_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pbc_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pbc_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pbc_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mprotect_pbc_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pbc_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pbc_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pbc_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pbc_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pbc_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pbc_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pbc_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pbc_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pbc_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pbc_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pbc_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pbc_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pbc_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mprotect_pbc_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pbc_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pbc_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mprotect_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_mprotect_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb8_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pbc_0_proc0
// static void setup_mmap_mprotect_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pb8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb8_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pbc_2_proc0
// static void setup_mmap_mprotect_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pb8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
static void setup_mmap_mprotect_pb4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pb4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
static void setup_mmap_mprotect_pb4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pb4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb4_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pb4_0_proc1
// static void setup_mmap_mprotect_pb4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb4_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pb4_1_proc1
// static void setup_mmap_mprotect_pb4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb4_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb4_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pb4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
static void setup_mmap_mprotect_pb4_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pb4_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb4_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb4_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb4_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pb4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb4_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_pb4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pb4_4_proc1
// static void setup_mmap_mprotect_pb4_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb4_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb4_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb4_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pb4_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb4_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
static void setup_mmap_mprotect_pb4_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pb4_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb4_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb4_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb4_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pb4_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb4_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_pb4_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pb4_6_proc1
// static void setup_mmap_mprotect_pb4_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb4_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
// static void setup_mmap_mprotect_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pbc_0_0
// static int test_mmap_mprotect_pb0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_pae_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_mprotect_pae_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_1_proc0
// static void setup_mmap_mprotect_pae_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_mprotect_pae_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_mprotect_pae_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_4_proc0
// static void setup_mmap_mprotect_pae_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_3_proc0
// static void setup_mmap_mprotect_pae_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_5_proc0
// static void setup_mmap_mprotect_pae_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pae_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pae_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pae_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pae_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_16_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pae_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_0_proc0
// static void setup_mmap_mprotect_pae_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_18_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_10_proc0
// static void setup_mmap_mprotect_pae_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_19_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_11_proc0
// static void setup_mmap_mprotect_pae_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_12_proc0
// static void setup_mmap_mprotect_pae_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_13_proc0
// static void setup_mmap_mprotect_pae_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_14_proc0
// static void setup_mmap_mprotect_pae_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_23_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_15_proc0
// static void setup_mmap_mprotect_pae_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_16_proc0
// static void setup_mmap_mprotect_pae_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_25_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_25_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_25_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_25_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_26_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_26_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pae_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_26_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_27_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_27_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pae_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_27_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_27_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_28_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_28_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_28_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_29_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_9_proc0
// static void setup_mmap_mprotect_pae_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_29_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_29_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_30_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_25_proc0
// static void setup_mmap_mprotect_pae_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_30_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_31_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_27_proc0
// static void setup_mmap_mprotect_pae_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_31_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_31_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_32_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_28_proc0
// static void setup_mmap_mprotect_pae_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_32_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_32_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_33_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_33_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pae_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_33_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_33_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_34_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_34_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_34_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_34_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_35_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_35_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_35_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_36_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_26_proc0
// static void setup_mmap_mprotect_pae_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_36_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_37_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_33_proc0
// static void setup_mmap_mprotect_pae_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_37_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_38_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_34_proc0
// static void setup_mmap_mprotect_pae_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_38_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_39_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_35_proc0
// static void setup_mmap_mprotect_pae_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_39_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_40_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_40_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pae_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_40_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_40_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_40_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_41_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_41_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pae_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_41_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_pae_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_41_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_41_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_42_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_42_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pae_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_42_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_pae_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_42_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_42_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_43_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pae_43_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pae_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pae_43_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_pae_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_43_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_43_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_pae_44_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_mprotect_pae_44_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_44_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_0_proc0
// static void setup_mmap_mprotect_pae_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_44_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_44_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_45_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_45_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_1_proc0
// static void setup_mmap_mprotect_pae_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_45_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_45_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_46_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_46_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_46_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_4_proc0
// static void setup_mmap_mprotect_pae_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_46_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_46_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_47_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_47_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_3_proc0
// static void setup_mmap_mprotect_pae_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_47_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_47_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_48_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_48_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_48_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_5_proc0
// static void setup_mmap_mprotect_pae_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_48_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_48_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_49_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_49_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_49_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_1_proc0
// static void setup_mmap_mprotect_pae_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_49_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_49_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_50_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_50_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_50_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_3_proc0
// static void setup_mmap_mprotect_pae_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_50_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_50_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_51_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_51_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_51_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_4_proc0
// static void setup_mmap_mprotect_pae_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_51_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_51_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_52_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_52_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_52_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_5_proc0
// static void setup_mmap_mprotect_pae_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_52_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_52_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_53_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_53_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_53_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_9_proc0
// static void setup_mmap_mprotect_pae_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_53_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_53_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_54_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_54_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_54_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_10_proc0
// static void setup_mmap_mprotect_pae_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_54_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_54_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_55_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_55_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_55_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_11_proc0
// static void setup_mmap_mprotect_pae_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_55_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_55_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_56_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_56_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_12_proc0
// static void setup_mmap_mprotect_pae_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_56_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_56_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_57_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_57_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_57_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_13_proc0
// static void setup_mmap_mprotect_pae_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_57_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_57_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_58_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_58_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_14_proc0
// static void setup_mmap_mprotect_pae_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_58_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_58_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_59_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_59_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_59_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_16_proc0
// static void setup_mmap_mprotect_pae_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_59_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_59_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_60_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_60_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_60_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_60_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_15_proc0
// static void setup_mmap_mprotect_pae_60_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_60_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_60_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_61_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_61_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_61_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_61_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_25_proc0
// static void setup_mmap_mprotect_pae_61_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_61_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_61_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_62_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_62_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_62_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_62_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_35_proc0
// static void setup_mmap_mprotect_pae_62_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_62_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_62_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_63_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_63_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_63_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_63_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_28_proc0
// static void setup_mmap_mprotect_pae_63_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_63_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_63_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_64_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_64_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_64_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_64_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_27_proc0
// static void setup_mmap_mprotect_pae_64_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_64_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_64_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_65_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_65_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_65_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_65_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_33_proc0
// static void setup_mmap_mprotect_pae_65_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_65_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_65_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_66_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_66_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_66_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_66_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_34_proc0
// static void setup_mmap_mprotect_pae_66_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_66_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_66_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_67_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_67_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_pae_67_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_67_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_26_proc0
// static void setup_mmap_mprotect_pae_67_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_67_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_67_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_68_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_68_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_68_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_68_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_0_proc0
// static void setup_mmap_mprotect_pae_68_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_68_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_68_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_69_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_69_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_69_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_69_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_9_proc0
// static void setup_mmap_mprotect_pae_69_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_69_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_69_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_70_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_70_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_70_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_70_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_10_proc0
// static void setup_mmap_mprotect_pae_70_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_70_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_70_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_71_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_71_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_71_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_71_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_11_proc0
// static void setup_mmap_mprotect_pae_71_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_71_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_71_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_72_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_72_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_72_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_72_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_12_proc0
// static void setup_mmap_mprotect_pae_72_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_72_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_72_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_73_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_73_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_73_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_73_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_13_proc0
// static void setup_mmap_mprotect_pae_73_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_73_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_73_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_74_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_74_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_74_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_74_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_25_proc0
// static void setup_mmap_mprotect_pae_74_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_74_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_74_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_75_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_75_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_75_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_75_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_28_proc0
// static void setup_mmap_mprotect_pae_75_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_75_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_75_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_76_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_76_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_76_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_76_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 0, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_27_proc0
// static void setup_mmap_mprotect_pae_76_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_76_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_76_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_77_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_77_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_77_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_77_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_14_proc0
// static void setup_mmap_mprotect_pae_77_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_77_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_77_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_78_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_78_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_78_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_78_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_26_proc0
// static void setup_mmap_mprotect_pae_78_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_78_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_78_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_79_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_79_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_79_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_79_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_16_proc0
// static void setup_mmap_mprotect_pae_79_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_79_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_79_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_80_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_80_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_80_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_80_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_15_proc0
// static void setup_mmap_mprotect_pae_80_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_80_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_80_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_81_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_81_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_81_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_81_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_33_proc0
// static void setup_mmap_mprotect_pae_81_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_81_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_81_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_82_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_82_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_82_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_82_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_34_proc0
// static void setup_mmap_mprotect_pae_82_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_82_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_82_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_83_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_83_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_2_1
// static void setup_mmap_mprotect_pae_83_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_83_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345601000, 1, 0);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_35_proc0
// static void setup_mmap_mprotect_pae_83_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_83_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_83_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_84_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_84_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_pae_84_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_84_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_40_proc0
// static void setup_mmap_mprotect_pae_84_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_84_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_84_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_85_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_85_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_pae_85_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_85_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_42_proc0
// static void setup_mmap_mprotect_pae_85_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_85_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_85_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_86_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_86_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_pae_86_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_86_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_41_proc0
// static void setup_mmap_mprotect_pae_86_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_86_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_86_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pae_87_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_44_0
// static int test_mmap_mprotect_pae_87_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_pae_87_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pae_87_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_43_proc0
// static void setup_mmap_mprotect_pae_87_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pae_87_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pae_87_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pa8_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
static void setup_mmap_mprotect_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_mprotect_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pa8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pa8_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_40_proc0
// static void setup_mmap_mprotect_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pa8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pa8_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_42_proc0
// static void setup_mmap_mprotect_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pa8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pa8_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pa8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_41_proc0
// static void setup_mmap_mprotect_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pa8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pa8_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_43_proc0
// static void setup_mmap_mprotect_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pa4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pa4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_pa4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pa4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pa4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pa4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pa4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_pa4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_pa4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pa4_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pa4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pa4_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pa4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pa4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_pa4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_pa4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pa4_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pa4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pa4_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_pa4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pa4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_pa4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_pa4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pa4_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pae_0_0
// static int test_mmap_mprotect_pa0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_p98_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_mprotect_p98_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p98_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p98_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p98_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_1_proc0
// static void setup_mmap_mprotect_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p98_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p98_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p98_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p98_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_3_proc0
// static void setup_mmap_mprotect_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p98_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p98_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p98_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p98_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_45_proc0
// static void setup_mmap_mprotect_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p98_3_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p98_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p98_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p98_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_0_1
// static void setup_mmap_mprotect_p98_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p98_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_46_proc0
// static void setup_mmap_mprotect_p98_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p98_4_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p98_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p90_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p90_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p90_0_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p90_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p90_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p90_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pe0_0_1
// static void setup_mmap_mprotect_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p90_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p88_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p88_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p88_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p88_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p88_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p88_1_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p88_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p88_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p88_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p88_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p88_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p88_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p88_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p88_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p88_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p88_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p88_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p88_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p88_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p88_3_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p88_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p80_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p98_0_0
// static int test_mmap_mprotect_p80_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p80_0_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p80_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_p7c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_mprotect_p7c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p7c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p7c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p7c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p7c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p7c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p7c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_p7c_2_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_mprotect_p7c_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p7c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p7c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p7c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p7c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p7c_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p7c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p7c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p7c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p7c_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p7c_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p7c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p7c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p7c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p7c_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p7c_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p7c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p7c_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p7c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p7c_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p7c_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p7c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p7c_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p7c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p7c_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p7c_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p7c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p7c_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p7c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p7c_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p7c_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p7c_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p7c_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p7c_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_8_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p7c_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p7c_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p7c_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p7c_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p7c_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_9_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p7c_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p7c_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p7c_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p7c_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p7c_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_10_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p7c_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p7c_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p7c_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p7c_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p7c_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_11_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p7c_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p7c_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p7c_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p7c_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p7c_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_12_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p7c_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p7c_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p7c_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p7c_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p7c_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_13_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p7c_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p7c_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p7c_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p7c_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p7c_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_14_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p7c_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p7c_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p7c_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p7c_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p7c_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p7c_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p7c_15_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p7c_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p68_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p68_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p68_0_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p68_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p68_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p68_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p68_1_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p68_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p58_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p58_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p58_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p58_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p58_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p58_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p58_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p58_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p58_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p58_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p58_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p58_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p58_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p58_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p58_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p58_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p58_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p58_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p58_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p58_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p58_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p58_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p58_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p58_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p58_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p58_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p58_4_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p58_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p58_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p58_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p58_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p58_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p58_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p58_5_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p58_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p58_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p58_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p58_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p58_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p58_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p58_6_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p58_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p58_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p58_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p58_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p58_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p58_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p58_7_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p58_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p48_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_0_0
// static int test_mmap_mprotect_p48_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p48_0_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p48_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p48_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p7c_2_0
// static int test_mmap_mprotect_p48_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p48_1_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p48_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_p3c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_mprotect_p3c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pbc_0_proc0
// static void setup_mmap_mprotect_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p3c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p3c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p3c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_p3c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_p3c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p3c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p3c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p3c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p3c_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p3c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_p3c_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_p3c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p3c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p3c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p3c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p3c_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p3c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_p3c_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_p3c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p3c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p3c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p3c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p3c_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p3c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p3c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pbc_2_proc0
// static void setup_mmap_mprotect_p3c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p3c_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p3c_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p3c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p3c_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p3c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_p3c_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_mprotect_p3c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p3c_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p3c_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p3c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p3c_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p3c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_p3c_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_mprotect_p3c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p3c_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p3c_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p3c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p3c_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p3c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
static void setup_mmap_mprotect_p3c_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_mprotect_p3c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p3c_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p3c_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p38_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p38_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
// static void setup_mmap_mprotect_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p38_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p38_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p34_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p34_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
// static void setup_mmap_mprotect_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pb4_0_proc1
// static void setup_mmap_mprotect_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p34_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p34_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p34_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p34_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
// static void setup_mmap_mprotect_p34_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pb4_1_proc1
// static void setup_mmap_mprotect_p34_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p34_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p34_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p34_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p34_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p34_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_p34_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pb4_0_proc1
// static void setup_mmap_mprotect_p34_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p34_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p34_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p34_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p34_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p34_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_p34_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pb4_1_proc1
// static void setup_mmap_mprotect_p34_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p34_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p34_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p34_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p34_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p34_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
// static void setup_mmap_mprotect_p34_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pb4_4_proc1
// static void setup_mmap_mprotect_p34_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p34_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p34_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p34_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p34_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p34_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_p34_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pb4_4_proc1
// static void setup_mmap_mprotect_p34_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p34_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p34_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p34_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p34_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p34_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
// static void setup_mmap_mprotect_p34_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pb4_6_proc1
// static void setup_mmap_mprotect_p34_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p34_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p34_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p34_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p34_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p34_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_p34_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pb4_6_proc1
// static void setup_mmap_mprotect_p34_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p34_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p30_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_0_proc0
// static void setup_mmap_mprotect_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p3c_0_0
// static int test_mmap_mprotect_p30_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_mprotect_pbc_0_common
// static void setup_mmap_mprotect_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pb8_1_proc0
// static void setup_mmap_mprotect_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_mprotect_pbc_0_proc1
// static void setup_mmap_mprotect_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_final
// static void setup_mmap_mprotect_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_mprotect_pbc_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_p2f_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_mprotect_p2f_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p2f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_40_proc0
// static void setup_mmap_mprotect_p2f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p2f_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p2f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_40_proc0
// static void setup_mmap_mprotect_p2f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_p2f_2_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_mprotect_p2f_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p2f_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_40_proc0
// static void setup_mmap_mprotect_p2f_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p2f_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p2f_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_40_proc0
// static void setup_mmap_mprotect_p2f_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p2f_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p2f_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_42_proc0
// static void setup_mmap_mprotect_p2f_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p2f_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p2f_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_42_proc0
// static void setup_mmap_mprotect_p2f_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p2f_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p2f_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_42_proc0
// static void setup_mmap_mprotect_p2f_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p2f_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p2f_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pae_42_proc0
// static void setup_mmap_mprotect_p2f_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p2f_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p2f_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_41_proc0
// static void setup_mmap_mprotect_p2f_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p2f_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p2f_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_43_proc0
// static void setup_mmap_mprotect_p2f_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p2f_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p2f_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_41_proc0
// static void setup_mmap_mprotect_p2f_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p2f_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p2f_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_43_proc0
// static void setup_mmap_mprotect_p2f_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p2f_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p2f_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_41_proc0
// static void setup_mmap_mprotect_p2f_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p2f_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p2f_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pae_41_proc0
// static void setup_mmap_mprotect_p2f_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p2f_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p2f_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_43_proc0
// static void setup_mmap_mprotect_p2f_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2f_15_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p2f_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_42_1
// static void setup_mmap_mprotect_p2f_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2f_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pae_43_proc0
// static void setup_mmap_mprotect_p2f_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2f_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2f_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p2a_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p2a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p2a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p2a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p2a_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p2a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p2a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p2a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p2a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p2a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p26_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p26_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p26_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p26_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p26_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p26_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p26_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p26_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p26_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p26_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p26_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p26_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p26_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p26_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p26_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p26_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p26_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p26_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p26_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p26_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p26_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p26_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p26_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p26_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p26_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p26_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p26_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p26_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p26_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p26_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p26_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p26_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p26_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p26_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p26_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p26_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p26_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p26_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p26_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p26_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p26_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p26_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p26_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p26_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p26_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p26_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p26_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p26_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p26_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p26_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p26_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p26_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p26_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p26_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p26_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p26_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p22_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_0_0
// static int test_mmap_mprotect_p22_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p22_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p22_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p22_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p22_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p22_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p22_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p2f_2_0
// static int test_mmap_mprotect_p22_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p22_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p22_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pa8_0_proc0
// static void setup_mmap_mprotect_p22_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p22_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p22_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
static int test_mmap_mprotect_p18_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_mprotect_p18_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p18_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p18_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p18_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p18_0_0
// static int test_mmap_mprotect_p18_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p18_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p18_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p18_0_0
// static int test_mmap_mprotect_p18_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p18_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p18_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p18_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p18_2_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p18_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p18_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p18_0_0
// static int test_mmap_mprotect_p18_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p18_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p18_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p18_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p18_3_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p18_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p10_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p18_0_0
// static int test_mmap_mprotect_p10_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p10_0_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p10_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p08_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p18_0_0
// static int test_mmap_mprotect_p08_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p08_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p08_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p08_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_41_proc0
// static void setup_mmap_mprotect_p08_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p08_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p08_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p18_0_0
// static int test_mmap_mprotect_p08_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p08_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p08_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p08_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_mprotect_pf8_76_proc0
// static void setup_mmap_mprotect_p08_1_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p08_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p08_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p18_0_0
// static int test_mmap_mprotect_p08_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p08_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_mprotect_pf8_0_common
// static void setup_mmap_mprotect_p08_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p08_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_mprotect_pf8_43_proc0
// static void setup_mmap_mprotect_p08_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_mprotect_pf8_0_final
// static void setup_mmap_mprotect_p08_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p08_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p18_0_0
// static int test_mmap_mprotect_p08_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pf8_41_1
// static void setup_mmap_mprotect_p08_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p08_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p08_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_mprotect_pf8_77_proc0
// static void setup_mmap_mprotect_p08_3_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p08_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal

/*
 * calls: mmap mprotect
 */
// static int test_mmap_mprotect_p00_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_p18_0_0
// static int test_mmap_mprotect_p00_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mmap_mprotect_pc0_0_1
// static void setup_mmap_mprotect_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_9_common
// static void setup_mmap_mprotect_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_mprotect_pf8_0_proc1
// static void setup_mmap_mprotect_p00_0_final(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal
// static void setup_mmap_mprotect_p00_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_mprotect_pf8_0_procfinal


/*
 * calls: mmap munmap
 */
static int test_mmap_munmap_pe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_munmap_pe_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mmap_munmap_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mmap_munmap_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_munmap_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_munmap_pe_0_final(void) {
  
}
static void setup_mmap_munmap_pe_0_procfinal(void) {
  
}

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
static void setup_mmap_munmap_pe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mmap_munmap_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
static void setup_mmap_munmap_pe_1_final(void) {
  unlink("__i0");
}
// static void setup_mmap_munmap_pe_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
static void setup_mmap_munmap_pe_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_munmap_pe_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_9_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_pe_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
static void setup_mmap_munmap_pe_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_munmap_pe_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_11_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_pe_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
static void setup_mmap_munmap_pe_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_munmap_pe_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_13_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_pe_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pe_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
static void setup_mmap_munmap_pe_16_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_munmap_pe_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_16_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_pe_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
static void setup_mmap_munmap_pe_17_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_munmap_pe_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_17_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_pe_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
static void setup_mmap_munmap_pe_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_munmap_pe_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_18_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_pe_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_munmap_pe_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_20_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_munmap_pe_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_21_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_munmap_pe_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pe_22_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_munmap_pe_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pe_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
static void setup_mmap_munmap_pe_23_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_munmap_pe_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_23_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_pe_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pe_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
// static int test_mmap_munmap_pe_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pe_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
static void setup_mmap_munmap_pe_24_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_munmap_pe_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pe_24_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_pe_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_0
static int test_mmap_munmap_pc_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_mmap_munmap_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pc_0_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_pc_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
static int test_mmap_munmap_pb8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_munmap_pb8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
static void setup_mmap_munmap_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_munmap_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_munmap_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_munmap_pb8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_munmap_pb8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pb8_0_0
// static int test_mmap_munmap_pb8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_munmap_pb8_0_common
static void setup_mmap_munmap_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_munmap_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_0_proc1
// static void setup_mmap_munmap_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_final
// static void setup_mmap_munmap_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pb8_0_0
// static int test_mmap_munmap_pb0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_munmap_pb8_0_common
// static void setup_mmap_munmap_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_0_proc0
// static void setup_mmap_munmap_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_0_proc1
// static void setup_mmap_munmap_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_final
// static void setup_mmap_munmap_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pb8_0_0
// static int test_mmap_munmap_pb0_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_munmap_pb8_0_common
// static void setup_mmap_munmap_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_1_proc0
// static void setup_mmap_munmap_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_0_proc1
// static void setup_mmap_munmap_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_final
// static void setup_mmap_munmap_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_procfinal

/*
 * calls: mmap munmap
 */
static int test_mmap_munmap_pa8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_munmap_pa8_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_munmap_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_munmap_pa8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_munmap_pa8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_munmap_pa8_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_munmap_pa8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_munmap_pa8_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_munmap_pa8_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_munmap_pa8_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_15_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_16_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mmap_munmap_pa8_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_16_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_17_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mmap_munmap_pa8_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_17_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_18_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_munmap_pa8_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_19_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_20_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mmap_munmap_pa8_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_20_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_21_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_21_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_22_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_22_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_22_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_23_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mmap_munmap_pa8_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_23_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_23_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa8_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa8_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pe_0_1
// static void setup_mmap_munmap_pa8_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
static void setup_mmap_munmap_pa8_24_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mmap_munmap_pa8_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa8_24_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa8_24_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pa8_0_0
// static int test_mmap_munmap_pa0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pa8_0_proc0
// static void setup_mmap_munmap_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
static int test_mmap_munmap_p9_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_munmap_p9_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p9_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p9_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p9_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p9_0_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p9_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p9_0_0
// static int test_mmap_munmap_p8_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p8_0_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
static int test_mmap_munmap_p70_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_munmap_p70_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_0_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p70_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
static int test_mmap_munmap_p70_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_munmap_p70_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_1_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p70_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p70_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p70_0_0
// static int test_mmap_munmap_p70_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p70_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p70_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_munmap_pe_3_proc0
// static void setup_mmap_munmap_p70_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p70_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p70_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p70_0_0
// static int test_mmap_munmap_p70_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p70_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p70_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_munmap_pe_11_proc0
// static void setup_mmap_munmap_p70_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_3_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p70_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p70_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p70_0_0
// static int test_mmap_munmap_p70_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p70_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p70_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_munmap_pe_6_proc0
// static void setup_mmap_munmap_p70_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p70_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p70_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p70_0_0
// static int test_mmap_munmap_p70_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p70_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p70_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_munmap_pe_13_proc0
// static void setup_mmap_munmap_p70_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_5_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p70_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p70_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p70_1_0
// static int test_mmap_munmap_p70_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p70_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p70_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_munmap_pe_3_proc0
// static void setup_mmap_munmap_p70_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p70_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p70_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p70_1_0
// static int test_mmap_munmap_p70_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p70_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p70_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_munmap_pe_6_proc0
// static void setup_mmap_munmap_p70_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p70_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p70_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p70_1_0
// static int test_mmap_munmap_p70_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p70_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p70_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_munmap_pe_11_proc0
// static void setup_mmap_munmap_p70_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_8_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p70_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p70_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p70_1_0
// static int test_mmap_munmap_p70_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p70_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p70_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_munmap_pe_13_proc0
// static void setup_mmap_munmap_p70_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p70_9_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p70_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p50_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p70_0_0
// static int test_mmap_munmap_p50_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p50_0_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p50_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p50_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p70_1_0
// static int test_mmap_munmap_p50_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p50_1_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p50_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
static int test_mmap_munmap_p38_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_munmap_p38_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_munmap_pb8_0_common
// static void setup_mmap_munmap_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_0_proc0
// static void setup_mmap_munmap_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_0_proc1
// static void setup_mmap_munmap_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_final
// static void setup_mmap_munmap_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p38_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p38_0_0
// static int test_mmap_munmap_p38_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_munmap_pb8_0_common
// static void setup_mmap_munmap_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_1_proc0
// static void setup_mmap_munmap_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_0_proc1
// static void setup_mmap_munmap_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_final
// static void setup_mmap_munmap_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p38_0_0
// static int test_mmap_munmap_p30_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_munmap_pb8_0_common
// static void setup_mmap_munmap_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_0_proc0
// static void setup_mmap_munmap_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_0_proc1
// static void setup_mmap_munmap_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_final
// static void setup_mmap_munmap_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p38_0_0
// static int test_mmap_munmap_p30_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_munmap_pb8_0_common
// static void setup_mmap_munmap_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_1_proc0
// static void setup_mmap_munmap_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_munmap_pb8_0_proc1
// static void setup_mmap_munmap_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_final
// static void setup_mmap_munmap_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_munmap_pb8_0_procfinal

/*
 * calls: mmap munmap
 */
static int test_mmap_munmap_p2c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_munmap_p2c_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pa8_0_proc0
// static void setup_mmap_munmap_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
static int test_mmap_munmap_p2c_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_munmap_p2c_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p2c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p2c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pa8_0_proc0
// static void setup_mmap_munmap_p2c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p2c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p2c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p2c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p2c_0_0
// static int test_mmap_munmap_p2c_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p2c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p2c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_munmap_pa8_3_proc0
// static void setup_mmap_munmap_p2c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p2c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p2c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p2c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p2c_0_0
// static int test_mmap_munmap_p2c_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p2c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p2c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_munmap_pa8_4_proc0
// static void setup_mmap_munmap_p2c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p2c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p2c_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p2c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p2c_0_0
// static int test_mmap_munmap_p2c_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p2c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p2c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_munmap_pa8_16_proc0
// static void setup_mmap_munmap_p2c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p2c_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p2c_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p2c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p2c_0_0
// static int test_mmap_munmap_p2c_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p2c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p2c_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_munmap_pa8_17_proc0
// static void setup_mmap_munmap_p2c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p2c_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p2c_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p2c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p2c_1_0
// static int test_mmap_munmap_p2c_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p2c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p2c_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mmap_munmap_pa8_3_proc0
// static void setup_mmap_munmap_p2c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p2c_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p2c_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p2c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p2c_1_0
// static int test_mmap_munmap_p2c_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p2c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p2c_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mmap_munmap_pa8_16_proc0
// static void setup_mmap_munmap_p2c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p2c_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p2c_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p2c_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p2c_1_0
// static int test_mmap_munmap_p2c_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p2c_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p2c_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mmap_munmap_pa8_4_proc0
// static void setup_mmap_munmap_p2c_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p2c_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p2c_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p2c_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p2c_1_0
// static int test_mmap_munmap_p2c_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p2c_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p2c_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mmap_munmap_pa8_17_proc0
// static void setup_mmap_munmap_p2c_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p2c_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p2c_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p24_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p2c_0_0
// static int test_mmap_munmap_p24_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pa8_0_proc0
// static void setup_mmap_munmap_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p24_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p24_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p2c_1_0
// static int test_mmap_munmap_p24_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p24_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pe_1_common
// static void setup_mmap_munmap_p24_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_munmap_pa8_0_proc0
// static void setup_mmap_munmap_p24_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p24_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_munmap_pe_1_final
// static void setup_mmap_munmap_p24_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
static int test_mmap_munmap_p1_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_munmap_p1_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p1_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p1_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p1_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p1_0_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p1_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal

/*
 * calls: mmap munmap
 */
// static int test_mmap_munmap_p0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_p1_0_0
// static int test_mmap_munmap_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_munmap_pc_0_1
// static void setup_mmap_munmap_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_common
// static void setup_mmap_munmap_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_munmap_pe_0_proc1
// static void setup_mmap_munmap_p0_0_final(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal
// static void setup_mmap_munmap_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_munmap_pe_0_procfinal


/*
 * calls: mmap open
 */
static int test_mmap_open_pf8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_open_pf8_0_1(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_mmap_open_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mmap_open_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_open_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_open_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_mmap_open_pf8_0_procfinal(void) {
  
}

/*
 * calls: mmap open
 */
// static int test_mmap_open_pf70_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
static int test_mmap_open_pf70_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_mmap_open_pf70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_pf70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pf70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pf70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pf70_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pf70_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pf70_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_pf70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
static void setup_mmap_open_pf70_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23973888, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_pf70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pf70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pf70_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pf70_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pf70_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_pf70_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mmap_open_pf70_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_open_pf70_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_open_pf70_2_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_open_pf70_2_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap open
 */
// static int test_mmap_open_pf50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pf50_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_pf50_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_pf50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pf50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pf50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pf50_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pf30_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
static int test_mmap_open_pf30_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_mmap_open_pf30_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_pf30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pf30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pf30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pf30_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pf30_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pf30_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pf30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
static void setup_mmap_open_pf30_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_pf30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pf30_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pf30_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pf30_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pf30_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
static void setup_mmap_open_pf30_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_pf30_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pf30_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pf30_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pf30_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pf10_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pf10_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pf10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_pf10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pf10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pf10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pf10_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pee_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pee_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_pee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mmap_open_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pee_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_pee_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pee_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pee_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_pee_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_open_pee_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pee_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pee_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pee_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pee_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pee_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_pee_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_open_pee_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_pee_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pee_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pee_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pea_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pea_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pea_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_pea_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pe6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pe6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pe6_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_pe6_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pe6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pe6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pee_1_common
// static void setup_mmap_open_pe6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pe6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pe6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pe6_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pe6_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pe6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_common
// static void setup_mmap_open_pe6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_pe6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pe6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pe6_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pe2_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pe2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pe2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_pe2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pe2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pe2_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_pe2_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pde_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
static int test_mmap_open_pde_0_1(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_mmap_open_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_pde_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pde_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pde_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pde_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pde_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
static void setup_mmap_open_pde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 33169408, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pde_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pde_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pde_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pde_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
static void setup_mmap_open_pde_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_pde_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pde_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pde_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pde_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pda_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pda_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pda_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pda_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pd6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
static int test_mmap_open_pd6_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_mmap_open_pd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_pd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pd6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pd6_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pd6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pd6_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_pd6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_pd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf30_1_proc0
// static void setup_mmap_open_pd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pd6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pd6_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pd6_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pd6_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_pd6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_2_common
// static void setup_mmap_open_pd6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pd6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pd6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pd6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pd2_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
// static int test_mmap_open_pd2_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pd2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pd2_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_0
static int test_mmap_open_pc0_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_mmap_open_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pc0_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_pbe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_open_pbe_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
static void setup_mmap_open_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_pbe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbe_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
// static void setup_mmap_open_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbe_0_common
static void setup_mmap_open_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_open_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbdc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbdc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_pbdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pde_2_common
// static void setup_mmap_open_pbdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pbdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbdc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbdc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_pbdc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_pbdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pbdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbd4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbd4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_pbd4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_pbd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pbd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbd4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbd4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_pbd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbd4_0_common
// static void setup_mmap_open_pbd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pbd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbcc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbcc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pbcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_2_common
// static void setup_mmap_open_pbcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pbcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbcc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbcc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbcc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbcc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pbcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_2_common
// static void setup_mmap_open_pbcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pbcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbcc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbcc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbc4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbc4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
static void setup_mmap_open_pbc4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_pbc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pbc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbc4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbc4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbc4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbc4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pbc4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_pbc4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pbc4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbc4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbc4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbb8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_pbb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_open_pbb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pbb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pbb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pbb8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_pbb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pbb8_0_common
// static void setup_mmap_open_pbb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pbb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pbb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pbb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pba8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pba8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_pba8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_open_pba8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pba8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pba8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pba8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pba8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pba8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_pba8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pba8_0_common
// static void setup_mmap_open_pba8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pba8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pba8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pba8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb98_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb98_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
static void setup_mmap_open_pb98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_open_pb98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pb98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb98_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb98_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb98_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb98_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pb98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pbb8_0_common
// static void setup_mmap_open_pb98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pb98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb98_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb98_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb88_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb88_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
static void setup_mmap_open_pb88_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_open_pb88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pb88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb88_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb88_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb88_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb88_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pb88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pba8_0_common
// static void setup_mmap_open_pb88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pb88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb88_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb88_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb78_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb78_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_pb78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_2_common
// static void setup_mmap_open_pb78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pb78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb78_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb78_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_pb78_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbdc_1_common
// static void setup_mmap_open_pb78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pb78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb78_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb78_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb68_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb68_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_pb68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbd4_0_common
// static void setup_mmap_open_pb68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pb68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb68_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb68_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_pb68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbd4_0_common
// static void setup_mmap_open_pb68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pb68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb68_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb68_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb58_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb58_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_pb58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_2_common
// static void setup_mmap_open_pb58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pb58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb58_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb58_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb58_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb58_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_pb58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_2_common
// static void setup_mmap_open_pb58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pb58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb58_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb58_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb48_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb48_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_pb48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_pb48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pb48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb48_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb48_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb48_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb48_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_pb48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_pb48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pb48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb48_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb48_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
static void setup_mmap_open_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_open_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pbe_0_0
// static int test_mmap_open_pb0_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
// static void setup_mmap_open_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pb0_0_common
// static void setup_mmap_open_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_pae_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_open_pae_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
// static void setup_mmap_open_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
static void setup_mmap_open_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pae_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_padc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_padc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_padc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_padc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf70_1_proc0
// static void setup_mmap_open_padc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
static void setup_mmap_open_padc_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_mmap_open_padc_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_padc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_padc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_padc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_padc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_padc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_padc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_padc_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pad4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pad4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_pad4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
static void setup_mmap_open_pad4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_pad4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pad4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pad4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pacc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pacc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pacc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_pacc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf30_1_proc0
// static void setup_mmap_open_pacc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pacc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pacc_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pac4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pac4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pac4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
static void setup_mmap_open_pac4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_pac4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pac4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pac4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pab8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pab8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_pab8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mmap_open_pab8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_pab8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pab8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pab8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_paa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_paa8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_paa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_common
// static void setup_mmap_open_paa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_paa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_paa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_paa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pa98_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pa98_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
static void setup_mmap_open_pa98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mmap_open_pa98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1150976, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_pa98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pa98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pa98_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pa88_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pa88_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_pa88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_open_pa98_0_common
// static void setup_mmap_open_pa88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_pa88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pa88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pa88_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pa78_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pa78_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_pa78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_padc_0_common
// static void setup_mmap_open_pa78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf70_1_proc0
// static void setup_mmap_open_pa78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pa78_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_open_padc_0_final
// static void setup_mmap_open_pa78_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pa78_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pa78_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_pa78_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_pa78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf70_1_proc0
// static void setup_mmap_open_pa78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pa78_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pa78_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pa68_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pa68_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_pa68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
static void setup_mmap_open_pa68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_pa68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pa68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pa68_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pa58_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pa58_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_pa58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_pa58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf30_1_proc0
// static void setup_mmap_open_pa58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pa58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pa58_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pa48_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pa48_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_pa48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_pa48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pac4_0_proc0
// static void setup_mmap_open_pa48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pa48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pa48_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pae_0_0
// static int test_mmap_open_pa0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
// static void setup_mmap_open_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_open_pa98_0_common
// static void setup_mmap_open_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_p9c_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_open_p9c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
// static void setup_mmap_open_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p9b4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p9b4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p9b4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_p9b4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p9b4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p9b4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p9b4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p9a8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p9a8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p9a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p9a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p9a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p9a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p9a8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p994_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p994_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p994_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p994_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p994_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p994_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p994_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p988_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p988_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p988_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p988_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p988_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p988_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p988_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p968_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p968_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p968_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p968_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p968_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p968_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p968_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p950_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p950_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p950_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p950_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p950_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p950_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p950_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p928_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p928_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p928_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p928_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p928_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p928_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p928_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p910_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p910_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p910_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p910_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p910_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p910_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p910_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p8e8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p8e8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p8e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p8e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p8e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p8e8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p8e8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p8d0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p8d0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p8d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p8d0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p8d0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p8a8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p8a8_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p8a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p8a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p8a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p8a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p8a8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p89_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p89_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p89_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p89_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p89_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p89_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p89_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p80_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p9c_0_0
// static int test_mmap_open_p80_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
// static void setup_mmap_open_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p80_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p80_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_p7c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_open_p7c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
// static void setup_mmap_open_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p7c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p7c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_p7c_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_open_p7c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
// static void setup_mmap_open_p7c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p7c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p7c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p7c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p7c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p778_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p778_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p778_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_p778_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p778_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p778_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p778_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p778_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p778_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p778_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_p778_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf70_1_proc0
// static void setup_mmap_open_p778_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p778_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p778_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p778_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p778_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p778_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p778_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p778_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p778_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p778_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p778_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p778_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p778_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pde_2_common
// static void setup_mmap_open_p778_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p778_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p778_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p778_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p778_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p778_4_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p778_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p778_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p778_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p778_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p778_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p778_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p778_5_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p778_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbdc_1_common
// static void setup_mmap_open_p778_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p778_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p778_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p778_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p758_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p758_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p758_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p758_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p758_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p758_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p758_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p758_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p758_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p758_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p758_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p758_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p758_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p758_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p738_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p738_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p738_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p738_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p738_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p738_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p738_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p738_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p738_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p738_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p738_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p738_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p738_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p738_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p738_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p738_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p738_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p738_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf30_1_proc0
// static void setup_mmap_open_p738_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p738_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p738_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p738_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p738_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p738_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_2_common
// static void setup_mmap_open_p738_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p738_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p738_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p738_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p738_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p738_4_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p738_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p738_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf30_1_proc0
// static void setup_mmap_open_p738_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p738_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p738_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p738_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p738_5_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p738_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_2_common
// static void setup_mmap_open_p738_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p738_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p738_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p738_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p718_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p718_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p718_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p718_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p718_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p718_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p718_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p718_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p718_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p718_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p718_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p718_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p718_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p718_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p6f0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p6f0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p6f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p6f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p6f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p6f0_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p6f0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p6f0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p6f0_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p6f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p6f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p6f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p6f0_1_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p6f0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p6f0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p6f0_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p6f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pee_1_common
// static void setup_mmap_open_p6f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p6f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p6f0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p6f0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p6f0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p6f0_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p6f0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_common
// static void setup_mmap_open_p6f0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_p6f0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p6f0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p6f0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p6f0_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p6f0_4_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_p6f0_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_open_p6f0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p6f0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p6f0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p6f0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p6f0_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p6f0_5_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p6f0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_common
// static void setup_mmap_open_p6f0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_p6f0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p6f0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p6f0_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p6b0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p6b0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p6b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p6b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p6b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p6b0_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p6b0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p6b0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p6b0_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p6b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p6b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p6b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p6b0_1_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p6b0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p670_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p670_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p670_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p670_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p670_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p670_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p670_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p670_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p670_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p670_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pee_1_common
// static void setup_mmap_open_p670_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p670_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p670_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p670_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p670_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p670_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p670_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_common
// static void setup_mmap_open_p670_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_p670_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p670_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p670_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p670_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p670_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p670_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p670_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p670_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p670_3_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p670_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p670_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p670_4_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p670_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_p6f0_4_common
// static void setup_mmap_open_p670_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p670_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p670_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p670_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p670_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p670_5_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
static void setup_mmap_open_p670_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mmap_open_p670_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_p670_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p670_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p670_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p630_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p630_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p630_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p630_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p630_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p630_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p630_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p630_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p630_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p630_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p630_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p630_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p630_1_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p630_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p5f0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p5f0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p5f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_p5f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p5f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p5f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p5f0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p5f0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p5f0_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p5f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p5f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p5f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p5f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p5f0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p5f0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p5f0_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p5f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p5f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p5f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p5f0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p5f0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p5f0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p5f0_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p5f0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbdc_1_common
// static void setup_mmap_open_p5f0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p5f0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p5f0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p5f0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p5f0_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p5f0_4_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p5f0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_p5f0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf70_1_proc0
// static void setup_mmap_open_p5f0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p5f0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p5f0_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p5f0_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p5f0_5_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p5f0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_2_common
// static void setup_mmap_open_p5f0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p5f0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p5f0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p5f0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p5b0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p5b0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p5b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p5b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p5b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p5b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p5b0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p5b0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p5b0_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p5b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_p5b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p5b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p5b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p5b0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p570_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p570_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p570_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p570_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p570_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p570_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p570_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p570_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p570_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p570_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p570_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p570_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p570_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p570_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p570_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p570_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p570_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p570_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf30_1_proc0
// static void setup_mmap_open_p570_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p570_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p570_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p570_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p570_3_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p570_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_2_common
// static void setup_mmap_open_p570_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p570_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p570_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p570_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p570_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p570_4_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p570_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p570_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf30_1_proc0
// static void setup_mmap_open_p570_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p570_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p570_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p570_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p570_5_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p570_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_2_common
// static void setup_mmap_open_p570_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p570_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p570_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p570_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p530_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p530_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p530_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p530_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p530_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p530_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p530_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p530_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p530_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p530_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf30_0_common
// static void setup_mmap_open_p530_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p530_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p530_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p530_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p48_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_0_0
// static int test_mmap_open_p48_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
// static void setup_mmap_open_p48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p48_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p48_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p48_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p7c_1_0
// static int test_mmap_open_p48_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
// static void setup_mmap_open_p48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p48_1_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p48_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_p3e_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_open_p3e_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
// static void setup_mmap_open_p3e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbe_0_common
// static void setup_mmap_open_p3e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p3e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3e_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
// static void setup_mmap_open_p3e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbe_0_common
// static void setup_mmap_open_p3e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p3e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3dc_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3dc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p3dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbdc_1_common
// static void setup_mmap_open_p3dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p3dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3dc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3dc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3dc_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3dc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p3dc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_2_common
// static void setup_mmap_open_p3dc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p3dc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3dc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3dc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3d4_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3d4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_p3d4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_p3d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p3d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3d4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3d4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3d4_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3d4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_p3d4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_p3d4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p3d4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3d4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3d4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3cc_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3cc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p3cc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_p3cc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p3cc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3cc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3cc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3cc_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3cc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p3cc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_p3cc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p3cc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3cc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3cc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3c4_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3c4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p3c4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_p3c4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p3c4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3c4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3c4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3c4_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3c4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p3c4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_p3c4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p3c4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3c4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3c4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3b8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3b8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p3b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pbb8_0_common
// static void setup_mmap_open_p3b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p3b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3b8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3b8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3b8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3b8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p3b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pbb8_0_common
// static void setup_mmap_open_p3b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p3b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3b8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3b8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3a8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3a8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p3a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pb88_0_common
// static void setup_mmap_open_p3a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p3a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3a8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3a8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p3a8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p3a8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p3a8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pb88_0_common
// static void setup_mmap_open_p3a8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p3a8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p3a8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p3a8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p398_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p398_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p398_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pbb8_0_common
// static void setup_mmap_open_p398_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p398_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p398_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p398_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p398_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p398_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p398_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pbb8_0_common
// static void setup_mmap_open_p398_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p398_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p398_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p398_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p388_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p388_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p388_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pba8_0_common
// static void setup_mmap_open_p388_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p388_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p388_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p388_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p388_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p388_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p388_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pb88_0_common
// static void setup_mmap_open_p388_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p388_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p388_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p388_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p378_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p378_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p378_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pde_2_common
// static void setup_mmap_open_p378_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p378_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p378_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p378_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p378_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p378_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p378_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_2_common
// static void setup_mmap_open_p378_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p378_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p378_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p378_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p368_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p368_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p368_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p3d4_0_common
// static void setup_mmap_open_p368_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p368_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p368_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p368_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p368_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p368_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p368_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p3d4_1_common
// static void setup_mmap_open_p368_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p368_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p368_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p368_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p358_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p358_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p358_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_p358_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p358_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p358_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p358_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p358_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p358_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p358_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_p358_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p358_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p358_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p358_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p348_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p348_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p348_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_p348_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p348_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p348_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p348_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p348_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p348_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p348_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pbc4_0_common
// static void setup_mmap_open_p348_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p348_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p348_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p348_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p30_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
// static void setup_mmap_open_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pb0_0_common
// static void setup_mmap_open_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc0
// static void setup_mmap_open_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p3e_0_0
// static int test_mmap_open_p30_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
// static void setup_mmap_open_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_open_pb0_0_common
// static void setup_mmap_open_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pbe_1_proc0
// static void setup_mmap_open_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_open_pf70_2_proc1
// static void setup_mmap_open_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_final
// static void setup_mmap_open_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_open_pf70_2_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_p2f_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_open_p2f_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
// static void setup_mmap_open_p2f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p2f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2f_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2f_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_p2f_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_open_p2f_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
// static void setup_mmap_open_p2f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p2f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2f_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2f_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2de_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2de_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_p2de_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_p2de_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p2de_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2de_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_open_padc_0_final
// static void setup_mmap_open_p2de_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2de_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2de_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_p2de_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_p2de_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2de_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2de_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_open_padc_0_final
// static void setup_mmap_open_p2de_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2de_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2de_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2de_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p2de_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p2de_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2de_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2de_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2de_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2de_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2de_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2de_0_common
// static void setup_mmap_open_p2de_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p2de_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2de_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_open_padc_0_final
// static void setup_mmap_open_p2de_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2de_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2de_4_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2de_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2de_1_common
// static void setup_mmap_open_p2de_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2de_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2de_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_open_padc_0_final
// static void setup_mmap_open_p2de_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2de_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2de_5_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2de_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p2de_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2de_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2de_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2de_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2de_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2de_6_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2de_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p2de_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p2de_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2de_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2de_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2de_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2de_7_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_p2de_7_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_p2de_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2de_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2de_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2de_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2d6_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2d6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2d6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_p2d6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pad4_0_proc0
// static void setup_mmap_open_p2d6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2d6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2d6_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2d6_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2d6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2d6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p2d6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p2d6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2d6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2d6_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2d6_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2d6_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2d6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2de_7_common
// static void setup_mmap_open_p2d6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2d6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2d6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2d6_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2d6_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2d6_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_p2d6_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_p2d6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2d6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2d6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2d6_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2ce_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2ce_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p2ce_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p2ce_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pac4_0_proc0
// static void setup_mmap_open_p2ce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2ce_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2ce_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2ce_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2ce_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p2ce_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p2ce_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pac4_0_proc0
// static void setup_mmap_open_p2ce_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2ce_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2ce_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2ce_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2ce_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
static void setup_mmap_open_p2ce_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_open_p2ce_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2ce_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2ce_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2ce_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2ce_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2ce_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p2ce_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2ce_2_common
// static void setup_mmap_open_p2ce_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2ce_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2ce_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2ce_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2c6_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2c6_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p2c6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p2c6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pac4_0_proc0
// static void setup_mmap_open_p2c6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2c6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2c6_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2c6_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2c6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p2c6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p2c6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pac4_0_proc0
// static void setup_mmap_open_p2c6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2c6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2c6_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2c6_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2c6_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p2c6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p2c6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2c6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2c6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2c6_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2c6_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2c6_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p2c6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p2c6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2c6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2c6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2c6_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2bc_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2bc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2bc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_p670_5_common
static void setup_mmap_open_p2bc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2191360, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_p2bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2bc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2bc_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2bc_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2bc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2bc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_p670_5_common
// static void setup_mmap_open_p2bc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2bc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2bc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2bc_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2bc_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2bc_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2bc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_open_pa98_0_common
// static void setup_mmap_open_p2bc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p2bc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2bc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2bc_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_p2bc_3_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x16dd000UL);
  
  return xerrno(r);
}
// static int test_mmap_open_p2bc_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
static void setup_mmap_open_p2bc_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mmap_open_p2bc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf70_1_proc0
// static void setup_mmap_open_p2bc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2bc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2bc_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2ac_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2ac_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2ac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_common
// static void setup_mmap_open_p2ac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_p2ac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2ac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2ac_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2ac_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2ac_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2ac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_common
// static void setup_mmap_open_p2ac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_p2ac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2ac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2ac_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2ac_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p2ac_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2ac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_p670_5_common
// static void setup_mmap_open_p2ac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2ac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2ac_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2ac_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p2ac_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p2ac_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p2ac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_p670_5_common
// static void setup_mmap_open_p2ac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p2ac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p2ac_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p2ac_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p29c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p29c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p29c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_open_pa98_0_common
// static void setup_mmap_open_p29c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1150976, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pa98_0_proc0
// static void setup_mmap_open_p29c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p29c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p29c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_p29c_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1710000UL);
  
  return xerrno(r);
}
// static int test_mmap_open_p29c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
static void setup_mmap_open_p29c_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_open_p29c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24182784, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_p29c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p29c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p29c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p29c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p29c_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
static void setup_mmap_open_p29c_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_open_p29c_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4677632, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_p29c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p29c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p29c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p29c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x16dd000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2bc_3_0
// static int test_mmap_open_p29c_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p29c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_p2bc_3_common
// static void setup_mmap_open_p29c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf70_1_proc0
// static void setup_mmap_open_p29c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p29c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p29c_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p28c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p28c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p28c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_common
// static void setup_mmap_open_p28c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_p28c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p28c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p28c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p28c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p28c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p28c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_p670_5_common
// static void setup_mmap_open_p28c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_proc0
// static void setup_mmap_open_p28c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p28c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p28c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p28c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p28c_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p28c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_pee_2_common
// static void setup_mmap_open_p28c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p28c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p28c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p28c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_p28c_3_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x188b000UL);
  
  return xerrno(r);
}
// static int test_mmap_open_p28c_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p28c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_open_p670_5_common
static void setup_mmap_open_p28c_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 25735168, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_open_p28c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p28c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p28c_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p27c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p27c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p27c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2de_0_common
// static void setup_mmap_open_p27c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p27c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p27c_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_open_padc_0_final
// static void setup_mmap_open_p27c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p27c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p27c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p27c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2de_1_common
// static void setup_mmap_open_p27c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p27c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p27c_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_open_padc_0_final
// static void setup_mmap_open_p27c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p27c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p27c_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p27c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p27c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p27c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p27c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p27c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p27c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p27c_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p27c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_padc_0_common
// static void setup_mmap_open_p27c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf70_1_proc0
// static void setup_mmap_open_p27c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p27c_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_open_padc_0_final
// static void setup_mmap_open_p27c_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p27c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p27c_4_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p27c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_padc_0_common
// static void setup_mmap_open_p27c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p27c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p27c_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_mmap_open_padc_0_final
// static void setup_mmap_open_p27c_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p27c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p27c_5_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p27c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2ce_2_common
// static void setup_mmap_open_p27c_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p27c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p27c_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p27c_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p27c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p27c_6_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p27c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p27c_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23973888, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pf70_1_proc0
// static void setup_mmap_open_p27c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p27c_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p27c_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p27c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p27c_7_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p27c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2de_7_common
// static void setup_mmap_open_p27c_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p27c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p27c_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p27c_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p26c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p26c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p26c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p26c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9347072, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pa68_0_proc0
// static void setup_mmap_open_p26c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p26c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p26c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p26c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p26c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p26c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p26c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pde_1_proc0
// static void setup_mmap_open_p26c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p26c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p26c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p26c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p26c_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p26c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2de_7_common
// static void setup_mmap_open_p26c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p26c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p26c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p26c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p26c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p26c_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p26c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2d6_3_common
// static void setup_mmap_open_p26c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p26c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p26c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p26c_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p25c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p25c_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p25c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p25c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pac4_0_proc0
// static void setup_mmap_open_p25c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p25c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p25c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p25c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p25c_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p25c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p25c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pac4_0_proc0
// static void setup_mmap_open_p25c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p25c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p25c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p25c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p25c_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p25c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2ce_2_common
// static void setup_mmap_open_p25c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p25c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p25c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p25c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p25c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p25c_3_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p25c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_p2ce_2_common
// static void setup_mmap_open_p25c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p25c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p25c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p25c_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p24c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p24c_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p24c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p24c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pac4_0_proc0
// static void setup_mmap_open_p24c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p24c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p24c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p24c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p24c_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p24c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p24c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pac4_0_proc0
// static void setup_mmap_open_p24c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p24c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p24c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p24c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p24c_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p24c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p24c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p24c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p24c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p24c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p24c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p24c_3_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p24c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p24c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p24c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p24c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p24c_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p22_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_0_0
// static int test_mmap_open_p22_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
// static void setup_mmap_open_p22_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_open_pa98_0_common
// static void setup_mmap_open_p22_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p22_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p22_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p22_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p22_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_p2f_1_0
// static int test_mmap_open_p22_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
// static void setup_mmap_open_p22_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_open_pa98_0_common
// static void setup_mmap_open_p22_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_open_pae_0_proc0
// static void setup_mmap_open_p22_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p22_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p22_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
static int test_mmap_open_p1c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_open_p1c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf8_0_1
// static void setup_mmap_open_p1c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p1c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p1c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p1c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p1c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p1b4_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p1b4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p1b4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p1b4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p1b4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p1b4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p1b4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p1a8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p1a8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p1a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_p1a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p1a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p1a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p1a8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p194_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p194_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p194_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p194_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p194_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p194_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p194_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p188_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p188_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p188_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p188_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p188_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p188_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p188_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p168_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p168_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p168_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p168_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p168_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p168_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p168_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p150_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p150_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf70_0_1
// static void setup_mmap_open_p150_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p150_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p150_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p150_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p150_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p128_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p128_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p128_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p128_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p128_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p128_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p128_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p110_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p110_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pf30_0_1
// static void setup_mmap_open_p110_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p110_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p110_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p110_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p110_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p0e8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p0e8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p0e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf70_0_common
// static void setup_mmap_open_p0e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p0e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p0e8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p0e8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p0d0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p0d0_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pde_0_1
// static void setup_mmap_open_p0d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf8_0_common
// static void setup_mmap_open_p0d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p0d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p0d0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p0d0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p0a8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p0a8_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p0a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p0a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p0a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p0a8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p0a8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p09_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p09_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_open_pd6_0_1
// static void setup_mmap_open_p09_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_open_pf50_0_common
// static void setup_mmap_open_p09_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p09_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p09_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_open_pf8_0_final
// static void setup_mmap_open_p09_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal

/*
 * calls: mmap open
 */
// static int test_mmap_open_p00_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_open_p1c_0_0
// static int test_mmap_open_p00_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_open_pc0_0_1
// static void setup_mmap_open_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_open_pee_0_common
// static void setup_mmap_open_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_open_pf8_0_proc1
// static void setup_mmap_open_p00_0_final(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal
// static void setup_mmap_open_p00_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_open_pf8_0_procfinal


/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_pf8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_pipe_pf8_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mmap_pipe_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mmap_pipe_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_pipe_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_pipe_pf8_0_final(void) {
  
}
static void setup_mmap_pipe_pf8_0_procfinal(void) {
  
}

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_pf8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_0
// static int test_mmap_pipe_pf8_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
static void setup_mmap_pipe_pf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_pipe_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pipe_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
static void setup_mmap_pipe_pf8_1_final(void) {
  unlink("__i0");
}
// static void setup_mmap_pipe_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_pf8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_0
// static int test_mmap_pipe_pf8_2_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
static void setup_mmap_pipe_pf8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pipe_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_pipe_pf8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_pipe_pf8_2_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_pipe_pf8_2_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_pf8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_0
// static int test_mmap_pipe_pf8_3_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pf8_2_common
static void setup_mmap_pipe_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pipe_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_pd8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_0
// static int test_mmap_pipe_pd8_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_common
// static void setup_mmap_pipe_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_pd8_0_final(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal
// static void setup_mmap_pipe_pd8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_pbe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_pipe_pbe_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pf8_2_common
// static void setup_mmap_pipe_pbe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc0
// static void setup_mmap_pipe_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_pbe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pbe_0_0
// static int test_mmap_pipe_pbe_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pf8_2_common
// static void setup_mmap_pipe_pbe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_3_proc0
// static void setup_mmap_pipe_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_pb6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pbe_0_0
// static int test_mmap_pipe_pb6_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
static void setup_mmap_pipe_pb6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_pipe_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc0
// static void setup_mmap_pipe_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_pb6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pbe_0_0
// static int test_mmap_pipe_pb6_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pb6_0_common
// static void setup_mmap_pipe_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_3_proc0
// static void setup_mmap_pipe_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_pae_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_pipe_pae_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
static void setup_mmap_pipe_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_pipe_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pipe_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_pae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_pae_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_pa6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pae_0_0
// static int test_mmap_pipe_pa6_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_common
// static void setup_mmap_pipe_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_proc0
// static void setup_mmap_pipe_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_pa6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_p96_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_pipe_p96_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p96_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_common
// static void setup_mmap_pipe_p96_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p96_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p96_0_final(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal
// static void setup_mmap_pipe_p96_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p8c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p96_0_0
// static int test_mmap_pipe_p8c_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_common
// static void setup_mmap_pipe_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p8c_0_final(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal
// static void setup_mmap_pipe_p8c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_p7c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pipe_p7c_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_common
// static void setup_mmap_pipe_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p7c_0_final(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal
// static void setup_mmap_pipe_p7c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_p7c_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pipe_p7c_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p7c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_common
// static void setup_mmap_pipe_p7c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p7c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p7c_1_final(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal
// static void setup_mmap_pipe_p7c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p7c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p7c_0_0
// static int test_mmap_pipe_p7c_2_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p7c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_common
// static void setup_mmap_pipe_p7c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_proc0
// static void setup_mmap_pipe_p7c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p7c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_p7c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p7c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p7c_0_0
// static int test_mmap_pipe_p7c_3_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p7c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pb6_0_common
// static void setup_mmap_pipe_p7c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc0
// static void setup_mmap_pipe_p7c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_p7c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_p7c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p7c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p7c_0_0
// static int test_mmap_pipe_p7c_4_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p7c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pf8_2_common
// static void setup_mmap_pipe_p7c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_3_proc0
// static void setup_mmap_pipe_p7c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_p7c_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_p7c_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p7c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p7c_1_0
// static int test_mmap_pipe_p7c_5_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p7c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_common
static void setup_mmap_pipe_p7c_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pipe_p7c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p7c_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_p7c_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p7c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p7c_1_0
// static int test_mmap_pipe_p7c_6_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p7c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pb6_0_common
// static void setup_mmap_pipe_p7c_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc0
// static void setup_mmap_pipe_p7c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_p7c_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_p7c_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p7c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p7c_1_0
// static int test_mmap_pipe_p7c_7_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p7c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pb6_0_common
// static void setup_mmap_pipe_p7c_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_3_proc0
// static void setup_mmap_pipe_p7c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_p7c_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_p7c_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p5c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p7c_0_0
// static int test_mmap_pipe_p5c_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_common
// static void setup_mmap_pipe_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p5c_0_final(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal
// static void setup_mmap_pipe_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p5c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p7c_1_0
// static int test_mmap_pipe_p5c_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p5c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_common
// static void setup_mmap_pipe_p5c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p5c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p5c_1_final(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal
// static void setup_mmap_pipe_p5c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_p3e_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_pipe_p3e_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p3e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pb6_0_common
// static void setup_mmap_pipe_p3e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc0
// static void setup_mmap_pipe_p3e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_p3e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_p3e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p3e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p3e_0_0
// static int test_mmap_pipe_p3e_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p3e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pb6_0_common
// static void setup_mmap_pipe_p3e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_3_proc0
// static void setup_mmap_pipe_p3e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_p3e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_p3e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p36_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p3e_0_0
// static int test_mmap_pipe_p36_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pipe_pb6_0_common
// static void setup_mmap_pipe_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc0
// static void setup_mmap_pipe_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p36_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p3e_0_0
// static int test_mmap_pipe_p36_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
static void setup_mmap_pipe_p36_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_pipe_p36_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_3_proc0
// static void setup_mmap_pipe_p36_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pipe_pf8_2_proc1
// static void setup_mmap_pipe_p36_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_final
// static void setup_mmap_pipe_p36_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pipe_pf8_2_procfinal

/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_p2f0_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pipe_p2f0_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p2f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_common
// static void setup_mmap_pipe_p2f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_proc0
// static void setup_mmap_pipe_p2f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p2f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_p2f0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_p2f0_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pipe_p2f0_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p2f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_common
// static void setup_mmap_pipe_p2f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_proc0
// static void setup_mmap_pipe_p2f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p2f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_p2f0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_p2f0_2_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x985000UL);
  
  return xerrno(r);
}
// static int test_mmap_pipe_p2f0_2_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p2f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_common
static void setup_mmap_pipe_p2f0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pipe_p2f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p2f0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_p2f0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p2f0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p2f0_1_0
// static int test_mmap_pipe_p2f0_3_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p2f0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pipe_pf8_1_common
static void setup_mmap_pipe_p2f0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pipe_p2f0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p2f0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_p2f0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p270_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p2f0_0_0
// static int test_mmap_pipe_p270_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p270_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_common
// static void setup_mmap_pipe_p270_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pipe_pae_0_proc0
// static void setup_mmap_pipe_p270_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p270_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_p270_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p270_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p2f0_1_0
// static int test_mmap_pipe_p270_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p270_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pipe_pf8_1_common
// static void setup_mmap_pipe_p270_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pipe_pf8_1_proc0
// static void setup_mmap_pipe_p270_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p270_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_p270_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p270_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p2f0_0_0
// static int test_mmap_pipe_p270_2_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
static void setup_mmap_pipe_p270_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mmap_pipe_p270_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pipe_p2f0_3_proc0
// static void setup_mmap_pipe_p270_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p270_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_p270_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p270_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p2f0_1_0
// static int test_mmap_pipe_p270_3_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p270_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pipe_p270_2_common
// static void setup_mmap_pipe_p270_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pipe_p2f0_3_proc0
// static void setup_mmap_pipe_p270_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p270_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pipe_pf8_1_final
// static void setup_mmap_pipe_p270_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
static int test_mmap_pipe_p16_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_pipe_p16_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p16_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_common
// static void setup_mmap_pipe_p16_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p16_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p16_0_final(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal
// static void setup_mmap_pipe_p16_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal

/*
 * calls: mmap pipe
 */
// static int test_mmap_pipe_p0c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_p16_0_0
// static int test_mmap_pipe_p0c_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_pipe_pf8_0_1
// static void setup_mmap_pipe_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_common
// static void setup_mmap_pipe_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pipe_pf8_0_proc1
// static void setup_mmap_pipe_p0c_0_final(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal
// static void setup_mmap_pipe_p0c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pipe_pf8_0_procfinal


/*
 * calls: mmap pread
 */
static int test_mmap_pread_pf8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_pread_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_mmap_pread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pread_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_pread_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_pread_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_pread_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
static int test_mmap_pread_pf8_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_mmap_pread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
static void setup_mmap_pread_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
static void setup_mmap_pread_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
static void setup_mmap_pread_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
static void setup_mmap_pread_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
static int test_mmap_pread_pf4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_mmap_pread_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mmap_pread_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_mmap_pread_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_pread_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_mmap_pread_pf4_0_procfinal(void) {
  
}

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
static void setup_mmap_pread_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pread_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
static void setup_mmap_pread_pf4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pread_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
static void setup_mmap_pread_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pread_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pf4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pf4_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf4_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf4_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_pf4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
static void setup_mmap_pread_pf4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pread_pf4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pf4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pf4_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf4_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf4_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_pf4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
static void setup_mmap_pread_pf4_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pf4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pf4_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pf4_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
static int test_mmap_pread_pf0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_mmap_pread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mmap_pread_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_proc0
// static void setup_mmap_pread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
static void setup_mmap_pread_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pread_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
static void setup_mmap_pread_pf0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pread_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_pf0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_pf0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_4_proc0
// static void setup_mmap_pread_pf0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pf0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pf0_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pf0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pf0_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
static void setup_mmap_pread_pf0_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_pread_pf0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_5_proc0
// static void setup_mmap_pread_pf0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pf0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pf0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
static int test_mmap_pread_pe0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_mmap_pread_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mmap_pread_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pe0_0_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
static int test_mmap_pread_pe0_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_mmap_pread_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
static void setup_mmap_pread_pe0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pread_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pd8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pd8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
static void setup_mmap_pread_pd8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pd4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
static int test_mmap_pread_pd4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_mmap_pread_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
static void setup_mmap_pread_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pread_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pd4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
static int test_mmap_pread_pd0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_mmap_pread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pd0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pf8_0_0
// static int test_mmap_pread_pc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pc0_0_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
static int test_mmap_pread_pbe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_pread_pbe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
static void setup_mmap_pread_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
static void setup_mmap_pread_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbe_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbe_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_pbe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
static void setup_mmap_pread_pbe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pbe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbe_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbe_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbe_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_pbe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
static void setup_mmap_pread_pbe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pbe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbe_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbe_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_pbe_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pbe_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_pbe_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbe_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbe_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbe_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbe_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_pbe_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pbe_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pbe_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbe_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbe_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbd_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbd_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_pbd_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_pbd_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_2_proc0
// static void setup_mmap_pread_pbd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbd_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbd_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbd_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbd_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_pbd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
static void setup_mmap_pread_pbd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pbd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbd_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbd_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbd_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbd_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_pbd_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_pbd_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_5_proc0
// static void setup_mmap_pread_pbd_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbd_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbd_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbd_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbd_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_pbd_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
static void setup_mmap_pread_pbd_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pbd_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbd_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbd_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_pbc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_2_common
// static void setup_mmap_pread_pbc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf0_2_proc0
// static void setup_mmap_pread_pbc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbc0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbc0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_pbc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_2_common
static void setup_mmap_pread_pbc0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pbc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbc0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbc0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbc0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbc0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
static void setup_mmap_pread_pbc0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_pread_pbc0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_5_proc0
// static void setup_mmap_pread_pbc0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbc0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbc0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pbc0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pbc0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_pbc0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_5_common
// static void setup_mmap_pread_pbc0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pbd_3_proc0
// static void setup_mmap_pread_pbc0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pbc0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pbc0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb6_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb6_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_pb6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pb6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_pb6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pb6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb6_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb6_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_pb6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pb6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pb6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pb6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb5_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_pb5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_pb5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
static void setup_mmap_pread_pb5_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pb5_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb5_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb5_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_pb5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_pb5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pb5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_0_proc1
// static void setup_mmap_pread_pb5_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb5_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb5_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb5_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_pb5_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_pb5_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
static void setup_mmap_pread_pb5_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pb5_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb5_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb5_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb5_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_pb5_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_pb5_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pb5_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_pb5_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb5_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_pb40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_2_common
// static void setup_mmap_pread_pb40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
static void setup_mmap_pread_pb40_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pb40_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb40_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb40_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb40_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_pb40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_2_common
// static void setup_mmap_pread_pb40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pb40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb40_0_proc1
// static void setup_mmap_pread_pb40_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb40_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb40_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb40_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_pb40_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pbc0_2_common
// static void setup_mmap_pread_pb40_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_pb40_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_pb40_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb40_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb40_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb40_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_pb40_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_5_common
// static void setup_mmap_pread_pb40_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pb40_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_pb40_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb40_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pbe_0_0
// static int test_mmap_pread_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
static int test_mmap_pread_pae_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_pread_pae_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
static void setup_mmap_pread_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pread_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pae_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pae_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
static void setup_mmap_pread_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pread_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pad_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pad_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_pad_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_pad_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_proc0
// static void setup_mmap_pread_pad_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pad_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pad_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pad_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pad_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_pad_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_pad_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_pad_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pad_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pad_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pad_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pad_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_pad_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_pad_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_pad_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pad_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pad_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pad_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pad_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_pad_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_pad_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_pad_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pad_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pad_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pac0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pac0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_pac0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
static void setup_mmap_pread_pac0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pread_pac0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pac0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pac0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pac0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pac0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_pac0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
static void setup_mmap_pread_pac0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pread_pac0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pac0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pac0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pac0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pac0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_pac0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_pac0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_pac0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pac0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pac0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pac0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pac0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_pac0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_pac0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_pac0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pac0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pac0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
static void setup_mmap_pread_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mmap_pread_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pa6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pa6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_0_proc1
// static void setup_mmap_pread_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_pa6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pa6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pa6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pa6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_0_proc1
// static void setup_mmap_pread_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_pa6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_pa6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pa5_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pa5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_pa5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_pa5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_pa5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_pa5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pa5_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pa5_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pa5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_pa5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_pa5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_pa5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_pa5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pa5_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pa40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pa40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_pa40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_pa40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_1_proc0
// static void setup_mmap_pread_pa40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_1_proc0
// static void setup_mmap_pread_pa40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pa40_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pa40_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pa40_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_pa40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_pa40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_pa40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_pa40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pa40_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_pae_0_0
// static int test_mmap_pread_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pa8_0_common
// static void setup_mmap_pread_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
static int test_mmap_pread_p9c_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_pread_p9c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_1_proc0
// static void setup_mmap_pread_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p9c_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p9c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p9c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_4_proc0
// static void setup_mmap_pread_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p9a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p9a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_1_proc0
// static void setup_mmap_pread_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p9a_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p9a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p9a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_4_proc0
// static void setup_mmap_pread_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p98_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_1_proc0
// static void setup_mmap_pread_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p98_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p98_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p98_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_4_proc0
// static void setup_mmap_pread_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p98_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p90_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p90_0_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_p90_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p90_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p90_1_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_p90_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p8c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p8c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p8c_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p8c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p8a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p8a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p8a_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p8a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p88_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p88_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_1_proc0
// static void setup_mmap_pread_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p88_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p88_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p88_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p88_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p80_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p9c_0_0
// static int test_mmap_pread_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p80_0_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_p80_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
static int test_mmap_pread_p7c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pread_p7c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p7c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p7c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p7c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p7c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_1_proc0
// static void setup_mmap_pread_p7c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p7c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p7c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p7c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p7c_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p7c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p7c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_2_proc0
// static void setup_mmap_pread_p7c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p7c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p7c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
static int test_mmap_pread_p7c_3_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pread_p7c_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p7c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p7c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p7c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p7c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p7c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p7c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p7c_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p7c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p7c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_2_proc0
// static void setup_mmap_pread_p7c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p7c_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p7c_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p7c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p7c_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p7c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p7c_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_1_proc0
// static void setup_mmap_pread_p7c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p7c_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p7c_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p7c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p7c_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p7c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p7c_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_3_proc0
// static void setup_mmap_pread_p7c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p7c_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p7c_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p7c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p7c_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p7c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p7c_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_4_proc0
// static void setup_mmap_pread_p7c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p7c_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p7c_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p7c_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p7c_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p7c_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p7c_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_4_proc0
// static void setup_mmap_pread_p7c_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p7c_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p7c_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p7c_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p7c_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p7c_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p7c_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_3_proc0
// static void setup_mmap_pread_p7c_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p7c_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p7c_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p76_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_proc0
// static void setup_mmap_pread_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p76_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p76_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p76_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p76_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_1_proc0
// static void setup_mmap_pread_p76_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p76_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p76_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p76_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p76_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_proc0
// static void setup_mmap_pread_p76_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p76_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p76_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p76_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p76_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_1_proc0
// static void setup_mmap_pread_p76_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p76_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p76_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p76_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p76_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_2_proc0
// static void setup_mmap_pread_p76_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p76_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p76_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p76_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p76_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_2_proc0
// static void setup_mmap_pread_p76_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p76_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p76_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p76_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p76_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_p76_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p76_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p76_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p76_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p76_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_4_proc0
// static void setup_mmap_pread_p76_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p76_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p76_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p76_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p76_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_5_proc0
// static void setup_mmap_pread_p76_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p76_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p76_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p76_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p76_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_p76_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p76_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p76_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p76_10_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p76_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_4_proc0
// static void setup_mmap_pread_p76_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p76_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p76_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p76_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p76_11_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p76_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p76_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_5_proc0
// static void setup_mmap_pread_p76_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p76_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p76_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p72_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p72_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_proc0
// static void setup_mmap_pread_p72_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p72_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p72_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p72_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p72_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_1_proc0
// static void setup_mmap_pread_p72_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p72_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p72_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p72_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p72_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_proc0
// static void setup_mmap_pread_p72_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p72_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p72_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p72_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p72_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_1_proc0
// static void setup_mmap_pread_p72_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p72_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p72_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p72_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_2_common
// static void setup_mmap_pread_p72_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf0_2_proc0
// static void setup_mmap_pread_p72_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p72_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p72_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p72_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_2_common
// static void setup_mmap_pread_p72_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf0_2_proc0
// static void setup_mmap_pread_p72_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p72_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p72_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p72_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p72_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_p72_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p72_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p72_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p72_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p72_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_4_proc0
// static void setup_mmap_pread_p72_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p72_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p72_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p72_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p72_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_4_proc0
// static void setup_mmap_pread_p72_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p72_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p72_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p72_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pbc0_2_common
// static void setup_mmap_pread_p72_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_5_proc0
// static void setup_mmap_pread_p72_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p72_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p72_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p72_10_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p72_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_p72_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p72_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p72_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p72_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p72_11_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p72_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_5_common
// static void setup_mmap_pread_p72_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_5_proc0
// static void setup_mmap_pread_p72_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p72_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p72_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p68_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p68_0_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p68_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p68_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p68_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p68_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_p68_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p68_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p68_2_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_p68_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p68_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p68_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_p68_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p68_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p68_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p68_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p68_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p5c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p5c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p5c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p5c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p5c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p5c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p5c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p5c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p5c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p5c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p5c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p5c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p5c_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p5c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p5c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p5c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p5c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p5c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p5c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p5c_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p5c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p5c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p5c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p5c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p5c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p56_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p56_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p56_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p56_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p56_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p56_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p56_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p56_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p56_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p56_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p56_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p56_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p56_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p56_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p56_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p56_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p56_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p56_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p56_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p56_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p56_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p56_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p56_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p56_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p56_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p56_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p56_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p56_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p52_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p52_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p52_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p52_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p52_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p52_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p52_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p52_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p52_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p52_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p52_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p52_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p52_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p52_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p52_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p52_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p52_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p52_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p52_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p52_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p52_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p52_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p52_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p52_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p52_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p52_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p52_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p52_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p48_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_0_0
// static int test_mmap_pread_p48_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_p48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p48_0_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_p48_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p48_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p7c_3_0
// static int test_mmap_pread_p48_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_p48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p48_1_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_p48_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
static int test_mmap_pread_p3e_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_pread_p3e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p3e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p3e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pbe_0_proc0
// static void setup_mmap_pread_p3e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p3e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p3e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pbe_1_proc0
// static void setup_mmap_pread_p3e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3e_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3e_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p3e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p3e_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pbe_3_proc0
// static void setup_mmap_pread_p3e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3e_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3e_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3e_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3e_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p3e_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p3e_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p3e_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3e_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3e_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3e_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3e_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p3e_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p3e_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pbe_2_proc0
// static void setup_mmap_pread_p3e_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3e_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3e_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3e_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3e_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p3e_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p3e_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p3e_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3e_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3e_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3d_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3d_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p3d_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p3d_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_2_proc0
// static void setup_mmap_pread_p3d_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3d_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3d_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3d_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3d_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p3d_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p3d_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pbd_1_proc0
// static void setup_mmap_pread_p3d_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3d_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3d_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3d_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3d_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p3d_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p3d_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_5_proc0
// static void setup_mmap_pread_p3d_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3d_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3d_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3d_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3d_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p3d_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p3d_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pbd_3_proc0
// static void setup_mmap_pread_p3d_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3d_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3d_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3c0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3c0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p3c0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_2_common
// static void setup_mmap_pread_p3c0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf0_2_proc0
// static void setup_mmap_pread_p3c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3c0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3c0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3c0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3c0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p3c0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_2_common
// static void setup_mmap_pread_p3c0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pbc0_1_proc0
// static void setup_mmap_pread_p3c0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3c0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3c0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3c0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3c0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p3c0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pbc0_2_common
// static void setup_mmap_pread_p3c0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf4_5_proc0
// static void setup_mmap_pread_p3c0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3c0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3c0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p3c0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p3c0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p3c0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_5_common
// static void setup_mmap_pread_p3c0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pbd_3_proc0
// static void setup_mmap_pread_p3c0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p3c0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p3c0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p38_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p38_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p38_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p36_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p36_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p36_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p36_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p36_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p36_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p36_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p36_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p36_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p36_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p36_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p36_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p36_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p36_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p36_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p36_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p36_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p36_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p36_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p36_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p36_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p36_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p35_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p35_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p35_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p35_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p35_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_0_proc1
// static void setup_mmap_pread_p35_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p35_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p35_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p35_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p35_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p35_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p35_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_0_proc1
// static void setup_mmap_pread_p35_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p35_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p35_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p35_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p35_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p35_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p35_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_p35_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p35_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p35_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p35_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p35_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf4_2_common
// static void setup_mmap_pread_p35_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p35_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_p35_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p35_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p340_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p340_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p340_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_2_common
// static void setup_mmap_pread_p340_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p340_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb40_0_proc1
// static void setup_mmap_pread_p340_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p340_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p340_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p340_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p340_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_2_common
// static void setup_mmap_pread_p340_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p340_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb40_0_proc1
// static void setup_mmap_pread_p340_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p340_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p340_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p340_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p340_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pbc0_2_common
// static void setup_mmap_pread_p340_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p340_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_p340_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p340_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p340_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p340_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p340_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf0_5_common
// static void setup_mmap_pread_p340_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p340_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_p340_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p340_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p3e_0_0
// static int test_mmap_pread_p30_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
static int test_mmap_pread_p2f_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pread_p2f_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p2f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p2f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pae_0_proc0
// static void setup_mmap_pread_p2f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p2f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p2f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2f_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2f_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p2f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p2f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pae_1_proc0
// static void setup_mmap_pread_p2f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p2f_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p2f_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2f_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2f_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p2f_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p2f_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_2_proc0
// static void setup_mmap_pread_p2f_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p2f_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p2f_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2f_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2f_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p2f_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p2f_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_3_proc0
// static void setup_mmap_pread_p2f_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p2f_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p2f_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
static int test_mmap_pread_p2f_4_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pread_p2f_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p2f_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p2f_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pae_0_proc0
// static void setup_mmap_pread_p2f_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p2f_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p2f_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2f_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2f_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p2f_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p2f_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_2_proc0
// static void setup_mmap_pread_p2f_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p2f_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p2f_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2f_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2f_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p2f_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p2f_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pae_1_proc0
// static void setup_mmap_pread_p2f_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p2f_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p2f_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2f_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2f_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p2f_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p2f_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_3_proc0
// static void setup_mmap_pread_p2f_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p2f_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p2f_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2d8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p2d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p2d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_proc0
// static void setup_mmap_pread_p2d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2d8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2d8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2d8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2d8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p2d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p2d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_proc0
// static void setup_mmap_pread_p2d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2d8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2d8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2d8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2d8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p2d8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p2d8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_p2d8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2d8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2d8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2d8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2d8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p2d8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p2d8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_p2d8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2d8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2d8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2d8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2d8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p2d8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p2d8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p2d8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2d8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2d8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2d8_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2d8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p2d8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p2d8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p2d8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2d8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2d8_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2d8_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2d8_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p2d8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p2d8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p2d8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2d8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2d8_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2d8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2d8_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p2d8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p2d8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p2d8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2d8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2d8_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2c8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2c8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p2c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p2c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_0_proc0
// static void setup_mmap_pread_p2c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2c8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2c8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2c8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2c8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p2c8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p2c8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_0_proc0
// static void setup_mmap_pread_p2c8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2c8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2c8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2c8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2c8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p2c8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p2c8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_p2c8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2c8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2c8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2c8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2c8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p2c8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p2c8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_1_proc0
// static void setup_mmap_pread_p2c8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2c8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2c8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2c8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2c8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p2c8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p2c8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_1_proc0
// static void setup_mmap_pread_p2c8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2c8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2c8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2c8_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2c8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p2c8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p2c8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p2c8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2c8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2c8_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2c8_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2c8_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p2c8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p2c8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_3_proc0
// static void setup_mmap_pread_p2c8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2c8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2c8_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2c8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2c8_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p2c8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p2c8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p2c8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2c8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2c8_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_p2a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pa8_0_common
// static void setup_mmap_pread_p2a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p2a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_p2a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pa8_0_common
// static void setup_mmap_pread_p2a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p2a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2a_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p2a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_p2a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pa8_0_common
// static void setup_mmap_pread_p2a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p2a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2a_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p2a_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p2a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_p2a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pa8_0_common
// static void setup_mmap_pread_p2a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p2a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p2a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p2a_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p27_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p27_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p27_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p27_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_0_proc1
// static void setup_mmap_pread_p27_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p27_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p27_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p27_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p27_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p27_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p27_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_0_proc1
// static void setup_mmap_pread_p27_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p27_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p27_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p27_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p27_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p27_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p27_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_0_proc1
// static void setup_mmap_pread_p27_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p27_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p27_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p27_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p27_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p27_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p27_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_0_proc1
// static void setup_mmap_pread_p27_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p27_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p27_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p27_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p27_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p27_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p27_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_p27_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p27_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p27_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p27_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p27_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p27_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p27_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_p27_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p27_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p27_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p27_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p27_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p27_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p27_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_p27_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p27_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p27_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p27_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p27_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p27_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pae_0_common
// static void setup_mmap_pread_p27_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pb5_2_proc1
// static void setup_mmap_pread_p27_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p27_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p27_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p258_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p258_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p258_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p258_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p258_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p258_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p258_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p258_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p258_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p258_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p258_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p258_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p258_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p258_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p258_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p258_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p258_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p258_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p258_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p258_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p258_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p258_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p258_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p258_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p258_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p258_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p258_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p258_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p248_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p248_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p248_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p248_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_1_proc0
// static void setup_mmap_pread_p248_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_1_proc0
// static void setup_mmap_pread_p248_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p248_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p248_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p248_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p248_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p248_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_1_proc0
// static void setup_mmap_pread_p248_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_1_proc0
// static void setup_mmap_pread_p248_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p248_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p248_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p248_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p248_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p248_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p248_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p248_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p248_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p248_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p248_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p248_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p248_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p248_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p248_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p248_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p22_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p22_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p22_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pa8_0_common
// static void setup_mmap_pread_p22_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p22_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p22_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p22_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p22_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p22_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p22_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pa8_0_common
// static void setup_mmap_pread_p22_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p22_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p22_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p22_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p22_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_0_0
// static int test_mmap_pread_p22_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p22_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pa8_0_common
// static void setup_mmap_pread_p22_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p22_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p22_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p22_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p22_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p2f_4_0
// static int test_mmap_pread_p22_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p22_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pa8_0_common
// static void setup_mmap_pread_p22_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p22_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p22_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p22_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
static int test_mmap_pread_p1c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_pread_p1c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p1c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p1c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_1_proc0
// static void setup_mmap_pread_p1c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p1c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p1c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p1c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p1c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_1_1
// static void setup_mmap_pread_p1c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p1c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_4_proc0
// static void setup_mmap_pread_p1c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p1c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p1c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p1a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p1a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p1a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p1a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_1_proc0
// static void setup_mmap_pread_p1a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p1a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p1a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p1a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p1a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf4_0_1
// static void setup_mmap_pread_p1a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p1a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_4_proc0
// static void setup_mmap_pread_p1a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p1a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p1a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p18_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p18_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_1_proc0
// static void setup_mmap_pread_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p18_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p18_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p18_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p18_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf0_0_1
// static void setup_mmap_pread_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_4_proc0
// static void setup_mmap_pread_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p18_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p10_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p10_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_1_1
// static void setup_mmap_pread_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p10_0_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_p10_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p10_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p10_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_p10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p10_1_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_p10_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p0c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p0c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc0
// static void setup_mmap_pread_p0c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p0c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p0c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p0c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pf8_0_1
// static void setup_mmap_pread_p0c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pread_pf8_0_common
// static void setup_mmap_pread_p0c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pf8_0_proc1
// static void setup_mmap_pread_p0c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pread_pd8_1_proc1
// static void setup_mmap_pread_p0c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_final
// static void setup_mmap_pread_p0c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pread_pf8_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p0a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p0a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pd4_0_proc1
// static void setup_mmap_pread_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p0a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p0a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd4_0_1
// static void setup_mmap_pread_p0a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pread_pf4_0_common
// static void setup_mmap_pread_p0a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p0a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p0a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p0a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p08_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p08_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p08_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p08_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p08_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pac0_1_proc0
// static void setup_mmap_pread_p08_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p08_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p08_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p08_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pd0_0_1
// static void setup_mmap_pread_p08_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pread_pf0_0_common
// static void setup_mmap_pread_p08_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p08_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pread_pe0_1_proc0
// static void setup_mmap_pread_p08_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pread_pf4_0_final
// static void setup_mmap_pread_p08_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal

/*
 * calls: mmap pread
 */
// static int test_mmap_pread_p00_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pread_p1c_0_0
// static int test_mmap_pread_p00_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_pread_pe0_0_1
// static void setup_mmap_pread_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pread_pe0_0_common
// static void setup_mmap_pread_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pread_pf4_0_proc1
// static void setup_mmap_pread_p00_0_final(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal
// static void setup_mmap_pread_p00_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pread_pf4_0_procfinal


/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_pf8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_pwrite_pf8_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_mmap_pwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_pwrite_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_pwrite_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_pwrite_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
static int test_mmap_pwrite_pf8_1_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
// static void setup_mmap_pwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
static void setup_mmap_pwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf8_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
static void setup_mmap_pwrite_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf8_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
static void setup_mmap_pwrite_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf8_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
static void setup_mmap_pwrite_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
static int test_mmap_pwrite_pf4_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_mmap_pwrite_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mmap_pwrite_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_mmap_pwrite_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_pwrite_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_mmap_pwrite_pf4_0_procfinal(void) {
  
}

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf4_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf4_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pf4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pf4_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf4_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pf4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pf4_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf4_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf4_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
static void setup_mmap_pwrite_pf4_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pwrite_pf4_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pf4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pf4_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pf4_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf4_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf4_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
static void setup_mmap_pwrite_pf4_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pwrite_pf4_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pf4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pf4_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pf4_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
static void setup_mmap_pwrite_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_pwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
static void setup_mmap_pwrite_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pf0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_3_proc0
// static void setup_mmap_pwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pf0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf0_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
static void setup_mmap_pwrite_pf0_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pwrite_pf0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pf0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pf0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pf0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pf0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pf0_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pf0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_pf0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_5_proc0
// static void setup_mmap_pwrite_pf0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pf0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pf0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
static int test_mmap_pwrite_pe0_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
static void setup_mmap_pwrite_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mmap_pwrite_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pe0_0_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
static int test_mmap_pwrite_pe0_1_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_mmap_pwrite_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_pe0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pd8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pd8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pd8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pd8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
static void setup_mmap_pwrite_pd8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pd4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
static int test_mmap_pwrite_pd4_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_mmap_pwrite_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
static void setup_mmap_pwrite_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pd4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pd4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pd4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pd0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
static void setup_mmap_pwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pd0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pd0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_0
// static int test_mmap_pwrite_pc0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pc0_0_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_pbe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_pwrite_pbe_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
static void setup_mmap_pwrite_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbe_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
static void setup_mmap_pwrite_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbe_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbe_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_pbe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
static void setup_mmap_pwrite_pbe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pbe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbe_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbe_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbe_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_pbe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
static void setup_mmap_pwrite_pbe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pbe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbe_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbe_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_pbe_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pbe_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_pbe_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbe_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbe_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbe_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbe_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_pbe_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pbe_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pbe_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbe_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbe_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbd0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pbd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_5_common
// static void setup_mmap_pwrite_pbd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf0_4_proc0
// static void setup_mmap_pwrite_pbd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbd0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbd0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pbd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
// static void setup_mmap_pwrite_pbd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_5_proc0
// static void setup_mmap_pwrite_pbd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbd0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbd0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pbd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
static void setup_mmap_pwrite_pbd0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pbd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbd0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbd0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pbd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_5_common
static void setup_mmap_pwrite_pbd0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pbd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbc0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
static void setup_mmap_pwrite_pbc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pwrite_pbc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pbc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbc0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbc0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pbc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_pbc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_5_proc0
// static void setup_mmap_pwrite_pbc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbc0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbc0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbc0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbc0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pbc0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
static void setup_mmap_pwrite_pbc0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pbc0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbc0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbc0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pbc0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pbc0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
static void setup_mmap_pwrite_pbc0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_pwrite_pbc0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pbd0_3_proc0
// static void setup_mmap_pwrite_pbc0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pbc0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pbc0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb8_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb6_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb6_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb6_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb6_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_pb6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pb6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_pb6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pb6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb6_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb6_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_pb6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pb6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pb6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pb6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb50_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pb50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_5_common
// static void setup_mmap_pwrite_pb50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
static void setup_mmap_pwrite_pb50_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pb50_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb50_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb50_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb50_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pb50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
// static void setup_mmap_pwrite_pb50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
static void setup_mmap_pwrite_pb50_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pb50_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb50_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb50_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb50_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pb50_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
// static void setup_mmap_pwrite_pb50_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
static void setup_mmap_pwrite_pb50_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pb50_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb50_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb50_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb50_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pb50_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_5_common
// static void setup_mmap_pwrite_pb50_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pb50_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_pb50_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb50_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb40_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pb40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pbc0_0_common
// static void setup_mmap_pwrite_pb40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
static void setup_mmap_pwrite_pb40_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pb40_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb40_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb40_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb40_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pb40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_pb40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_pb40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_pb40_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb40_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb40_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb40_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pb40_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_pb40_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pb40_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_0_proc1
// static void setup_mmap_pwrite_pb40_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb40_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb40_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb40_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pb40_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_pb40_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pb40_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_pb40_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb40_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pbe_0_0
// static int test_mmap_pwrite_pb0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_pae_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_pwrite_pae_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
static void setup_mmap_pwrite_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_pwrite_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pae_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pae_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
static void setup_mmap_pwrite_pae_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pad0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pad0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pad0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_pad0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_proc0
// static void setup_mmap_pwrite_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pad0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pad0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pad0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pad0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pad0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_pad0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pad0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pad0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pad0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pad0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pad0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pad0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_pad0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_pad0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pad0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pad0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pad0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pad0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pad0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_pad0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pad0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pad0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pad0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pac0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pac0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pac0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_pac0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_proc0
// static void setup_mmap_pwrite_pac0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pac0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pac0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pac0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pac0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_pac0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_pac0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_pac0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pac0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pac0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pac0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pac0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pac0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
static void setup_mmap_pwrite_pac0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pac0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pac0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pac0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pac0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pac0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pac0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_pac0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pac0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pac0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pac0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pa8_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
static void setup_mmap_pwrite_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_pwrite_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pa6_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
static void setup_mmap_pwrite_pa6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_pwrite_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_pa6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pa6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pa6_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pa6_0_proc0
// static void setup_mmap_pwrite_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_pa6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_pa6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pa50_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pa50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_pa50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_pa50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd4_0_proc1
// static void setup_mmap_pwrite_pa50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pa50_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa50_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
static int test_mmap_pwrite_pa50_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_mmap_pwrite_pa50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
static void setup_mmap_pwrite_pa50_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pa50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pa50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pa50_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa50_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pa50_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pa50_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_pa50_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pa50_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pa50_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pa50_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa50_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pa50_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pa50_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_pa50_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pa50_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pa50_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pa50_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pa40_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pa40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
static void setup_mmap_pwrite_pa40_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pa40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd0_0_proc1
// static void setup_mmap_pwrite_pa40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pa40_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa40_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
static int test_mmap_pwrite_pa40_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 12288);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_mmap_pwrite_pa40_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_pwrite_pa40_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_pa40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_proc0
// static void setup_mmap_pwrite_pa40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pa40_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa40_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pa40_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pa40_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_pa40_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_2_proc0
// static void setup_mmap_pwrite_pa40_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pa40_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pa40_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa40_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pa40_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_pa40_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_pa40_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pa40_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_pa40_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pa40_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pae_0_0
// static int test_mmap_pwrite_pa0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_proc0
// static void setup_mmap_pwrite_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p9c_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_pwrite_p9c_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_1_proc0
// static void setup_mmap_pwrite_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p9c_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p9c_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p9c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_4_proc0
// static void setup_mmap_pwrite_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p9a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p9a_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_1_proc0
// static void setup_mmap_pwrite_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p9a_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p9a_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p9a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_3_proc0
// static void setup_mmap_pwrite_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p98_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p98_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
static void setup_mmap_pwrite_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p98_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p98_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p98_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_3_proc0
// static void setup_mmap_pwrite_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p98_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p90_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p90_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p90_0_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p90_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p90_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p90_1_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_p90_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p8c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p8c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p8c_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p8c_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p8a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p8a_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd4_0_proc1
// static void setup_mmap_pwrite_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p8a_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p8a_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p88_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p88_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd0_0_proc1
// static void setup_mmap_pwrite_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p88_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p88_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p88_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p88_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p80_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p9c_0_0
// static int test_mmap_pwrite_p80_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p80_0_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_p80_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p7c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pwrite_p7c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p7c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p7c_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p7c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p7c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_1_proc0
// static void setup_mmap_pwrite_p7c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p7c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p7c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p7c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p7c_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p7c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p7c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_2_proc0
// static void setup_mmap_pwrite_p7c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p7c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p7c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p7c_3_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pwrite_p7c_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p7c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p7c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p7c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p7c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p7c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p7c_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p7c_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p7c_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p7c_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_2_proc0
// static void setup_mmap_pwrite_p7c_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p7c_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p7c_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p7c_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p7c_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p7c_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p7c_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_1_proc0
// static void setup_mmap_pwrite_p7c_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p7c_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p7c_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p7c_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p7c_6_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p7c_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p7c_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_3_proc0
// static void setup_mmap_pwrite_p7c_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p7c_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p7c_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p7c_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p7c_7_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p7c_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p7c_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_4_proc0
// static void setup_mmap_pwrite_p7c_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p7c_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p7c_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p7c_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p7c_8_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p7c_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p7c_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_4_proc0
// static void setup_mmap_pwrite_p7c_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p7c_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p7c_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p7c_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p7c_9_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p7c_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p7c_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_3_proc0
// static void setup_mmap_pwrite_p7c_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p7c_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p7c_9_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p76_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p76_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_proc0
// static void setup_mmap_pwrite_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p76_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p76_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p76_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p76_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_1_proc0
// static void setup_mmap_pwrite_p76_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p76_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p76_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p76_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p76_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_1_proc0
// static void setup_mmap_pwrite_p76_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p76_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p76_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p76_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p76_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_3_proc0
// static void setup_mmap_pwrite_p76_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p76_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p76_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p76_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p76_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_3_proc0
// static void setup_mmap_pwrite_p76_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p76_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p76_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p76_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_p76_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p76_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p76_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p76_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p76_6_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
// static void setup_mmap_pwrite_p76_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_4_proc0
// static void setup_mmap_pwrite_p76_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p76_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p76_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p76_7_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
// static void setup_mmap_pwrite_p76_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_5_proc0
// static void setup_mmap_pwrite_p76_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p76_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p76_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p76_8_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_p76_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p76_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p76_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p76_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p76_9_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p76_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_p76_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p76_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p76_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p76_10_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
// static void setup_mmap_pwrite_p76_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_4_proc0
// static void setup_mmap_pwrite_p76_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p76_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p76_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p76_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p76_11_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p76_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_5_common
// static void setup_mmap_pwrite_p76_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_5_proc0
// static void setup_mmap_pwrite_p76_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p76_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p76_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p72_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p72_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_proc0
// static void setup_mmap_pwrite_p72_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p72_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p72_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p72_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p72_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_1_proc0
// static void setup_mmap_pwrite_p72_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p72_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p72_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p72_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p72_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_3_proc0
// static void setup_mmap_pwrite_p72_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p72_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p72_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p72_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_p72_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf0_4_proc0
// static void setup_mmap_pwrite_p72_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p72_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p72_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p72_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p72_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_p72_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p72_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p72_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p72_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_p72_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_5_proc0
// static void setup_mmap_pwrite_p72_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p72_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p72_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p72_6_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p72_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_proc0
// static void setup_mmap_pwrite_p72_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p72_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p72_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p72_7_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p72_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_1_proc0
// static void setup_mmap_pwrite_p72_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p72_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p72_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p72_8_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p72_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_3_proc0
// static void setup_mmap_pwrite_p72_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p72_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p72_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p72_9_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p72_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_p72_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p72_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p72_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p72_10_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_p72_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf0_4_proc0
// static void setup_mmap_pwrite_p72_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p72_10_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p72_10_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p72_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p72_11_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p72_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_p72_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_5_proc0
// static void setup_mmap_pwrite_p72_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p72_11_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p72_11_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p68_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p68_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p68_0_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_p68_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p68_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p68_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p68_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p68_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p68_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p68_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_p68_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p68_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p68_2_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_p68_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p68_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p68_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_p68_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p68_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p68_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p68_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p68_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p5c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p5c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p5c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p5c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p5c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p5c_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p5c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p5c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p5c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p5c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p5c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p5c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p5c_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p5c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p5c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p5c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p5c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p5c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p5c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p5c_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p5c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p5c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p5c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p5c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p5c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p56_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p56_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p56_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p56_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p56_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd4_0_proc1
// static void setup_mmap_pwrite_p56_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p56_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p56_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p56_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p56_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p56_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p56_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p56_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p56_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p56_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p56_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p56_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p56_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p56_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p56_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p56_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p56_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p56_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p56_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p56_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p56_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p56_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p56_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p52_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p52_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p52_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p52_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p52_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd0_0_proc1
// static void setup_mmap_pwrite_p52_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p52_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p52_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p52_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p52_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p52_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p52_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p52_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p52_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p52_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p52_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p52_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p52_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p52_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd4_0_proc1
// static void setup_mmap_pwrite_p52_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p52_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p52_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p52_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p52_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p52_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p52_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p52_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p52_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p48_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_0_0
// static int test_mmap_pwrite_p48_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_p48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p48_0_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_p48_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p48_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p7c_3_0
// static int test_mmap_pwrite_p48_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_p48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p48_1_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_p48_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p3e_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_pwrite_p3e_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p3e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p3e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pbe_0_proc0
// static void setup_mmap_pwrite_p3e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3e_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p3e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p3e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pbe_1_proc0
// static void setup_mmap_pwrite_p3e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3e_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3e_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p3e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p3e_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pbe_3_proc0
// static void setup_mmap_pwrite_p3e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3e_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3e_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3e_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3e_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p3e_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p3e_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p3e_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3e_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3e_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3e_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3e_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p3e_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p3e_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p3e_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3e_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3e_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3d0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3d0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p3d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_5_common
// static void setup_mmap_pwrite_p3d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf0_4_proc0
// static void setup_mmap_pwrite_p3d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3d0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3d0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p3d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
// static void setup_mmap_pwrite_p3d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_5_proc0
// static void setup_mmap_pwrite_p3d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3d0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3d0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p3d0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
// static void setup_mmap_pwrite_p3d0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pbd0_2_proc0
// static void setup_mmap_pwrite_p3d0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3d0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3d0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3d0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3d0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p3d0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_5_common
// static void setup_mmap_pwrite_p3d0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pbd0_3_proc0
// static void setup_mmap_pwrite_p3d0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3d0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3d0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3c0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3c0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p3c0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pbc0_0_common
// static void setup_mmap_pwrite_p3c0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pbc0_0_proc0
// static void setup_mmap_pwrite_p3c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3c0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3c0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3c0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3c0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p3c0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_p3c0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf4_5_proc0
// static void setup_mmap_pwrite_p3c0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3c0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3c0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3c0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3c0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p3c0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_p3c0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pbc0_2_proc0
// static void setup_mmap_pwrite_p3c0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3c0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3c0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p3c0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p3c0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p3c0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_p3c0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pbd0_3_proc0
// static void setup_mmap_pwrite_p3c0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p3c0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p3c0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p38_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p38_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p38_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p38_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p36_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p36_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p36_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p36_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p36_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p36_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p36_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p36_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p36_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p36_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p36_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p36_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p36_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p36_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p36_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p36_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p36_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p36_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p36_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p36_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p36_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p36_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p36_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p350_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p350_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p350_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_5_common
// static void setup_mmap_pwrite_p350_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p350_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_0_proc1
// static void setup_mmap_pwrite_p350_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p350_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p350_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p350_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p350_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
// static void setup_mmap_pwrite_p350_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p350_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_p350_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p350_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p350_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p350_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p350_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_4_common
// static void setup_mmap_pwrite_p350_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p350_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_2_proc1
// static void setup_mmap_pwrite_p350_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p350_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p350_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p350_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p350_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf4_5_common
// static void setup_mmap_pwrite_p350_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p350_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_p350_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p350_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p340_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p340_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p340_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pbc0_0_common
// static void setup_mmap_pwrite_p340_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p340_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb40_0_proc1
// static void setup_mmap_pwrite_p340_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p340_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p340_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p340_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p340_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_p340_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p340_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_p340_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p340_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p340_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p340_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p340_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_p340_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p340_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_0_proc1
// static void setup_mmap_pwrite_p340_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p340_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p340_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p340_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p340_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf0_4_common
// static void setup_mmap_pwrite_p340_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p340_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_p340_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p340_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p30_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p3e_0_0
// static int test_mmap_pwrite_p30_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p2f_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pwrite_p2f_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p2f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p2f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pae_0_proc0
// static void setup_mmap_pwrite_p2f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p2f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p2f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2f_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2f_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p2f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p2f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pae_1_proc0
// static void setup_mmap_pwrite_p2f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p2f_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p2f_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2f_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2f_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p2f_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p2f_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_2_proc0
// static void setup_mmap_pwrite_p2f_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p2f_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p2f_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2f_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2f_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p2f_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p2f_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_3_proc0
// static void setup_mmap_pwrite_p2f_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p2f_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p2f_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p2f_4_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_pwrite_p2f_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p2f_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p2f_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pae_0_proc0
// static void setup_mmap_pwrite_p2f_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p2f_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p2f_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2f_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2f_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p2f_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p2f_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_2_proc0
// static void setup_mmap_pwrite_p2f_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p2f_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p2f_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2f_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2f_6_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p2f_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p2f_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pae_1_proc0
// static void setup_mmap_pwrite_p2f_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p2f_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p2f_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2f_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2f_7_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p2f_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p2f_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_3_proc0
// static void setup_mmap_pwrite_p2f_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p2f_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p2f_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2d8_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p2d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p2d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_proc0
// static void setup_mmap_pwrite_p2d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2d8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p2d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_p2d8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p2d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2d8_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p2d8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p2d8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_p76_8_proc0
// static void setup_mmap_pwrite_p2d8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
static int test_mmap_pwrite_p2d8_3_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_mmap_pwrite_p2d8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_pwrite_p2d8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23973888, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p2d8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
static int test_mmap_pwrite_p2d8_4_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_mmap_pwrite_p2d8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2d8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_p2d8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p2d8_5_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1000UL);
  
  return xerrno(r);
}
// static int test_mmap_pwrite_p2d8_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p2d8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_p2d8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p2d8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p2d8_6_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x7000UL);
  
  return xerrno(r);
}
// static int test_mmap_pwrite_p2d8_6_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2d8_3_1
// static void setup_mmap_pwrite_p2d8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_p2d8_3_common
static void setup_mmap_pwrite_p2d8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p2d8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2d8_7_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p2d8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p2d8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_p2d8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2d8_8_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p2d8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p2d8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_p2d8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2d8_9_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa50_1_1
// static void setup_mmap_pwrite_p2d8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2d8_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p2d8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2d8_10_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p2d8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p2d8_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p2d8_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2d8_11_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa50_1_1
// static void setup_mmap_pwrite_p2d8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2d8_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p2d8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2d8_5_0
// static int test_mmap_pwrite_p2d8_12_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p2d8_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p2d8_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_1_proc0
// static void setup_mmap_pwrite_p2d8_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2d8_13_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p2d8_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p2d8_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa40_0_proc0
// static void setup_mmap_pwrite_p2d8_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2d8_14_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2d8_14_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p2d8_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p2d8_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p2d8_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2d8_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2d8_14_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2c8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2c8_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p2c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_proc0
// static void setup_mmap_pwrite_p2c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2c8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2c8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2c8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2c8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p2c8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2c8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p2c8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2c8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2c8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2c8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2c8_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p2c8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2c8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_proc0
// static void setup_mmap_pwrite_p2c8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2c8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2c8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2c8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2c8_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p2c8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
static void setup_mmap_pwrite_p2c8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p2c8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2c8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2c8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2c8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2c8_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p2c8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2c8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_p2c8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2c8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2c8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2c8_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2c8_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p2c8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2c8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_2_proc0
// static void setup_mmap_pwrite_p2c8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2c8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2c8_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2c8_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2c8_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p2c8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2c8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p2c8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2c8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2c8_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2c8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2c8_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p2c8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2c8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p2c8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2c8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2c8_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2c8_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2c8_8_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p2c8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p2c8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p2c8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2c8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2c8_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2a_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_p2a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_p2a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_proc0
// static void setup_mmap_pwrite_p2a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2a_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_p2a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_p2a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_proc0
// static void setup_mmap_pwrite_p2a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2a_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p2a_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_p2a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_p2a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p2a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2a_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p2a_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p2a_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_p2a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_p2a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p2a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p2a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p2a_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p27_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p27_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p27_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p27_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pa6_0_proc0
// static void setup_mmap_pwrite_p27_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p27_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p27_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p27_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p27_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p27_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p27_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pa6_0_proc0
// static void setup_mmap_pwrite_p27_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p27_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p27_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p27_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p27_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p27_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p27_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pa6_0_proc0
// static void setup_mmap_pwrite_p27_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p27_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p27_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p27_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p27_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p27_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p27_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pa6_0_proc0
// static void setup_mmap_pwrite_p27_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p27_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p27_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p27_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p27_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p27_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p27_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_p27_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p27_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p27_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p27_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p27_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p27_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p27_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_p27_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p27_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p27_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p27_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p27_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p27_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p27_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_p27_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p27_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p27_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p27_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p27_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p27_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pae_0_common
// static void setup_mmap_pwrite_p27_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pb50_1_proc1
// static void setup_mmap_pwrite_p27_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p27_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p27_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p258_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p258_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p258_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p258_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd4_0_proc1
// static void setup_mmap_pwrite_p258_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p258_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p258_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p258_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p258_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p258_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p258_2_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x705000UL);
  
  return xerrno(r);
}
// static int test_mmap_pwrite_p258_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p258_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
static void setup_mmap_pwrite_p258_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7360512, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p258_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa40_0_proc0
// static void setup_mmap_pwrite_p258_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p258_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa50_1_1
// static void setup_mmap_pwrite_p258_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p258_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p258_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa50_1_1
// static void setup_mmap_pwrite_p258_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p258_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p258_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd4_0_proc1
// static void setup_mmap_pwrite_p258_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p258_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa50_1_1
// static void setup_mmap_pwrite_p258_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p258_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_p2d8_1_proc0
// static void setup_mmap_pwrite_p258_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p258_6_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1000UL);
  
  return xerrno(r);
}
// static int test_mmap_pwrite_p258_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa50_1_1
// static void setup_mmap_pwrite_p258_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p258_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_1_proc0
// static void setup_mmap_pwrite_p258_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p258_7_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x6000UL);
  
  return xerrno(r);
}
static int test_mmap_pwrite_p258_7_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_mmap_pwrite_p258_7_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mmap_pwrite_p258_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_p2d8_1_proc0
// static void setup_mmap_pwrite_p258_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pad0_1_proc0
// static void setup_mmap_pwrite_p258_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p258_8_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p258_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p258_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_1_proc0
// static void setup_mmap_pwrite_p258_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p258_9_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p258_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p258_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2d8_5_0
// static int test_mmap_pwrite_p258_10_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p258_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p258_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_2_proc0
// static void setup_mmap_pwrite_p258_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_1_proc0
// static void setup_mmap_pwrite_p258_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p258_11_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa50_1_1
// static void setup_mmap_pwrite_p258_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p258_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_1_proc0
// static void setup_mmap_pwrite_p258_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p258_12_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p258_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p258_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_2_proc0
// static void setup_mmap_pwrite_p258_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p258_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p258_13_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p258_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p258_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p258_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p258_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p248_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p248_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p248_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa40_0_proc0
// static void setup_mmap_pwrite_p248_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd0_0_proc1
// static void setup_mmap_pwrite_p248_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p248_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p248_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p248_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p248_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p248_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p248_2_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x20ae000UL);
  
  return xerrno(r);
}
static int test_mmap_pwrite_p248_2_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_mmap_pwrite_p248_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_p258_7_common
static void setup_mmap_pwrite_p248_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34267136, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p248_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p248_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p248_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa50_1_1
// static void setup_mmap_pwrite_p248_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_p248_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_p2d8_1_proc0
static void setup_mmap_pwrite_p248_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p248_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p248_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa50_1_1
// static void setup_mmap_pwrite_p248_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
static void setup_mmap_pwrite_p248_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9355264, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p248_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p248_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p248_5_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x3000UL);
  
  return xerrno(r);
}
// static int test_mmap_pwrite_p248_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa40_1_1
// static void setup_mmap_pwrite_p248_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa40_1_common
// static void setup_mmap_pwrite_p248_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_1_proc0
// static void setup_mmap_pwrite_p248_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_proc0
// static void setup_mmap_pwrite_p248_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x6000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p258_7_0
// static int test_mmap_pwrite_p248_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p248_2_1
// static void setup_mmap_pwrite_p248_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_p258_7_common
static void setup_mmap_pwrite_p248_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_mmap_pwrite_p248_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p248_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2d8_5_0
// static int test_mmap_pwrite_p248_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p248_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p248_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p248_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p248_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p248_8_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p248_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p248_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p248_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pac0_2_proc0
// static void setup_mmap_pwrite_p248_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p248_9_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pa50_1_1
// static void setup_mmap_pwrite_p248_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_p248_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p248_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_1_proc0
// static void setup_mmap_pwrite_p248_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_10_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p248_10_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p248_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p248_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p248_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa50_2_proc0
// static void setup_mmap_pwrite_p248_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_10_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_11_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p248_11_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p248_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p248_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
static void setup_mmap_pwrite_p248_11_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1843200, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_pwrite_p248_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_11_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_12_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p248_12_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p248_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p248_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p248_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p248_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_12_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p248_13_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p248_13_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p248_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p248_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p248_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p248_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p248_13_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p22_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p22_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p22_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_p22_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_proc0
// static void setup_mmap_pwrite_p22_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p22_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p22_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p22_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p22_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p22_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_p22_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_proc0
// static void setup_mmap_pwrite_p22_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p22_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p22_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p22_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_0_0
// static int test_mmap_pwrite_p22_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p22_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_p22_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p22_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p22_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p22_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p22_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p2f_4_0
// static int test_mmap_pwrite_p22_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p22_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pa8_0_common
// static void setup_mmap_pwrite_p22_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p22_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p22_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p22_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
static int test_mmap_pwrite_p1c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_pwrite_p1c_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p1c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p1c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_1_proc0
// static void setup_mmap_pwrite_p1c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p1c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p1c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p1c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p1c_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_1_1
// static void setup_mmap_pwrite_p1c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p1c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_4_proc0
// static void setup_mmap_pwrite_p1c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p1c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p1c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p1a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p1a_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p1a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p1a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_1_proc0
// static void setup_mmap_pwrite_p1a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p1a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p1a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p1a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p1a_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p1a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p1a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_3_proc0
// static void setup_mmap_pwrite_p1a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p1a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p1a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p18_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p18_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_p98_0_proc0
// static void setup_mmap_pwrite_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p18_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p18_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p18_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p18_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf4_0_1
// static void setup_mmap_pwrite_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_3_proc0
// static void setup_mmap_pwrite_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p18_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p18_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p10_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p10_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_1_1
// static void setup_mmap_pwrite_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p10_0_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_p10_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p10_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p10_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_p10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p10_1_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_p10_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p0c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p0c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc0
// static void setup_mmap_pwrite_p0c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p0c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p0c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p0c_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pf8_0_1
// static void setup_mmap_pwrite_p0c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_pwrite_pf8_0_common
// static void setup_mmap_pwrite_p0c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pf8_0_proc1
// static void setup_mmap_pwrite_p0c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_pwrite_pd8_1_proc1
// static void setup_mmap_pwrite_p0c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_final
// static void setup_mmap_pwrite_p0c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_pwrite_pf8_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p0a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p0a_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd4_0_proc1
// static void setup_mmap_pwrite_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p0a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p0a_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p0a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf4_0_common
// static void setup_mmap_pwrite_p0a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p0a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p0a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p0a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p08_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p08_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p08_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p08_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p08_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pd0_0_proc1
// static void setup_mmap_pwrite_p08_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p08_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p08_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p08_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pd4_0_1
// static void setup_mmap_pwrite_p08_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pf0_0_common
// static void setup_mmap_pwrite_p08_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p08_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_pwrite_pe0_1_proc0
// static void setup_mmap_pwrite_p08_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_pwrite_pf4_0_final
// static void setup_mmap_pwrite_p08_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal

/*
 * calls: mmap pwrite
 */
// static int test_mmap_pwrite_p00_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_p1c_0_0
// static int test_mmap_pwrite_p00_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_pwrite_pe0_0_1
// static void setup_mmap_pwrite_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pe0_0_common
// static void setup_mmap_pwrite_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_pwrite_pf4_0_proc1
// static void setup_mmap_pwrite_p00_0_final(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal
// static void setup_mmap_pwrite_p00_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_pwrite_pf4_0_procfinal


/*
 * calls: mmap read
 */
static int test_mmap_read_pfc_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_read_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_mmap_read_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_read_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_read_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_read_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
static int test_mmap_read_pfc_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_mmap_read_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
static void setup_mmap_read_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pfc_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
static void setup_mmap_read_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pfc_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_pfc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
static void setup_mmap_read_pfc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pfc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pfc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pfc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
static int test_mmap_read_pfb0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_mmap_read_pfb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_pfb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pfb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pfb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pfb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pfb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_pfb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
static void setup_mmap_read_pfb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pfb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pfb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pfb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfb0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pfb0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_pfb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
static void setup_mmap_read_pfb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pfb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pfb0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pfb0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfb0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pfb0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_pfb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
static void setup_mmap_read_pfb0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pfb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pfb0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pfb0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
static int test_mmap_read_pfa0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_mmap_read_pfa0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_read_pfa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_pfa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pfa0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pfa0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfa0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pfa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_pfa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
static void setup_mmap_read_pfa0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_read_pfa0_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pfa0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pfa0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfa0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pfa0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_pfa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
static void setup_mmap_read_pfa0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pfa0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_pfa0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pfa0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pfa0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pfa0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
static void setup_mmap_read_pfa0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_pfa0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_read_pfa0_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_read_pfa0_3_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_mmap_read_pfa0_3_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: mmap read
 */
// static int test_mmap_read_pf8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
static int test_mmap_read_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_mmap_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_read_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pf8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_1_proc0
// static void setup_mmap_read_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pf8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pf8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pf8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pf8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pf8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_3_proc0
// static void setup_mmap_read_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pf4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pf4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
static void setup_mmap_read_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mmap_read_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_mmap_read_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_read_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_mmap_read_pf4_0_procfinal(void) {
  
}

/*
 * calls: mmap read
 */
// static int test_mmap_read_pf4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
static void setup_mmap_read_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pf4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pf4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
static void setup_mmap_read_pf4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pf0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
static void setup_mmap_read_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_read_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pf0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
static void setup_mmap_read_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pf0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pf0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
static void setup_mmap_read_pf0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pe0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
static void setup_mmap_read_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mmap_read_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pe0_0_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pe0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
static void setup_mmap_read_pe0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pdc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pdb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
static int test_mmap_read_pdb0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_mmap_read_pdb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_pdb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
static void setup_mmap_read_pdb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pdb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pdb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pdb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pdb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_pdb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
static void setup_mmap_read_pdb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pdb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pdb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pdb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pdb0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pdb0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_pdb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_pdb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pdb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pdb0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pdb0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pdb0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pdb0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_pdb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_pdb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pdb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pdb0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pdb0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pda0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
static int test_mmap_read_pda0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_mmap_read_pda0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_pda0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
static void setup_mmap_read_pda0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pda0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pda0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pda0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pda0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pda0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
static void setup_mmap_read_pda0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pda0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_pda0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pda0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pda0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pda0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
static void setup_mmap_read_pda0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_pda0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_read_pda0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_read_pda0_2_final(void) {
  unlink("__i0");
  close(22);
  close(23);
  close(20);
  close(21);
}
static void setup_mmap_read_pda0_2_procfinal(void) {
  close(22);
  close(23);
  close(20);
  close(21);
}

/*
 * calls: mmap read
 */
// static int test_mmap_read_pda0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pda0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pda0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_3_common
static void setup_mmap_read_pda0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_read_pda0_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pda0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_pda0_3_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pda0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pda0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pda0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_pda0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_pda0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_pda0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pda0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pd8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
static int test_mmap_read_pd8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_mmap_read_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pd4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
static void setup_mmap_read_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pfc_0_0
// static int test_mmap_read_pc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pc0_0_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_pbf_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_read_pbf_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_pbf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
static void setup_mmap_read_pbf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pbf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbf_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbf_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_pbf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_pbf_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_1_proc0
// static void setup_mmap_read_pbf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbf_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbf_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_pbf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_pbf_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pbf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbec_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_pbec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_pbec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_pbec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbec_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbec_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_pbec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_pbec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_3_proc0
// static void setup_mmap_read_pbec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbec_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbec_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_pbec_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_pbec_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pbec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbec_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbec_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbe8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbe8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
static void setup_mmap_read_pbe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_pbe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pbe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_3_proc1
// static void setup_mmap_read_pbe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_pbe8_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbe8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbe8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_pbe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pbe8_0_common
// static void setup_mmap_read_pbe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(22, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_3_proc0
// static void setup_mmap_read_pbe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_3_proc1
// static void setup_mmap_read_pbe8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_pbe8_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbe8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbe8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_pbe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
static void setup_mmap_read_pbe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pbe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_pbe8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbe8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbe8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbe8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pbe8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_pbe8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_pbe8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_pbe8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbe8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbe0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_pbe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pbe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_pbe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbe0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_pbe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pbe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_3_proc0
// static void setup_mmap_read_pbe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbe0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbe0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_pbe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pbe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pbe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbe0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbe0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbd_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbd_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_pbd_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf4_2_common
// static void setup_mmap_read_pbd_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pf4_2_proc0
// static void setup_mmap_read_pbd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbd_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbd_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbd_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbd_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
static void setup_mmap_read_pbd_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_pbd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pbd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbd_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbd_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_pbc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf0_2_common
// static void setup_mmap_read_pbc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pf0_2_proc0
// static void setup_mmap_read_pbc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pbc0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pbc0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
static void setup_mmap_read_pbc0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_pbc0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pbc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pbc0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pbc0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb7_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_pb7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_pb7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pb7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pb7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb7_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_pb7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_pb7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pb7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pb7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb6c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb6c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_pb6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_pb6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pb6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pb6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb6c_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb6c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_pb6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_pb6c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pb6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pb6c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb6c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb68_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pb68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pda0_2_common
// static void setup_mmap_read_pb68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_2_proc0
// static void setup_mmap_read_pb68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_2_proc1
// static void setup_mmap_read_pb68_0_final(void) {
//   unlink("__i0");
//   close(22);
//   close(23);
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pda0_2_final
// static void setup_mmap_read_pb68_0_procfinal(void) {
//   close(22);
//   close(23);
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pda0_2_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb68_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pb68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_3_common
// static void setup_mmap_read_pb68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_3_proc0
// static void setup_mmap_read_pb68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_3_proc1
// static void setup_mmap_read_pb68_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_pb68_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb68_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb68_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pb68_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_pb68_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_pb68_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_pb68_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb68_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb60_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_pb60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pb60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pb60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pb60_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb60_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb60_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb60_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_pb60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pb60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pb60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pb60_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb60_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb5_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pb5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf4_2_common
// static void setup_mmap_read_pb5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
static void setup_mmap_read_pb5_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pb5_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb5_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb5_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pb5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf4_2_common
// static void setup_mmap_read_pb5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pb5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pb5_0_proc1
// static void setup_mmap_read_pb5_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb5_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_pb40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf0_2_common
// static void setup_mmap_read_pb40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
static void setup_mmap_read_pb40_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_pb40_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb40_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb40_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb40_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_pb40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf0_2_common
// static void setup_mmap_read_pb40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pb40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pb40_0_proc1
// static void setup_mmap_read_pb40_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb40_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_pbf_0_0
// static int test_mmap_read_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_paf_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_read_paf_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
static void setup_mmap_read_paf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_paf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_paf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_paf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_paf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_paec_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_paec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_paec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_paec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_paec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_paec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_paec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pae8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pae8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_pae8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_pae8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_2_proc0
// static void setup_mmap_read_pae8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_pae8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pae8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pae0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pae0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_pae0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pae0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_pae0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_pae0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pae0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pad_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pad_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_pad_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_pad_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_proc0
// static void setup_mmap_read_pad_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pad_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pad_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pad_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pad_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pad_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_pad_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pd4_0_proc1
// static void setup_mmap_read_pad_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pad_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pad_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pac0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pac0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_pac0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_pac0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_proc0
// static void setup_mmap_read_pac0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pac0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pac0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pac0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pac0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_pac0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_pac0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_pac0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pac0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pac0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
static void setup_mmap_read_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_read_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pa7_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pa7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_pa7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_paf_0_common
// static void setup_mmap_read_pa7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_pa7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_pa7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pa7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pa6c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pa6c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_pa6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_pa6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_pa6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pa6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pa6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pa68_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pa68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pa68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_pa68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_1_proc0
// static void setup_mmap_read_pa68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_pa68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pa68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pa60_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pa60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_pa60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_pa60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_pa60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_pa60_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_pa60_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pa5_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pa5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_pa5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_pa5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pd4_0_proc1
// static void setup_mmap_read_pa5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pd4_0_proc1
// static void setup_mmap_read_pa5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pa5_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pa40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pa40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_pa40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_pa40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_pa40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_pa40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pa40_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_read_paf_0_0
// static int test_mmap_read_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_common
// static void setup_mmap_read_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_proc0
// static void setup_mmap_read_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p9e_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_read_p9e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p9e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_2_proc0
// static void setup_mmap_read_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p9d8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p9d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p9d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p9d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_1_proc0
// static void setup_mmap_read_p9d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p9d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p9d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p9d0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p9d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p9d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p9d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc0
// static void setup_mmap_read_p9d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p9d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p9d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p9c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p9c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_1_proc0
// static void setup_mmap_read_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p9a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p9a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
static void setup_mmap_read_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p98_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_1_proc0
// static void setup_mmap_read_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p98_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p90_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p90_0_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_p90_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p90_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p90_1_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_p90_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p8e_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p8e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p8e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p8e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p8d8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p8d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p8d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p8d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p8d0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p8d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p8d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p8d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p8d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p8c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p8c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p8a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p8a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pd4_0_proc1
// static void setup_mmap_read_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p88_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p88_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p88_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p80_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p9e_0_0
// static int test_mmap_read_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p80_0_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_p80_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p7e_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_read_p7e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p7e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p7e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p7e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p7e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p7e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_1_proc0
// static void setup_mmap_read_p7e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7e_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7e_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p7e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p7e_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_2_proc0
// static void setup_mmap_read_p7e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7e_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7e_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7e_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7e_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p7e_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p7e_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_3_proc0
// static void setup_mmap_read_p7e_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7e_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7e_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p7e_4_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_read_p7e_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p7e_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p7e_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_1_proc0
// static void setup_mmap_read_p7e_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7e_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7e_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7e_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7e_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p7e_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p7e_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_3_proc0
// static void setup_mmap_read_p7e_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7e_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7e_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7e_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7e_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p7e_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p7e_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_2_proc0
// static void setup_mmap_read_p7e_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7e_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7e_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7e_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7e_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p7e_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p7e_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pbf_0_proc0
// static void setup_mmap_read_p7e_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7e_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7e_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7b8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p7b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p7b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_p7b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7b8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7b8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7b8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7b8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p7b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p7b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_1_proc0
// static void setup_mmap_read_p7b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7b8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7b8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7b8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7b8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p7b8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p7b8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_p7b8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7b8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7b8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7b8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7b8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p7b8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p7b8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_3_proc0
// static void setup_mmap_read_p7b8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7b8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7b8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7b8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7b8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p7b8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p7b8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_p7b8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7b8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7b8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7b8_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7b8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p7b8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p7b8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_p7b8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7b8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7b8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7b8_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7b8_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p7b8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p7b8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_1_proc0
// static void setup_mmap_read_p7b8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7b8_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7b8_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7b8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7b8_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p7b8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p7b8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_3_proc0
// static void setup_mmap_read_p7b8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7b8_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7b8_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7a8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7a8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p7a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p7a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_p7a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7a8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7a8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7a8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7a8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p7a8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p7a8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc0
// static void setup_mmap_read_p7a8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p7a8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7a8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7a8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7a8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p7a8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p7a8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_2_proc0
// static void setup_mmap_read_p7a8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p7a8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7a8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7a8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7a8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p7a8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p7a8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc0
// static void setup_mmap_read_p7a8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p7a8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7a8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7a8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p7a8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p7a8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_3_common
// static void setup_mmap_read_p7a8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(22, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_3_proc0
// static void setup_mmap_read_p7a8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_3_proc1
// static void setup_mmap_read_p7a8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_p7a8_4_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7a8_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7a8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p7a8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p7a8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_2_proc0
// static void setup_mmap_read_p7a8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p7a8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7a8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7a8_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7a8_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p7a8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_3_common
// static void setup_mmap_read_p7a8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(22, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pbe8_0_proc0
// static void setup_mmap_read_p7a8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_3_proc1
// static void setup_mmap_read_p7a8_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_p7a8_6_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7a8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7a8_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p7a8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p7a8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_p7a8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p7a8_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p7a8_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p7a8_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p7a8_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p7a8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_3_common
// static void setup_mmap_read_p7a8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(22, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_3_proc0
// static void setup_mmap_read_p7a8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_3_proc1
// static void setup_mmap_read_p7a8_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_p7a8_8_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p790_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p790_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p790_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p790_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_p790_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p790_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p790_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p790_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p790_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p790_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p790_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_1_proc0
// static void setup_mmap_read_p790_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p790_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p790_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p790_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p790_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p790_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p790_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_p790_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p790_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p790_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p790_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p790_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p790_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p790_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_3_proc0
// static void setup_mmap_read_p790_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p790_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p790_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p790_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p790_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p790_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p790_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_p790_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p790_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p790_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p790_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p790_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p790_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p790_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_p790_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p790_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p790_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p790_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p790_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p790_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p790_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_1_proc0
// static void setup_mmap_read_p790_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p790_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p790_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p790_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p790_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p790_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p790_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_3_proc0
// static void setup_mmap_read_p790_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p790_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p790_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p76_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p76_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_proc0
// static void setup_mmap_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p76_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p76_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p76_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p76_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p76_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p76_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_1_proc0
// static void setup_mmap_read_p76_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p76_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p76_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p76_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p76_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p76_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p76_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_1_proc0
// static void setup_mmap_read_p76_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p76_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p76_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p76_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p76_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p76_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pbd_1_common
static void setup_mmap_read_p76_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_p76_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p76_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p76_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p76_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p76_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p76_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
static void setup_mmap_read_p76_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_p76_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p76_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p76_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p76_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p76_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p76_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf4_2_common
// static void setup_mmap_read_p76_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pf4_2_proc0
// static void setup_mmap_read_p76_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p76_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p76_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p72_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p72_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p72_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p72_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_proc0
// static void setup_mmap_read_p72_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p72_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p72_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p72_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p72_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p72_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p72_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_1_proc0
// static void setup_mmap_read_p72_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p72_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p72_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p72_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p72_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p72_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p72_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_1_proc0
// static void setup_mmap_read_p72_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p72_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p72_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p72_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p72_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p72_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pbc0_1_common
// static void setup_mmap_read_p72_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pf0_2_proc0
// static void setup_mmap_read_p72_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p72_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p72_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p72_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p72_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p72_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p72_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_proc0
// static void setup_mmap_read_p72_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p72_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p72_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p72_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p72_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p72_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf0_2_common
// static void setup_mmap_read_p72_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pf0_2_proc0
// static void setup_mmap_read_p72_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p72_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p72_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p68_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p68_0_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p68_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p68_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p68_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p68_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p68_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_p68_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p68_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p68_2_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_p68_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p68_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p68_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p68_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p68_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p68_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p68_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p68_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5e_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p5e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p5e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p5e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p5e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p5e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p5e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p5e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p5e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p5e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p5e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5b8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p5b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p5b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p5b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p5b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5b8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5b8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5b8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p5b8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p5b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p5b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_p5b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5b8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5b8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5b8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p5b8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p5b8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p5b8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p5b8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5b8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5b8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5b8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p5b8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p5b8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p5b8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_p5b8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5b8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5b8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5b8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p5b8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p5b8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p5b8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5b8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5b8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5b8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5b8_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p5b8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p5b8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p5b8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p5b8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5b8_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5b8_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5b8_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p5b8_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p5b8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p5b8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5b8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5b8_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5b8_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5b8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p5b8_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p5b8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p5b8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p5b8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5b8_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5b8_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5a8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p5a8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p5a8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p5a8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p5a8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p5a8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5a8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5a8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p5a8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p5a8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p5a8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_1_proc0
// static void setup_mmap_read_p5a8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p5a8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5a8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5a8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p5a8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p5a8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p5a8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p5a8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p5a8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5a8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5a8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p5a8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p5a8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p5a8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_1_proc0
// static void setup_mmap_read_p5a8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p5a8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5a8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5a8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p5a8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p5a8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_3_common
// static void setup_mmap_read_p5a8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_3_proc0
// static void setup_mmap_read_p5a8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_3_proc1
// static void setup_mmap_read_p5a8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_p5a8_4_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5a8_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p5a8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p5a8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pda0_2_common
// static void setup_mmap_read_p5a8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_2_proc0
// static void setup_mmap_read_p5a8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_2_proc1
// static void setup_mmap_read_p5a8_5_final(void) {
//   unlink("__i0");
//   close(22);
//   close(23);
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pda0_2_final
// static void setup_mmap_read_p5a8_5_procfinal(void) {
//   close(22);
//   close(23);
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pda0_2_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5a8_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p5a8_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p5a8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p5a8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5a8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5a8_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5a8_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5a8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p5a8_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p5a8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pda0_2_common
// static void setup_mmap_read_p5a8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_2_proc0
// static void setup_mmap_read_p5a8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_2_proc1
// static void setup_mmap_read_p5a8_7_final(void) {
//   unlink("__i0");
//   close(22);
//   close(23);
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pda0_2_final
// static void setup_mmap_read_p5a8_7_procfinal(void) {
//   close(22);
//   close(23);
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pda0_2_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5a8_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p5a8_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p5a8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p5a8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5a8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p5a8_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p5a8_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p5a8_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p5a8_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p5a8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_3_common
// static void setup_mmap_read_p5a8_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_3_proc0
// static void setup_mmap_read_p5a8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_3_proc1
// static void setup_mmap_read_p5a8_9_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_p5a8_9_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p590_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p590_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p590_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p590_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p590_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p590_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p590_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p590_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p590_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p590_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p590_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p590_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p590_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p590_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p56_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p56_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p56_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p56_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p56_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pd4_0_proc1
// static void setup_mmap_read_p56_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p56_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p56_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p56_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p56_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p56_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p56_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pd4_0_proc1
// static void setup_mmap_read_p56_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p56_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p52_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p52_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p52_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p52_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p52_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p52_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p52_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p52_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p52_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p52_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p52_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p52_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p52_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p52_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p48_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_0_0
// static int test_mmap_read_p48_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_p48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p48_0_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_p48_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p48_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p7e_4_0
// static int test_mmap_read_p48_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_p48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p48_1_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_p48_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p3f_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_read_p3f_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p3f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p3f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pbf_0_proc0
// static void setup_mmap_read_p3f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3f_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3f_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p3f_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p3f_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_1_proc0
// static void setup_mmap_read_p3f_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3f_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3f_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3f_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3f_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p3f_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p3f_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p3f_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3f_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3f_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3ec_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3ec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p3ec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p3ec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_p3ec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3ec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3ec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3ec_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3ec_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p3ec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p3ec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_3_proc0
// static void setup_mmap_read_p3ec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3ec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3ec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3ec_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3ec_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p3ec_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p3ec_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p3ec_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3ec_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3ec_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3e8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3e8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
static void setup_mmap_read_p3e8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_read_p3e8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_read_p3e8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_p3e8_0_final(void) {
//   unlink("__i0");
//   close(22);
//   close(23);
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pda0_2_final
// static void setup_mmap_read_p3e8_0_procfinal(void) {
//   close(22);
//   close(23);
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pda0_2_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3e8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3e8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p3e8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p3e8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_p3e8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3e8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3e8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3e8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3e8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p3e8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_3_common
// static void setup_mmap_read_p3e8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(22, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_3_proc0
// static void setup_mmap_read_p3e8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_3_proc1
// static void setup_mmap_read_p3e8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_p3e8_2_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3e8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3e8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p3e8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p3e8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p3e8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p3e8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3e8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3e0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3e0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p3e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p3e0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_0_proc0
// static void setup_mmap_read_p3e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3e0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3e0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3e0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3e0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p3e0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p3e0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_3_proc0
// static void setup_mmap_read_p3e0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3e0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3e0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3e0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3e0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p3e0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p3e0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p3e0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3e0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3e0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3d_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3d_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p3d_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf4_2_common
// static void setup_mmap_read_p3d_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pf4_2_proc0
// static void setup_mmap_read_p3d_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3d_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3d_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3d_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3d_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p3d_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pbd_1_common
// static void setup_mmap_read_p3d_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pbd_1_proc0
// static void setup_mmap_read_p3d_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3d_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3d_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3c0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3c0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p3c0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf0_2_common
// static void setup_mmap_read_p3c0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pf0_2_proc0
// static void setup_mmap_read_p3c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3c0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3c0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p3c0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p3c0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p3c0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pbc0_1_common
// static void setup_mmap_read_p3c0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pbc0_1_proc0
// static void setup_mmap_read_p3c0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p3c0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p3c0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p38_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p38_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p38_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p37_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p37_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p37_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p37_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p37_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p37_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p37_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p37_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p37_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p37_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p37_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p37_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p37_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p37_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p36c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p36c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p36c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p36c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p36c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p36c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p36c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p36c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p36c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p36c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p36c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p36c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p36c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p36c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p368_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p368_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p368_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_3_common
static void setup_mmap_read_p368_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_p368_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_3_proc1
// static void setup_mmap_read_p368_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_p368_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p368_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p368_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p368_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_3_common
// static void setup_mmap_read_p368_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_3_proc0
// static void setup_mmap_read_p368_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_3_proc1
// static void setup_mmap_read_p368_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_final
// static void setup_mmap_read_p368_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_read_pfa0_3_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p368_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p368_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p368_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p368_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p368_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p368_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p368_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p360_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p360_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p360_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p360_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p360_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p360_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p360_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p360_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p360_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p360_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p360_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p360_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p360_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p360_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p35_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p35_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p35_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf4_2_common
// static void setup_mmap_read_p35_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p35_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pb5_0_proc1
// static void setup_mmap_read_p35_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p35_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p35_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p35_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p35_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf4_2_common
// static void setup_mmap_read_p35_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p35_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pb5_0_proc1
// static void setup_mmap_read_p35_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p35_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p340_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p340_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p340_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf0_2_common
// static void setup_mmap_read_p340_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p340_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pb40_0_proc1
// static void setup_mmap_read_p340_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p340_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p340_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p340_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p340_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf0_2_common
// static void setup_mmap_read_p340_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p340_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pb40_0_proc1
// static void setup_mmap_read_p340_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p340_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p3f_0_0
// static int test_mmap_read_p30_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p2f8_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_read_p2f8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p2f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_paf_0_common
// static void setup_mmap_read_p2f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_paf_0_proc0
// static void setup_mmap_read_p2f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p2f8_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_read_p2f8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p2f8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_paf_0_common
// static void setup_mmap_read_p2f8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_paf_0_proc0
// static void setup_mmap_read_p2f8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2f8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2f8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2f8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2f8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p2f8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_paf_0_common
// static void setup_mmap_read_p2f8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_3_proc0
// static void setup_mmap_read_p2f8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2f8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2f8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2f8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2f8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p2f8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_paf_0_common
// static void setup_mmap_read_p2f8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_3_proc0
// static void setup_mmap_read_p2f8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2f8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2f8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2ee_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2ee_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p2ee_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p2ee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_p2ee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2ee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2ee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2ee_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2ee_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p2ee_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p2ee_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_p2ee_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2ee_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2ee_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p2ee_2_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1e27000UL);
  
  return xerrno(r);
}
// static int test_mmap_read_p2ee_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p2ee_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
static void setup_mmap_read_p2ee_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_p2ee_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2ee_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2ee_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p2ee_3_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
  
  return xerrno(r);
}
// static int test_mmap_read_p2ee_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p2ee_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p2ee_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_p2ee_2_proc0
// static void setup_mmap_read_p2ee_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2ee_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2ee_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2ea_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2ea_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p2ea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
static void setup_mmap_read_p2ea_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_p2ea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p2ea_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2ea_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2ea_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2ee_2_0
// static int test_mmap_read_p2ea_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p2ea_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
static void setup_mmap_read_p2ea_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_p2ea_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p2ea_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2ea_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2ea_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2ea_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p2ea_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p2ea_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_2_proc0
// static void setup_mmap_read_p2ea_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p2ea_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2ea_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2ea_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2ee_3_0
// static int test_mmap_read_p2ea_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p2ea_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p2ea_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_p2ea_1_proc0
// static void setup_mmap_read_p2ea_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p2ea_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2ea_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2e4_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2e4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p2e4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p2e4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_p2e4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2e4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2e4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2e4_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2e4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p2e4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p2e4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_2_proc0
// static void setup_mmap_read_p2e4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2e4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2e4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2e4_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2e4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p2e4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
static void setup_mmap_read_p2e4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_p2e4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2e4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2e4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2e4_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2e4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p2e4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p2e4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_p2e4_2_proc0
// static void setup_mmap_read_p2e4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p2e4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p2e4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2d8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p2d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p2d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_proc0
// static void setup_mmap_read_p2d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2d8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2d8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2d8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2d8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p2d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
static void setup_mmap_read_p2d8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_p2d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2d8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2d8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2d8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2d8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p2d8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p2d8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_p76_4_proc0
// static void setup_mmap_read_p2d8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2d8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2d8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2d8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2d8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p2d8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
static void setup_mmap_read_p2d8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_p2d8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2d8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2d8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2d8_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2d8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p2d8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p2d8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_proc0
// static void setup_mmap_read_p2d8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2d8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2d8_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p2d8_5_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e28000UL);
  
  return xerrno(r);
}
// static int test_mmap_read_p2d8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p2d8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
static void setup_mmap_read_p2d8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31621120, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_p2d8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2d8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2d8_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p2d8_6_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x986000UL);
  
  return xerrno(r);
}
// static int test_mmap_read_p2d8_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p2d8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
static void setup_mmap_read_p2d8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_p2d8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2d8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2d8_6_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2d8_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2d8_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p2d8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p2d8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p2d8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2d8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2d8_7_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2d8_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2d8_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p2d8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p2d8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_proc0
// static void setup_mmap_read_p2d8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2d8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2d8_8_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2d8_9_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2d8_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p2d8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p2d8_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p2d8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2d8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2d8_9_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2c8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2c8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p2c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p2c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_proc0
// static void setup_mmap_read_p2c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2c8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2c8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2c8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2c8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p2c8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p2c8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p2c8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2c8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2c8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2c8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2c8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p2c8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p2c8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_proc0
// static void setup_mmap_read_p2c8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2c8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2c8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2c8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2c8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p2c8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p2c8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p2c8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2c8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2c8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p2a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_common
// static void setup_mmap_read_p2a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_proc0
// static void setup_mmap_read_p2a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p2a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_common
// static void setup_mmap_read_p2a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_proc0
// static void setup_mmap_read_p2a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2a_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p2a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p2a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_common
// static void setup_mmap_read_p2a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p2a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2a_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p2a_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p2a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p2a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_common
// static void setup_mmap_read_p2a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p2a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p2a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p2a_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p278_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p278_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p278_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_paf_0_common
// static void setup_mmap_read_p278_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_p278_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p278_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p278_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p278_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p278_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p278_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_paf_0_common
// static void setup_mmap_read_p278_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_p278_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p278_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p278_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p278_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p278_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p278_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_paf_0_common
// static void setup_mmap_read_p278_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pb40_0_proc1
// static void setup_mmap_read_p278_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p278_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p278_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p278_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p278_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p278_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_paf_0_common
// static void setup_mmap_read_p278_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pb40_0_proc1
// static void setup_mmap_read_p278_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p278_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p278_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p26e_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p26e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p26e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p26e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_p26e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p26e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p26e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p26e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p26e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p26e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p26e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_p26e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p26e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p26e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p26e_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2ee_2_0
// static int test_mmap_read_p26e_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p26e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
static void setup_mmap_read_p26e_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_p26e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p26e_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p26e_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p26e_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2ee_3_0
// static int test_mmap_read_p26e_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p26e_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p26e_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_p26e_2_proc0
// static void setup_mmap_read_p26e_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p26e_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p26e_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p26a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p26a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p26a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p26a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_1_proc0
// static void setup_mmap_read_p26a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p26a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p26a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p26a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p26a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p26a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p26a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_1_proc0
// static void setup_mmap_read_p26a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p26a_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p26a_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p26a_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2ee_2_0
// static int test_mmap_read_p26a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p26a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
static void setup_mmap_read_p26a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_read_p26a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p26a_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p26a_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p26a_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x1e27000UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2ee_3_0
// static int test_mmap_read_p26a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p26a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p26a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_p26a_2_proc0
// static void setup_mmap_read_p26a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p26a_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p26a_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p264_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p264_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p264_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p264_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_p264_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p264_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p264_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p264_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p264_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p264_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p264_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_1_proc0
// static void setup_mmap_read_p264_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p264_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p264_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p264_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p264_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p264_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p264_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pb40_0_proc1
// static void setup_mmap_read_p264_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p264_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p264_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p264_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p264_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p264_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p264_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pb40_0_proc1
// static void setup_mmap_read_p264_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p264_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p264_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p258_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p258_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p258_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p258_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pd4_0_proc1
// static void setup_mmap_read_p258_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pd4_0_proc1
// static void setup_mmap_read_p258_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p258_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p258_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p258_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p258_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p258_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
static void setup_mmap_read_p258_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_read_p258_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p258_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p258_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p258_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p258_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p258_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_p2d8_1_proc0
// static void setup_mmap_read_p258_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_p2d8_1_proc0
// static void setup_mmap_read_p258_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p258_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p258_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p258_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p258_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p258_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p258_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_p2d8_1_proc0
// static void setup_mmap_read_p258_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p258_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p258_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p258_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p258_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p258_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p258_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p258_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p258_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p258_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p258_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p258_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p258_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p258_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p258_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p258_5_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p248_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p248_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p248_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p248_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p248_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p248_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p248_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p248_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p248_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p248_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p248_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p248_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p248_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p248_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p22_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p22_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p22_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_common
// static void setup_mmap_read_p22_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_proc0
// static void setup_mmap_read_p22_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p22_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p22_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p22_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p22_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p22_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_common
// static void setup_mmap_read_p22_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_proc0
// static void setup_mmap_read_p22_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p22_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p22_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p22_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_0_0
// static int test_mmap_read_p22_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p22_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_common
// static void setup_mmap_read_p22_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p22_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p22_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p22_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p22_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_read_p2f8_1_0
// static int test_mmap_read_p22_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p22_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pa8_0_common
// static void setup_mmap_read_p22_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p22_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p22_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p22_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
static int test_mmap_read_p1e_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_read_p1e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p1e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p1e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_2_proc0
// static void setup_mmap_read_p1e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p1e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p1e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p1d8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p1d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfb0_0_1
// static void setup_mmap_read_p1d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p1d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_1_proc0
// static void setup_mmap_read_p1d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p1d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p1d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p1d0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p1d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p1d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p1d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc0
// static void setup_mmap_read_p1d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p1d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p1d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p1c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p1c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p1c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p1c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfb0_1_proc0
// static void setup_mmap_read_p1c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p1c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p1c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p1a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p1a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfa0_0_1
// static void setup_mmap_read_p1a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p1a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_p9a_0_proc0
// static void setup_mmap_read_p1a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p1a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p1a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p18_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p18_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pf8_0_1
// static void setup_mmap_read_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_1_proc0
// static void setup_mmap_read_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p18_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p18_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p10_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p10_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_1_1
// static void setup_mmap_read_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p10_0_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_p10_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p10_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p10_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_p10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p10_1_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_p10_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p0e_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p0e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p0e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfc_0_common
// static void setup_mmap_read_p0e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p0e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc0
// static void setup_mmap_read_p0e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p0e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p0d8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p0d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pdb0_0_1
// static void setup_mmap_read_p0d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfb0_0_common
// static void setup_mmap_read_p0d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p0d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p0d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p0d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p0d0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p0d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p0d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pfa0_0_common
// static void setup_mmap_read_p0d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfa0_1_proc1
// static void setup_mmap_read_p0d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pda0_0_proc1
// static void setup_mmap_read_p0d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p0d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p0c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p0c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_read_pf8_0_common
// static void setup_mmap_read_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pfc_0_proc1
// static void setup_mmap_read_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_read_pdb0_0_proc1
// static void setup_mmap_read_p0c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_final
// static void setup_mmap_read_p0c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_read_pfc_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p0a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p0a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pda0_0_1
// static void setup_mmap_read_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_read_pf4_0_common
// static void setup_mmap_read_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pd4_0_proc1
// static void setup_mmap_read_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p08_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p08_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pd8_0_1
// static void setup_mmap_read_p08_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_read_pf0_0_common
// static void setup_mmap_read_p08_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p08_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_read_pe0_1_proc0
// static void setup_mmap_read_p08_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_read_pf4_0_final
// static void setup_mmap_read_p08_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal

/*
 * calls: mmap read
 */
// static int test_mmap_read_p00_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_read_p1e_0_0
// static int test_mmap_read_p00_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mmap_read_pfc_0_1
// static void setup_mmap_read_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_read_pe0_0_common
// static void setup_mmap_read_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_read_pf4_0_proc1
// static void setup_mmap_read_p00_0_final(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal
// static void setup_mmap_read_p00_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_read_pf4_0_procfinal


/*
 * calls: mmap rename
 */
static int test_mmap_rename_pf0_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_rename_pf0_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mmap_rename_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mmap_rename_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_rename_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_rename_pf0_0_final(void) {
  unlink("__i0");
}
static void setup_mmap_rename_pf0_0_procfinal(void) {
  
}

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pe8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_0
static int test_mmap_rename_pe8_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mmap_rename_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_rename_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_0
// static int test_mmap_rename_pe0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_0
static int test_mmap_rename_pc_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_mmap_rename_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mmap_rename_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_pc_0_final(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal
// static void setup_mmap_rename_pc_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
static int test_mmap_rename_pbc_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_rename_pbc_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
static void setup_mmap_rename_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mmap_rename_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_rename_pbc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_rename_pbc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_rename_pbc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pbc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pbc_0_0
// static int test_mmap_rename_pbc_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
// static void setup_mmap_rename_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pbc_0_common
static void setup_mmap_rename_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_rename_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pba_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pbc_0_0
// static int test_mmap_rename_pba_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
static void setup_mmap_rename_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_rename_pba_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc0
// static void setup_mmap_rename_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_pba_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_pba_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pba_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pbc_0_0
// static int test_mmap_rename_pba_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_pba_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pba_0_common
// static void setup_mmap_rename_pba_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_1_proc0
// static void setup_mmap_rename_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_pba_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_pba_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pbc_0_0
// static int test_mmap_rename_pb8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pbc_0_common
// static void setup_mmap_rename_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc0
// static void setup_mmap_rename_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pbc_0_0
// static int test_mmap_rename_pb8_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pbc_0_common
// static void setup_mmap_rename_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_1_proc0
// static void setup_mmap_rename_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pbc_0_0
// static int test_mmap_rename_pb0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
static void setup_mmap_rename_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_rename_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc0
// static void setup_mmap_rename_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pbc_0_0
// static int test_mmap_rename_pb0_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
// static void setup_mmap_rename_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_rename_pb0_0_common
// static void setup_mmap_rename_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_1_proc0
// static void setup_mmap_rename_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
static int test_mmap_rename_pac_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_rename_pac_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
// static void setup_mmap_rename_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
static void setup_mmap_rename_pac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_rename_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_pac_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_paa_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pac_0_0
// static int test_mmap_rename_paa_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pe8_0_common
static void setup_mmap_rename_paa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_rename_paa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_paa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_paa_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pac_0_0
// static int test_mmap_rename_pa8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_pac_0_proc0
// static void setup_mmap_rename_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pac_0_0
// static int test_mmap_rename_pa0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
static void setup_mmap_rename_pa0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_mmap_rename_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_pac_0_proc0
// static void setup_mmap_rename_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
static int test_mmap_rename_p98_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_rename_p98_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
// static void setup_mmap_rename_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p98_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p94_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p98_0_0
// static int test_mmap_rename_p94_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pe8_0_common
// static void setup_mmap_rename_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p94_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p94_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p90_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p98_0_0
// static int test_mmap_rename_p90_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p90_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p98_0_0
// static int test_mmap_rename_p8_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
// static void setup_mmap_rename_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_rename_pc_0_common
// static void setup_mmap_rename_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p8_0_final(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal
// static void setup_mmap_rename_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
static int test_mmap_rename_p78_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_rename_p78_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
// static void setup_mmap_rename_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p78_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p78_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
static int test_mmap_rename_p78_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_rename_p78_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
// static void setup_mmap_rename_p78_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p78_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p78_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p6c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p78_0_0
// static int test_mmap_rename_p6c_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pe8_0_common
// static void setup_mmap_rename_p6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p6c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p6c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p6c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p78_1_0
// static int test_mmap_rename_p6c_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pe8_0_common
// static void setup_mmap_rename_p6c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p6c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p6c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p64_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p78_0_0
// static int test_mmap_rename_p64_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p64_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p64_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p64_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p78_1_0
// static int test_mmap_rename_p64_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p64_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p64_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p64_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p64_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p64_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p50_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p78_0_0
// static int test_mmap_rename_p50_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
// static void setup_mmap_rename_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_rename_pc_0_common
// static void setup_mmap_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p50_0_final(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal
// static void setup_mmap_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p50_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p78_1_0
// static int test_mmap_rename_p50_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
// static void setup_mmap_rename_p50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_rename_pc_0_common
// static void setup_mmap_rename_p50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p50_1_final(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal
// static void setup_mmap_rename_p50_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
static int test_mmap_rename_p3c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_rename_p3c_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
// static void setup_mmap_rename_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pbc_0_common
// static void setup_mmap_rename_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc0
// static void setup_mmap_rename_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p3c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p3c_0_0
// static int test_mmap_rename_p3c_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
// static void setup_mmap_rename_p3c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pbc_0_common
// static void setup_mmap_rename_p3c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_1_proc0
// static void setup_mmap_rename_p3c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_p3c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_p3c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p3a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p3c_0_0
// static int test_mmap_rename_p3a_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p3a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pba_0_common
// static void setup_mmap_rename_p3a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc0
// static void setup_mmap_rename_p3a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_p3a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_p3a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p3a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p3c_0_0
// static int test_mmap_rename_p3a_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p3a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pba_0_common
// static void setup_mmap_rename_p3a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_1_proc0
// static void setup_mmap_rename_p3a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_p3a_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_p3a_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p38_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p3c_0_0
// static int test_mmap_rename_p38_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pbc_0_common
// static void setup_mmap_rename_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc0
// static void setup_mmap_rename_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p38_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p3c_0_0
// static int test_mmap_rename_p38_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pbc_0_common
// static void setup_mmap_rename_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_1_proc0
// static void setup_mmap_rename_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p3c_0_0
// static int test_mmap_rename_p30_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
// static void setup_mmap_rename_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_rename_pb0_0_common
// static void setup_mmap_rename_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc0
// static void setup_mmap_rename_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p3c_0_0
// static int test_mmap_rename_p30_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
// static void setup_mmap_rename_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_rename_pb0_0_common
// static void setup_mmap_rename_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_1_proc0
// static void setup_mmap_rename_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_rename_pbc_0_proc1
// static void setup_mmap_rename_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_final
// static void setup_mmap_rename_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_rename_pbc_0_procfinal

/*
 * calls: mmap rename
 */
static int test_mmap_rename_p2e_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_rename_p2e_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
// static void setup_mmap_rename_p2e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p2e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_pac_0_proc0
// static void setup_mmap_rename_p2e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p2e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p2e_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
static int test_mmap_rename_p2e_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_rename_p2e_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
// static void setup_mmap_rename_p2e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p2e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_pac_0_proc0
// static void setup_mmap_rename_p2e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p2e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p2e_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p2b0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p2e_0_0
// static int test_mmap_rename_p2b0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p2b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pe8_0_common
// static void setup_mmap_rename_p2b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_paa_0_proc0
// static void setup_mmap_rename_p2b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p2b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p2b0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p2b0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p2e_1_0
// static int test_mmap_rename_p2b0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p2b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pe8_0_common
// static void setup_mmap_rename_p2b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_paa_0_proc0
// static void setup_mmap_rename_p2b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p2b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p2b0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p2b0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p2e_0_0
// static int test_mmap_rename_p2b0_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
static void setup_mmap_rename_p2b0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_rename_p2b0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_pac_0_proc0
// static void setup_mmap_rename_p2b0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p2b0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p2b0_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p2b0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p2e_1_0
// static int test_mmap_rename_p2b0_3_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p2b0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_p2b0_2_common
// static void setup_mmap_rename_p2b0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_pac_0_proc0
// static void setup_mmap_rename_p2b0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p2b0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p2b0_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p29_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p2e_0_0
// static int test_mmap_rename_p29_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p29_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p29_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_pac_0_proc0
// static void setup_mmap_rename_p29_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p29_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p29_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p29_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p2e_1_0
// static int test_mmap_rename_p29_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p29_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p29_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_pac_0_proc0
// static void setup_mmap_rename_p29_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p29_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p29_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p24_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p2e_0_0
// static int test_mmap_rename_p24_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
// static void setup_mmap_rename_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_rename_pa0_0_common
// static void setup_mmap_rename_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_pac_0_proc0
// static void setup_mmap_rename_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p24_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p24_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p2e_1_0
// static int test_mmap_rename_p24_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
// static void setup_mmap_rename_p24_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_rename_pa0_0_common
// static void setup_mmap_rename_p24_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_rename_pac_0_proc0
// static void setup_mmap_rename_p24_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p24_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p24_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
static int test_mmap_rename_p18_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_rename_p18_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pf0_0_1
// static void setup_mmap_rename_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p18_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p18_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p14_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p18_0_0
// static int test_mmap_rename_p14_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pe8_0_common
// static void setup_mmap_rename_p14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p14_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p14_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p10_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p18_0_0
// static int test_mmap_rename_p10_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pe8_0_1
// static void setup_mmap_rename_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_rename_pf0_0_common
// static void setup_mmap_rename_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_rename_pf0_0_final
// static void setup_mmap_rename_p10_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal

/*
 * calls: mmap rename
 */
// static int test_mmap_rename_p0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_p18_0_0
// static int test_mmap_rename_p0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_rename_pc_0_1
// static void setup_mmap_rename_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_rename_pc_0_common
// static void setup_mmap_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_rename_pf0_0_proc1
// static void setup_mmap_rename_p0_0_final(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal
// static void setup_mmap_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_rename_pf0_0_procfinal


/*
 * calls: mmap stat
 */
static int test_mmap_stat_pe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_mmap_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mmap_stat_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_stat_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_stat_pe_0_final(void) {
  unlink("__i0");
}
static void setup_mmap_stat_pe_0_procfinal(void) {
  
}

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_pc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_stat_pe_0_0
static int test_mmap_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_mmap_stat_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mmap_stat_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_pc_0_final(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal
// static void setup_mmap_stat_pc_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
static int test_mmap_stat_pb8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_stat_pb8_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
static void setup_mmap_stat_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mmap_stat_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_stat_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_stat_pb8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_stat_pb8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_stat_pb8_0_0
// static int test_mmap_stat_pb8_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
// static void setup_mmap_stat_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_stat_pb8_0_common
static void setup_mmap_stat_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_stat_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_0_proc1
// static void setup_mmap_stat_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_final
// static void setup_mmap_stat_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_stat_pb8_0_0
// static int test_mmap_stat_pb0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
static void setup_mmap_stat_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_stat_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_0_proc0
// static void setup_mmap_stat_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_0_proc1
// static void setup_mmap_stat_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_final
// static void setup_mmap_stat_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_stat_pb8_0_0
// static int test_mmap_stat_pb0_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
// static void setup_mmap_stat_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_stat_pb0_0_common
// static void setup_mmap_stat_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_1_proc0
// static void setup_mmap_stat_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_0_proc1
// static void setup_mmap_stat_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_final
// static void setup_mmap_stat_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_procfinal

/*
 * calls: mmap stat
 */
static int test_mmap_stat_pa8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_stat_pa8_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
// static void setup_mmap_stat_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_stat_pe_0_common
static void setup_mmap_stat_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_stat_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_stat_pe_0_final
// static void setup_mmap_stat_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_stat_pa8_0_0
// static int test_mmap_stat_pa0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
static void setup_mmap_stat_pa0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_mmap_stat_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_stat_pa8_0_proc0
// static void setup_mmap_stat_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_stat_pe_0_final
// static void setup_mmap_stat_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
static int test_mmap_stat_p9_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_stat_p9_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
// static void setup_mmap_stat_p9_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_stat_pe_0_common
// static void setup_mmap_stat_p9_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p9_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p9_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_stat_pe_0_final
// static void setup_mmap_stat_p9_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_stat_p9_0_0
// static int test_mmap_stat_p8_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
// static void setup_mmap_stat_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_stat_pc_0_common
// static void setup_mmap_stat_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p8_0_final(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal
// static void setup_mmap_stat_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
static int test_mmap_stat_p70_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_stat_p70_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
// static void setup_mmap_stat_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_stat_pe_0_common
// static void setup_mmap_stat_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_stat_pe_0_final
// static void setup_mmap_stat_p70_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
static int test_mmap_stat_p70_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_stat_p70_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
// static void setup_mmap_stat_p70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_stat_pe_0_common
// static void setup_mmap_stat_p70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_stat_pe_0_final
// static void setup_mmap_stat_p70_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_p50_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_stat_p70_0_0
// static int test_mmap_stat_p50_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
// static void setup_mmap_stat_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_stat_pc_0_common
// static void setup_mmap_stat_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p50_0_final(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal
// static void setup_mmap_stat_p50_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_p50_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_stat_p70_1_0
// static int test_mmap_stat_p50_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
// static void setup_mmap_stat_p50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_stat_pc_0_common
// static void setup_mmap_stat_p50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p50_1_final(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal
// static void setup_mmap_stat_p50_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
static int test_mmap_stat_p38_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_stat_p38_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
// static void setup_mmap_stat_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_stat_pb8_0_common
// static void setup_mmap_stat_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_0_proc0
// static void setup_mmap_stat_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_0_proc1
// static void setup_mmap_stat_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_final
// static void setup_mmap_stat_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_p38_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_stat_p38_0_0
// static int test_mmap_stat_p38_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
// static void setup_mmap_stat_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_stat_pb8_0_common
// static void setup_mmap_stat_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_1_proc0
// static void setup_mmap_stat_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_0_proc1
// static void setup_mmap_stat_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_final
// static void setup_mmap_stat_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_stat_p38_0_0
// static int test_mmap_stat_p30_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
// static void setup_mmap_stat_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_stat_pb0_0_common
// static void setup_mmap_stat_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_0_proc0
// static void setup_mmap_stat_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_0_proc1
// static void setup_mmap_stat_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_final
// static void setup_mmap_stat_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_stat_p38_0_0
// static int test_mmap_stat_p30_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
// static void setup_mmap_stat_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_stat_pb0_0_common
// static void setup_mmap_stat_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_1_proc0
// static void setup_mmap_stat_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_stat_pb8_0_proc1
// static void setup_mmap_stat_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_final
// static void setup_mmap_stat_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_stat_pb8_0_procfinal

/*
 * calls: mmap stat
 */
static int test_mmap_stat_p2c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_stat_p2c_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
// static void setup_mmap_stat_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_stat_pe_0_common
// static void setup_mmap_stat_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_stat_pa8_0_proc0
// static void setup_mmap_stat_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_stat_pe_0_final
// static void setup_mmap_stat_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
static int test_mmap_stat_p2c_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_stat_p2c_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
// static void setup_mmap_stat_p2c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_stat_pe_0_common
// static void setup_mmap_stat_p2c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_stat_pa8_0_proc0
// static void setup_mmap_stat_p2c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p2c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_stat_pe_0_final
// static void setup_mmap_stat_p2c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_p24_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_stat_p2c_0_0
// static int test_mmap_stat_p24_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
// static void setup_mmap_stat_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_stat_pa0_0_common
// static void setup_mmap_stat_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_stat_pa8_0_proc0
// static void setup_mmap_stat_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_stat_pe_0_final
// static void setup_mmap_stat_p24_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_p24_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_stat_p2c_1_0
// static int test_mmap_stat_p24_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
// static void setup_mmap_stat_p24_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_stat_pa0_0_common
// static void setup_mmap_stat_p24_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_stat_pa8_0_proc0
// static void setup_mmap_stat_p24_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p24_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_stat_pe_0_final
// static void setup_mmap_stat_p24_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
static int test_mmap_stat_p1_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_stat_p1_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pe_0_1
// static void setup_mmap_stat_p1_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_stat_pe_0_common
// static void setup_mmap_stat_p1_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p1_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p1_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_stat_pe_0_final
// static void setup_mmap_stat_p1_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal

/*
 * calls: mmap stat
 */
// static int test_mmap_stat_p0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_stat_p1_0_0
// static int test_mmap_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mmap_stat_pc_0_1
// static void setup_mmap_stat_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_stat_pc_0_common
// static void setup_mmap_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_stat_pe_0_proc1
// static void setup_mmap_stat_p0_0_final(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal
// static void setup_mmap_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_stat_pe_0_procfinal


/*
 * calls: mmap unlink
 */
static int test_mmap_unlink_pe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_unlink_pe_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mmap_unlink_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mmap_unlink_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_unlink_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_unlink_pe_0_final(void) {
  unlink("__i0");
}
static void setup_mmap_unlink_pe_0_procfinal(void) {
  
}

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_pc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_0
static int test_mmap_unlink_pc_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_mmap_unlink_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mmap_unlink_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_pc_0_final(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal
// static void setup_mmap_unlink_pc_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
static int test_mmap_unlink_pb8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_unlink_pb8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
static void setup_mmap_unlink_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mmap_unlink_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_unlink_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_unlink_pb8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_unlink_pb8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pb8_0_0
// static int test_mmap_unlink_pb8_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_pb8_0_common
static void setup_mmap_unlink_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_unlink_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_0_proc1
// static void setup_mmap_unlink_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_final
// static void setup_mmap_unlink_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pb8_0_0
// static int test_mmap_unlink_pb0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
static void setup_mmap_unlink_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_unlink_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_0_proc0
// static void setup_mmap_unlink_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_0_proc1
// static void setup_mmap_unlink_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_final
// static void setup_mmap_unlink_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pb8_0_0
// static int test_mmap_unlink_pb0_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
// static void setup_mmap_unlink_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_unlink_pb0_0_common
// static void setup_mmap_unlink_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_1_proc0
// static void setup_mmap_unlink_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_0_proc1
// static void setup_mmap_unlink_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_final
// static void setup_mmap_unlink_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_procfinal

/*
 * calls: mmap unlink
 */
static int test_mmap_unlink_pa8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_unlink_pa8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_pe_0_common
static void setup_mmap_unlink_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_unlink_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pa8_0_0
// static int test_mmap_unlink_pa0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
static void setup_mmap_unlink_pa0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mmap_unlink_pa0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_unlink_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
static int test_mmap_unlink_p90_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_unlink_p90_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_pe_0_common
// static void setup_mmap_unlink_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_p90_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p90_0_0
// static int test_mmap_unlink_p8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
// static void setup_mmap_unlink_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pc_0_common
// static void setup_mmap_unlink_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p8_0_final(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal
// static void setup_mmap_unlink_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
static int test_mmap_unlink_p70_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_unlink_p70_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_pe_0_common
// static void setup_mmap_unlink_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_p70_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
static int test_mmap_unlink_p70_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_unlink_p70_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_p70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_pe_0_common
// static void setup_mmap_unlink_p70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p70_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_p70_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p50_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p70_0_0
// static int test_mmap_unlink_p50_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
// static void setup_mmap_unlink_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pc_0_common
// static void setup_mmap_unlink_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p50_0_final(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal
// static void setup_mmap_unlink_p50_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p50_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p70_1_0
// static int test_mmap_unlink_p50_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
// static void setup_mmap_unlink_p50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pc_0_common
// static void setup_mmap_unlink_p50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p50_1_final(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal
// static void setup_mmap_unlink_p50_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
static int test_mmap_unlink_p38_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_unlink_p38_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_pb8_0_common
// static void setup_mmap_unlink_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_0_proc0
// static void setup_mmap_unlink_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_0_proc1
// static void setup_mmap_unlink_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_final
// static void setup_mmap_unlink_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p38_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p38_0_0
// static int test_mmap_unlink_p38_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_pb8_0_common
// static void setup_mmap_unlink_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_1_proc0
// static void setup_mmap_unlink_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_0_proc1
// static void setup_mmap_unlink_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_final
// static void setup_mmap_unlink_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p38_0_0
// static int test_mmap_unlink_p30_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
// static void setup_mmap_unlink_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_unlink_pb0_0_common
// static void setup_mmap_unlink_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_0_proc0
// static void setup_mmap_unlink_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_0_proc1
// static void setup_mmap_unlink_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_final
// static void setup_mmap_unlink_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p38_0_0
// static int test_mmap_unlink_p30_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
// static void setup_mmap_unlink_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_unlink_pb0_0_common
// static void setup_mmap_unlink_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_1_proc0
// static void setup_mmap_unlink_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_unlink_pb8_0_proc1
// static void setup_mmap_unlink_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_final
// static void setup_mmap_unlink_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_unlink_pb8_0_procfinal

/*
 * calls: mmap unlink
 */
static int test_mmap_unlink_p2c_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_unlink_p2c_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_pe_0_common
// static void setup_mmap_unlink_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_unlink_pa8_0_proc0
// static void setup_mmap_unlink_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
static int test_mmap_unlink_p2c_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_unlink_p2c_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_p2c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_pe_0_common
// static void setup_mmap_unlink_p2c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_unlink_pa8_0_proc0
// static void setup_mmap_unlink_p2c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p2c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_p2c_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p2c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p2c_0_0
// static int test_mmap_unlink_p2c_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
static void setup_mmap_unlink_p2c_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_mmap_unlink_p2c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_unlink_pa0_0_proc0
// static void setup_mmap_unlink_p2c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p2c_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_p2c_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p2c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p2c_1_0
// static int test_mmap_unlink_p2c_3_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_p2c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_p2c_2_common
// static void setup_mmap_unlink_p2c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_unlink_pa0_0_proc0
// static void setup_mmap_unlink_p2c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p2c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_p2c_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p24_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p2c_0_0
// static int test_mmap_unlink_p24_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
// static void setup_mmap_unlink_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_unlink_pa0_0_common
// static void setup_mmap_unlink_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_unlink_pa0_0_proc0
// static void setup_mmap_unlink_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_p24_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p24_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p2c_1_0
// static int test_mmap_unlink_p24_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
// static void setup_mmap_unlink_p24_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_unlink_pa0_0_common
// static void setup_mmap_unlink_p24_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_unlink_pa0_0_proc0
// static void setup_mmap_unlink_p24_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p24_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_p24_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
static int test_mmap_unlink_p10_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_unlink_p10_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pe_0_1
// static void setup_mmap_unlink_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mmap_unlink_pe_0_common
// static void setup_mmap_unlink_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_unlink_pe_0_final
// static void setup_mmap_unlink_p10_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal

/*
 * calls: mmap unlink
 */
// static int test_mmap_unlink_p0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_p10_0_0
// static int test_mmap_unlink_p0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mmap_unlink_pc_0_1
// static void setup_mmap_unlink_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pc_0_common
// static void setup_mmap_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_unlink_pe_0_proc1
// static void setup_mmap_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal
// static void setup_mmap_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_unlink_pe_0_procfinal


/*
 * calls: mmap write
 */
static int test_mmap_write_pfe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
static int test_mmap_write_pfe_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_mmap_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_write_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mmap_write_pfe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mmap write
 */
// static int test_mmap_write_pfe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
static int test_mmap_write_pfe_1_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_mmap_write_pfe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
static void setup_mmap_write_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_write_pfe_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pfe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pfe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pfe_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pfe_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_pfe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
static void setup_mmap_write_pfe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pfe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_pfe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pfe_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pfe_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pfe_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
static void setup_mmap_write_pfe_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_write_pfe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_write_pfe_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_write_pfe_3_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_mmap_write_pfe_3_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: mmap write
 */
// static int test_mmap_write_pfc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
static int test_mmap_write_pfc_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_mmap_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pfc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pfc_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
static void setup_mmap_write_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pfc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pfc_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
static void setup_mmap_write_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pfc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pfc_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pfc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
static void setup_mmap_write_pfc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pfc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pfc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pfc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pf8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
static int test_mmap_write_pf8_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_mmap_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pf8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
static int test_mmap_write_pf8_1_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_mmap_write_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
static void setup_mmap_write_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pf8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pf8_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
static void setup_mmap_write_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pf8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pf8_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
static void setup_mmap_write_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pf4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pf4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
static void setup_mmap_write_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mmap_write_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_mmap_write_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mmap_write_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_mmap_write_pf4_0_procfinal(void) {
  
}

/*
 * calls: mmap write
 */
// static int test_mmap_write_pf4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pf4_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
static void setup_mmap_write_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_write_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pf4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pf4_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pf4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pf4_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
static void setup_mmap_write_pf4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_write_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pf0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
static void setup_mmap_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mmap_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pf0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pf0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_1_proc0
// static void setup_mmap_write_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pf0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pf0_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
static void setup_mmap_write_pf0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_write_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf4_2_proc0
// static void setup_mmap_write_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pe0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
static void setup_mmap_write_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mmap_write_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pe0_0_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pe0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
static void setup_mmap_write_pe0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_write_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pde_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pde_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_pde_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pde_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pde_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
static void setup_mmap_write_pde_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_write_pde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_write_pde_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pde_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pde_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pde_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_pde_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_pde_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_pde_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_pde_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pde_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pde_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pde_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
static void setup_mmap_write_pde_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_write_pde_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_write_pde_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pde_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_pde_3_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pdc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
static int test_mmap_write_pdc_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_mmap_write_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pdc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pdc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
static void setup_mmap_write_pdc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pdc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pdc_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pdc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_pdc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pdc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pdc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pdc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pdc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pdc_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pdc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_pdc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pdc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pdc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pdc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pd8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pd4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pd4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pfe_0_0
// static int test_mmap_write_pc0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pc0_0_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
static int test_mmap_write_pbf8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_write_pbf8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_pbf8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_3_common
// static void setup_mmap_write_pbf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(23, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_3_proc0
// static void setup_mmap_write_pbf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_3_proc1
// static void setup_mmap_write_pbf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_pbf8_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbf8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbf8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
static void setup_mmap_write_pbf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_write_pbf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_write_pbf8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_mmap_write_pbf8_1_final(void) {
  unlink("__i0");
  close(22);
  close(23);
  close(20);
  close(21);
}
static void setup_mmap_write_pbf8_1_procfinal(void) {
  close(22);
  close(23);
  close(20);
  close(21);
}

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbf8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbf8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_pbf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_pbf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_pbf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_pbf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbf0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pbf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_pbf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_0_proc0
// static void setup_mmap_write_pbf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pbf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbf0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbf0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pbf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_pbf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_1_proc0
// static void setup_mmap_write_pbf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pbf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbf0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbf0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pbf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_pbf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pbf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pbf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbe_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbe_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
static void setup_mmap_write_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_pbe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_3_proc0
// static void setup_mmap_write_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbe_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbe_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_pbe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_pbe_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pbe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pbe_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbe_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbd0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pbd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf4_2_common
// static void setup_mmap_write_pbd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf4_2_proc0
// static void setup_mmap_write_pbd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pbd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbd0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbd0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
static void setup_mmap_write_pbd0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mmap_write_pbd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pbd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pbd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbc0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pbc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf0_2_common
// static void setup_mmap_write_pbc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf4_2_proc0
// static void setup_mmap_write_pbc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pbc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pbc0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pbc0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
static void setup_mmap_write_pbc0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mmap_write_pbc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pbd0_1_proc0
// static void setup_mmap_write_pbc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pbc0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pbc0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb78_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_pb78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_3_common
static void setup_mmap_write_pb78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pb78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc1
// static void setup_mmap_write_pb78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_pb78_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb78_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb78_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_pb78_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_3_common
// static void setup_mmap_write_pb78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc0
// static void setup_mmap_write_pb78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc1
// static void setup_mmap_write_pb78_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_pb78_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb78_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb78_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_pb78_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_pb78_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_pb78_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_pb78_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb78_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb70_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pb70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_pb70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pb70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pb70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb70_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb70_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pb70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_pb70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pb70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pb70_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb70_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb6_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb50_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pb50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf4_2_common
// static void setup_mmap_write_pb50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
static void setup_mmap_write_pb50_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pb50_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb50_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb50_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb50_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pb50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf4_2_common
// static void setup_mmap_write_pb50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pb50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_pb50_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb50_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb40_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pb40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf0_2_common
// static void setup_mmap_write_pb40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pb40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_pb40_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb40_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb40_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb40_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pb40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf0_2_common
// static void setup_mmap_write_pb40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pb40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_pb40_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb40_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_pbf8_0_0
// static int test_mmap_write_pb0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
static int test_mmap_write_paf8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, 1250999402496);
  return xerrno(r);
}
// static int test_mmap_write_paf8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_paf8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_paf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_2_proc0
// static void setup_mmap_write_paf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_paf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_paf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_paf0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_paf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_paf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_paf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_3_proc0
// static void setup_mmap_write_paf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_paf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_paf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pae_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pae_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
static void setup_mmap_write_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pad0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pad0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pad0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_pad0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pad0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pad0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pad0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pad0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pad0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_pad0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_pad0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pad0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pad0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pac0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pac0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_pac0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_pac0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_pac0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pac0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pac0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pac0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pac0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pac0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_pac0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_pac0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pac0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pac0_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pa8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
static void setup_mmap_write_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mmap_write_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mmap_write_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pa78_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pa78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_pa78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_pa78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc0
// static void setup_mmap_write_pa78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_pa78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pa78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pa70_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pa70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pa70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_pa70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pdc_1_proc0
// static void setup_mmap_write_pa70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_pa70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pa70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pa6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pa6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pdc_1_proc0
// static void setup_mmap_write_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_pa6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_pa6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pa50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pa50_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pa50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_pa50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_pa50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_pa50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pa50_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pa40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pa40_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_pa40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_pa40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_pa40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_pa40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pa40_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, 1250999402496);
//   return xerrno(r);
// }
// ^ See test_mmap_write_paf8_0_0
// static int test_mmap_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_common
// static void setup_mmap_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_proc0
// static void setup_mmap_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
static int test_mmap_write_p9f_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_write_p9f_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p9f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p9f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc0
// static void setup_mmap_write_p9f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p9f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p9f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p9e_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p9e_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p9e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_2_proc0
// static void setup_mmap_write_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p9c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p9c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_1_proc0
// static void setup_mmap_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p9a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p9a_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_1_proc0
// static void setup_mmap_write_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p98_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p98_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_1_proc0
// static void setup_mmap_write_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p98_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p90_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p90_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p90_0_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_p90_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p90_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p90_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p90_1_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_p90_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p8f_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p8f_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p8f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p8f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p8f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p8f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p8f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p8e_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p8e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p8e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p8e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p8c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p8c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p8a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p8a_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p88_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p88_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p88_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p80_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED | MAP_FIXED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p9f_0_0
// static int test_mmap_write_p80_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p80_0_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_p80_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
static int test_mmap_write_p7f0_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_write_p7f0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p7f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p7f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p7f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7f0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7f0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p7f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p7f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc0
// static void setup_mmap_write_p7f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p7f0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7f0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
static int test_mmap_write_p7f0_2_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_write_p7f0_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p7f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p7f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc0
// static void setup_mmap_write_p7f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p7f0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7f0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7f0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7f0_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p7f0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p7f0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_2_proc0
// static void setup_mmap_write_p7f0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p7f0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7f0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7f0_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7f0_4_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p7f0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_3_common
// static void setup_mmap_write_p7f0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(23, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_3_proc0
// static void setup_mmap_write_p7f0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_3_proc1
// static void setup_mmap_write_p7f0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_p7f0_4_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7f0_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7f0_5_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p7f0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p7f0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_2_proc0
// static void setup_mmap_write_p7f0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p7f0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7f0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7f0_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7f0_6_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p7f0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_3_common
// static void setup_mmap_write_p7f0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(23, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_3_proc0
// static void setup_mmap_write_p7f0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_3_proc1
// static void setup_mmap_write_p7f0_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_p7f0_6_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7f0_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7f0_7_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p7f0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_3_common
static void setup_mmap_write_p7f0_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_p7f0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_3_proc1
// static void setup_mmap_write_p7f0_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_p7f0_7_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7f0_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7f0_8_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p7f0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
static void setup_mmap_write_p7f0_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_p7f0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p7f0_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7f0_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7d0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7d0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p7d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p7d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_0_proc0
// static void setup_mmap_write_p7d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7d0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7d0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p7d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p7d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_1_proc0
// static void setup_mmap_write_p7d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7d0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7d0_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p7d0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p7d0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_2_proc0
// static void setup_mmap_write_p7d0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7d0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7d0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7d0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7d0_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p7d0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p7d0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_3_proc0
// static void setup_mmap_write_p7d0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7d0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7d0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7d0_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7d0_4_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p7d0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p7d0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_1_proc0
// static void setup_mmap_write_p7d0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7d0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7d0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7d0_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7d0_5_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p7d0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p7d0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_3_proc0
// static void setup_mmap_write_p7d0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7d0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7d0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7d0_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7d0_6_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p7d0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p7d0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_2_proc0
// static void setup_mmap_write_p7d0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7d0_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7d0_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7d0_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7d0_7_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p7d0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p7d0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_0_proc0
// static void setup_mmap_write_p7d0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7d0_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7d0_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7a_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p7a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p7a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p7a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7a_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p7a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p7a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_1_proc0
// static void setup_mmap_write_p7a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7a_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7a_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7a_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7a_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p7a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p7a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_2_proc0
// static void setup_mmap_write_p7a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7a_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7a_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7a_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p7a_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p7a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p7a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_3_proc0
// static void setup_mmap_write_p7a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7a_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7a_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7a_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7a_4_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p7a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p7a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p7a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7a_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7a_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7a_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7a_5_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p7a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p7a_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_2_proc0
// static void setup_mmap_write_p7a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7a_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7a_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7a_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7a_6_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p7a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p7a_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_1_proc0
// static void setup_mmap_write_p7a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7a_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7a_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p7a_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p7a_7_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p7a_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p7a_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_3_proc0
// static void setup_mmap_write_p7a_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p7a_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p7a_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p76_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p76_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p76_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p76_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p76_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p76_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p76_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p76_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p76_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_1_proc0
// static void setup_mmap_write_p76_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p76_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p76_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p76_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p76_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p76_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p76_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_1_proc0
// static void setup_mmap_write_p76_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p76_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p76_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p76_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p76_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p76_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pbd0_1_common
// static void setup_mmap_write_p76_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf4_2_proc0
// static void setup_mmap_write_p76_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p76_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p76_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p76_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p76_4_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p76_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p76_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_p76_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p76_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p76_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p76_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p76_5_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p76_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf4_2_common
// static void setup_mmap_write_p76_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf4_2_proc0
// static void setup_mmap_write_p76_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p76_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p76_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p72_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p72_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p72_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p72_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_p72_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p72_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p72_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p72_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p72_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p72_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p72_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_1_proc0
// static void setup_mmap_write_p72_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p72_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p72_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p72_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p72_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p72_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p72_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_1_proc0
// static void setup_mmap_write_p72_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p72_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p72_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p72_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p72_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p72_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pbc0_1_common
// static void setup_mmap_write_p72_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf4_2_proc0
// static void setup_mmap_write_p72_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p72_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p72_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p72_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p72_4_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p72_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p72_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_p72_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p72_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p72_4_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p72_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p72_5_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p72_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf0_2_common
// static void setup_mmap_write_p72_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf4_2_proc0
// static void setup_mmap_write_p72_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p72_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p72_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p68_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p68_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p68_0_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p68_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p68_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p68_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p68_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p68_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p68_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_p68_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p68_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p68_2_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_p68_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p68_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p68_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p68_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p68_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p68_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p68_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p68_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5f0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p5f0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p5f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p5f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5f0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p5f0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p5f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p5f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p5f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p5f0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5f0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5f0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p5f0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p5f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p5f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p5f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p5f0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5f0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5f0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p5f0_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p5f0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p5f0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc0
// static void setup_mmap_write_p5f0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p5f0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5f0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5f0_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p5f0_4_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p5f0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_3_common
// static void setup_mmap_write_p5f0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc0
// static void setup_mmap_write_p5f0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc1
// static void setup_mmap_write_p5f0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_p5f0_4_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5f0_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p5f0_5_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p5f0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p5f0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc0
// static void setup_mmap_write_p5f0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p5f0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5f0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5f0_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p5f0_6_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p5f0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_3_common
// static void setup_mmap_write_p5f0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc0
// static void setup_mmap_write_p5f0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc1
// static void setup_mmap_write_p5f0_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_p5f0_6_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5f0_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p5f0_7_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p5f0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_3_common
// static void setup_mmap_write_p5f0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb78_0_proc0
// static void setup_mmap_write_p5f0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc1
// static void setup_mmap_write_p5f0_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_p5f0_7_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5f0_8_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p5f0_8_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p5f0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p5f0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p5f0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p5f0_8_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5f0_8_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5d0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p5d0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p5d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p5d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p5d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5d0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p5d0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p5d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p5d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pdc_1_proc0
// static void setup_mmap_write_p5d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5d0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p5d0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p5d0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p5d0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p5d0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5d0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5d0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5d0_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p5d0_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p5d0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p5d0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pdc_1_proc0
// static void setup_mmap_write_p5d0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5d0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5d0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5d0_4_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p5d0_4_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p5d0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p5d0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p5d0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5d0_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5d0_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5d0_5_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p5d0_5_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p5d0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p5d0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5d0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5d0_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5d0_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5d0_6_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p5d0_6_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p5d0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p5d0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p5d0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5d0_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5d0_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5d0_7_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p5d0_7_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p5d0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p5d0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5d0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p5d0_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5d0_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p5a_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p5a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p5a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p5a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p5a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p5a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p5a_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p5a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p5a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p5a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p5a_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p5a_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p56_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p56_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p56_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p56_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p56_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p56_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p56_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p56_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p56_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p56_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p56_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p56_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p56_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p56_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p52_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p52_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p52_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p52_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p52_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p52_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p52_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p52_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p52_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p52_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p52_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p52_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p52_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p52_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p48_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_0_0
// static int test_mmap_write_p48_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_p48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p48_0_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_p48_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p48_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_PRIVATE | MAP_ANONYMOUS, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p7f0_2_0
// static int test_mmap_write_p48_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_p48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p48_1_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_p48_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
static int test_mmap_write_p3f8_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(19);
  return xerrno(r);
}
// static int test_mmap_write_p3f8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p3f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_3_common
// static void setup_mmap_write_p3f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(23, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_p7f0_7_proc0
// static void setup_mmap_write_p3f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_3_proc1
// static void setup_mmap_write_p3f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_p3f8_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3f8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3f8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p3f8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_3_common
// static void setup_mmap_write_p3f8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(23, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_3_proc0
// static void setup_mmap_write_p3f8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_3_proc1
// static void setup_mmap_write_p3f8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_p3f8_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3f8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3f8_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p3f8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p3f8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_p7f0_8_proc0
// static void setup_mmap_write_p3f8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p3f8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3f8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3f8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3f8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p3f8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p3f8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p3f8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p3f8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3f8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3f0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3f0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p3f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p3f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_0_proc0
// static void setup_mmap_write_p3f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p3f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3f0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3f0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p3f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p3f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_1_proc0
// static void setup_mmap_write_p3f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p3f0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3f0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3f0_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3f0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p3f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p3f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p3f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p3f0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3f0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3e_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3e_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p3e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p3e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pbe_0_proc0
// static void setup_mmap_write_p3e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p3e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3e_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3e_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p3e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p3e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_3_proc0
// static void setup_mmap_write_p3e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p3e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3e_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3e_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p3e_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p3e_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p3e_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p3e_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3e_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3d0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3d0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p3d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf4_2_common
// static void setup_mmap_write_p3d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf4_2_proc0
// static void setup_mmap_write_p3d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p3d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3d0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3d0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p3d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pbd0_1_common
// static void setup_mmap_write_p3d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pbd0_1_proc0
// static void setup_mmap_write_p3d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p3d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3c0_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3c0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p3c0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf0_2_common
// static void setup_mmap_write_p3c0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf4_2_proc0
// static void setup_mmap_write_p3c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p3c0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3c0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p3c0_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p3c0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p3c0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pbc0_1_common
// static void setup_mmap_write_p3c0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pbd0_1_proc0
// static void setup_mmap_write_p3c0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p3c0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p3c0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p38_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p38_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p38_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p38_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p378_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p378_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p378_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_3_common
// static void setup_mmap_write_p378_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb78_0_proc0
// static void setup_mmap_write_p378_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc1
// static void setup_mmap_write_p378_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_p378_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p378_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p378_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p378_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_3_common
// static void setup_mmap_write_p378_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc0
// static void setup_mmap_write_p378_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_3_proc1
// static void setup_mmap_write_p378_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_final
// static void setup_mmap_write_p378_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_mmap_write_pfe_3_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p378_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p378_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p378_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p378_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p378_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p378_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p378_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p370_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p370_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p370_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p370_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p370_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p370_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p370_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p370_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p370_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p370_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p370_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p370_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p370_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p370_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p36_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p36_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p36_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p36_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p36_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p36_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p36_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p36_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p36_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p350_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p350_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p350_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf4_2_common
// static void setup_mmap_write_p350_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p350_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_p350_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p350_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p350_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p350_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p350_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf4_2_common
// static void setup_mmap_write_p350_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p350_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_p350_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p350_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p340_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p340_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p340_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf0_2_common
// static void setup_mmap_write_p340_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p340_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_p340_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p340_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p340_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p340_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p340_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf0_2_common
// static void setup_mmap_write_p340_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p340_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_p340_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p340_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p30_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p30_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(19);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p3f8_0_0
// static int test_mmap_write_p30_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
static int test_mmap_write_p2fc_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_write_p2fc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p2fc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p2fc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_2_proc0
// static void setup_mmap_write_p2fc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p2fc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2fc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
static int test_mmap_write_p2fc_1_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
  
  return xerrno(r);
}
// static int test_mmap_write_p2fc_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p2fc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p2fc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_2_proc0
// static void setup_mmap_write_p2fc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p2fc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2fc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2fc_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2fc_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p2fc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
static void setup_mmap_write_p2fc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_p2fc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p2fc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2fc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2fc_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2fc_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p2fc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p2fc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_p2fc_2_proc0
// static void setup_mmap_write_p2fc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p2fc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2fc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2f4_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2f4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p2f4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p2f4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_3_proc0
// static void setup_mmap_write_p2f4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p2f4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2f4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2f4_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2f4_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p2f4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p2f4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_3_proc0
// static void setup_mmap_write_p2f4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p2f4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2f4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2f4_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2f4_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p2f4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
static void setup_mmap_write_p2f4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_p2f4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p2f4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2f4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2f4_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2f4_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p2f4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p2f4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_p2f4_2_proc0
// static void setup_mmap_write_p2f4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p2f4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2f4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2e8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2e8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p2e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p2e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pae_0_proc0
// static void setup_mmap_write_p2e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p2e8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2e8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2e8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2e8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p2e8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p2e8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_2_proc0
// static void setup_mmap_write_p2e8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p2e8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2e8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2e8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2e8_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p2e8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p2e8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pae_0_proc0
// static void setup_mmap_write_p2e8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p2e8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2e8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2e8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2e8_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p2e8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p2e8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_2_proc0
// static void setup_mmap_write_p2e8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p2e8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p2e8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2d8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2d8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p2d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p2d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_p2d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2d8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2d8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2d8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2d8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p2d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p2d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p2d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2d8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2d8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2d8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2d8_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p2d8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p2d8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_p2d8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2d8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2d8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2d8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2d8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p2d8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p2d8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p2d8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2d8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2d8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2c8_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2c8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p2c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p2c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_p2c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2c8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2c8_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2c8_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2c8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p2c8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p2c8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p2c8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2c8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2c8_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2c8_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2c8_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p2c8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p2c8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_proc0
// static void setup_mmap_write_p2c8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2c8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2c8_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2c8_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2c8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p2c8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p2c8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p2c8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2c8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2c8_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2a_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p2a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_common
// static void setup_mmap_write_p2a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_proc0
// static void setup_mmap_write_p2a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2a_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2a_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p2a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_common
// static void setup_mmap_write_p2a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_proc0
// static void setup_mmap_write_p2a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2a_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2a_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p2a_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p2a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_common
// static void setup_mmap_write_p2a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p2a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2a_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p2a_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p2a_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p2a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_common
// static void setup_mmap_write_p2a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p2a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p2a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p2a_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p27c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p27c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p27c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p27c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc0
// static void setup_mmap_write_p27c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p27c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p27c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p27c_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p27c_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p27c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p27c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc0
// static void setup_mmap_write_p27c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p27c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p27c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p27c_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p27c_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p27c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
static void setup_mmap_write_p27c_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mmap_write_p27c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p27c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p27c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p27c_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p27c_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p27c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p27c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_p27c_2_proc0
// static void setup_mmap_write_p27c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p27c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p27c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p274_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p274_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p274_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p274_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pdc_1_proc0
// static void setup_mmap_write_p274_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p274_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p274_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p274_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p274_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p274_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p274_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pdc_1_proc0
// static void setup_mmap_write_p274_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p274_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p274_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p274_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p274_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p274_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p274_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_p274_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p274_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p274_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p274_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p274_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p274_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p274_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_p274_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p274_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p274_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p268_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p268_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p268_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p268_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pdc_1_proc0
// static void setup_mmap_write_p268_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p268_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p268_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p268_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p268_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p268_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p268_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pdc_1_proc0
// static void setup_mmap_write_p268_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p268_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p268_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p268_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p268_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p268_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p268_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_p268_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p268_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p268_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p268_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p268_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p268_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p268_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pb50_0_proc1
// static void setup_mmap_write_p268_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p268_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p268_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p258_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p258_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p258_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p258_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p258_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p258_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p258_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p258_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p258_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p258_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p258_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p258_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p258_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p258_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p248_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p248_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p248_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p248_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p248_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p248_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p248_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p248_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p248_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p248_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p248_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p248_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p248_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p248_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p22_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p22_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p22_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_common
// static void setup_mmap_write_p22_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_proc0
// static void setup_mmap_write_p22_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p22_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p22_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p22_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p22_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p22_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_common
// static void setup_mmap_write_p22_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_proc0
// static void setup_mmap_write_p22_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p22_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p22_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p22_2_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_0_0
// static int test_mmap_write_p22_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p22_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_common
// static void setup_mmap_write_p22_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p22_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p22_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p22_2_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p22_3_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ | PROT_WRITE, MAP_SHARED, 10, 0x0UL);
//   
//   return xerrno(r);
// }
// ^ See test_mmap_write_p2fc_1_0
// static int test_mmap_write_p22_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p22_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pa8_0_common
// static void setup_mmap_write_p22_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p22_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p22_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p22_3_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
static int test_mmap_write_p1f_0_0(void) {
  int* va = (int*) 0x0UL;
  long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_mmap_write_p1f_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_1_1
// static void setup_mmap_write_p1f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfe_0_common
// static void setup_mmap_write_p1f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc0
// static void setup_mmap_write_p1f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p1f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p1f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p1e_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p1e_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p1e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p1e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfc_2_proc0
// static void setup_mmap_write_p1e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p1e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p1e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p1c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p1c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p1c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p1c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_1_proc0
// static void setup_mmap_write_p1c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p1c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p1c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p1a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p1a_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p1a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p1a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_1_proc0
// static void setup_mmap_write_p1a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p1a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p1a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p18_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p18_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfc_0_1
// static void setup_mmap_write_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_1_proc0
// static void setup_mmap_write_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p18_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p18_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p10_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p10_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_1_1
// static void setup_mmap_write_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p10_0_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_p10_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p10_1_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p10_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_p10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p10_1_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_p10_1_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p0f_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p0f_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pfe_0_1
// static void setup_mmap_write_p0f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pde_1_common
// static void setup_mmap_write_p0f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_1_proc1
// static void setup_mmap_write_p0f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pde_1_proc1
// static void setup_mmap_write_p0f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p0f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p0e_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p0e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p0e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pfc_0_common
// static void setup_mmap_write_p0e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p0e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc0
// static void setup_mmap_write_p0e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p0e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p0c_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p0c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p0c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mmap_write_pf8_0_common
// static void setup_mmap_write_p0c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pfe_0_proc1
// static void setup_mmap_write_p0c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mmap_write_pf8_0_proc0
// static void setup_mmap_write_p0c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_final
// static void setup_mmap_write_p0c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mmap_write_pfe_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p0a_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p0a_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p0a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mmap_write_pf4_0_common
// static void setup_mmap_write_p0a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p0a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p0a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p0a_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p08_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p08_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pdc_0_1
// static void setup_mmap_write_p08_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mmap_write_pf0_0_common
// static void setup_mmap_write_p08_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p08_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mmap_write_pe0_1_proc0
// static void setup_mmap_write_p08_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mmap_write_pf4_0_final
// static void setup_mmap_write_p08_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal

/*
 * calls: mmap write
 */
// static int test_mmap_write_p00_0_0(void) {
//   int* va = (int*) 0x0UL;
//   long r = (intptr_t) mmap(va, 4096, PROT_READ, MAP_SHARED, 10, 0x0UL);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mmap_write_p1f_0_0
// static int test_mmap_write_p00_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mmap_write_pf8_0_1
// static void setup_mmap_write_p00_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mmap_write_pe0_0_common
// static void setup_mmap_write_p00_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p00_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mmap_write_pf4_0_proc1
// static void setup_mmap_write_p00_0_final(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal
// static void setup_mmap_write_p00_0_procfinal(void) {
//   
// }
// ^ See setup_mmap_write_pf4_0_procfinal


/*
 * calls: mprotect mprotect
 */
static int test_mprotect_mprotect_pe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_mprotect_pe_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mprotect_mprotect_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mprotect_mprotect_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
static void setup_mprotect_mprotect_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_mprotect_pe_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_mprotect_pe_0_procfinal(void) {
  
}

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
static int test_mprotect_mprotect_pe_1_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_mprotect_mprotect_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_0_proc0
// static void setup_mprotect_mprotect_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
static int test_mprotect_mprotect_pe_2_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_mprotect_mprotect_pe_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_0_proc0
// static void setup_mprotect_mprotect_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_0_proc0
// static void setup_mprotect_mprotect_pe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
static void setup_mprotect_mprotect_pe_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mprotect_mprotect_pe_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mprotect_mprotect_pe_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_4_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mprotect_mprotect_pe_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_5_proc0
// static void setup_mprotect_mprotect_pe_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_5_proc0
// static void setup_mprotect_mprotect_pe_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_5_proc0
// static void setup_mprotect_mprotect_pe_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_pe_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_pe_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_10_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mprotect_mprotect_pe_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_11_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_10_proc0
// static void setup_mprotect_mprotect_pe_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_12_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_11_proc0
// static void setup_mprotect_mprotect_pe_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_13_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_10_proc0
// static void setup_mprotect_mprotect_pe_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_14_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_10_proc0
// static void setup_mprotect_mprotect_pe_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_15_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_16_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_11_proc0
// static void setup_mprotect_mprotect_pe_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_16_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_16_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_17_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_11_proc0
// static void setup_mprotect_mprotect_pe_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_17_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_17_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_pe_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_18_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_pe_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_19_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_19_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_20_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_20_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_20_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_20_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_18_proc0
// static void setup_mprotect_mprotect_pe_20_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_20_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_20_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_21_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_21_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_21_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_21_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_19_proc0
// static void setup_mprotect_mprotect_pe_21_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_21_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_21_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_22_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_22_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_22_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_22_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_4_proc0
// static void setup_mprotect_mprotect_pe_22_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_22_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_22_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_23_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_23_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_23_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
static void setup_mprotect_mprotect_pe_23_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mprotect_mprotect_pe_23_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_23_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_23_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_24_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_24_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_24_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_24_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_23_proc0
// static void setup_mprotect_mprotect_pe_24_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_24_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_24_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_25_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_25_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_25_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_25_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_4_proc0
// static void setup_mprotect_mprotect_pe_25_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_25_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_25_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_26_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_26_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_26_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_26_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_18_proc0
// static void setup_mprotect_mprotect_pe_26_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_26_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_26_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_27_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_27_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_27_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_27_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_23_proc0
// static void setup_mprotect_mprotect_pe_27_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_27_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_27_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_28_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_28_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_28_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_28_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_19_proc0
// static void setup_mprotect_mprotect_pe_28_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_28_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_28_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_29_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_29_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_29_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_29_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_4_proc0
// static void setup_mprotect_mprotect_pe_29_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_29_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_29_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_30_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_30_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_30_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_30_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_18_proc0
// static void setup_mprotect_mprotect_pe_30_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_30_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_30_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_31_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_31_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_31_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_31_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_23_proc0
// static void setup_mprotect_mprotect_pe_31_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_31_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_31_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_32_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_32_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_32_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_32_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_19_proc0
// static void setup_mprotect_mprotect_pe_32_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_32_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_32_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_33_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_33_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_33_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_33_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_pe_33_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_33_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_33_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_34_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_34_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_34_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
static void setup_mprotect_mprotect_pe_34_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mprotect_mprotect_pe_34_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_34_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_34_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_35_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_35_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_35_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_35_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_pe_35_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_35_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_35_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_36_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_36_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_36_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_36_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_33_proc0
// static void setup_mprotect_mprotect_pe_36_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_36_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_36_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_37_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_37_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_37_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_37_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_35_proc0
// static void setup_mprotect_mprotect_pe_37_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_37_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_37_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_38_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_38_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_38_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_38_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_33_proc0
// static void setup_mprotect_mprotect_pe_38_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_38_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_38_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_39_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_39_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_39_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_39_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_33_proc0
// static void setup_mprotect_mprotect_pe_39_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_39_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_39_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_40_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_40_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_40_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_40_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_35_proc0
// static void setup_mprotect_mprotect_pe_40_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_40_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_40_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_41_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_41_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_41_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_41_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_35_proc0
// static void setup_mprotect_mprotect_pe_41_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_41_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_41_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_42_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_42_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_42_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_42_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mprotect_mprotect_pe_42_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_42_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_42_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_43_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_43_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_43_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_43_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_34_proc0
// static void setup_mprotect_mprotect_pe_43_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_43_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_43_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_44_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_44_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_44_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_44_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_42_proc0
// static void setup_mprotect_mprotect_pe_44_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_44_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_44_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_45_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_45_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_45_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_45_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_34_proc0
// static void setup_mprotect_mprotect_pe_45_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_45_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_45_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_46_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_46_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_46_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_46_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_42_proc0
// static void setup_mprotect_mprotect_pe_46_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_46_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_46_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_47_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_47_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_47_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_47_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_34_proc0
// static void setup_mprotect_mprotect_pe_47_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_47_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_47_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_48_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_48_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_48_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_48_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_42_proc0
// static void setup_mprotect_mprotect_pe_48_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_48_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_48_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_49_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_49_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_49_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
static void setup_mprotect_mprotect_pe_49_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mprotect_mprotect_pe_49_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_49_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_49_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_50_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_50_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_50_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_50_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mprotect_mprotect_pe_50_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_50_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_50_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_51_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_51_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_51_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_51_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_9_proc0
// static void setup_mprotect_mprotect_pe_51_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_51_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_51_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_52_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_52_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_52_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_52_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_50_proc0
// static void setup_mprotect_mprotect_pe_52_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_52_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_52_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_53_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_53_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_53_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_53_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_9_proc0
// static void setup_mprotect_mprotect_pe_53_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_53_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_53_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_54_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_54_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_54_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_54_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_9_proc0
// static void setup_mprotect_mprotect_pe_54_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_54_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_54_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_55_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_55_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_55_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_55_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_50_proc0
// static void setup_mprotect_mprotect_pe_55_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_55_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_55_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_56_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_56_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_56_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_56_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_50_proc0
// static void setup_mprotect_mprotect_pe_56_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_56_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_56_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_57_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_57_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_57_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_57_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_pe_57_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_57_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_57_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_58_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_58_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_58_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_58_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_49_proc0
// static void setup_mprotect_mprotect_pe_58_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_58_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_58_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_59_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_59_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_59_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_59_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_57_proc0
// static void setup_mprotect_mprotect_pe_59_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_59_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_59_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_60_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_60_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_60_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_60_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_49_proc0
// static void setup_mprotect_mprotect_pe_60_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_60_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_60_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_61_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_61_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_pe_61_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_61_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_57_proc0
// static void setup_mprotect_mprotect_pe_61_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_61_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_61_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_62_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_62_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_62_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_62_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_anon(0x12345601000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_49_proc0
// static void setup_mprotect_mprotect_pe_62_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_62_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_62_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_63_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_63_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_1_1
// static void setup_mprotect_mprotect_pe_63_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_63_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
//   init_map_file(0x12345601000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_57_proc0
// static void setup_mprotect_mprotect_pe_63_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_63_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_63_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_64_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_64_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pe_64_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_64_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_pe_64_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_64_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_64_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_65_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_65_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pe_65_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_pe_65_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_pe_65_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_65_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_65_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_66_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_66_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static void setup_mprotect_mprotect_pe_66_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_66_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_pe_66_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_66_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_66_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_67_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_67_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static void setup_mprotect_mprotect_pe_67_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pe_67_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_pe_67_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_67_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pe_67_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_68_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_68_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pe_68_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
static void setup_mprotect_mprotect_pe_68_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_mprotect_pe_68_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_68_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_68_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_69_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pe_69_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pe_69_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
static void setup_mprotect_mprotect_pe_69_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_mprotect_pe_69_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_69_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_69_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_70_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_70_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static void setup_mprotect_mprotect_pe_70_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_70_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_pe_70_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_70_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_70_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pe_71_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static int test_mprotect_mprotect_pe_71_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ | PROT_WRITE);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_2_0
// static void setup_mprotect_mprotect_pe_71_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pe_71_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_pe_71_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pe_71_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pe_71_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
static int test_mprotect_mprotect_pc_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_mprotect_mprotect_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pc_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pc_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pc_0_1
// static void setup_mprotect_mprotect_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pc_1_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pc_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pc_0_1
// static void setup_mprotect_mprotect_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pc_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pc_0_1
// static void setup_mprotect_mprotect_pc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_pc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_pc_3_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_pa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_pa_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pa_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_pa_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_pa_3_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pa_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_4_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_pa_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_pa_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_5_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_pa_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_pa_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_6_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_pa_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_pa_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_7_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pa_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_pa_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_pa_7_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pa_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_8_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_pa_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_pa_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_9_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_pa_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_pa_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_10_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_pa_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_pa_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_10_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_11_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_pa_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_pa_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_11_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_12_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_pa_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_pa_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_12_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_13_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pa_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_pa_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_pa_13_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pa_13_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_14_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_pa_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_pa_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_pa_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_pa_14_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_pa_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_pa_15_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_pa_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_pa_15_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_pa_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_pa_15_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_pa_15_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
static int test_mprotect_mprotect_p8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static void setup_mprotect_mprotect_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_p8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static void setup_mprotect_mprotect_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p8_1_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_p8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_p8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static void setup_mprotect_mprotect_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_p8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static int test_mprotect_mprotect_p8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static void setup_mprotect_mprotect_p8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_p8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_p8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p8_3_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_p8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p6_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_p6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_p6_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p6_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
static void setup_mprotect_mprotect_p6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mprotect_mprotect_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p6_1_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_p6_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p6_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p6_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_p6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
static void setup_mprotect_mprotect_p6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mprotect_mprotect_p6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_p6_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p6_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p6_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_1
// static void setup_mprotect_mprotect_p6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
static void setup_mprotect_mprotect_p6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mprotect_mprotect_p6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p6_3_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_p6_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p4_0_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pc_0_1
// static void setup_mprotect_mprotect_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p4_0_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_p4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p4_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static void setup_mprotect_mprotect_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p4_1_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_p4_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p2_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p2_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_64_proc0
// static void setup_mprotect_mprotect_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_p2_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p2_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p2_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_p2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_p2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_mprotect_pe_68_proc0
// static void setup_mprotect_mprotect_p2_1_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_p2_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p2_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p2_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_p2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_mprotect_pe_0_common
// static void setup_mprotect_mprotect_p2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_mprotect_pe_65_proc0
// static void setup_mprotect_mprotect_p2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_mprotect_pe_0_final
// static void setup_mprotect_mprotect_p2_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p2_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p2_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_pe_0_0
// static void setup_mprotect_mprotect_p2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_p2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_mprotect_pe_69_proc0
// static void setup_mprotect_mprotect_p2_3_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_p2_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal

/*
 * calls: mprotect mprotect
 */
// static int test_mprotect_mprotect_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static int test_mprotect_mprotect_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_mprotect_p8_0_1
// static void setup_mprotect_mprotect_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_4_common
// static void setup_mprotect_mprotect_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_mprotect_pe_0_proc1
// static void setup_mprotect_mprotect_p0_0_final(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal
// static void setup_mprotect_mprotect_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_mprotect_pe_0_procfinal


/*
 * calls: mprotect munmap
 */
static int test_mprotect_munmap_pe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_munmap_pe_0_1(void) {
  int* va = (int*) 0x12345601000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mprotect_munmap_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mprotect_munmap_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
static void setup_mprotect_munmap_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_munmap_pe_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_munmap_pe_0_procfinal(void) {
  
}

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_1_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_munmap_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_2_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
static void setup_mprotect_munmap_pe_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mprotect_munmap_pe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_munmap_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_2_final(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal
// static void setup_mprotect_munmap_pe_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_3_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_munmap_pe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_4_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_2_common
static void setup_mprotect_munmap_pe_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_munmap_pe_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_4_final(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal
// static void setup_mprotect_munmap_pe_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_5_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mprotect_munmap_pe_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_6_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mprotect_munmap_pe_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_7_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_2_common
static void setup_mprotect_munmap_pe_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mprotect_munmap_pe_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_7_final(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal
// static void setup_mprotect_munmap_pe_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_8_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mprotect_munmap_pe_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_9_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mprotect_munmap_pe_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_10_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mprotect_munmap_pe_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_10_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_11_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mprotect_munmap_pe_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_11_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_12_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_12_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mprotect_munmap_pe_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_12_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_13_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_13_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_13_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mprotect_munmap_pe_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_13_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_14_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_14_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_14_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mprotect_munmap_pe_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_14_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_15_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_15_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_15_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_15_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_file(0x12345601000, 1, "__i0", 0x0);
}
// static void setup_mprotect_munmap_pe_15_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_15_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_15_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_16_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_16_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_16_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_2_common
static void setup_mprotect_munmap_pe_16_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mprotect_munmap_pe_16_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_16_final(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal
// static void setup_mprotect_munmap_pe_16_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_17_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_17_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_17_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_2_common
static void setup_mprotect_munmap_pe_17_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 0, 0);
}
// static void setup_mprotect_munmap_pe_17_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_17_final(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal
// static void setup_mprotect_munmap_pe_17_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_18_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_18_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_18_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
static void setup_mprotect_munmap_pe_18_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_file(0x12345601000, 0, "__i0", 0x0);
}
// static void setup_mprotect_munmap_pe_18_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_18_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_pe_18_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_pe_19_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_pe_19_1(void) {
//   int* va = (int*) 0x12345601000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_1
// static void setup_mprotect_munmap_pe_19_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_2_common
static void setup_mprotect_munmap_pe_19_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
  init_map_anon(0x12345601000, 1, 0);
}
// static void setup_mprotect_munmap_pe_19_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_pe_19_final(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal
// static void setup_mprotect_munmap_pe_19_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
static int test_mprotect_munmap_p8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_mprotect_munmap_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
// static void setup_mprotect_munmap_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_munmap_pe_1_proc0
// static void setup_mprotect_munmap_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_p8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_p8_1_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_p8_0_1
// static void setup_mprotect_munmap_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_2_common
// static void setup_mprotect_munmap_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_munmap_pe_2_proc0
// static void setup_mprotect_munmap_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_p8_1_final(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal
// static void setup_mprotect_munmap_p8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_p8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_p8_2_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_p8_0_1
// static void setup_mprotect_munmap_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_munmap_pe_0_common
// static void setup_mprotect_munmap_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_munmap_pe_3_proc0
// static void setup_mprotect_munmap_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_p8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_munmap_pe_0_final
// static void setup_mprotect_munmap_p8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_p8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_pe_0_0
// static int test_mprotect_munmap_p8_3_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_p8_0_1
// static void setup_mprotect_munmap_p8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_2_common
// static void setup_mprotect_munmap_p8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_munmap_pe_4_proc0
// static void setup_mprotect_munmap_p8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_p8_3_final(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal
// static void setup_mprotect_munmap_p8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
static int test_mprotect_munmap_p4_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static int test_mprotect_munmap_p4_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_p8_0_1
// static void setup_mprotect_munmap_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_2_common
// static void setup_mprotect_munmap_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_p4_0_final(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal
// static void setup_mprotect_munmap_p4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal

/*
 * calls: mprotect munmap
 */
// static int test_mprotect_munmap_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_p4_0_0
// static int test_mprotect_munmap_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_munmap_p8_0_1
// static void setup_mprotect_munmap_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_2_common
// static void setup_mprotect_munmap_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_munmap_pe_0_proc1
// static void setup_mprotect_munmap_p0_0_final(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal
// static void setup_mprotect_munmap_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_munmap_pe_0_procfinal


/*
 * calls: mprotect open
 */
static int test_mprotect_open_pf_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_open_pf_0_1(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_mprotect_open_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mprotect_open_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mprotect_open_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_open_pf_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_open_pf_0_procfinal(void) {
  
}

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pf_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pf_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_1
// static void setup_mprotect_open_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
static void setup_mprotect_open_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_open_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pf_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pf_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pf_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pf_2_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_1
// static void setup_mprotect_open_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
static void setup_mprotect_open_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_open_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pf_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pf_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pf_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pf_3_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_1
// static void setup_mprotect_open_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
static void setup_mprotect_open_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_open_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pf_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pf_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pee_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
static int test_mprotect_open_pee_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_mprotect_open_pee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mprotect_open_pee_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
// static void setup_mprotect_open_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pee_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pee_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pee_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pee_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
static void setup_mprotect_open_pee_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mprotect_open_pee_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x16dd000);
}
// static void setup_mprotect_open_pee_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pee_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pee_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pee_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pee_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pee_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
// static void setup_mprotect_open_pee_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pee_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pee_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pee_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pee_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pee_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pee_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
// static void setup_mprotect_open_pee_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pee_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pee_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pee_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pea_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pea_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pee_1_common
static void setup_mprotect_open_pea_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x20ad000);
}
// static void setup_mprotect_open_pea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pea_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pea_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pea_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pea_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pee_0_common
// static void setup_mprotect_open_pea_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pea_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pea_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pea_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pea_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pea_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pea_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pee_0_common
static void setup_mprotect_open_pea_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x261000);
}
// static void setup_mprotect_open_pea_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pea_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pea_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pea_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pea_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pea_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
// static void setup_mprotect_open_pea_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pea_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pea_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pea_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pe6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
static int test_mprotect_open_pe6_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_mprotect_open_pe6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mprotect_open_pe6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_mprotect_open_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pe6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pe6_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pe6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pe6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pe6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
static void setup_mprotect_open_pe6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2297000);
}
// static void setup_mprotect_open_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pe6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pe6_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pe6_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pe6_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pe6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pe6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pe6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pe6_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pe6_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pe6_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pe6_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pe6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pe6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pe6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pe6_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pe6_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pe2_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pe2_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pe2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pe2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2297000);
// }
// ^ See setup_mprotect_open_pe6_0_proc0
// static void setup_mprotect_open_pe2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pe2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pe2_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pe2_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pe2_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pe2_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pe2_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x2297000);
// }
// ^ See setup_mprotect_open_pe6_1_proc0
// static void setup_mprotect_open_pe2_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pe2_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pe2_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pe2_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pe2_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pe2_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pe2_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pe2_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pe2_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pe2_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pe2_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pe2_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pe2_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pe2_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pe2_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pe2_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pe2_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pdc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pdc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
static void setup_mprotect_open_pdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mprotect_open_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x22f1000);
}
// static void setup_mprotect_open_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pdc_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pdc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pdc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
static void setup_mprotect_open_pdc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mprotect_open_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pdc_1_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_pdc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pdc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pdc_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
static void setup_mprotect_open_pdc_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mprotect_open_pdc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x1720000);
}
// static void setup_mprotect_open_pdc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pdc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pdc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pdc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pdc_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pdc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_pdc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pdc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pdc_3_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_pdc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pd4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pd4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_open_pdc_0_common
// static void setup_mprotect_open_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x22f1000);
// }
// ^ See setup_mprotect_open_pdc_0_proc0
// static void setup_mprotect_open_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pd4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pd4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pd4_1_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_pd4_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pd4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pd4_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_open_pdc_0_common
static void setup_mprotect_open_pd4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x22f1000);
}
// static void setup_mprotect_open_pd4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pd4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pd4_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pd4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pd4_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pd4_3_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_pd4_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pcc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pcc_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_open_pdc_0_common
// static void setup_mprotect_open_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x22f1000);
// }
// ^ See setup_mprotect_open_pdc_0_proc0
// static void setup_mprotect_open_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pcc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pcc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pcc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_pcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pcc_1_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_pcc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pcc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pcc_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
static void setup_mprotect_open_pcc_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mprotect_open_pcc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x1720000);
// }
// ^ See setup_mprotect_open_pdc_2_proc0
// static void setup_mprotect_open_pcc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pcc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pcc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pcc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pcc_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pcc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_pcc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pcc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pcc_3_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_pcc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pc4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pc4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_open_pcc_2_common
static void setup_mprotect_open_pc4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1720000);
}
// static void setup_mprotect_open_pc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pc4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pc4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pc4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pc4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_pc4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pc4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pc4_1_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_pc4_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pc4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pc4_2_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pc4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_open_pdc_0_common
// static void setup_mprotect_open_pc4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x22f1000);
// }
// ^ See setup_mprotect_open_pd4_2_proc0
// static void setup_mprotect_open_pc4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pc4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pc4_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pc4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pc4_3_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_pc4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_pc4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pc4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pc4_3_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_pc4_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pbc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
static int test_mprotect_open_pbc_0_1(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_mprotect_open_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pee_1_common
// static void setup_mprotect_open_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x20ad000);
// }
// ^ See setup_mprotect_open_pea_0_proc0
// static void setup_mprotect_open_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pbc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pbc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pbc_0_1
// static void setup_mprotect_open_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
// static void setup_mprotect_open_pbc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x261000);
// }
// ^ See setup_mprotect_open_pea_2_proc0
// static void setup_mprotect_open_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pbc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pbc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pbc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pbc_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pbc_0_1
// static void setup_mprotect_open_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
// static void setup_mprotect_open_pbc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pbc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pbc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pbc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pbc_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pbc_0_1
// static void setup_mprotect_open_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pee_0_common
// static void setup_mprotect_open_pbc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pbc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pbc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pb4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pb4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pbc_0_1
// static void setup_mprotect_open_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
// static void setup_mprotect_open_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x20ad000);
// }
// ^ See setup_mprotect_open_pea_0_proc0
// static void setup_mprotect_open_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pb4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pb4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pb4_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pbc_0_1
// static void setup_mprotect_open_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pee_1_common
// static void setup_mprotect_open_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x16dd000);
// }
// ^ See setup_mprotect_open_pee_1_proc0
// static void setup_mprotect_open_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pb4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pb4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pb4_2_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pbc_0_1
// static void setup_mprotect_open_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pee_1_common
// static void setup_mprotect_open_pb4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pb4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pb4_3_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pbc_0_1
// static void setup_mprotect_open_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pee_0_common
// static void setup_mprotect_open_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pac_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
static int test_mprotect_open_pac_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_mprotect_open_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2297000);
// }
// ^ See setup_mprotect_open_pe6_0_proc0
// static void setup_mprotect_open_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pac_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pac_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pac_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pac_0_1
// static void setup_mprotect_open_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x2297000);
// }
// ^ See setup_mprotect_open_pe6_1_proc0
// static void setup_mprotect_open_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pac_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pac_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pac_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pac_0_1
// static void setup_mprotect_open_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pac_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pac_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pac_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pac_3_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pac_0_1
// static void setup_mprotect_open_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pac_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pac_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pa4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pa4_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pac_0_1
// static void setup_mprotect_open_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2297000);
// }
// ^ See setup_mprotect_open_pe6_0_proc0
// static void setup_mprotect_open_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pa4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pa4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pa4_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pac_0_1
// static void setup_mprotect_open_pa4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pa4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x2297000);
// }
// ^ See setup_mprotect_open_pe6_1_proc0
// static void setup_mprotect_open_pa4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pa4_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pa4_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pa4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pa4_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pac_0_1
// static void setup_mprotect_open_pa4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pa4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_pa4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pa4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pa4_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_pa4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_pa4_3_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pac_0_1
// static void setup_mprotect_open_pa4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_pa4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_pa4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_pa4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_pa4_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
static int test_mprotect_open_p8_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_mprotect_open_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_open_pdc_2_common
// static void setup_mprotect_open_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_open_pf_0_proc0
// static void setup_mprotect_open_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_p8_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p8_0_1
// static void setup_mprotect_open_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_open_pf_1_proc0
// static void setup_mprotect_open_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p8_1_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_p8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_p8_2_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p8_0_1
// static void setup_mprotect_open_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_open_pdc_2_common
// static void setup_mprotect_open_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_open_pf_2_proc0
// static void setup_mprotect_open_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_0
// static int test_mprotect_open_p8_3_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p8_0_1
// static void setup_mprotect_open_p8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_p8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_open_pf_3_proc0
// static void setup_mprotect_open_p8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p8_3_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_p8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
static int test_mprotect_open_p7_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static int test_mprotect_open_p7_0_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pf_0_1
// static void setup_mprotect_open_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
// static void setup_mprotect_open_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p7_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p7_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p6e_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p6e_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_p6e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
// static void setup_mprotect_open_p6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p6e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p6e_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p6a_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p6a_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_p6a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pee_0_common
// static void setup_mprotect_open_p6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p6a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p6a_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p66_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p66_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_p66_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_p66_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p66_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p66_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p66_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p62_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p62_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_p62_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_p62_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p62_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p62_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p62_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p5c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p5c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p5c_0_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p54_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p54_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pee_0_1
// static void setup_mprotect_open_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p54_0_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_p54_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p4c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p4c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p4c_0_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_p4c_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p44_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p44_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pe6_0_1
// static void setup_mprotect_open_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p44_0_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_p44_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p3c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p3c_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pbc_0_1
// static void setup_mprotect_open_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pf_0_common
// static void setup_mprotect_open_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p3c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p3c_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p34_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p34_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pbc_0_1
// static void setup_mprotect_open_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pee_1_common
// static void setup_mprotect_open_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p34_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p2c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p2c_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pac_0_1
// static void setup_mprotect_open_p2c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_p2c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p2c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p2c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p2c_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p24_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p24_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_mprotect_open_pac_0_1
// static void setup_mprotect_open_p24_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_open_pe6_0_common
// static void setup_mprotect_open_p24_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p24_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p24_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_open_pf_0_final
// static void setup_mprotect_open_p24_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal

/*
 * calls: mprotect open
 */
// static int test_mprotect_open_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p7_0_0
// static int test_mprotect_open_p0_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_open_p8_0_1
// static void setup_mprotect_open_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_open_pdc_1_common
// static void setup_mprotect_open_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_open_pf_0_proc1
// static void setup_mprotect_open_p0_0_final(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal
// static void setup_mprotect_open_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_open_pf_0_procfinal


/*
 * calls: mprotect pipe
 */
static int test_mprotect_pipe_pf0_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_pipe_pf0_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mprotect_pipe_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mprotect_pipe_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
static void setup_mprotect_pipe_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_pipe_pf0_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_pipe_pf0_0_procfinal(void) {
  
}

/*
 * calls: mprotect pipe
 */
// static int test_mprotect_pipe_pf0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_0
// static int test_mprotect_pipe_pf0_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_1
// static void setup_mprotect_pipe_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pipe_pf0_0_common
static void setup_mprotect_pipe_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_pipe_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_pf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pipe_pf0_0_final
// static void setup_mprotect_pipe_pf0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal

/*
 * calls: mprotect pipe
 */
// static int test_mprotect_pipe_pf0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_0
// static int test_mprotect_pipe_pf0_2_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_1
static void setup_mprotect_pipe_pf0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mprotect_pipe_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pipe_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_pf0_2_final(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal
// static void setup_mprotect_pipe_pf0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal

/*
 * calls: mprotect pipe
 */
// static int test_mprotect_pipe_pf0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_0
// static int test_mprotect_pipe_pf0_3_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_1
// static void setup_mprotect_pipe_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_2_common
static void setup_mprotect_pipe_pf0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pipe_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_pf0_3_final(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal
// static void setup_mprotect_pipe_pf0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal

/*
 * calls: mprotect pipe
 */
// static int test_mprotect_pipe_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_0
// static int test_mprotect_pipe_pb0_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_1
// static void setup_mprotect_pipe_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pipe_pf0_0_common
// static void setup_mprotect_pipe_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mprotect_pipe_pf0_0_proc0
// static void setup_mprotect_pipe_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pipe_pf0_0_final
// static void setup_mprotect_pipe_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal

/*
 * calls: mprotect pipe
 */
// static int test_mprotect_pipe_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_0
// static int test_mprotect_pipe_pb0_1_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_1
// static void setup_mprotect_pipe_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pipe_pf0_0_common
// static void setup_mprotect_pipe_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mprotect_pipe_pf0_1_proc0
// static void setup_mprotect_pipe_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pipe_pf0_0_final
// static void setup_mprotect_pipe_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal

/*
 * calls: mprotect pipe
 */
// static int test_mprotect_pipe_pb0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_0
// static int test_mprotect_pipe_pb0_2_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_1
// static void setup_mprotect_pipe_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_2_common
// static void setup_mprotect_pipe_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pipe_pf0_2_proc0
// static void setup_mprotect_pipe_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_pb0_2_final(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal
// static void setup_mprotect_pipe_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal

/*
 * calls: mprotect pipe
 */
// static int test_mprotect_pipe_pb0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_0
// static int test_mprotect_pipe_pb0_3_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_1
// static void setup_mprotect_pipe_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_2_common
// static void setup_mprotect_pipe_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pipe_pf0_3_proc0
// static void setup_mprotect_pipe_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_pb0_3_final(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal
// static void setup_mprotect_pipe_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal

/*
 * calls: mprotect pipe
 */
static int test_mprotect_pipe_p70_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static int test_mprotect_pipe_p70_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_1
// static void setup_mprotect_pipe_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_2_common
// static void setup_mprotect_pipe_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_p70_0_final(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal
// static void setup_mprotect_pipe_p70_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal

/*
 * calls: mprotect pipe
 */
// static int test_mprotect_pipe_p30_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_p70_0_0
// static int test_mprotect_pipe_p30_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pipe_pf0_0_1
// static void setup_mprotect_pipe_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_2_common
// static void setup_mprotect_pipe_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pipe_pf0_0_proc1
// static void setup_mprotect_pipe_p30_0_final(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal
// static void setup_mprotect_pipe_p30_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pipe_pf0_0_procfinal


/*
 * calls: mprotect pread
 */
static int test_mprotect_pread_pf_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_pread_pf_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_mprotect_pread_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mprotect_pread_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mprotect_pread_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mprotect_pread_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mprotect_pread_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pf_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pf_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_pread_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pf_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pf_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pread_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_pf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pf_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pf_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pread_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_pf_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pf_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pf_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pf_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pf_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_pread_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_pf_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pf_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pf_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pf_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pread_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_pf_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pf_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pf_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pf_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pf_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pf_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_pread_pf_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_pf_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pf_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pf_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pf_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pf_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pf_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pread_pf_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_pf_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pf_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
static int test_mprotect_pread_pe8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_mprotect_pread_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mprotect_pread_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
static void setup_mprotect_pread_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_pread_pe8_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_pread_pe8_0_procfinal(void) {
  
}

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pread_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_pread_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pe8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pe8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pread_pe8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pe8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pe8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mprotect_pread_pe8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe8_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pe8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pe8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_pread_pe8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe8_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe8_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe8_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pe8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pe8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_pread_pe8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe8_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe8_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe8_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pe8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pe8_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_pread_pe8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe8_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe8_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe8_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pe8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pe8_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pread_pe8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe8_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe8_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe8_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pe8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pe8_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pread_pe8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe8_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
static int test_mprotect_pread_pe0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_mprotect_pread_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mprotect_pread_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mprotect_pread_pe8_0_proc0
// static void setup_mprotect_pread_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pread_pe8_1_proc0
// static void setup_mprotect_pread_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mprotect_pread_pe8_2_proc0
// static void setup_mprotect_pread_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pe0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pe0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pread_pe8_3_proc0
// static void setup_mprotect_pread_pe0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pe0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
static void setup_mprotect_pread_pe0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_mprotect_pread_pe0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe0_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe0_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pe0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pe0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pe8_5_proc0
// static void setup_mprotect_pread_pe0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe0_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe0_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe0_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pe0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pe0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pread_pe8_8_proc0
// static void setup_mprotect_pread_pe0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe0_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe0_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe0_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pe0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
static void setup_mprotect_pread_pe0_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2297000);
}
// static void setup_mprotect_pread_pe0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe0_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe0_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe0_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pe0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pe0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pe8_7_proc0
// static void setup_mprotect_pread_pe0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe0_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe0_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pe0_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pe0_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pe0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pe0_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pread_pe8_9_proc0
// static void setup_mprotect_pread_pe0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pe0_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pe0_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
static int test_mprotect_pread_pc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_mprotect_pread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_pread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pc_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pc_0_1
static void setup_mprotect_pread_pc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mprotect_pread_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pc_1_final(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal
// static void setup_mprotect_pread_pc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pc_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pc_0_1
// static void setup_mprotect_pread_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_pread_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pc_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pc_0_1
// static void setup_mprotect_pread_pc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pc_1_common
static void setup_mprotect_pread_pc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pread_pc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_pc_3_final(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal
// static void setup_mprotect_pread_pc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pb_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mprotect_pread_pb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_pread_pb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pb_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_pread_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pb_0_proc1
// static void setup_mprotect_pread_pb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pb_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pb_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pb_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pread_pb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pb_0_proc1
// static void setup_mprotect_pread_pb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pb_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pb_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pb_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
static void setup_mprotect_pread_pb_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pread_pb_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pb_0_proc1
// static void setup_mprotect_pread_pb_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pb_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pb_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pb_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pb_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
// static void setup_mprotect_pread_pb_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pb_0_proc0
static void setup_mprotect_pread_pb_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_pread_pb_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pb_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pb_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pb_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pb_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
// static void setup_mprotect_pread_pb_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pread_pb_2_proc0
// static void setup_mprotect_pread_pb_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pb_4_proc1
// static void setup_mprotect_pread_pb_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pb_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pb_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pb_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pb_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
// static void setup_mprotect_pread_pb_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pb_1_proc0
// static void setup_mprotect_pread_pb_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pb_4_proc1
// static void setup_mprotect_pread_pb_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pb_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pb_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pb_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_pb_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
// static void setup_mprotect_pread_pb_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pread_pb_3_proc0
// static void setup_mprotect_pread_pb_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pb_4_proc1
// static void setup_mprotect_pread_pb_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_pb_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
static void setup_mprotect_pread_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pread_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pread_pc_1_proc0
// static void setup_mprotect_pread_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
static void setup_mprotect_pread_pa8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_pread_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_pa8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pread_pc_3_proc0
// static void setup_mprotect_pread_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pc_0_proc0
// static void setup_mprotect_pread_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pc_2_proc0
// static void setup_mprotect_pread_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_pa8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa8_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa8_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pa8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_pa8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pc_0_proc0
static void setup_mprotect_pread_pa8_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pread_pa8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa8_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa8_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa8_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pa8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_pa8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pc_2_proc0
// static void setup_mprotect_pread_pa8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_pa8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa8_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa8_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa8_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pa8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_pa8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pread_pc_1_proc0
// static void setup_mprotect_pread_pa8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_pa8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa8_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa8_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa8_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_pa8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_pa8_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pread_pc_3_proc0
// static void setup_mprotect_pread_pa8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_pa8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa8_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mprotect_pread_pa8_0_proc0
// static void setup_mprotect_pread_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pread_pc_1_proc0
// static void setup_mprotect_pread_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pa0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mprotect_pread_pa8_2_proc0
// static void setup_mprotect_pread_pa0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_pa0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pa0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pa0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pread_pc_3_proc0
// static void setup_mprotect_pread_pa0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_pa0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pa0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pa0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pc_0_proc0
static void setup_mprotect_pread_pa0_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pread_pa0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa0_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa0_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pa0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pa0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pc_0_proc0
// static void setup_mprotect_pread_pa0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_pa0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa0_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa0_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa0_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pa0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pa0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pc_2_proc0
// static void setup_mprotect_pread_pa0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa0_4_proc1
// static void setup_mprotect_pread_pa0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa0_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa0_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa0_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pa0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pa0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pread_pc_1_proc0
// static void setup_mprotect_pread_pa0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_pa0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa0_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa0_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa0_8_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pa0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pa0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pc_2_proc0
// static void setup_mprotect_pread_pa0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_pa0_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa0_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_pa0_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_pa0_9_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_pa0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_pa0_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pread_pc_3_proc0
// static void setup_mprotect_pread_pa0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_pa0_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_pa0_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_p8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pc_0_1
// static void setup_mprotect_pread_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pc_0_proc0
// static void setup_mprotect_pread_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_p8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pc_0_1
// static void setup_mprotect_pread_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pc_1_common
// static void setup_mprotect_pread_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pread_pc_1_proc0
// static void setup_mprotect_pread_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p8_1_final(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal
// static void setup_mprotect_pread_p8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_p8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pc_0_1
// static void setup_mprotect_pread_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pread_pc_2_proc0
// static void setup_mprotect_pread_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_p8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_pf_0_0
// static int test_mprotect_pread_p8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pc_0_1
// static void setup_mprotect_pread_p8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pc_1_common
// static void setup_mprotect_pread_p8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pread_pc_3_proc0
// static void setup_mprotect_pread_p8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p8_3_final(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal
// static void setup_mprotect_pread_p8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
static int test_mprotect_pread_p7_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static int test_mprotect_pread_p7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
// static void setup_mprotect_pread_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pb_0_proc1
// static void setup_mprotect_pread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p7_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
// static void setup_mprotect_pread_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pb_4_proc1
// static void setup_mprotect_pread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p68_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p68_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p60_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p60_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p60_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pc_0_1
// static void setup_mprotect_pread_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pc_1_common
// static void setup_mprotect_pread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p4_0_final(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal
// static void setup_mprotect_pread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p3_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p3_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
// static void setup_mprotect_pread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pb_0_proc1
// static void setup_mprotect_pread_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p3_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p3_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pf_0_1
// static void setup_mprotect_pread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pread_pf_0_common
// static void setup_mprotect_pread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pf_0_proc1
// static void setup_mprotect_pread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pread_pb_4_proc1
// static void setup_mprotect_pread_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_final
// static void setup_mprotect_pread_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pread_pf_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p28_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p28_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p28_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe8_0_1
// static void setup_mprotect_pread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe8_0_common
// static void setup_mprotect_pread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p20_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_0_proc1
// static void setup_mprotect_pread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p20_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p20_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pe0_0_1
// static void setup_mprotect_pread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pread_pe0_0_common
// static void setup_mprotect_pread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pread_pa8_6_proc1
// static void setup_mprotect_pread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pread_pe8_0_final
// static void setup_mprotect_pread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal

/*
 * calls: mprotect pread
 */
// static int test_mprotect_pread_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pread_p7_0_0
// static int test_mprotect_pread_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_pread_pc_0_1
// static void setup_mprotect_pread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pc_1_common
// static void setup_mprotect_pread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pread_pe8_0_proc1
// static void setup_mprotect_pread_p0_0_final(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal
// static void setup_mprotect_pread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pread_pe8_0_procfinal


/*
 * calls: mprotect pwrite
 */
static int test_mprotect_pwrite_pf_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_pwrite_pf_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_mprotect_pwrite_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mprotect_pwrite_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mprotect_pwrite_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mprotect_pwrite_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mprotect_pwrite_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pf_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pf_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_pwrite_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pf_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pf_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pf_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pf_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_pwrite_pf_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_pf_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pf_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pf_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pf_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pf_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pf_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_pwrite_pf_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_pf_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pf_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pf_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pf_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pf_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pf_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pwrite_pf_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_pf_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pf_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pf_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pf_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pf_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pf_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pwrite_pf_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_pf_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pf_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pf_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pf_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pf_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pf_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pwrite_pf_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_pf_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pf_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pf_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pf_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pf_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pf_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pwrite_pf_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_pf_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pf_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
static int test_mprotect_pwrite_pe8_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_mprotect_pwrite_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mprotect_pwrite_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
static void setup_mprotect_pwrite_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_pwrite_pe8_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_pwrite_pe8_0_procfinal(void) {
  
}

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
// static void setup_mprotect_pwrite_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1150976, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pwrite_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_mprotect_pwrite_pe8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_pwrite_pe8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1150976, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x476000);
}
// static void setup_mprotect_pwrite_pe8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x8ea000);
}
// static void setup_mprotect_pwrite_pe8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x1000);
}
// static void setup_mprotect_pwrite_pe8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_8_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_pwrite_pe8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_9_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pwrite_pe8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_10_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pwrite_pe8_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_10_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe8_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe8_11_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pe8_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pwrite_pe8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe8_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe8_11_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
static void setup_mprotect_pwrite_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mprotect_pwrite_pe0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
// static void setup_mprotect_pwrite_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
static void setup_mprotect_pwrite_pe0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
// static void setup_mprotect_pwrite_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
static void setup_mprotect_pwrite_pe0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
}
// static void setup_mprotect_pwrite_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
static int test_mprotect_pwrite_pe0_3_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_mprotect_pwrite_pe0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mprotect_pwrite_pe0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_pwrite_pe0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_pe0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pe8_4_proc0
// static void setup_mprotect_pwrite_pe0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe0_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
static void setup_mprotect_pwrite_pe0_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
}
// static void setup_mprotect_pwrite_pe0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe0_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_pe0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pe8_8_proc0
// static void setup_mprotect_pwrite_pe0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe0_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
static void setup_mprotect_pwrite_pe0_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pwrite_pe0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe0_8_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_pe0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pwrite_pe8_9_proc0
// static void setup_mprotect_pwrite_pe0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe0_9_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
static void setup_mprotect_pwrite_pe0_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pwrite_pe0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pe0_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pe0_10_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pe0_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_pe0_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pwrite_pe8_11_proc0
// static void setup_mprotect_pwrite_pe0_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pe0_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pe0_10_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
static int test_mprotect_pwrite_pc_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_mprotect_pwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_pwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pc_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pc_0_1
static void setup_mprotect_pwrite_pc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mprotect_pwrite_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pc_1_final(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal
// static void setup_mprotect_pwrite_pc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pc_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pc_0_1
// static void setup_mprotect_pwrite_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_pwrite_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pc_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pc_0_1
// static void setup_mprotect_pwrite_pc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pc_1_common
static void setup_mprotect_pwrite_pc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pwrite_pc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_pc_3_final(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal
// static void setup_mprotect_pwrite_pc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pb_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pb_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mprotect_pwrite_pb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_pwrite_pb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pb_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pb_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_pwrite_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pb_0_proc1
// static void setup_mprotect_pwrite_pb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pb_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pb_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
// static void setup_mprotect_pwrite_pb_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pb_0_proc0
static void setup_mprotect_pwrite_pb_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_pwrite_pb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pb_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pb_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pb_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
// static void setup_mprotect_pwrite_pb_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pwrite_pb_1_proc0
// static void setup_mprotect_pwrite_pb_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pb_2_proc1
// static void setup_mprotect_pwrite_pb_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pb_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pb_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pb_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pb_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pb_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_pwrite_pb_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pb_0_proc1
// static void setup_mprotect_pwrite_pb_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pb_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pb_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pb_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pb_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
// static void setup_mprotect_pwrite_pb_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pb_4_proc0
// static void setup_mprotect_pwrite_pb_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pb_2_proc1
// static void setup_mprotect_pwrite_pb_5_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pb_5_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pb_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pb_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pb_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
static void setup_mprotect_pwrite_pb_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_pwrite_pb_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pb_0_proc1
// static void setup_mprotect_pwrite_pb_6_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pb_6_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pb_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pb_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_pb_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
// static void setup_mprotect_pwrite_pb_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pwrite_pb_6_proc0
// static void setup_mprotect_pwrite_pb_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pb_2_proc1
// static void setup_mprotect_pwrite_pb_7_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_pb_7_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
static void setup_mprotect_pwrite_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pwrite_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x8ea000);
}
static void setup_mprotect_pwrite_pa8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pwrite_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pwrite_pc_1_proc0
static void setup_mprotect_pwrite_pa8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 33169408, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pwrite_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_pa8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pc_0_proc0
static void setup_mprotect_pwrite_pa8_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pwrite_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pc_0_proc0
static void setup_mprotect_pwrite_pa8_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pwrite_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pa8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x476000);
}
// static void setup_mprotect_pwrite_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_2_proc1
// static void setup_mprotect_pwrite_pa8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
static void setup_mprotect_pwrite_pa8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x8ea000);
}
// static void setup_mprotect_pwrite_pa8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9347072, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_1_proc1
// static void setup_mprotect_pwrite_pa8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_pa8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pc_2_proc0
// static void setup_mprotect_pwrite_pa8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_3_proc1
// static void setup_mprotect_pwrite_pa8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_8_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_pa8_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pc_2_proc0
// static void setup_mprotect_pwrite_pa8_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_4_proc1
// static void setup_mprotect_pwrite_pa8_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_9_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_pa8_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pwrite_pc_1_proc0
// static void setup_mprotect_pwrite_pa8_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_4_proc1
// static void setup_mprotect_pwrite_pa8_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_10_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_pa8_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pwrite_pc_3_proc0
static void setup_mprotect_pwrite_pa8_10_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pwrite_pa8_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_10_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa8_11_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa8_11_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa8_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_pa8_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pwrite_pc_3_proc0
// static void setup_mprotect_pwrite_pa8_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_4_proc1
// static void setup_mprotect_pwrite_pa8_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa8_11_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
static void setup_mprotect_pwrite_pa0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
static void setup_mprotect_pwrite_pa0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe0_3_1
// static void setup_mprotect_pwrite_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_3_common
// static void setup_mprotect_pwrite_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pc_0_proc0
// static void setup_mprotect_pwrite_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_3_proc1
// static void setup_mprotect_pwrite_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
static void setup_mprotect_pwrite_pa0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
}
static void setup_mprotect_pwrite_pa0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pwrite_pa0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
static int test_mprotect_pwrite_pa0_3_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_mprotect_pwrite_pa0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mprotect_pwrite_pa0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x5000);
}
static void setup_mprotect_pwrite_pa0_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pwrite_pa0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe0_3_1
// static void setup_mprotect_pwrite_pa0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_3_common
static void setup_mprotect_pwrite_pa0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x1000);
}
// static void setup_mprotect_pwrite_pa0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_3_proc1
// static void setup_mprotect_pwrite_pa0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa0_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pa0_3_1
// static void setup_mprotect_pwrite_pa0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa0_3_common
// static void setup_mprotect_pwrite_pa0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pwrite_pc_1_proc0
// static void setup_mprotect_pwrite_pa0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa0_3_proc1
// static void setup_mprotect_pwrite_pa0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_6_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa0_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_pa0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pc_2_proc0
static void setup_mprotect_pwrite_pa0_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_pwrite_pa0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_6_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_7_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa0_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_pa0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pwrite_pc_3_proc0
// static void setup_mprotect_pwrite_pa0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_0_proc1
// static void setup_mprotect_pwrite_pa0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_7_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_8_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa0_8_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa0_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_pa0_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pwrite_pc_1_proc0
// static void setup_mprotect_pwrite_pa0_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_4_proc1
// static void setup_mprotect_pwrite_pa0_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_8_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_9_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa0_9_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa0_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_pa0_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pc_2_proc0
// static void setup_mprotect_pwrite_pa0_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_4_proc1
// static void setup_mprotect_pwrite_pa0_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_9_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_pa0_10_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_pa0_10_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_pa0_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_pa0_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pwrite_pc_3_proc0
// static void setup_mprotect_pwrite_pa0_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_4_proc1
// static void setup_mprotect_pwrite_pa0_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_pa0_10_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_p8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pc_0_1
// static void setup_mprotect_pwrite_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pc_0_proc0
// static void setup_mprotect_pwrite_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_p8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pc_0_1
// static void setup_mprotect_pwrite_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pc_1_common
// static void setup_mprotect_pwrite_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_pwrite_pc_1_proc0
// static void setup_mprotect_pwrite_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p8_1_final(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal
// static void setup_mprotect_pwrite_p8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_p8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pc_0_1
// static void setup_mprotect_pwrite_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_pwrite_pc_2_proc0
// static void setup_mprotect_pwrite_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_p8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_0
// static int test_mprotect_pwrite_p8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pc_0_1
// static void setup_mprotect_pwrite_p8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pc_1_common
// static void setup_mprotect_pwrite_p8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_pwrite_pc_3_proc0
// static void setup_mprotect_pwrite_p8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p8_3_final(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal
// static void setup_mprotect_pwrite_p8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
static int test_mprotect_pwrite_p7_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static int test_mprotect_pwrite_p7_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
// static void setup_mprotect_pwrite_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pb_0_proc1
// static void setup_mprotect_pwrite_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p7_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p7_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
// static void setup_mprotect_pwrite_p7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pb_2_proc1
// static void setup_mprotect_pwrite_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p68_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p68_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_10_proc1
// static void setup_mprotect_pwrite_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_p68_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p68_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p68_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_p68_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_4_proc1
// static void setup_mprotect_pwrite_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_p68_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p60_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p60_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa0_6_proc1
// static void setup_mprotect_pwrite_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_p60_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p60_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p60_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_4_proc1
// static void setup_mprotect_pwrite_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_p60_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p4_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pc_0_1
// static void setup_mprotect_pwrite_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pc_1_common
// static void setup_mprotect_pwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p4_0_final(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal
// static void setup_mprotect_pwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p3_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p3_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
// static void setup_mprotect_pwrite_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pb_0_proc1
// static void setup_mprotect_pwrite_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p3_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p3_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pf_0_1
// static void setup_mprotect_pwrite_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_pwrite_pf_0_common
// static void setup_mprotect_pwrite_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pf_0_proc1
// static void setup_mprotect_pwrite_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_pwrite_pb_2_proc1
// static void setup_mprotect_pwrite_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_final
// static void setup_mprotect_pwrite_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_pwrite_pf_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p28_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p28_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_0_proc1
// static void setup_mprotect_pwrite_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_p28_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p28_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p28_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe8_0_common
// static void setup_mprotect_pwrite_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_4_proc1
// static void setup_mprotect_pwrite_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_p28_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p20_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p20_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa0_0_proc1
// static void setup_mprotect_pwrite_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_p20_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p20_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p20_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pe8_0_1
// static void setup_mprotect_pwrite_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pe0_0_common
// static void setup_mprotect_pwrite_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_pwrite_pa8_4_proc1
// static void setup_mprotect_pwrite_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_pwrite_pe8_0_final
// static void setup_mprotect_pwrite_p20_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal

/*
 * calls: mprotect pwrite
 */
// static int test_mprotect_pwrite_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_p7_0_0
// static int test_mprotect_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_mprotect_pwrite_pc_0_1
// static void setup_mprotect_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pc_1_common
// static void setup_mprotect_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_pwrite_pe8_0_proc1
// static void setup_mprotect_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal
// static void setup_mprotect_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_pwrite_pe8_0_procfinal


/*
 * calls: mprotect read
 */
static int test_mprotect_read_pf8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_read_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_mprotect_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mprotect_read_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mprotect_read_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mprotect_read_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mprotect_read_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf8_0_common
static void setup_mprotect_read_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_read_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf8_0_common
static void setup_mprotect_read_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_read_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf8_0_common
static void setup_mprotect_read_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_read_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
static int test_mprotect_read_pf6_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_mprotect_read_pf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mprotect_read_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mprotect_read_pf6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf6_0_1
// static void setup_mprotect_read_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
static void setup_mprotect_read_pf6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_read_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf6_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf6_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf6_0_1
// static void setup_mprotect_read_pf6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
static void setup_mprotect_read_pf6_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_read_pf6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf6_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf6_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf6_0_1
// static void setup_mprotect_read_pf6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
static void setup_mprotect_read_pf6_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_read_pf6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
static int test_mprotect_read_pf4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_mprotect_read_pf4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
static void setup_mprotect_read_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
static void setup_mprotect_read_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_read_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
static void setup_mprotect_read_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mprotect_read_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
}
// static void setup_mprotect_read_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf4_0_proc1
// static void setup_mprotect_read_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf4_1_common
static void setup_mprotect_read_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_read_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf4_0_proc1
// static void setup_mprotect_read_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf4_1_common
static void setup_mprotect_read_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_read_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf4_0_proc1
// static void setup_mprotect_read_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
static int test_mprotect_read_pf0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_mprotect_read_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_mprotect_read_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mprotect_read_pf6_0_proc0
// static void setup_mprotect_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf0_0_common
// static void setup_mprotect_read_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_read_pf6_1_proc0
// static void setup_mprotect_read_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf0_0_common
// static void setup_mprotect_read_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mprotect_read_pf6_2_proc0
// static void setup_mprotect_read_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pf0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pf0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf0_0_common
// static void setup_mprotect_read_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_read_pf6_3_proc0
// static void setup_mprotect_read_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
static void setup_mprotect_read_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mprotect_read_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
static void setup_mprotect_read_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_read_pe8_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_read_pe8_0_procfinal(void) {
  
}

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2297000);
}
// static void setup_mprotect_read_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
// static void setup_mprotect_read_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pe8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pe8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x704000);
}
// static void setup_mprotect_read_pe8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pe8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pe8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_read_pe8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe8_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pe8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pe8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_read_pe8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe8_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
static void setup_mprotect_read_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_mprotect_read_pe0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
// static void setup_mprotect_read_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
static void setup_mprotect_read_pe0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x2297000);
}
// static void setup_mprotect_read_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
static void setup_mprotect_read_pe0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_read_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pe0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
static void setup_mprotect_read_pe0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_read_pe0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pe0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
static void setup_mprotect_read_pe0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_read_pe0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe0_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pe0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pe0_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pe0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
static void setup_mprotect_read_pe0_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_read_pe0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pe0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pe0_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_read_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pc_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
static void setup_mprotect_read_pc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mprotect_read_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_read_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pc_1_final(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal
// static void setup_mprotect_read_pc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pc_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_read_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pc_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_pc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_read_pc_1_common
static void setup_mprotect_read_pc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_read_pc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_pc_3_final(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal
// static void setup_mprotect_read_pc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf8_0_common
static void setup_mprotect_read_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mprotect_read_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_read_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf8_0_common
static void setup_mprotect_read_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_read_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb8_0_proc1
// static void setup_mprotect_read_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf8_0_common
static void setup_mprotect_read_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_read_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb8_0_proc1
// static void setup_mprotect_read_pb8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf8_0_common
static void setup_mprotect_read_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_read_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb8_0_proc1
// static void setup_mprotect_read_pb8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf6_0_1
// static void setup_mprotect_read_pb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
static void setup_mprotect_read_pb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
static void setup_mprotect_read_pb6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_read_pb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf6_0_1
// static void setup_mprotect_read_pb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
static void setup_mprotect_read_pb6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_read_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_pb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb6_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb6_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf6_0_1
// static void setup_mprotect_read_pb6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
// static void setup_mprotect_read_pb6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_read_pb8_2_proc0
// static void setup_mprotect_read_pb6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_pb6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb6_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb6_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf6_0_1
// static void setup_mprotect_read_pb6_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
// static void setup_mprotect_read_pb6_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_read_pb8_3_proc0
// static void setup_mprotect_read_pb6_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_pb6_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb6_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf4_1_common
static void setup_mprotect_read_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x5000);
}
static void setup_mprotect_read_pb4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_read_pb4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb4_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf4_1_common
static void setup_mprotect_read_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_read_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb4_0_proc1
// static void setup_mprotect_read_pb4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb4_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pb4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf4_1_common
static void setup_mprotect_read_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x5000);
}
// static void setup_mprotect_read_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb4_0_proc1
// static void setup_mprotect_read_pb4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb4_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
static void setup_mprotect_read_pb4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_read_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb4_0_proc1
// static void setup_mprotect_read_pb4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf0_0_common
// static void setup_mprotect_read_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 0, "__i0", 0x2000);
// }
// ^ See setup_mprotect_read_pb6_0_proc0
// static void setup_mprotect_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf0_0_common
// static void setup_mprotect_read_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_file(0x12345600000, 1, "__i0", 0x2000);
// }
// ^ See setup_mprotect_read_pb6_1_proc0
// static void setup_mprotect_read_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf0_0_common
// static void setup_mprotect_read_pb0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_read_pb8_2_proc0
// static void setup_mprotect_read_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_pb0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pb0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pb0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf0_0_common
// static void setup_mprotect_read_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_read_pb8_3_proc0
// static void setup_mprotect_read_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_pb0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_pb0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x985000);
}
static void setup_mprotect_read_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_read_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2297000);
}
static void setup_mprotect_read_pa8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_read_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pa8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x704000);
}
static void setup_mprotect_read_pa8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_read_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
static void setup_mprotect_read_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x704000);
}
// static void setup_mprotect_read_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa8_2_proc1
// static void setup_mprotect_read_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
// static void setup_mprotect_read_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_read_pc_1_proc0
// static void setup_mprotect_read_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa8_1_proc1
// static void setup_mprotect_read_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
// static void setup_mprotect_read_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_read_pc_3_proc0
// static void setup_mprotect_read_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa8_1_proc1
// static void setup_mprotect_read_pa8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
// static void setup_mprotect_read_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x985000);
// }
// ^ See setup_mprotect_read_pa8_0_proc0
static void setup_mprotect_read_pa0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_read_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
// static void setup_mprotect_read_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x2297000);
// }
// ^ See setup_mprotect_read_pa8_1_proc0
// static void setup_mprotect_read_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa0_0_proc1
// static void setup_mprotect_read_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
// static void setup_mprotect_read_pa0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_read_pc_0_proc0
// static void setup_mprotect_read_pa0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa0_0_proc1
// static void setup_mprotect_read_pa0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pa0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
// static void setup_mprotect_read_pa0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_read_pc_2_proc0
// static void setup_mprotect_read_pa0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa0_0_proc1
// static void setup_mprotect_read_pa0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa0_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pa0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
// static void setup_mprotect_read_pa0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_read_pc_1_proc0
// static void setup_mprotect_read_pa0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa0_0_proc1
// static void setup_mprotect_read_pa0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa0_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_pa0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_pa0_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_pa0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
// static void setup_mprotect_read_pa0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_read_pc_3_proc0
// static void setup_mprotect_read_pa0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa0_0_proc1
// static void setup_mprotect_read_pa0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_pa0_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_p8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
// static void setup_mprotect_read_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_read_pc_0_proc0
// static void setup_mprotect_read_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_p8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_read_pc_1_common
// static void setup_mprotect_read_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_read_pc_1_proc0
// static void setup_mprotect_read_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p8_1_final(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal
// static void setup_mprotect_read_p8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_p8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
// static void setup_mprotect_read_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_read_pc_2_proc0
// static void setup_mprotect_read_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_p8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_pf8_0_0
// static int test_mprotect_read_p8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_p8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_read_pc_1_common
// static void setup_mprotect_read_p8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_read_pc_3_proc0
// static void setup_mprotect_read_p8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p8_3_final(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal
// static void setup_mprotect_read_p8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
static int test_mprotect_read_p78_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static int test_mprotect_read_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf8_0_common
// static void setup_mprotect_read_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb8_0_proc1
// static void setup_mprotect_read_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p76_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf6_0_1
// static void setup_mprotect_read_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
// static void setup_mprotect_read_p76_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p74_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf4_1_common
// static void setup_mprotect_read_p74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb4_0_proc1
// static void setup_mprotect_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf4_0_proc1
// static void setup_mprotect_read_p74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_p74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p70_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf0_0_common
// static void setup_mprotect_read_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p68_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
// static void setup_mprotect_read_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa8_0_proc1
// static void setup_mprotect_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p60_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
// static void setup_mprotect_read_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa0_0_proc1
// static void setup_mprotect_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_p60_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_read_pc_1_common
// static void setup_mprotect_read_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p4_0_final(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal
// static void setup_mprotect_read_p4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p38_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf8_0_common
// static void setup_mprotect_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb8_0_proc1
// static void setup_mprotect_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p36_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf6_0_1
// static void setup_mprotect_read_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf6_0_common
// static void setup_mprotect_read_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p34_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf4_1_common
// static void setup_mprotect_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf4_0_proc1
// static void setup_mprotect_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb4_0_proc1
// static void setup_mprotect_read_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p30_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_read_pf0_0_common
// static void setup_mprotect_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pf8_0_proc1
// static void setup_mprotect_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_read_pb6_0_proc1
// static void setup_mprotect_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_final
// static void setup_mprotect_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_read_pf8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p28_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf4_0_1
// static void setup_mprotect_read_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_read_pe8_0_common
// static void setup_mprotect_read_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa8_0_proc1
// static void setup_mprotect_read_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_p28_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p20_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf0_0_1
// static void setup_mprotect_read_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_read_pe0_0_common
// static void setup_mprotect_read_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_read_pa0_0_proc1
// static void setup_mprotect_read_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_read_pe8_0_final
// static void setup_mprotect_read_p20_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal

/*
 * calls: mprotect read
 */
// static int test_mprotect_read_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_read_p78_0_0
// static int test_mprotect_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_mprotect_read_pf8_0_1
// static void setup_mprotect_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_read_pc_1_common
// static void setup_mprotect_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_read_pe8_0_proc1
// static void setup_mprotect_read_p0_0_final(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal
// static void setup_mprotect_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_read_pe8_0_procfinal


/*
 * calls: mprotect rename
 */
static int test_mprotect_rename_pe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_rename_pe_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mprotect_rename_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mprotect_rename_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mprotect_rename_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_rename_pe_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_rename_pe_0_procfinal(void) {
  
}

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_pe_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_1
// static void setup_mprotect_rename_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pe_0_common
static void setup_mprotect_rename_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_rename_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pe_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pe_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_pe_2_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_1
// static void setup_mprotect_rename_pe_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pe_0_common
static void setup_mprotect_rename_pe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_rename_pe_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pe_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pe_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pe_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_pe_3_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_1
// static void setup_mprotect_rename_pe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pe_0_common
static void setup_mprotect_rename_pe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_rename_pe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pe_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pe_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
static int test_mprotect_rename_pd0_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mprotect_rename_pd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_mprotect_rename_pd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
// static void setup_mprotect_rename_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pd0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_pd0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pd0_0_1
// static void setup_mprotect_rename_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pd0_0_common
// static void setup_mprotect_rename_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_rename_pe_2_proc0
// static void setup_mprotect_rename_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pd0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_pd0_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pd0_0_1
// static void setup_mprotect_rename_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pd0_0_common
static void setup_mprotect_rename_pd0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_rename_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pd0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pd0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pd0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_pd0_3_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pd0_0_1
// static void setup_mprotect_rename_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pd0_0_common
// static void setup_mprotect_rename_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_rename_pe_3_proc0
// static void setup_mprotect_rename_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pd0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pd0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_pc_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pd0_0_1
// static void setup_mprotect_rename_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pe_0_common
// static void setup_mprotect_rename_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_rename_pe_0_proc0
// static void setup_mprotect_rename_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pc_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_pc_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pd0_0_1
// static void setup_mprotect_rename_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pe_0_common
// static void setup_mprotect_rename_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_rename_pe_2_proc0
// static void setup_mprotect_rename_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_pc_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pd0_0_1
// static void setup_mprotect_rename_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pe_0_common
// static void setup_mprotect_rename_pc_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_rename_pe_1_proc0
// static void setup_mprotect_rename_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_pc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_pc_3_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pd0_0_1
// static void setup_mprotect_rename_pc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pe_0_common
// static void setup_mprotect_rename_pc_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_rename_pe_3_proc0
// static void setup_mprotect_rename_pc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_pc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_pc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
static int test_mprotect_rename_p8_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_mprotect_rename_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_mprotect_rename_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_rename_pe_0_proc0
// static void setup_mprotect_rename_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_p8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_p8_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_p8_0_1
static void setup_mprotect_rename_p8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mprotect_rename_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_rename_pe_2_proc0
// static void setup_mprotect_rename_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p8_1_final(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal
// static void setup_mprotect_rename_p8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_p8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_p8_2_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_p8_0_1
// static void setup_mprotect_rename_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_rename_p8_0_common
// static void setup_mprotect_rename_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_rename_pe_1_proc0
// static void setup_mprotect_rename_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_p8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_p8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_0
// static int test_mprotect_rename_p8_3_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_p8_0_1
// static void setup_mprotect_rename_p8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_rename_p8_1_common
// static void setup_mprotect_rename_p8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_rename_pe_3_proc0
// static void setup_mprotect_rename_p8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p8_3_final(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal
// static void setup_mprotect_rename_p8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
static int test_mprotect_rename_p6_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static int test_mprotect_rename_p6_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pe_0_1
// static void setup_mprotect_rename_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pe_0_common
// static void setup_mprotect_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_p50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_p6_0_0
// static int test_mprotect_rename_p50_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pd0_0_1
// static void setup_mprotect_rename_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pd0_0_common
// static void setup_mprotect_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_p4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_p6_0_0
// static int test_mprotect_rename_p4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_pd0_0_1
// static void setup_mprotect_rename_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_rename_pe_0_common
// static void setup_mprotect_rename_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_rename_pe_0_final
// static void setup_mprotect_rename_p4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal

/*
 * calls: mprotect rename
 */
// static int test_mprotect_rename_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_p6_0_0
// static int test_mprotect_rename_p0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_rename_p8_0_1
// static void setup_mprotect_rename_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_rename_p8_1_common
// static void setup_mprotect_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_rename_pe_0_proc1
// static void setup_mprotect_rename_p0_0_final(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal
// static void setup_mprotect_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_rename_pe_0_procfinal


/*
 * calls: mprotect stat
 */
static int test_mprotect_stat_pc_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_mprotect_stat_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mprotect_stat_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mprotect_stat_pc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_stat_pc_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_stat_pc_0_procfinal(void) {
  
}

/*
 * calls: mprotect stat
 */
// static int test_mprotect_stat_pc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_stat_pc_0_0
// static int test_mprotect_stat_pc_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mprotect_stat_pc_0_1
// static void setup_mprotect_stat_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_stat_pc_0_common
static void setup_mprotect_stat_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_stat_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_stat_pc_0_final
// static void setup_mprotect_stat_pc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal

/*
 * calls: mprotect stat
 */
// static int test_mprotect_stat_pc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_stat_pc_0_0
// static int test_mprotect_stat_pc_2_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mprotect_stat_pc_0_1
// static void setup_mprotect_stat_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_stat_pc_0_common
static void setup_mprotect_stat_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_stat_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_pc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_stat_pc_0_final
// static void setup_mprotect_stat_pc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal

/*
 * calls: mprotect stat
 */
// static int test_mprotect_stat_pc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_stat_pc_0_0
// static int test_mprotect_stat_pc_3_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mprotect_stat_pc_0_1
// static void setup_mprotect_stat_pc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_stat_pc_0_common
static void setup_mprotect_stat_pc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_stat_pc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_pc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_stat_pc_0_final
// static void setup_mprotect_stat_pc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal

/*
 * calls: mprotect stat
 */
// static int test_mprotect_stat_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_stat_pc_0_0
static int test_mprotect_stat_p8_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_mprotect_stat_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_mprotect_stat_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_stat_pc_0_proc0
// static void setup_mprotect_stat_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_stat_pc_0_final
// static void setup_mprotect_stat_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal

/*
 * calls: mprotect stat
 */
// static int test_mprotect_stat_p8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_stat_pc_0_0
// static int test_mprotect_stat_p8_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mprotect_stat_p8_0_1
// static void setup_mprotect_stat_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_stat_p8_0_common
// static void setup_mprotect_stat_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_stat_pc_1_proc0
// static void setup_mprotect_stat_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_p8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_stat_pc_0_final
// static void setup_mprotect_stat_p8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal

/*
 * calls: mprotect stat
 */
// static int test_mprotect_stat_p8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_stat_pc_0_0
// static int test_mprotect_stat_p8_2_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mprotect_stat_p8_0_1
static void setup_mprotect_stat_p8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mprotect_stat_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_stat_pc_2_proc0
// static void setup_mprotect_stat_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_p8_2_final(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal
// static void setup_mprotect_stat_p8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal

/*
 * calls: mprotect stat
 */
// static int test_mprotect_stat_p8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_stat_pc_0_0
// static int test_mprotect_stat_p8_3_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mprotect_stat_p8_0_1
// static void setup_mprotect_stat_p8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_stat_p8_2_common
// static void setup_mprotect_stat_p8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_stat_pc_3_proc0
// static void setup_mprotect_stat_p8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_p8_3_final(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal
// static void setup_mprotect_stat_p8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal

/*
 * calls: mprotect stat
 */
static int test_mprotect_stat_p4_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static int test_mprotect_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mprotect_stat_pc_0_1
// static void setup_mprotect_stat_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_stat_pc_0_common
// static void setup_mprotect_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_stat_pc_0_final
// static void setup_mprotect_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal

/*
 * calls: mprotect stat
 */
// static int test_mprotect_stat_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_stat_p4_0_0
// static int test_mprotect_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_mprotect_stat_p8_0_1
// static void setup_mprotect_stat_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_stat_p8_2_common
// static void setup_mprotect_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_stat_pc_0_proc1
// static void setup_mprotect_stat_p0_0_final(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal
// static void setup_mprotect_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_stat_pc_0_procfinal


/*
 * calls: mprotect unlink
 */
static int test_mprotect_unlink_pc_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_unlink_pc_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_mprotect_unlink_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_mprotect_unlink_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
static void setup_mprotect_unlink_pc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_unlink_pc_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_unlink_pc_0_procfinal(void) {
  
}

/*
 * calls: mprotect unlink
 */
// static int test_mprotect_unlink_pc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_0
// static int test_mprotect_unlink_pc_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_1
// static void setup_mprotect_unlink_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_unlink_pc_0_common
static void setup_mprotect_unlink_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_unlink_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_unlink_pc_0_final
// static void setup_mprotect_unlink_pc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal

/*
 * calls: mprotect unlink
 */
// static int test_mprotect_unlink_pc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_0
// static int test_mprotect_unlink_pc_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_1
// static void setup_mprotect_unlink_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_unlink_pc_0_common
static void setup_mprotect_unlink_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_unlink_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_pc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_unlink_pc_0_final
// static void setup_mprotect_unlink_pc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal

/*
 * calls: mprotect unlink
 */
// static int test_mprotect_unlink_pc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_0
// static int test_mprotect_unlink_pc_3_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_1
// static void setup_mprotect_unlink_pc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_unlink_pc_0_common
static void setup_mprotect_unlink_pc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_unlink_pc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_pc_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_unlink_pc_0_final
// static void setup_mprotect_unlink_pc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal

/*
 * calls: mprotect unlink
 */
// static int test_mprotect_unlink_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_0
static int test_mprotect_unlink_p8_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_mprotect_unlink_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mprotect_unlink_p8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_unlink_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_unlink_pc_0_final
// static void setup_mprotect_unlink_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal

/*
 * calls: mprotect unlink
 */
// static int test_mprotect_unlink_p8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_0
// static int test_mprotect_unlink_p8_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_p8_0_1
static void setup_mprotect_unlink_p8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_mprotect_unlink_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_unlink_pc_2_proc0
// static void setup_mprotect_unlink_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_p8_1_final(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal
// static void setup_mprotect_unlink_p8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal

/*
 * calls: mprotect unlink
 */
// static int test_mprotect_unlink_p8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_0
// static int test_mprotect_unlink_p8_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_p8_0_1
// static void setup_mprotect_unlink_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_unlink_p8_0_common
static void setup_mprotect_unlink_p8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_unlink_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_p8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_unlink_pc_0_final
// static void setup_mprotect_unlink_p8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal

/*
 * calls: mprotect unlink
 */
// static int test_mprotect_unlink_p8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_0
// static int test_mprotect_unlink_p8_3_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_p8_0_1
// static void setup_mprotect_unlink_p8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_p8_1_common
// static void setup_mprotect_unlink_p8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_unlink_pc_3_proc0
// static void setup_mprotect_unlink_p8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_p8_3_final(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal
// static void setup_mprotect_unlink_p8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal

/*
 * calls: mprotect unlink
 */
static int test_mprotect_unlink_p4_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static int test_mprotect_unlink_p4_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_pc_0_1
// static void setup_mprotect_unlink_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_mprotect_unlink_pc_0_common
// static void setup_mprotect_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_unlink_pc_0_final
// static void setup_mprotect_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal

/*
 * calls: mprotect unlink
 */
// static int test_mprotect_unlink_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_p4_0_0
// static int test_mprotect_unlink_p0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_mprotect_unlink_p8_0_1
// static void setup_mprotect_unlink_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_p8_1_common
// static void setup_mprotect_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_unlink_pc_0_proc1
// static void setup_mprotect_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal
// static void setup_mprotect_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_unlink_pc_0_procfinal


/*
 * calls: mprotect write
 */
static int test_mprotect_write_pfc_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_mprotect_write_pfc_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_mprotect_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_mprotect_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
static void setup_mprotect_write_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_mprotect_write_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_mprotect_write_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pfc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pfc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pfc_0_1
// static void setup_mprotect_write_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pfc_0_common
static void setup_mprotect_write_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_write_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pfc_0_proc1
// static void setup_mprotect_write_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pfc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pfc_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pfc_0_1
// static void setup_mprotect_write_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pfc_0_common
static void setup_mprotect_write_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_write_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pfc_0_proc1
// static void setup_mprotect_write_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pfc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pfc_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pfc_0_1
// static void setup_mprotect_write_pfc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pfc_0_common
static void setup_mprotect_write_pfc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_write_pfc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pfc_0_proc1
// static void setup_mprotect_write_pfc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pfc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pf8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
static int test_mprotect_write_pf8_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_mprotect_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mprotect_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
static void setup_mprotect_write_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pf8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pf8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf8_0_common
static void setup_mprotect_write_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_write_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pf8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pf8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf8_0_common
static void setup_mprotect_write_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_write_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pf8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pf8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf8_0_common
static void setup_mprotect_write_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_write_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pf0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
static int test_mprotect_write_pf0_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_mprotect_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_mprotect_write_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pf0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pf0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf0_0_common
static void setup_mprotect_write_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_write_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pf0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pf0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf0_0_common
static void setup_mprotect_write_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_write_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pf0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pf0_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf0_0_common
static void setup_mprotect_write_pf0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_write_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
static void setup_mprotect_write_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_mprotect_write_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
static void setup_mprotect_write_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_mprotect_write_pe8_0_final(void) {
  unlink("__i0");
}
static void setup_mprotect_write_pe8_0_procfinal(void) {
  
}

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
static void setup_mprotect_write_pe8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
}
// static void setup_mprotect_write_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pe8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
static void setup_mprotect_write_pe8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_write_pe8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pe8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
static void setup_mprotect_write_pe8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_write_pe8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe8_4_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pe8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
static void setup_mprotect_write_pe8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_write_pe8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe8_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe8_5_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pe8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
static void setup_mprotect_write_pe8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_write_pe8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe8_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
static void setup_mprotect_write_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_mprotect_write_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x2297000);
// }
// ^ See setup_mprotect_write_pe8_0_proc0
// static void setup_mprotect_write_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
// }
// ^ See setup_mprotect_write_pe8_1_proc0
// static void setup_mprotect_write_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pe0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pe0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_write_pe8_2_proc0
// static void setup_mprotect_write_pe0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe0_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pe0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pe0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_write_pe8_3_proc0
// static void setup_mprotect_write_pe0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe0_4_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pe0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pe0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_write_pe8_4_proc0
// static void setup_mprotect_write_pe0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe0_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pe0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pe0_5_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pe0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pe0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_write_pe8_5_proc0
// static void setup_mprotect_write_pe0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pe0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pe0_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
static void setup_mprotect_write_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
// static void setup_mprotect_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pc_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
static void setup_mprotect_write_pc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_mprotect_write_pc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_write_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pc_1_final(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal
// static void setup_mprotect_write_pc_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pc_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_pc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
static void setup_mprotect_write_pc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_write_pc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pc_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pc_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pc_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_pc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_write_pc_1_common
static void setup_mprotect_write_pc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_write_pc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_pc_3_final(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal
// static void setup_mprotect_write_pc_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pbc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pbc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pfc_0_1
// static void setup_mprotect_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pfc_0_common
static void setup_mprotect_write_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
static void setup_mprotect_write_pbc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pbc_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pbc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pfc_0_1
// static void setup_mprotect_write_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pfc_0_common
static void setup_mprotect_write_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_write_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pbc_0_proc1
// static void setup_mprotect_write_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pbc_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pbc_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pfc_0_1
// static void setup_mprotect_write_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pfc_0_common
static void setup_mprotect_write_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_write_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pbc_0_proc1
// static void setup_mprotect_write_pbc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pbc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pbc_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pbc_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pfc_0_1
// static void setup_mprotect_write_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pfc_0_common
static void setup_mprotect_write_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_write_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pbc_0_proc1
// static void setup_mprotect_write_pbc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pbc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pb8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf8_0_common
static void setup_mprotect_write_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x2000);
}
static void setup_mprotect_write_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_write_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pb8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pb8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf8_0_common
static void setup_mprotect_write_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 0, 0);
}
// static void setup_mprotect_write_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pb8_0_proc1
// static void setup_mprotect_write_pb8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pb8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pb8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pb8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf8_0_common
static void setup_mprotect_write_pb8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x2000);
}
// static void setup_mprotect_write_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pb8_0_proc1
// static void setup_mprotect_write_pb8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pb8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pb8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pb8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf8_0_common
static void setup_mprotect_write_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_anon(0x12345600000, 1, 0);
}
// static void setup_mprotect_write_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pb8_0_proc1
// static void setup_mprotect_write_pb8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pb8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pb0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf0_0_common
static void setup_mprotect_write_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 0, "__i0", 0x0);
}
static void setup_mprotect_write_pb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_mprotect_write_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pb0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pb0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf0_0_common
// static void setup_mprotect_write_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_write_pb8_1_proc0
// static void setup_mprotect_write_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pb0_0_proc1
// static void setup_mprotect_write_pb0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pb0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pb0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pb0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf0_0_common
static void setup_mprotect_write_pb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  init_map_file(0x12345600000, 1, "__i0", 0x0);
}
// static void setup_mprotect_write_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pb0_0_proc1
// static void setup_mprotect_write_pb0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pb0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pb0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pb0_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf0_0_common
// static void setup_mprotect_write_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_write_pb8_3_proc0
// static void setup_mprotect_write_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pb0_0_proc1
// static void setup_mprotect_write_pb0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_pb0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
static void setup_mprotect_write_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 0, "__i0", 0x2297000);
}
static void setup_mprotect_write_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_mprotect_write_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
static void setup_mprotect_write_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
}
// static void setup_mprotect_write_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
// static void setup_mprotect_write_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_write_pc_0_proc0
// static void setup_mprotect_write_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
// static void setup_mprotect_write_pa8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_write_pc_2_proc0
// static void setup_mprotect_write_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa8_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa8_4_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
// static void setup_mprotect_write_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_write_pc_1_proc0
// static void setup_mprotect_write_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa8_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa8_5_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
// static void setup_mprotect_write_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_write_pc_3_proc0
// static void setup_mprotect_write_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x2297000);
// }
// ^ See setup_mprotect_write_pa8_0_proc0
// static void setup_mprotect_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x20ad000);
// }
// ^ See setup_mprotect_write_pa8_1_proc0
// static void setup_mprotect_write_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa0_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pa0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_write_pc_0_proc0
// static void setup_mprotect_write_pa0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa0_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa0_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa0_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pa0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_write_pc_2_proc0
// static void setup_mprotect_write_pa0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa0_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa0_4_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa0_4_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pa0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_write_pc_1_proc0
// static void setup_mprotect_write_pa0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa0_4_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_pa0_5_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_pa0_5_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_pa0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_pa0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_write_pc_3_proc0
// static void setup_mprotect_write_pa0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_pa0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_pa0_5_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_p8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
// static void setup_mprotect_write_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 0, "__i0", 0x0);
// }
// ^ See setup_mprotect_write_pc_0_proc0
// static void setup_mprotect_write_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_p8_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p8_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_p8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_p8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_write_pc_1_common
// static void setup_mprotect_write_p8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 0, 0);
// }
// ^ See setup_mprotect_write_pc_1_proc0
// static void setup_mprotect_write_p8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p8_1_final(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal
// static void setup_mprotect_write_p8_1_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p8_2_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_p8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_p8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
// static void setup_mprotect_write_p8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_file(0x12345600000, 1, "__i0", 0x0);
// }
// ^ See setup_mprotect_write_pc_2_proc0
// static void setup_mprotect_write_p8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_p8_2_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p8_3_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_pfc_0_0
// static int test_mprotect_write_p8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_p8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_write_pc_1_common
// static void setup_mprotect_write_p8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   init_map_anon(0x12345600000, 1, 0);
// }
// ^ See setup_mprotect_write_pc_3_proc0
// static void setup_mprotect_write_p8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p8_3_final(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal
// static void setup_mprotect_write_p8_3_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
static int test_mprotect_write_p7c_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = mprotect(va, 4096, PROT_READ);
  expect_result("r", r, -1);
  expect_errno(12);
  return xerrno(r);
}
// static int test_mprotect_write_p7c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pfc_0_1
// static void setup_mprotect_write_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pfc_0_common
// static void setup_mprotect_write_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pbc_0_proc1
// static void setup_mprotect_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pfc_0_proc1
// static void setup_mprotect_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p78_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf8_0_common
// static void setup_mprotect_write_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pb8_0_proc1
// static void setup_mprotect_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p70_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf0_0_common
// static void setup_mprotect_write_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pb0_0_proc1
// static void setup_mprotect_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p68_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p68_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
// static void setup_mprotect_write_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p60_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p60_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_write_pc_1_common
// static void setup_mprotect_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p4_0_final(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal
// static void setup_mprotect_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p3c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pfc_0_1
// static void setup_mprotect_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pfc_0_common
// static void setup_mprotect_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pfc_0_proc1
// static void setup_mprotect_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pbc_0_proc1
// static void setup_mprotect_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p38_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf8_0_common
// static void setup_mprotect_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pb8_0_proc1
// static void setup_mprotect_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p30_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_mprotect_write_pf0_0_common
// static void setup_mprotect_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pf8_0_proc1
// static void setup_mprotect_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_mprotect_write_pb0_0_proc1
// static void setup_mprotect_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_final
// static void setup_mprotect_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_mprotect_write_pfc_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p28_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_mprotect_write_pe8_0_common
// static void setup_mprotect_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p20_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf8_0_1
// static void setup_mprotect_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_mprotect_write_pe0_0_common
// static void setup_mprotect_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_mprotect_write_pa8_0_proc1
// static void setup_mprotect_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_mprotect_write_pe8_0_final
// static void setup_mprotect_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal

/*
 * calls: mprotect write
 */
// static int test_mprotect_write_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = mprotect(va, 4096, PROT_READ);
//   expect_result("r", r, -1);
//   expect_errno(12);
//   return xerrno(r);
// }
// ^ See test_mprotect_write_p7c_0_0
// static int test_mprotect_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_mprotect_write_pf0_0_1
// static void setup_mprotect_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_mprotect_write_pc_1_common
// static void setup_mprotect_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_mprotect_write_pe8_0_proc1
// static void setup_mprotect_write_p0_0_final(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal
// static void setup_mprotect_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_mprotect_write_pe8_0_procfinal


/*
 * calls: munmap munmap
 */
static int test_munmap_munmap_p8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_munmap_munmap_p8_0_1(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_munmap_munmap_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_munmap_munmap_p8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_munmap_p8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_munmap_p8_0_final(void) {
  
}
static void setup_munmap_munmap_p8_0_procfinal(void) {
  
}

/*
 * calls: munmap munmap
 */
// static int test_munmap_munmap_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_munmap_p8_0_1
// static int test_munmap_munmap_p0_0_1(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_munmap_p8_0_1
// static void setup_munmap_munmap_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_munmap_munmap_p8_0_common
// static void setup_munmap_munmap_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_munmap_p8_0_proc1
// static void setup_munmap_munmap_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_munmap_p8_0_proc1
// static void setup_munmap_munmap_p0_0_final(void) {
//   
// }
// ^ See setup_munmap_munmap_p8_0_procfinal
// static void setup_munmap_munmap_p0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_munmap_p8_0_procfinal


/*
 * calls: munmap open
 */
static int test_munmap_open_pe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_munmap_open_pe_0_1(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_munmap_open_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_munmap_open_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_open_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_open_pe_0_final(void) {
  unlink("__i0");
}
static void setup_munmap_open_pe_0_procfinal(void) {
  
}

/*
 * calls: munmap open
 */
// static int test_munmap_open_pdc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
static int test_munmap_open_pdc_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_munmap_open_pdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_munmap_open_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_open_pe_0_final
// static void setup_munmap_open_pdc_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_pd4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
// static int test_munmap_open_pd4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_munmap_open_pdc_0_1
// static void setup_munmap_open_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_munmap_open_pdc_0_common
// static void setup_munmap_open_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_open_pe_0_final
// static void setup_munmap_open_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_pcc_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
static int test_munmap_open_pcc_0_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_munmap_open_pcc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_munmap_open_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_open_pe_0_final
// static void setup_munmap_open_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_pc4_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
// static int test_munmap_open_pc4_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_munmap_open_pcc_0_1
// static void setup_munmap_open_pc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_munmap_open_pcc_0_common
// static void setup_munmap_open_pc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_open_pe_0_final
// static void setup_munmap_open_pc4_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_pb8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
// static int test_munmap_open_pb8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_munmap_open_pdc_0_1
static void setup_munmap_open_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_munmap_open_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pb8_0_final(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal
// static void setup_munmap_open_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_pa8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
// static int test_munmap_open_pa8_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_munmap_open_pdc_0_1
// static void setup_munmap_open_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_munmap_open_pb8_0_common
// static void setup_munmap_open_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_pa8_0_final(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal
// static void setup_munmap_open_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_p98_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
// static int test_munmap_open_p98_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_munmap_open_pcc_0_1
// static void setup_munmap_open_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_munmap_open_pb8_0_common
// static void setup_munmap_open_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p98_0_final(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal
// static void setup_munmap_open_p98_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_p88_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
// static int test_munmap_open_p88_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_munmap_open_pcc_0_1
// static void setup_munmap_open_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_munmap_open_pb8_0_common
// static void setup_munmap_open_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p88_0_final(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal
// static void setup_munmap_open_p88_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_p78_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
static int test_munmap_open_p78_0_1(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_munmap_open_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_munmap_open_pdc_0_common
// static void setup_munmap_open_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p78_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_open_pe_0_final
// static void setup_munmap_open_p78_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_p68_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
// static int test_munmap_open_p68_0_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_munmap_open_p78_0_1
// static void setup_munmap_open_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_munmap_open_pdc_0_common
// static void setup_munmap_open_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_open_pe_0_final
// static void setup_munmap_open_p68_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_p58_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
static int test_munmap_open_p58_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_munmap_open_p58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_munmap_open_pcc_0_common
// static void setup_munmap_open_p58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_open_pe_0_final
// static void setup_munmap_open_p58_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_p48_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
// static int test_munmap_open_p48_0_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_munmap_open_p58_0_1
// static void setup_munmap_open_p48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_munmap_open_pcc_0_common
// static void setup_munmap_open_p48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_open_pe_0_final
// static void setup_munmap_open_p48_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal

/*
 * calls: munmap open
 */
// static int test_munmap_open_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_open_pe_0_0
static int test_munmap_open_p0_0_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_munmap_open_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_munmap_open_pb8_0_common
// static void setup_munmap_open_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_open_pe_0_proc1
// static void setup_munmap_open_p0_0_final(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal
// static void setup_munmap_open_p0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_open_pe_0_procfinal


/*
 * calls: munmap pipe
 */
static int test_munmap_pipe_pe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_munmap_pipe_pe_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_munmap_pipe_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_munmap_pipe_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_pipe_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_pipe_pe_0_final(void) {
  
}
static void setup_munmap_pipe_pe_0_procfinal(void) {
  
}

/*
 * calls: munmap pipe
 */
// static int test_munmap_pipe_p6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pipe_pe_0_0
// static int test_munmap_pipe_p6_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pipe_pe_0_1
// static void setup_munmap_pipe_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_munmap_pipe_pe_0_common
// static void setup_munmap_pipe_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pipe_pe_0_proc1
// static void setup_munmap_pipe_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pipe_pe_0_proc1
// static void setup_munmap_pipe_p6_0_final(void) {
//   
// }
// ^ See setup_munmap_pipe_pe_0_procfinal
// static void setup_munmap_pipe_p6_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pipe_pe_0_procfinal


/*
 * calls: munmap pread
 */
static int test_munmap_pread_pe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_munmap_pread_pe_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_munmap_pread_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_munmap_pread_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_munmap_pread_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_munmap_pread_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_munmap_pread_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_pe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
// static int test_munmap_pread_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_pread_pe_0_1
// static void setup_munmap_pread_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_pread_pe_0_common
static void setup_munmap_pread_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_munmap_pread_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_pread_pe_0_proc1
// static void setup_munmap_pread_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pread_pe_0_final
// static void setup_munmap_pread_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pread_pe_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_pd_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
static int test_munmap_pread_pd_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_munmap_pread_pd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_munmap_pread_pd_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_munmap_pread_pd_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_pread_pd_0_final(void) {
  unlink("__i0");
}
static void setup_munmap_pread_pd_0_procfinal(void) {
  
}

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_pd_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
// static int test_munmap_pread_pd_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_pread_pd_0_1
// static void setup_munmap_pread_pd_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_munmap_pread_pd_0_common
static void setup_munmap_pread_pd_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_munmap_pread_pd_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_pd_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pread_pd_0_final
// static void setup_munmap_pread_pd_1_procfinal(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
static int test_munmap_pread_pc0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_munmap_pread_pc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_munmap_pread_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_pread_pd_0_proc0
// static void setup_munmap_pread_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pread_pd_0_final
// static void setup_munmap_pread_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_pc0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
// static int test_munmap_pread_pc0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_pread_pc0_0_1
// static void setup_munmap_pread_pc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_munmap_pread_pc0_0_common
// static void setup_munmap_pread_pc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_pread_pd_1_proc0
// static void setup_munmap_pread_pc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_pc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pread_pd_0_final
// static void setup_munmap_pread_pc0_1_procfinal(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
static int test_munmap_pread_p8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_munmap_pread_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_munmap_pread_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_p8_0_final(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal
// static void setup_munmap_pread_p8_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_p6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
// static int test_munmap_pread_p6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_pread_pe_0_1
// static void setup_munmap_pread_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_pread_pe_0_common
// static void setup_munmap_pread_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_pread_pe_0_proc1
// static void setup_munmap_pread_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_pread_pe_0_proc0
// static void setup_munmap_pread_p6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pread_pe_0_final
// static void setup_munmap_pread_p6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pread_pe_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_p6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
// static int test_munmap_pread_p6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_pread_pe_0_1
// static void setup_munmap_pread_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_pread_pe_0_common
// static void setup_munmap_pread_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_pread_pe_0_proc1
// static void setup_munmap_pread_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_pread_pe_1_proc0
// static void setup_munmap_pread_p6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pread_pe_0_final
// static void setup_munmap_pread_p6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pread_pe_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_p5_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
// static int test_munmap_pread_p5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_pread_pd_0_1
// static void setup_munmap_pread_p5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_munmap_pread_pd_0_common
// static void setup_munmap_pread_p5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_p5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_pread_pd_0_proc0
// static void setup_munmap_pread_p5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pread_pd_0_final
// static void setup_munmap_pread_p5_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_p5_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
// static int test_munmap_pread_p5_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_pread_pd_0_1
// static void setup_munmap_pread_p5_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_munmap_pread_pd_0_common
// static void setup_munmap_pread_p5_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_p5_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_pread_pd_1_proc0
// static void setup_munmap_pread_p5_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pread_pd_0_final
// static void setup_munmap_pread_p5_1_procfinal(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_p40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
// static int test_munmap_pread_p40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_pread_pc0_0_1
// static void setup_munmap_pread_p40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_munmap_pread_pc0_0_common
// static void setup_munmap_pread_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_pread_pd_0_proc0
// static void setup_munmap_pread_p40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pread_pd_0_final
// static void setup_munmap_pread_p40_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_p40_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
// static int test_munmap_pread_p40_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_pread_pc0_0_1
// static void setup_munmap_pread_p40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_munmap_pread_pc0_0_common
// static void setup_munmap_pread_p40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_p40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_pread_pd_1_proc0
// static void setup_munmap_pread_p40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pread_pd_0_final
// static void setup_munmap_pread_p40_1_procfinal(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal

/*
 * calls: munmap pread
 */
// static int test_munmap_pread_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pread_pe_0_0
// static int test_munmap_pread_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_pread_p8_0_1
// static void setup_munmap_pread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_munmap_pread_p8_0_common
// static void setup_munmap_pread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pread_pd_0_proc1
// static void setup_munmap_pread_p0_0_final(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal
// static void setup_munmap_pread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pread_pd_0_procfinal


/*
 * calls: munmap pwrite
 */
static int test_munmap_pwrite_pe_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_munmap_pwrite_pe_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_munmap_pwrite_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_munmap_pwrite_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_munmap_pwrite_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_munmap_pwrite_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_munmap_pwrite_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_pe_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_pe_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_1
// static void setup_munmap_pwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_pwrite_pe_0_common
static void setup_munmap_pwrite_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_munmap_pwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_pwrite_pe_0_proc1
// static void setup_munmap_pwrite_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pwrite_pe_0_final
// static void setup_munmap_pwrite_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pwrite_pe_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_pd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
static int test_munmap_pwrite_pd0_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_munmap_pwrite_pd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_munmap_pwrite_pd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_munmap_pwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_pwrite_pd0_0_final(void) {
  unlink("__i0");
}
static void setup_munmap_pwrite_pd0_0_procfinal(void) {
  
}

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_pd0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_pd0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pd0_0_1
// static void setup_munmap_pwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_munmap_pwrite_pd0_0_common
static void setup_munmap_pwrite_pd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_munmap_pwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
// static void setup_munmap_pwrite_pd0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pwrite_pd0_0_final
// static void setup_munmap_pwrite_pd0_1_procfinal(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_pc0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pd0_0_1
static void setup_munmap_pwrite_pc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_munmap_pwrite_pc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_munmap_pwrite_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
// static void setup_munmap_pwrite_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pwrite_pd0_0_final
// static void setup_munmap_pwrite_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_pc0_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_pc0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pd0_0_1
// static void setup_munmap_pwrite_pc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_munmap_pwrite_pc0_0_common
// static void setup_munmap_pwrite_pc0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_pwrite_pd0_1_proc0
// static void setup_munmap_pwrite_pc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
// static void setup_munmap_pwrite_pc0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pwrite_pd0_0_final
// static void setup_munmap_pwrite_pc0_1_procfinal(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
static int test_munmap_pwrite_p8_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
static void setup_munmap_pwrite_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_munmap_pwrite_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
// static void setup_munmap_pwrite_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
// static void setup_munmap_pwrite_p8_0_final(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal
// static void setup_munmap_pwrite_p8_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_p6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_p6_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_1
// static void setup_munmap_pwrite_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_pwrite_pe_0_common
// static void setup_munmap_pwrite_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_pwrite_pe_0_proc1
// static void setup_munmap_pwrite_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_pwrite_pe_0_proc0
// static void setup_munmap_pwrite_p6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pwrite_pe_0_final
// static void setup_munmap_pwrite_p6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pwrite_pe_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_p6_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_p6_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_1
// static void setup_munmap_pwrite_p6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_pwrite_pe_0_common
// static void setup_munmap_pwrite_p6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_pwrite_pe_0_proc1
// static void setup_munmap_pwrite_p6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_pwrite_pe_1_proc0
// static void setup_munmap_pwrite_p6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pwrite_pe_0_final
// static void setup_munmap_pwrite_p6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_pwrite_pe_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_p50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_p50_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pd0_0_1
// static void setup_munmap_pwrite_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_munmap_pwrite_pd0_0_common
// static void setup_munmap_pwrite_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
static void setup_munmap_pwrite_p50_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_munmap_pwrite_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pwrite_pd0_0_final
// static void setup_munmap_pwrite_p50_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_p50_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_p50_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pd0_0_1
// static void setup_munmap_pwrite_p50_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_munmap_pwrite_pd0_0_common
// static void setup_munmap_pwrite_p50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
// static void setup_munmap_pwrite_p50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_pwrite_pd0_1_proc0
// static void setup_munmap_pwrite_p50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pwrite_pd0_0_final
// static void setup_munmap_pwrite_p50_1_procfinal(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_p40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_p40_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pd0_0_1
// static void setup_munmap_pwrite_p40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_munmap_pwrite_pc0_0_common
// static void setup_munmap_pwrite_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
static void setup_munmap_pwrite_p40_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_munmap_pwrite_p40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pwrite_pd0_0_final
// static void setup_munmap_pwrite_p40_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_p40_1_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_p40_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pd0_0_1
// static void setup_munmap_pwrite_p40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_munmap_pwrite_pc0_0_common
// static void setup_munmap_pwrite_p40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
// static void setup_munmap_pwrite_p40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_pwrite_pd0_1_proc0
// static void setup_munmap_pwrite_p40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_pwrite_pd0_0_final
// static void setup_munmap_pwrite_p40_1_procfinal(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal

/*
 * calls: munmap pwrite
 */
// static int test_munmap_pwrite_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_pe_0_0
// static int test_munmap_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_munmap_pwrite_p8_0_1
// static void setup_munmap_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_p8_0_common
// static void setup_munmap_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
// static void setup_munmap_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_pwrite_pd0_0_proc1
// static void setup_munmap_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal
// static void setup_munmap_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_pwrite_pd0_0_procfinal


/*
 * calls: munmap read
 */
static int test_munmap_read_pf_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_munmap_read_pf_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_munmap_read_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_munmap_read_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_munmap_read_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_munmap_read_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_munmap_read_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: munmap read
 */
// static int test_munmap_read_pec_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
static int test_munmap_read_pec_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_munmap_read_pec_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_munmap_read_pec_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_munmap_read_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pf_0_proc1
// static void setup_munmap_read_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_final
// static void setup_munmap_read_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_pe8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
static int test_munmap_read_pe8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_munmap_read_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_read_pec_0_common
static void setup_munmap_read_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_munmap_read_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_munmap_read_pe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_final
// static void setup_munmap_read_pe8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_pe0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
static int test_munmap_read_pe0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_munmap_read_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_munmap_read_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pec_0_proc0
// static void setup_munmap_read_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pf_0_proc1
// static void setup_munmap_read_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_final
// static void setup_munmap_read_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_pd_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
// static int test_munmap_read_pd_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_read_pe8_0_1
static void setup_munmap_read_pd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_munmap_read_pd_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_munmap_read_pd_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_read_pd_0_final(void) {
  unlink("__i0");
}
static void setup_munmap_read_pd_0_procfinal(void) {
  
}

/*
 * calls: munmap read
 */
// static int test_munmap_read_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
// static int test_munmap_read_pc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_read_pe0_0_1
static void setup_munmap_read_pc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_munmap_read_pc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_munmap_read_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_read_pd_0_proc1
// static void setup_munmap_read_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_read_pd_0_final
// static void setup_munmap_read_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_read_pd_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
// static int test_munmap_read_p8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_read_pf_0_1
static void setup_munmap_read_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_munmap_read_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_read_pd_0_proc1
// static void setup_munmap_read_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_read_pd_0_proc1
// static void setup_munmap_read_p8_0_final(void) {
//   
// }
// ^ See setup_munmap_read_pd_0_procfinal
// static void setup_munmap_read_p8_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_read_pd_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_p7_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
// static int test_munmap_read_p7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_read_pf_0_1
// static void setup_munmap_read_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_read_pf_0_common
// static void setup_munmap_read_p7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pf_0_proc1
// static void setup_munmap_read_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pf_0_proc0
// static void setup_munmap_read_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_final
// static void setup_munmap_read_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_p6c_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
// static int test_munmap_read_p6c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_read_pec_0_1
// static void setup_munmap_read_p6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_read_pec_0_common
// static void setup_munmap_read_p6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pf_0_proc1
// static void setup_munmap_read_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pec_0_proc0
// static void setup_munmap_read_p6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_final
// static void setup_munmap_read_p6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_p68_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
// static int test_munmap_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_read_pe8_0_1
// static void setup_munmap_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_read_pec_0_common
// static void setup_munmap_read_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pe8_0_proc1
// static void setup_munmap_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pe8_0_proc0
// static void setup_munmap_read_p68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_final
// static void setup_munmap_read_p68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_p60_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
// static int test_munmap_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_read_pe0_0_1
// static void setup_munmap_read_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_read_pe0_0_common
// static void setup_munmap_read_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pf_0_proc1
// static void setup_munmap_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_read_pec_0_proc0
// static void setup_munmap_read_p60_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_final
// static void setup_munmap_read_p60_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_read_pf_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_p5_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
// static int test_munmap_read_p5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_read_pe8_0_1
// static void setup_munmap_read_p5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_munmap_read_pd_0_common
// static void setup_munmap_read_p5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_read_pd_0_proc1
// static void setup_munmap_read_p5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_read_pd_0_proc0
// static void setup_munmap_read_p5_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_read_pd_0_final
// static void setup_munmap_read_p5_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_read_pd_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_p40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
// static int test_munmap_read_p40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_read_pe0_0_1
// static void setup_munmap_read_p40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_munmap_read_pc0_0_common
// static void setup_munmap_read_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_read_pd_0_proc1
// static void setup_munmap_read_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_read_pc0_0_proc0
// static void setup_munmap_read_p40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_read_pd_0_final
// static void setup_munmap_read_p40_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_read_pd_0_procfinal

/*
 * calls: munmap read
 */
// static int test_munmap_read_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_read_pf_0_0
// static int test_munmap_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_munmap_read_pf_0_1
// static void setup_munmap_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_munmap_read_p8_0_common
// static void setup_munmap_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_read_pd_0_proc1
// static void setup_munmap_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_read_pd_0_proc1
// static void setup_munmap_read_p0_0_final(void) {
//   
// }
// ^ See setup_munmap_read_pd_0_procfinal
// static void setup_munmap_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_read_pd_0_procfinal


/*
 * calls: munmap rename
 */
static int test_munmap_rename_pc_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_munmap_rename_pc_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_munmap_rename_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_munmap_rename_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_rename_pc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_rename_pc_0_final(void) {
  unlink("__i0");
}
static void setup_munmap_rename_pc_0_procfinal(void) {
  
}

/*
 * calls: munmap rename
 */
// static int test_munmap_rename_pa_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_rename_pc_0_0
static int test_munmap_rename_pa_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_munmap_rename_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_munmap_rename_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_rename_pc_0_proc1
// static void setup_munmap_rename_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_rename_pc_0_proc1
// static void setup_munmap_rename_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_rename_pc_0_final
// static void setup_munmap_rename_pa_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_rename_pc_0_procfinal

/*
 * calls: munmap rename
 */
// static int test_munmap_rename_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_rename_pc_0_0
// static int test_munmap_rename_p8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_rename_pa_0_1
// static void setup_munmap_rename_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_munmap_rename_pc_0_common
// static void setup_munmap_rename_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_rename_pc_0_proc1
// static void setup_munmap_rename_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_rename_pc_0_proc1
// static void setup_munmap_rename_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_rename_pc_0_final
// static void setup_munmap_rename_p8_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_rename_pc_0_procfinal

/*
 * calls: munmap rename
 */
// static int test_munmap_rename_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_rename_pc_0_0
static int test_munmap_rename_p0_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_munmap_rename_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_munmap_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_rename_pc_0_proc1
// static void setup_munmap_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_rename_pc_0_proc1
// static void setup_munmap_rename_p0_0_final(void) {
//   
// }
// ^ See setup_munmap_rename_pc_0_procfinal
// static void setup_munmap_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_rename_pc_0_procfinal


/*
 * calls: munmap stat
 */
static int test_munmap_stat_p8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_munmap_stat_p8_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_munmap_stat_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_munmap_stat_p8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_stat_p8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_stat_p8_0_final(void) {
  unlink("__i0");
}
static void setup_munmap_stat_p8_0_procfinal(void) {
  
}

/*
 * calls: munmap stat
 */
// static int test_munmap_stat_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_stat_p8_0_0
static int test_munmap_stat_p0_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_munmap_stat_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_munmap_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_stat_p8_0_proc1
// static void setup_munmap_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_stat_p8_0_proc1
// static void setup_munmap_stat_p0_0_final(void) {
//   
// }
// ^ See setup_munmap_stat_p8_0_procfinal
// static void setup_munmap_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_stat_p8_0_procfinal


/*
 * calls: munmap unlink
 */
static int test_munmap_unlink_p8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_munmap_unlink_p8_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_munmap_unlink_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_munmap_unlink_p8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_unlink_p8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_unlink_p8_0_final(void) {
  unlink("__i0");
}
static void setup_munmap_unlink_p8_0_procfinal(void) {
  
}

/*
 * calls: munmap unlink
 */
// static int test_munmap_unlink_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_unlink_p8_0_0
static int test_munmap_unlink_p0_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_munmap_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_munmap_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_unlink_p8_0_proc1
// static void setup_munmap_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_unlink_p8_0_proc1
// static void setup_munmap_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_munmap_unlink_p8_0_procfinal
// static void setup_munmap_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_unlink_p8_0_procfinal


/*
 * calls: munmap write
 */
static int test_munmap_write_pf8_0_0(void) {
  int* va = (int*) 0x12345600000UL;
  int r = munmap(va, 4096);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_munmap_write_pf8_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_munmap_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_munmap_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_munmap_write_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_munmap_write_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_munmap_write_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: munmap write
 */
// static int test_munmap_write_pf0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
static int test_munmap_write_pf0_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_munmap_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_munmap_write_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_munmap_write_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_munmap_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_write_pf8_0_final
// static void setup_munmap_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_write_pf8_0_procfinal

/*
 * calls: munmap write
 */
// static int test_munmap_write_pe_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
static int test_munmap_write_pe_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_munmap_write_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_munmap_write_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_munmap_write_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_write_pf0_0_proc1
// static void setup_munmap_write_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_write_pf8_0_final
// static void setup_munmap_write_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_write_pf8_0_procfinal

/*
 * calls: munmap write
 */
// static int test_munmap_write_pd0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
// static int test_munmap_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_munmap_write_pf0_0_1
static void setup_munmap_write_pd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_munmap_write_pd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_munmap_write_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_munmap_write_pd0_0_final(void) {
  unlink("__i0");
}
static void setup_munmap_write_pd0_0_procfinal(void) {
  
}

/*
 * calls: munmap write
 */
// static int test_munmap_write_pc0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
// static int test_munmap_write_pc0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_munmap_write_pf0_0_1
static void setup_munmap_write_pc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_munmap_write_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_write_pd0_0_proc0
// static void setup_munmap_write_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_write_pd0_0_proc1
// static void setup_munmap_write_pc0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_write_pd0_0_final
// static void setup_munmap_write_pc0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_write_pd0_0_procfinal

/*
 * calls: munmap write
 */
// static int test_munmap_write_p8_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
// static int test_munmap_write_p8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_munmap_write_pe_0_1
static void setup_munmap_write_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_munmap_write_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_write_pd0_0_proc1
// static void setup_munmap_write_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_write_pd0_0_proc1
// static void setup_munmap_write_p8_0_final(void) {
//   
// }
// ^ See setup_munmap_write_pd0_0_procfinal
// static void setup_munmap_write_p8_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_write_pd0_0_procfinal

/*
 * calls: munmap write
 */
// static int test_munmap_write_p78_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
// static int test_munmap_write_p78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_munmap_write_pf8_0_1
// static void setup_munmap_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_write_pf8_0_common
// static void setup_munmap_write_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_write_pf8_0_proc1
// static void setup_munmap_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_write_pf8_0_proc0
// static void setup_munmap_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_write_pf8_0_final
// static void setup_munmap_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_write_pf8_0_procfinal

/*
 * calls: munmap write
 */
// static int test_munmap_write_p70_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
// static int test_munmap_write_p70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_munmap_write_pf0_0_1
// static void setup_munmap_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_write_pf0_0_common
// static void setup_munmap_write_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_write_pf0_0_proc1
// static void setup_munmap_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_write_pf0_0_proc0
// static void setup_munmap_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_write_pf8_0_final
// static void setup_munmap_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_write_pf8_0_procfinal

/*
 * calls: munmap write
 */
// static int test_munmap_write_p6_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
// static int test_munmap_write_p6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_munmap_write_pe_0_1
// static void setup_munmap_write_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_munmap_write_pe_0_common
// static void setup_munmap_write_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_write_pf0_0_proc1
// static void setup_munmap_write_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_munmap_write_pe_0_proc0
// static void setup_munmap_write_p6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_write_pf8_0_final
// static void setup_munmap_write_p6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_munmap_write_pf8_0_procfinal

/*
 * calls: munmap write
 */
// static int test_munmap_write_p50_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
// static int test_munmap_write_p50_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_munmap_write_pf0_0_1
// static void setup_munmap_write_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_munmap_write_pd0_0_common
// static void setup_munmap_write_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_write_pd0_0_proc1
// static void setup_munmap_write_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_write_pd0_0_proc0
// static void setup_munmap_write_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_write_pd0_0_final
// static void setup_munmap_write_p50_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_write_pd0_0_procfinal

/*
 * calls: munmap write
 */
// static int test_munmap_write_p40_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
// static int test_munmap_write_p40_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_munmap_write_pf0_0_1
// static void setup_munmap_write_p40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_munmap_write_pc0_0_common
// static void setup_munmap_write_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_write_pd0_0_proc1
// static void setup_munmap_write_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_munmap_write_pd0_0_proc0
// static void setup_munmap_write_p40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_munmap_write_pd0_0_final
// static void setup_munmap_write_p40_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_write_pd0_0_procfinal

/*
 * calls: munmap write
 */
// static int test_munmap_write_p0_0_0(void) {
//   int* va = (int*) 0x12345600000UL;
//   int r = munmap(va, 4096);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_munmap_write_pf8_0_0
// static int test_munmap_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_munmap_write_pe_0_1
// static void setup_munmap_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_munmap_write_p8_0_common
// static void setup_munmap_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_write_pd0_0_proc1
// static void setup_munmap_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_munmap_write_pd0_0_proc1
// static void setup_munmap_write_p0_0_final(void) {
//   
// }
// ^ See setup_munmap_write_pd0_0_procfinal
// static void setup_munmap_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_munmap_write_pd0_0_procfinal


/*
 * calls: open open
 */
static int test_open_open_pfc_0_0(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_open_open_pfc_0_1(void) {
  int r = open("__f1", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static void setup_open_open_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_open_open_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_open_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_open_pfc_0_final(void) {
  unlink("__i0");
}
static void setup_open_open_pfc_0_procfinal(void) {
  
}

/*
 * calls: open open
 */
// static int test_open_open_pfc_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pfc_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
static void setup_open_open_pfc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pfc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pfc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pfc_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pfb8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
static int test_open_open_pfb8_0_1(void) {
  int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_open_open_pfb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_0_common
// static void setup_open_open_pfb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pfb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pfb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pfb8_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pfb8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
static int test_open_open_pfb8_1_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_open_open_pfb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pfb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pfb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pfb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pfb8_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pfa8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pfa8_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
static void setup_open_open_pfa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pfa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pfa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pfa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pfa8_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pfa8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pfa8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static void setup_open_open_pfa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_pfa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pfa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pfa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pfa8_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pf98_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
static int test_open_open_pf98_0_1(void) {
  int r = open("__f1", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_open_open_pf98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pf98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pf98_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pf98_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
static int test_open_open_pf98_1_1(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static void setup_open_open_pf98_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pf98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pf98_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pf88_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pf88_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_pf88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_0_common
// static void setup_open_open_pf88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pf88_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pf88_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pf88_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static void setup_open_open_pf88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_1_common
// static void setup_open_open_pf88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pf88_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pf70_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pf70_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_pf70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfb8_1_common
// static void setup_open_open_pf70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pf70_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pf50_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pf50_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_pf50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfb8_1_common
// static void setup_open_open_pf50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pf50_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pf30_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pf30_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_pf30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_pf30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pf30_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pf10_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pf10_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_pf10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfb8_1_common
// static void setup_open_open_pf10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pf10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pf10_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pef0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
static int test_open_open_pef0_0_1(void) {
  int r = open("__f1", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
static void setup_open_open_pef0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pef0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pef0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pef0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pef0_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pef0_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
static int test_open_open_pef0_1_1(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static void setup_open_open_pef0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfb8_1_common
// static void setup_open_open_pef0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pef0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pef0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pef0_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_ped0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_ped0_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_0_1
// static void setup_open_open_ped0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfa8_0_common
// static void setup_open_open_ped0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_ped0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_ped0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_ped0_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_ped0_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_ped0_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static void setup_open_open_ped0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_ped0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_ped0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_ped0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_ped0_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_peb_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
static int test_open_open_peb_0_1(void) {
  int r = open("__f1", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_open_open_peb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_0_common
// static void setup_open_open_peb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_peb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_peb_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_peb_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_peb_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
static int test_open_open_peb_1_1(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static void setup_open_open_peb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_1_common
// static void setup_open_open_peb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_peb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_peb_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_peb_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pe9_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pe9_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_0_1
// static void setup_open_open_pe9_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_0_common
// static void setup_open_open_pe9_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pe9_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pe9_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pe9_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pe9_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static int test_open_open_pe9_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static void setup_open_open_pe9_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_1_common
// static void setup_open_open_pe9_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pe9_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pe9_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pe9_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pe0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
static int test_open_open_pe0_0_1(void) {
  int r = open("__f1", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_open_open_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pdf0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pdf0_0_1(void) {
//   int r = open("__f1", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_1
// static void setup_open_open_pdf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_0_common
// static void setup_open_open_pdf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pdf0_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pdf0_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pdf0_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static void setup_open_open_pdf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_pdf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdf0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pdf0_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pdd6_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pdd6_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_pdd6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_0_common
// static void setup_open_open_pdd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdd6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pdd6_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pdd6_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pdd6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
static void setup_open_open_pdd6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pdd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdd6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pdd6_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pdc6_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pdc6_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_pdc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pef0_0_common
// static void setup_open_open_pdc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdc6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pdc6_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pdc6_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pdc6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static void setup_open_open_pdc6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_pdc6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdc6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdc6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pdc6_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pdac_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pdac_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_pdac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_pdac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pdac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pdac_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pd8c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pd8c_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_pd8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_pd8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pd8c_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pd6c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pd6c_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_0_1
// static void setup_open_open_pd6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfa8_0_common
// static void setup_open_open_pd6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd6c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pd6c_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pd6c_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pd6c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static void setup_open_open_pd6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_pd6c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd6c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pd6c_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pd4c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pd4c_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_0_1
// static void setup_open_open_pd4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pef0_0_common
// static void setup_open_open_pd4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd4c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pd4c_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pd4c_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pd4c_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static void setup_open_open_pd4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_pd4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd4c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd4c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pd4c_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pd2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pd2_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_pe0_0_1
// static void setup_open_open_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pd2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pd2_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pcf_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pcf_0_1(void) {
//   int r = open("__f1", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_1
// static void setup_open_open_pcf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_0_common
// static void setup_open_open_pcf_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcf_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pcf_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pcf_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pcf_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static void setup_open_open_pcf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_1_common
// static void setup_open_open_pcf_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcf_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pcf_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pcd6_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pcd6_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
static void setup_open_open_pcd6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pcd6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcd6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcd6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pcd6_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pcd6_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pcd6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
static void setup_open_open_pcd6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pcd6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcd6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcd6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pcd6_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pcc6_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pcc6_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_pcc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfa8_0_common
// static void setup_open_open_pcc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcc6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pcc6_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pcc6_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pcc6_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static void setup_open_open_pcc6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_pcc6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcc6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcc6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pcc6_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pcac_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pcac_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_pcac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_pcac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pcac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pcac_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pc8c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pc8c_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_pc8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_pc8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc8c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pc8c_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pc6c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pc6c_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_0_1
// static void setup_open_open_pc6c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pcd6_0_common
// static void setup_open_open_pc6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc6c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pc6c_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pc6c_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pc6c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static void setup_open_open_pc6c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pcd6_1_common
// static void setup_open_open_pc6c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc6c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc6c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pc6c_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pc4c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pc4c_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_0_1
// static void setup_open_open_pc4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfa8_0_common
// static void setup_open_open_pc4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc4c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pc4c_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pc4c_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pc4c_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static void setup_open_open_pc4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_pc4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc4c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc4c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pc4c_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pc2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_pc2_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_pe0_0_1
// static void setup_open_open_pc2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_1_common
// static void setup_open_open_pc2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pc2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pc2_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pbf0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pbf0_0_1(void) {
//   int r = open("__f1", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_1
static void setup_open_open_pbf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pbf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pbf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pbf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pbf0_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pbae_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pbae_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
static void setup_open_open_pbae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pbae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pbae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pbae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pbae_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pba30_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pba30_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
static void setup_open_open_pba30_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_open_open_pba30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pba30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pba30_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_pba30_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pb8e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pb8e_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
static void setup_open_open_pb8e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_pb8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pb8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pb8e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pb8e_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pb830_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pb830_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static void setup_open_open_pb830_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_pb830_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pb830_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pb830_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_pb830_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pb58_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pb58_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_pb58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_pb58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pb58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pb58_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_pb58_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pb18_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pb18_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_pb18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_pb18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pb18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pb18_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_pb18_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_padc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_padc_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_0_1
// static void setup_open_open_padc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pbae_0_common
// static void setup_open_open_padc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_padc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_padc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_padc_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pa9c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pa9c_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_0_1
// static void setup_open_open_pa9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pb8e_0_common
// static void setup_open_open_pa9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pa9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pa9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_pa9c_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_pa4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static int test_open_open_pa4_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_pe0_0_1
// static void setup_open_open_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_pa4_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p9f0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_p9f0_0_1(void) {
//   int r = open("__f1", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_1
// static void setup_open_open_p9f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pbf0_0_common
// static void setup_open_open_p9f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p9f0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p9f0_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p9ae_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_p9ae_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_p9ae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pbae_0_common
// static void setup_open_open_p9ae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p9ae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p9ae_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p9ae_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p9a30_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_p9a30_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static void setup_open_open_p9a30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p9a30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p9a30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p9a30_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p9a30_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p98e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_p98e_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_p98e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pb8e_0_common
// static void setup_open_open_p98e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p98e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p98e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p98e_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p9830_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_p9830_0_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static void setup_open_open_p9830_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p9830_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p9830_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p9830_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p9830_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p958_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_p958_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_p958_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p958_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p958_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p958_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p958_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p918_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_p918_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_p918_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p918_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p918_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p918_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p918_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p8dc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_p8dc_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_0_1
// static void setup_open_open_p8dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pbf0_0_common
// static void setup_open_open_p8dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p8dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p8dc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p8dc_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p89c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_p89c_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_0_1
// static void setup_open_open_p89c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pb8e_0_common
// static void setup_open_open_p89c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p89c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p89c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p89c_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p84_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static int test_open_open_p84_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_pe0_0_1
// static void setup_open_open_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p84_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p84_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p7e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p7e_0_1(void) {
//   int r = open("__f1", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_1
// static void setup_open_open_p7e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pef0_0_common
// static void setup_open_open_p7e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p7e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p7e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p7e_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p7e_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p7e_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static void setup_open_open_p7e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_p7e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p7e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p7e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p7e_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p7ac_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p7ac_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_p7ac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfa8_0_common
// static void setup_open_open_p7ac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p7ac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p7ac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p7ac_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p7ac_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p7ac_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
// static void setup_open_open_p7ac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_p7ac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p7ac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p7ac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p7ac_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p78c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p78c_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_p78c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pef0_0_common
// static void setup_open_open_p78c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p78c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p78c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p78c_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p78c_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p78c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static void setup_open_open_p78c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_p78c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p78c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p78c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p78c_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p758_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p758_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_p758_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfc_1_common
// static void setup_open_open_p758_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p758_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p758_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p758_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p718_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p718_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_p718_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_p718_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p718_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p718_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p718_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p6d8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p6d8_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_0_1
// static void setup_open_open_p6d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pcd6_0_common
// static void setup_open_open_p6d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p6d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p6d8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p6d8_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p6d8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p6d8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static void setup_open_open_p6d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_p6d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p6d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p6d8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p6d8_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p698_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p698_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_0_1
// static void setup_open_open_p698_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pef0_0_common
// static void setup_open_open_p698_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p698_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p698_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p698_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p698_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p698_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static void setup_open_open_p698_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfb8_1_common
// static void setup_open_open_p698_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p698_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p698_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p698_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p64_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static int test_open_open_p64_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_pe0_0_1
// static void setup_open_open_p64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfb8_1_common
// static void setup_open_open_p64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p64_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p64_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p5e_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p5e_0_1(void) {
//   int r = open("__f1", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_1
// static void setup_open_open_p5e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_0_common
// static void setup_open_open_p5e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p5e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p5e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p5e_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p5e_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p5e_1_1(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_0
// static void setup_open_open_p5e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_1_common
// static void setup_open_open_p5e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p5e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p5e_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p5e_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p5ac_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p5ac_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
static void setup_open_open_p5ac_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_p5ac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p5ac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p5ac_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p5ac_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p5ac_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p5ac_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_1_1
static void setup_open_open_p5ac_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_p5ac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p5ac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p5ac_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p5ac_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p58c_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p58c_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_p58c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfa8_0_common
// static void setup_open_open_p58c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p58c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p58c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p58c_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p58c_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p58c_1_1(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_1_1
// static void setup_open_open_p58c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_p58c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p58c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p58c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p58c_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p558_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p558_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_p558_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_p558_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p558_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p558_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p558_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p518_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p518_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_p518_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_p518_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p518_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p518_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p518_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p4d8_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p4d8_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_0_1
// static void setup_open_open_p4d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pcd6_0_common
// static void setup_open_open_p4d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p4d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p4d8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p4d8_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p4d8_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p4d8_1_1(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_1_1
// static void setup_open_open_p4d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pcd6_1_common
// static void setup_open_open_p4d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p4d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p4d8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p4d8_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p498_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p498_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_0_1
// static void setup_open_open_p498_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pfa8_0_common
// static void setup_open_open_p498_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p498_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p498_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p498_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p498_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p498_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static void setup_open_open_p498_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pdd6_1_common
// static void setup_open_open_p498_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p498_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p498_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p498_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p44_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_1_1
// static int test_open_open_p44_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_pe0_0_1
// static void setup_open_open_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pf98_1_common
// static void setup_open_open_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p44_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p44_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
static int test_open_open_p38_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_open_open_p38_0_1(void) {
//   int r = open("__f1", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_open_pfc_0_1
// static void setup_open_open_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pbae_0_common
// static void setup_open_open_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p38_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p38_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p370_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p370_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_p370_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pbae_0_common
// static void setup_open_open_p370_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p370_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p370_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p370_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p350_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p350_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_p350_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pbf0_0_common
// static void setup_open_open_p350_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p350_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p350_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p350_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p33_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p33_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
static void setup_open_open_p33_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_open_p33_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p33_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p33_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p33_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p31_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p31_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_p31_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_p33_0_common
// static void setup_open_open_p31_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p31_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p31_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p31_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p2d0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p2d0_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_p2d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p2d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p2d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p2d0_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p2d0_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p290_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p290_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pfb8_0_1
// static void setup_open_open_p290_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p290_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p290_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p290_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p290_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p250_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p250_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_p250_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p250_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p250_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p250_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p250_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p210_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p210_0_1(void) {
//   int r = open("__f1", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pf98_0_1
// static void setup_open_open_p210_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p210_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p210_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p210_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p210_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p1e_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p1e_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_0_1
// static void setup_open_open_p1e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pbf0_0_common
// static void setup_open_open_p1e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p1e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p1e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p1e_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p1a_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p1a_0_1(void) {
//   int r = open("__f1", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_pef0_0_1
// static void setup_open_open_p1a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_pbf0_0_common
// static void setup_open_open_p1a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p1a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p1a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p1a_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p16_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p16_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_0_1
// static void setup_open_open_p16_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_p33_0_common
// static void setup_open_open_p16_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p16_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p16_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p16_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p12_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p12_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_open_peb_0_1
// static void setup_open_open_p12_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_open_p33_0_common
// static void setup_open_open_p12_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p12_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p12_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_open_pfc_0_final
// static void setup_open_open_p12_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p0_0_1(void) {
//   int r = open("__f1", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_pe0_0_1
// static void setup_open_open_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p0_0_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p0_0_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal

/*
 * calls: open open
 */
// static int test_open_open_p0_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static int test_open_open_p0_1_1(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_open_p38_0_0
// static void setup_open_open_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_open_pba30_0_common
// static void setup_open_open_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_open_pfc_0_proc1
// static void setup_open_open_p0_1_final(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal
// static void setup_open_open_p0_1_procfinal(void) {
//   
// }
// ^ See setup_open_open_pfc_0_procfinal


/*
 * calls: open pipe
 */
static int test_open_pipe_pfc_0_0(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_open_pipe_pfc_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_open_pipe_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pipe_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_pipe_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_pipe_pfc_0_final(void) {
  unlink("__i0");
}
static void setup_open_pipe_pfc_0_procfinal(void) {
  
}

/*
 * calls: open pipe
 */
// static int test_open_pipe_pec_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pipe_pfc_0_0
// static int test_open_pipe_pec_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_pipe_pfc_0_1
// static void setup_open_pipe_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pipe_pfc_0_common
// static void setup_open_pipe_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_pec_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pipe_pfc_0_final
// static void setup_open_pipe_pec_0_procfinal(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal

/*
 * calls: open pipe
 */
static int test_open_pipe_pd70_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_pipe_pd70_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_pipe_pfc_0_1
static void setup_open_pipe_pd70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pipe_pd70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_pd70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_pd70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pipe_pfc_0_final
// static void setup_open_pipe_pd70_0_procfinal(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal

/*
 * calls: open pipe
 */
static int test_open_pipe_pc70_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
// static int test_open_pipe_pc70_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_pipe_pfc_0_1
static void setup_open_pipe_pc70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pipe_pc70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_pc70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_pc70_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pipe_pfc_0_final
// static void setup_open_pipe_pc70_0_procfinal(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal

/*
 * calls: open pipe
 */
// static int test_open_pipe_pae_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pipe_pd70_0_0
// static int test_open_pipe_pae_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_pipe_pfc_0_1
static void setup_open_pipe_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_open_pipe_pae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_pae_0_final(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal
// static void setup_open_pipe_pae_0_procfinal(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal

/*
 * calls: open pipe
 */
// static int test_open_pipe_p8e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pipe_pc70_0_0
// static int test_open_pipe_p8e_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_pipe_pfc_0_1
// static void setup_open_pipe_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pipe_pae_0_common
// static void setup_open_pipe_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_p8e_0_final(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal
// static void setup_open_pipe_p8e_0_procfinal(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal

/*
 * calls: open pipe
 */
static int test_open_pipe_p6e_0_0(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_pipe_p6e_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_pipe_pfc_0_1
// static void setup_open_pipe_p6e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pipe_pfc_0_common
// static void setup_open_pipe_p6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_p6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_p6e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pipe_pfc_0_final
// static void setup_open_pipe_p6e_0_procfinal(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal

/*
 * calls: open pipe
 */
static int test_open_pipe_p4e_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static int test_open_pipe_p4e_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_pipe_pfc_0_1
// static void setup_open_pipe_p4e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pipe_pc70_0_common
// static void setup_open_pipe_p4e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_p4e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_p4e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pipe_pfc_0_final
// static void setup_open_pipe_p4e_0_procfinal(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal

/*
 * calls: open pipe
 */
static int test_open_pipe_p38_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_open_pipe_p38_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_pipe_pfc_0_1
// static void setup_open_pipe_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pipe_pae_0_common
// static void setup_open_pipe_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_p38_0_final(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal
// static void setup_open_pipe_p38_0_procfinal(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal

/*
 * calls: open pipe
 */
// static int test_open_pipe_p18_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pipe_p38_0_0
// static int test_open_pipe_p18_0_1(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_pipe_pfc_0_1
// static void setup_open_pipe_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pipe_pae_0_common
// static void setup_open_pipe_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pipe_pfc_0_proc1
// static void setup_open_pipe_p18_0_final(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal
// static void setup_open_pipe_p18_0_procfinal(void) {
//   
// }
// ^ See setup_open_pipe_pfc_0_procfinal


/*
 * calls: open pread
 */
static int test_open_pread_pfc_0_0(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_open_pread_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pread_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_open_pread_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_open_pread_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_open_pread_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: open pread
 */
// static int test_open_pread_pfc_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
// static int test_open_pread_pfc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfc_0_common
static void setup_open_pread_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_open_pread_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pfa_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
static int test_open_pread_pfa_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pread_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_open_pread_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_pread_pfa_0_final(void) {
  unlink("__i0");
}
static void setup_open_pread_pfa_0_procfinal(void) {
  
}

/*
 * calls: open pread
 */
// static int test_open_pread_pfa_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
// static int test_open_pread_pfa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_pfa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
static void setup_open_pread_pfa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pfa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pfa_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pf8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
static int test_open_pread_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pf8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
// static int test_open_pread_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pf8_0_common
// static void setup_open_pread_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_1_proc0
// static void setup_open_pread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pf0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
static int test_open_pread_pf0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_open_pread_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pec_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
// static int test_open_pread_pec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfc_0_common
// static void setup_open_pread_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pec_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
// static int test_open_pread_pec_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfc_0_common
// static void setup_open_pread_pec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_pec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pea_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
// static int test_open_pread_pea_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pea_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pea_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
// static int test_open_pread_pea_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_pea_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_pea_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pea_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_1_proc0
// static void setup_open_pread_pea_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pea_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pe8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
// static int test_open_pread_pe8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pf8_0_common
// static void setup_open_pread_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pe8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
// static int test_open_pread_pe8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pf8_0_common
// static void setup_open_pread_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_1_proc0
// static void setup_open_pread_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pe0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pread_pfc_0_0
// static int test_open_pread_pe0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
static int test_open_pread_pdf0_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_pread_pdf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_pdf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_pdf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_pdf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pdf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pdf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pdf0_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pdf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_pdf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_pdf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_pdf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pdf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pdf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pdde_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
static int test_open_pread_pdde_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_open_pread_pdde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pf8_0_common
static void setup_open_pread_pdde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pdde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pdde_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pdde_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pdde_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
static int test_open_pread_pdde_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 28672);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pdde_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pread_pdde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pdde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pdde_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pdde_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pdc8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
static int test_open_pread_pdc8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 8192);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pdc8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pread_pdc8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2191360, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pdc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
static void setup_open_pread_pdc8_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_open_pread_pdc8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pdc8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
static int test_open_pread_pdc8_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 20480);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pdc8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pread_pdc8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pdc8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pdc8_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_pdc8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pda_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pda_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pda_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pda_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pd70_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pd70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_pd70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_pd70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pd70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_pd70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pd70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pd70_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pd70_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_pd70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd70_0_common
// static void setup_open_pread_pd70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pd70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_pd70_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pd70_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pd5c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pd5c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdde_0_1
static void setup_open_pread_pd5c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_pd5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
static void setup_open_pread_pd5c_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pd5c_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_pd5c_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pd5c_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pd5c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_pd5c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_pd5c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
static void setup_open_pread_pd5c_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pd5c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pd5c_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pd5c_2_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
static int test_open_pread_pd5c_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_open_pread_pd5c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pdc8_1_common
// static void setup_open_pread_pd5c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
static void setup_open_pread_pd5c_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pd5c_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_pd5c_2_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pd5c_3_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
static int test_open_pread_pd5c_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 1159168);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pd5c_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_pd5c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
static void setup_open_pread_pd5c_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1159168, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pd5c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pd5c_3_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pd48_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pd48_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_pd48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd5c_0_common
// static void setup_open_pread_pd48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
static void setup_open_pread_pd48_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pd48_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_pd48_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pd48_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pd48_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdc8_1_1
// static void setup_open_pread_pd48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pdc8_1_common
// static void setup_open_pread_pd48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pd48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pdc8_1_proc0
// static void setup_open_pread_pd48_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_pd48_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pd2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pd2_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd5c_3_common
// static void setup_open_pread_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pd2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pd2_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
static int test_open_pread_pcf_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
// static int test_open_pread_pcf_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_pcf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_pcf_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_pcf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pcf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pcf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pcf_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_pcf_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_pcf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pcf_0_common
// static void setup_open_pread_pcf_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_pcf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pcf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pcf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pcdc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_pcdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_pcdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_pcdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_pcdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pcdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pcdc_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pcdc_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
static int test_open_pread_pcdc_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 9363456);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pcdc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pread_pcdc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9363456, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pcdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pcdc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pcdc_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pccc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_pccc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdc8_1_1
static void setup_open_pread_pccc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_pccc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pdc8_1_proc0
// static void setup_open_pread_pccc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pccc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pccc_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pca_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_pca_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_pca_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd5c_3_common
// static void setup_open_pread_pca_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pca_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pca_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pca_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pc7_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_pc7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_pc7_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_pc7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pc7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_pc7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pc7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pc7_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_pc7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_pc7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pc7_0_common
// static void setup_open_pread_pc7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pc7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_pc7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pc7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pc58_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_pc58_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_pc58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_pc58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pc58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_pc58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pc58_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pc58_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
static int test_open_pread_pc58_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 5087232);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_open_pread_pc58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pccc_0_common
// static void setup_open_pread_pc58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
static void setup_open_pread_pc58_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pc58_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pc58_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pc48_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_pc48_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_pc48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pf8_0_common
// static void setup_open_pread_pc48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
static void setup_open_pread_pc48_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pc48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pc48_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pc48_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
static int test_open_pread_pc48_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_open_pread_pc48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pdde_1_common
// static void setup_open_pread_pc48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pc48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pd5c_2_proc1
// static void setup_open_pread_pc48_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pc48_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pc2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_pc2_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_pc2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd5c_3_common
// static void setup_open_pread_pc2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pc2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pc2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pc2_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pbe_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pbe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_pread_pbe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pbe_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pbe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pread_pbe_0_common
// static void setup_open_pread_pbe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pbb8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pbb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdde_0_1
static void setup_open_pread_pbb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_open_pread_pbb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 33169408, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pbb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pbb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pbb8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pbb8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
static int test_open_pread_pbb8_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 2523136);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pbb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_open_pread_pbb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2523136, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pbb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pbb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pbb8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pb90_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
static int test_open_pread_pb90_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 16384);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pb90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_open_pread_pb90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12275712, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pb90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pb90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pb90_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pb90_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
static int test_open_pread_pb90_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 28672);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_pb90_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_pread_pb90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pdde_1_proc0
// static void setup_open_pread_pb90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pb90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pb90_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pb4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pb4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
static void setup_open_pread_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_open_pread_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pb4_0_final(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal
// static void setup_open_pread_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pae_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pae_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_pread_pae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pae_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pae_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pread_pae_0_common
// static void setup_open_pread_pae_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pab0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pab0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
static void setup_open_pread_pab0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_open_pread_pab0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pab0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pdc8_1_proc0
// static void setup_open_pread_pab0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pab0_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pab0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 2523136);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pbb8_1_1
static void setup_open_pread_pab0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_pread_pab0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pab0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 2523136, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_1_proc0
// static void setup_open_pread_pab0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pab0_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pa90_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pa90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_pa90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_0_common
// static void setup_open_pread_pa90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pa90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_0_proc0
// static void setup_open_pread_pa90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pa90_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pa90_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pa90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 16384);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pb90_0_1
// static void setup_open_pread_pa90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pb90_0_common
// static void setup_open_pread_pa90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
static void setup_open_pread_pa90_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_pa90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_pa90_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_pa4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pdf0_0_0
// static int test_open_pread_pa4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pread_pb4_0_common
// static void setup_open_pread_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_pa4_0_final(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal
// static void setup_open_pread_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p9e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p9e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_p9e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_pread_p9e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p9e_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p9e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pread_p9e_0_common
// static void setup_open_pread_p9e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p9e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p9e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p9b8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p9b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdde_0_1
// static void setup_open_pread_p9b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_0_common
static void setup_open_pread_p9b8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1150976, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_p9b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p9b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p9b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p9b8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p9b8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 2523136);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pbb8_1_1
// static void setup_open_pread_p9b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_1_common
// static void setup_open_pread_p9b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 2523136, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_1_proc0
// static void setup_open_pread_p9b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p9b8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p9b8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p990_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p990_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 16384);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pb90_0_1
// static void setup_open_pread_p990_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pb90_0_common
static void setup_open_pread_p990_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 19165184, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_p990_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p990_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p990_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p990_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
static int test_open_pread_p990_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_open_pread_p990_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_open_pread_p990_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pread_p990_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p990_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p990_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p94_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p94_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pread_pb4_0_common
// static void setup_open_pread_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p94_0_final(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal
// static void setup_open_pread_p94_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p8e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p8e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_p8e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_pread_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_p8e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p8e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p8e_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p8e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_p8e_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_pread_p8e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p8e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_p8e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p8e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p8b0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p8b0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_p8b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_pread_pab0_0_common
// static void setup_open_pread_p8b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pdc8_1_proc0
// static void setup_open_pread_p8b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p8b0_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p8b0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 2523136);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pbb8_1_1
// static void setup_open_pread_p8b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pab0_1_common
// static void setup_open_pread_p8b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p8b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 2523136, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_1_proc0
// static void setup_open_pread_p8b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p8b0_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p890_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p890_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_0_common
// static void setup_open_pread_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 33169408, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_0_proc0
// static void setup_open_pread_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p890_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p890_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p890_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 16384);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pb90_0_1
// static void setup_open_pread_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pb90_0_common
// static void setup_open_pread_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p890_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 16384, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pa90_1_proc1
// static void setup_open_pread_p890_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p890_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p84_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_pcf_0_0
// static int test_open_pread_p84_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pread_pb4_0_common
// static void setup_open_pread_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p84_0_final(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal
// static void setup_open_pread_p84_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
static int test_open_pread_p7e_0_0(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_pread_p7e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p7e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pdf0_1_common
// static void setup_open_pread_p7e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_p7e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p7e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p7e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p7e_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p7e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p7e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pdf0_1_common
// static void setup_open_pread_p7e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_p7e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p7e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p7e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p7bc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p7bc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdde_0_1
// static void setup_open_pread_p7bc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pf8_0_common
// static void setup_open_pread_p7bc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pdde_0_proc0
// static void setup_open_pread_p7bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p7bc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p7bc_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p7bc_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
static int test_open_pread_p7bc_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 8192);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_open_pread_p7bc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd5c_3_common
// static void setup_open_pread_p7bc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_p7bc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p7bc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p7bc_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p790_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p790_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdc8_0_1
// static void setup_open_pread_p790_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pdc8_0_common
// static void setup_open_pread_p790_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 2191360, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pdc8_0_proc0
// static void setup_open_pread_p790_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p790_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_p790_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p790_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p790_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdc8_1_1
// static void setup_open_pread_p790_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pdc8_1_common
// static void setup_open_pread_p790_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pdc8_1_proc0
// static void setup_open_pread_p790_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p790_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_p790_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p74_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
static void setup_open_pread_p74_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_p74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p74_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p74_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p6e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p6e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_p6e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pread_p6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_p6e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p6e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p6e_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p6e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p6e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_p6e_0_common
// static void setup_open_pread_p6e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p6e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_p6e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p6e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p6b8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p6b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdde_0_1
// static void setup_open_pread_p6b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd5c_0_common
// static void setup_open_pread_p6b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p6b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pd5c_0_proc1
// static void setup_open_pread_p6b8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_p6b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p6b8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p6b8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_p6b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_p6b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p6b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pd5c_1_proc1
// static void setup_open_pread_p6b8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p6b8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p6b8_2_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p6b8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pd5c_2_1
// static void setup_open_pread_p6b8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pdc8_1_common
// static void setup_open_pread_p6b8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p6b8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pd5c_2_proc1
// static void setup_open_pread_p6b8_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_p6b8_2_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p6b8_3_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p6b8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 1159168);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pd5c_3_1
// static void setup_open_pread_p6b8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd5c_3_common
// static void setup_open_pread_p6b8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p6b8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1159168, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pd5c_3_proc1
// static void setup_open_pread_p6b8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p6b8_3_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p690_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p690_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_p690_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd5c_0_common
// static void setup_open_pread_p690_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p690_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pd48_0_proc1
// static void setup_open_pread_p690_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_p690_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p690_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p690_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdc8_1_1
// static void setup_open_pread_p690_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pdc8_1_common
// static void setup_open_pread_p690_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p690_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pdc8_1_proc0
// static void setup_open_pread_p690_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pread_pdc8_0_final
// static void setup_open_pread_p690_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p64_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p7e_0_0
// static int test_open_pread_p64_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_p64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_p74_0_common
// static void setup_open_pread_p64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p64_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p64_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
static int test_open_pread_p5e_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static int test_open_pread_p5e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p5e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pcf_0_common
// static void setup_open_pread_p5e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_p5e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p5e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p5e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p5e_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p5e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p5e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pcf_0_common
// static void setup_open_pread_p5e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_p5e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p5e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p5e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p5b8_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p5b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_p5b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_p5b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_p5b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p5b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p5b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p5b8_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p5b8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 9363456);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pcdc_1_1
// static void setup_open_pread_p5b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pcdc_1_common
// static void setup_open_pread_p5b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9363456, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pcdc_1_proc0
// static void setup_open_pread_p5b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p5b8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p5b8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p598_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p598_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pdc8_1_1
// static void setup_open_pread_p598_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pccc_0_common
// static void setup_open_pread_p598_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pdc8_1_proc0
// static void setup_open_pread_p598_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p598_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p598_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p54_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p54_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd5c_3_common
// static void setup_open_pread_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p54_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p54_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p4e_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p4e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p4e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pc7_0_common
// static void setup_open_pread_p4e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p4e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_p4e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p4e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p4e_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p4e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p4e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pc7_0_common
// static void setup_open_pread_p4e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p4e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_p4e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p4e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p4b_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p4b_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_p4b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pfa_0_common
// static void setup_open_pread_p4b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p4b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_p4b_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p4b_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p4b_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p4b_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5087232);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pc58_1_1
// static void setup_open_pread_p4b_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pccc_0_common
// static void setup_open_pread_p4b_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p4b_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5087232, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pc58_1_proc1
// static void setup_open_pread_p4b_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p4b_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p490_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p490_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_p490_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pf8_0_common
// static void setup_open_pread_p490_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p490_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pc48_0_proc1
// static void setup_open_pread_p490_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p490_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p490_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p490_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pc48_1_1
// static void setup_open_pread_p490_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pdde_1_common
// static void setup_open_pread_p490_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p490_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pd5c_2_proc1
// static void setup_open_pread_p490_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p490_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p44_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pread_p5e_0_0
// static int test_open_pread_p44_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pread_pd5c_3_common
// static void setup_open_pread_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p44_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p44_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
static int test_open_pread_p38_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_open_pread_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
static void setup_open_pread_p38_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_pread_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p38_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p38_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pread_p38_0_common
// static void setup_open_pread_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p34_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_pread_pab0_0_common
// static void setup_open_pread_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p34_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p34_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p34_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_p34_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_pread_pab0_0_common
// static void setup_open_pread_p34_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_1_proc0
// static void setup_open_pread_p34_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p34_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p34_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p30_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_0_common
// static void setup_open_pread_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p30_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p30_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p30_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_0_common
// static void setup_open_pread_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_1_proc0
// static void setup_open_pread_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p30_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p30_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p2_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p2_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pread_pb4_0_common
// static void setup_open_pread_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p2_0_final(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal
// static void setup_open_pread_p2_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p18_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p18_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pread_p38_0_common
// static void setup_open_pread_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc0
// static void setup_open_pread_p18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p18_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p18_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfc_0_1
// static void setup_open_pread_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pread_p38_0_common
// static void setup_open_pread_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_0_proc1
// static void setup_open_pread_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pread_pfc_1_proc0
// static void setup_open_pread_p18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_final
// static void setup_open_pread_p18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pread_pfc_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p14_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p14_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_p14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_pread_pab0_0_common
// static void setup_open_pread_p14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_p14_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p14_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p14_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p14_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pfa_0_1
// static void setup_open_pread_p14_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_pread_pab0_0_common
// static void setup_open_pread_p14_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p14_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_1_proc0
// static void setup_open_pread_p14_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p14_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p10_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p10_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_0_common
// static void setup_open_pread_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_0_proc0
// static void setup_open_pread_p10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p10_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p10_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p10_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf8_0_1
// static void setup_open_pread_p10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pread_pbb8_0_common
// static void setup_open_pread_p10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pread_pfa_1_proc0
// static void setup_open_pread_p10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pread_pfa_0_final
// static void setup_open_pread_p10_1_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal

/*
 * calls: open pread
 */
// static int test_open_pread_p0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pread_p38_0_0
// static int test_open_pread_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_pread_pf0_0_1
// static void setup_open_pread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pread_pb4_0_common
// static void setup_open_pread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pread_pfa_0_proc1
// static void setup_open_pread_p0_0_final(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal
// static void setup_open_pread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pread_pfa_0_procfinal


/*
 * calls: open pwrite
 */
static int test_open_pwrite_pfc_0_0(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_open_pwrite_pfc_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_open_pwrite_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pwrite_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_open_pwrite_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_open_pwrite_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_open_pwrite_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pfc_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pfc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pfc_0_common
static void setup_open_pwrite_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_open_pwrite_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pfa_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
static int test_open_pwrite_pfa_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_open_pwrite_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pwrite_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_open_pwrite_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_pwrite_pfa_0_final(void) {
  unlink("__i0");
}
static void setup_open_pwrite_pfa_0_procfinal(void) {
  
}

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pfa_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pfa_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_pfa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pfa_0_common
static void setup_open_pwrite_pfa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pfa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pfa_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pf8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pf8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
static void setup_open_pwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pf8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pf8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pf8_0_common
// static void setup_open_pwrite_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pfa_1_proc0
// static void setup_open_pwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pf0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
static int test_open_pwrite_pf0_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_open_pwrite_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pfa_0_common
// static void setup_open_pwrite_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pec_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pec_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pfc_0_common
// static void setup_open_pwrite_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pec_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pec_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pfc_0_common
// static void setup_open_pwrite_pec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_pec_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pec_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pea_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pea_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pfa_0_common
// static void setup_open_pwrite_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
static void setup_open_pwrite_pea_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pea_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pea_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pea_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_pea_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pfa_0_common
// static void setup_open_pwrite_pea_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pea_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pfa_1_proc0
// static void setup_open_pwrite_pea_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pea_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pe8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pe8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pf8_0_common
// static void setup_open_pwrite_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
static void setup_open_pwrite_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pe8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pe8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pf8_0_common
// static void setup_open_pwrite_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pfa_1_proc0
// static void setup_open_pwrite_pe8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pe8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pe0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_0
// static int test_open_pwrite_pe0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pfa_0_common
// static void setup_open_pwrite_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
static int test_open_pwrite_pdf0_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_pwrite_pdf0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
static void setup_open_pwrite_pdf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pdf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_pdf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pdf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pdf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pdf0_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pdf0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
static void setup_open_pwrite_pdf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pdf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_pdf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pdf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pdf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pdde_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
static int test_open_pwrite_pdde_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_open_pwrite_pdde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pwrite_pdde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pdde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
static void setup_open_pwrite_pdde_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_open_pwrite_pdde_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pdde_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pdde_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_pdde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pdde_0_common
static void setup_open_pwrite_pdde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pdde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pdde_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_pdde_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pdc8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
static int test_open_pwrite_pdc8_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_open_pwrite_pdc8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pwrite_pdc8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 90112, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pdc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pdc8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_pdc8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pda_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pda_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
static void setup_open_pwrite_pda_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pda_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pda_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pd70_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pd70_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
static void setup_open_pwrite_pd70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pd70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pd70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_pd70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pd70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pd70_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pd70_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
static void setup_open_pwrite_pd70_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pd70_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pd70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_pd70_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pd70_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pd5c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pd5c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
static void setup_open_pwrite_pd5c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pd5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
static void setup_open_pwrite_pd5c_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 25735168, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pd5c_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_pd5c_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pd5c_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pd5c_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_pd5c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pd5c_0_common
// static void setup_open_pwrite_pd5c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pd5c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pdde_1_proc0
// static void setup_open_pwrite_pd5c_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_pd5c_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pd48_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pd48_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_pd48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pd5c_0_common
// static void setup_open_pwrite_pd48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
static void setup_open_pwrite_pd48_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2191360, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pd48_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_pd48_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pd48_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
static int test_open_pwrite_pd48_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 16384);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_open_pwrite_pd48_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pd48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
static void setup_open_pwrite_pd48_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pd48_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_pd48_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pd2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pd2_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pfa_0_common
// static void setup_open_pwrite_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pd2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pd2_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
static int test_open_pwrite_pcf_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
// static int test_open_pwrite_pcf_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
static void setup_open_pwrite_pcf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pcf_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_pcf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pcf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pcf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pcf_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_pcf_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_pcf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pcf_0_common
// static void setup_open_pwrite_pcf_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_pcf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pcf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pcf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pcdc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_pcdc_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
static void setup_open_pwrite_pcdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pwrite_pcdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12279808, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pcdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pcdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pcdc_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pcdc_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_pcdc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_pcdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pcdc_0_common
// static void setup_open_pwrite_pcdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pdde_1_proc0
// static void setup_open_pwrite_pcdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pcdc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pcdc_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pccc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
static int test_open_pwrite_pccc_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_open_pwrite_pccc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_pwrite_pccc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pccc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pccc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pccc_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pca_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_pca_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
static void setup_open_pwrite_pca_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pca_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pca_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pca_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pca_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pc7_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_pc7_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
static void setup_open_pwrite_pc7_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pc7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pc7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_pc7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pc7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pc7_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_pc7_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_pc7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pc7_0_common
// static void setup_open_pwrite_pc7_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pc7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_pc7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pc7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pc58_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
static int test_open_pwrite_pc58_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_open_pwrite_pc58_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_pc58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pc58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pccc_0_proc0
// static void setup_open_pwrite_pc58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pc58_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pc58_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
static int test_open_pwrite_pc58_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_open_pwrite_pc58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pda_0_common
// static void setup_open_pwrite_pc58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
static void setup_open_pwrite_pc58_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pc58_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pc58_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pc48_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_pc48_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_pc48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pf8_0_common
// static void setup_open_pwrite_pc48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pc48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pea_0_proc1
// static void setup_open_pwrite_pc48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pc48_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pc48_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_pc48_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pccc_0_1
// static void setup_open_pwrite_pc48_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pc58_0_common
// static void setup_open_pwrite_pc48_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pc48_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pccc_0_proc0
// static void setup_open_pwrite_pc48_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pc48_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pc2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_pc2_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_pc2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pca_0_common
// static void setup_open_pwrite_pc2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pc2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pc2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pc2_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pbe_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pbe_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
static void setup_open_pwrite_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_pwrite_pbe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pbe_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pbe_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pwrite_pbe_0_common
// static void setup_open_pwrite_pbe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pbb8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pbb8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
static void setup_open_pwrite_pbb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_pwrite_pbb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 12279808, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pcdc_0_proc0
// static void setup_open_pwrite_pbb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pbb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pbb8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pbb8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pbb8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdc8_0_1
static void setup_open_pwrite_pbb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_open_pwrite_pbb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pbb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pbb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pbb8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pb90_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pb90_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_pb90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pbb8_1_common
static void setup_open_pwrite_pb90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 98304, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pb90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pb90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pb90_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pb90_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pb90_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_pb90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pbb8_1_common
// static void setup_open_pwrite_pb90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pdde_1_proc0
// static void setup_open_pwrite_pb90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pb90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pb90_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pb4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pb4_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
static void setup_open_pwrite_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_open_pwrite_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pb4_0_final(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal
// static void setup_open_pwrite_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pae_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pae_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
static void setup_open_pwrite_pae_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_pwrite_pae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pae_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pae_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pwrite_pae_0_common
// static void setup_open_pwrite_pae_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pab0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pab0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
static void setup_open_pwrite_pab0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_open_pwrite_pab0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pab0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pdde_0_proc0
// static void setup_open_pwrite_pab0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pab0_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pab0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_pab0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_pwrite_pab0_0_common
// static void setup_open_pwrite_pab0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pab0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pfa_1_proc0
// static void setup_open_pwrite_pab0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pab0_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pa90_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pa90_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
static void setup_open_pwrite_pa90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_pwrite_pa90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
static void setup_open_pwrite_pa90_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1150976, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_pa90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pa90_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pa90_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pa90_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pd48_1_1
static void setup_open_pwrite_pa90_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_pwrite_pa90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pa90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 16384, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pd48_1_proc1
// static void setup_open_pwrite_pa90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_pa90_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_pa4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdf0_0_0
// static int test_open_pwrite_pa4_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pwrite_pb4_0_common
// static void setup_open_pwrite_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_pa4_0_final(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal
// static void setup_open_pwrite_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p9e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p9e_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pwrite_pbe_0_common
// static void setup_open_pwrite_p9e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p9e_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p9e_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pwrite_pbe_0_common
// static void setup_open_pwrite_p9e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p9e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p9e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p9b8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p9b8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_p9b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pbb8_0_common
// static void setup_open_pwrite_p9b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 12279808, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pcdc_0_proc0
// static void setup_open_pwrite_p9b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p9b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p9b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p9b8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p9b8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_p9b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pbb8_0_common
// static void setup_open_pwrite_p9b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pdde_1_proc0
// static void setup_open_pwrite_p9b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p9b8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p9b8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p990_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p990_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pd48_1_1
static void setup_open_pwrite_p990_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_pwrite_p990_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 98304, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pb90_0_proc0
// static void setup_open_pwrite_p990_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p990_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p990_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p990_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p990_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_p990_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pbb8_1_common
// static void setup_open_pwrite_p990_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pdde_1_proc0
// static void setup_open_pwrite_p990_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p990_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p990_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p94_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p94_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pwrite_pb4_0_common
// static void setup_open_pwrite_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p94_0_final(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal
// static void setup_open_pwrite_p94_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p8e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p8e_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pwrite_pae_0_common
// static void setup_open_pwrite_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_p8e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p8e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p8e_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p8e_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p8e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pwrite_pae_0_common
// static void setup_open_pwrite_p8e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p8e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_p8e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p8e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p8b0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p8b0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_p8b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pa90_0_common
// static void setup_open_pwrite_p8b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pdde_0_proc0
// static void setup_open_pwrite_p8b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p8b0_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p8b0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_p8b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pa90_0_common
// static void setup_open_pwrite_p8b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p8b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pdde_1_proc0
// static void setup_open_pwrite_p8b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p8b0_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p890_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p890_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pa90_0_common
// static void setup_open_pwrite_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1150976, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pa90_0_proc1
// static void setup_open_pwrite_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p890_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p890_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p890_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pd48_1_1
// static void setup_open_pwrite_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pa90_1_common
// static void setup_open_pwrite_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p890_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 16384, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pd48_1_proc1
// static void setup_open_pwrite_p890_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p890_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p84_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pcf_0_0
// static int test_open_pwrite_p84_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pwrite_pb4_0_common
// static void setup_open_pwrite_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p84_0_final(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal
// static void setup_open_pwrite_p84_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
static int test_open_pwrite_p7e_0_0(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_pwrite_p7e_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p7e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pdf0_1_common
// static void setup_open_pwrite_p7e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_p7e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p7e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p7e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p7e_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p7e_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p7e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pdf0_0_common
// static void setup_open_pwrite_p7e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_p7e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p7e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p7e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p7bc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p7bc_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_p7bc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pdde_0_common
// static void setup_open_pwrite_p7bc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 12279808, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pcdc_0_proc0
// static void setup_open_pwrite_p7bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p7bc_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_p7bc_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p7bc_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p7bc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pd48_1_1
static void setup_open_pwrite_p7bc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_p7bc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 16384, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pd48_1_proc1
// static void setup_open_pwrite_p7bc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p7bc_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_p7bc_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p74_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p74_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pca_0_common
// static void setup_open_pwrite_p74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p74_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p74_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p6e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p6e_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p6e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pd70_1_common
// static void setup_open_pwrite_p6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_p6e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p6e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p6e_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p6e_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p6e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pd70_1_common
// static void setup_open_pwrite_p6e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p6e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_p6e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p6e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p6b8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p6b8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_p6b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pd5c_0_common
// static void setup_open_pwrite_p6b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p6b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 25735168, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pd5c_0_proc1
// static void setup_open_pwrite_p6b8_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_p6b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p6b8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p6b8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_p6b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pd5c_0_common
// static void setup_open_pwrite_p6b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p6b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pdde_1_proc0
// static void setup_open_pwrite_p6b8_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_p6b8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p690_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p690_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p690_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pd5c_0_common
// static void setup_open_pwrite_p690_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
static void setup_open_pwrite_p690_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24248320, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_pwrite_p690_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_p690_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p690_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p690_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pd48_1_1
// static void setup_open_pwrite_p690_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pd48_1_common
// static void setup_open_pwrite_p690_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p690_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 16384, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pd48_1_proc1
// static void setup_open_pwrite_p690_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pdde_0_final
// static void setup_open_pwrite_p690_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p64_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p7e_0_0
// static int test_open_pwrite_p64_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_p64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pda_0_common
// static void setup_open_pwrite_p64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p64_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p64_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
static int test_open_pwrite_p5e_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static int test_open_pwrite_p5e_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p5e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pcf_0_common
// static void setup_open_pwrite_p5e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_p5e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p5e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p5e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p5e_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p5e_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p5e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pcf_0_common
// static void setup_open_pwrite_p5e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_p5e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p5e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p5e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p5b8_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p5b8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_p5b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pcdc_0_common
// static void setup_open_pwrite_p5b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 12279808, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pcdc_0_proc0
// static void setup_open_pwrite_p5b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p5b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p5b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p5b8_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p5b8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdde_0_1
// static void setup_open_pwrite_p5b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pcdc_0_common
// static void setup_open_pwrite_p5b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pdde_1_proc0
// static void setup_open_pwrite_p5b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p5b8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p5b8_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p598_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p598_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pdc8_0_1
static void setup_open_pwrite_p598_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_pwrite_p598_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pccc_0_proc0
// static void setup_open_pwrite_p598_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p598_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p598_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p598_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p598_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p598_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pcdc_0_common
// static void setup_open_pwrite_p598_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pfa_1_proc0
// static void setup_open_pwrite_p598_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p598_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p598_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p54_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p54_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pca_0_common
// static void setup_open_pwrite_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p54_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p54_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p4e_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p4e_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p4e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pc7_0_common
// static void setup_open_pwrite_p4e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p4e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_p4e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p4e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p4e_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p4e_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p4e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pc7_0_common
// static void setup_open_pwrite_p4e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p4e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_p4e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p4e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p4b0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p4b0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pc58_0_1
// static void setup_open_pwrite_p4b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pc58_0_common
// static void setup_open_pwrite_p4b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p4b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pccc_0_proc0
// static void setup_open_pwrite_p4b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p4b0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p4b0_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p4b0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pc58_1_1
// static void setup_open_pwrite_p4b0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pda_0_common
// static void setup_open_pwrite_p4b0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p4b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pc58_1_proc1
// static void setup_open_pwrite_p4b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p4b0_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p490_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p490_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p490_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pf8_0_common
// static void setup_open_pwrite_p490_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p490_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pea_0_proc1
// static void setup_open_pwrite_p490_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p490_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p490_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p490_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pccc_0_1
// static void setup_open_pwrite_p490_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pc58_0_common
// static void setup_open_pwrite_p490_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p490_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pccc_0_proc0
// static void setup_open_pwrite_p490_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p490_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p44_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p5e_0_0
// static int test_open_pwrite_p44_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_pwrite_pca_0_common
// static void setup_open_pwrite_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p44_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p44_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
static int test_open_pwrite_p38_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_open_pwrite_p38_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
static void setup_open_pwrite_p38_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_pwrite_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p38_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p38_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p38_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pwrite_p38_0_common
// static void setup_open_pwrite_p38_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_p38_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p38_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p38_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p34_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p34_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_pwrite_pab0_0_common
// static void setup_open_pwrite_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pfa_0_proc0
// static void setup_open_pwrite_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p34_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p34_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p34_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p34_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_pwrite_pab0_0_common
// static void setup_open_pwrite_p34_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pfa_1_proc0
// static void setup_open_pwrite_p34_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p34_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p34_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p30_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p30_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pa90_0_common
// static void setup_open_pwrite_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pf8_0_proc0
// static void setup_open_pwrite_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p30_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p30_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p30_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pa90_0_common
// static void setup_open_pwrite_p30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pfa_1_proc0
// static void setup_open_pwrite_p30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p30_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p30_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p2_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p2_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pwrite_pb4_0_common
// static void setup_open_pwrite_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p2_0_final(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal
// static void setup_open_pwrite_p2_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p18_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p18_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pwrite_p38_0_common
// static void setup_open_pwrite_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc0
// static void setup_open_pwrite_p18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p18_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p18_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfc_0_1
// static void setup_open_pwrite_p18_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_pwrite_p38_0_common
// static void setup_open_pwrite_p18_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_0_proc1
// static void setup_open_pwrite_p18_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_pwrite_pfc_1_proc0
// static void setup_open_pwrite_p18_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_final
// static void setup_open_pwrite_p18_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_pwrite_pfc_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p14_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p14_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_pwrite_pab0_0_common
// static void setup_open_pwrite_p14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pea_0_proc1
// static void setup_open_pwrite_p14_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p14_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p14_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p14_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p14_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_pwrite_pab0_0_common
// static void setup_open_pwrite_p14_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p14_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pfa_1_proc0
// static void setup_open_pwrite_p14_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p14_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p10_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p10_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pa90_0_common
// static void setup_open_pwrite_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pe8_0_proc1
// static void setup_open_pwrite_p10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p10_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p10_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p10_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pfa_0_1
// static void setup_open_pwrite_p10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_pwrite_pa90_0_common
// static void setup_open_pwrite_p10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_pwrite_pfa_1_proc0
// static void setup_open_pwrite_p10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_pwrite_pfa_0_final
// static void setup_open_pwrite_p10_1_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal

/*
 * calls: open pwrite
 */
// static int test_open_pwrite_p0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_p38_0_0
// static int test_open_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_open_pwrite_pf0_0_1
// static void setup_open_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_pwrite_pb4_0_common
// static void setup_open_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_pwrite_pfa_0_proc1
// static void setup_open_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal
// static void setup_open_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_open_pwrite_pfa_0_procfinal


/*
 * calls: open read
 */
static int test_open_read_pfe_0_0(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_open_read_pfe_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_open_read_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_read_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_open_read_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_open_read_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_open_read_pfe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: open read
 */
// static int test_open_read_pfd8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
static int test_open_read_pfd8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_open_read_pfd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_read_pfd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_open_read_pfd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pfd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pfd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pfd0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
static int test_open_read_pfd0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_open_read_pfd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_read_pfd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_open_read_pfd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_open_read_pfd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pfd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pfc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
static int test_open_read_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_open_read_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pfc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pfa_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
// static int test_open_read_pfa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_read_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_open_read_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_read_pfa_0_final(void) {
  unlink("__i0");
}
static void setup_open_read_pfa_0_procfinal(void) {
  
}

/*
 * calls: open read
 */
// static int test_open_read_pf8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
// static int test_open_read_pf8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
static void setup_open_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_read_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pf0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
// static int test_open_read_pf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfa_0_common
// static void setup_open_read_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pee_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
// static int test_open_read_pee_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_pee_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfe_0_common
// static void setup_open_read_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_pee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_ped8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
// static int test_open_read_ped8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_ped8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfd8_0_common
// static void setup_open_read_ped8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_ped8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_ped8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_ped8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_ped0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
// static int test_open_read_ped0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_ped0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfd0_0_common
// static void setup_open_read_ped0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_ped0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_ped0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_ped0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pec_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
// static int test_open_read_pec_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfc_0_common
// static void setup_open_read_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pea_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
// static int test_open_read_pea_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfa_0_common
// static void setup_open_read_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pf8_0_proc0
// static void setup_open_read_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pea_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pe8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
// static int test_open_read_pe8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pf8_0_common
// static void setup_open_read_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pf8_0_proc0
// static void setup_open_read_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pe0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_read_pfe_0_0
// static int test_open_read_pe0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfa_0_common
// static void setup_open_read_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
static int test_open_read_pdf8_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_read_pdf8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_pdf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pdf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_pdf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pdf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pdf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pdee_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pdee_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
static void setup_open_read_pdee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pdee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pdee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pdee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pdee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pdea_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pdea_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_pdea_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pdea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_pdea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_pdea_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pdea_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pde4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pde4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
static void setup_open_read_pde4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pde4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pde4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pde4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pde4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pdde_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pdde_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_pdde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_read_pdde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pdde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
static void setup_open_read_pdde_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_open_read_pdde_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pdde_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pdde_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_pdde_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_read_pdde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23986176, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pdde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pdde_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pdde_1_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pdc8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pdc8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_pdc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pdde_0_common
static void setup_open_read_pdc8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pdc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pdc8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_read_pdde_0_final
// static void setup_open_read_pdc8_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pda_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pda_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_pda_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pda_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pda_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pd78_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pd78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_pd78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pd78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pd78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_pd78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pd78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pd6e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pd6e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
static void setup_open_read_pd6e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pd6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pd6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pd6e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pd6e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pd6a_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pd6a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_pd6a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pd6e_0_common
// static void setup_open_read_pd6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_pd6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_pd6a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pd6a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pd64_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pd64_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_pd64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfc_0_common
// static void setup_open_read_pd64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pd64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pd64_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pd64_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pd5c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pd5c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_pd5c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pd5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pd5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pdc8_0_proc0
// static void setup_open_read_pd5c_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_read_pdde_0_final
// static void setup_open_read_pd5c_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pd5c_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pd5c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_pd5c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pdde_1_common
// static void setup_open_read_pd5c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
static void setup_open_read_pd5c_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2494464, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pd5c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pd5c_1_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pd48_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pd48_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
static void setup_open_read_pd48_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pd48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pd48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pdde_0_proc0
// static void setup_open_read_pd48_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_read_pdde_0_final
// static void setup_open_read_pd48_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pd2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pd2_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_pd2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pda_0_common
// static void setup_open_read_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pd2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pd2_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
static int test_open_read_pcf8_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
// static int test_open_read_pcf8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_pcf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pcf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_pcf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pcf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pcf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pcee_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pcee_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_pcee_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pd6e_0_common
// static void setup_open_read_pcee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pcee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pcee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pcee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pcea_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pcea_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_pcea_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pcea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_pcea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_pcea_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pcea_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pce4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pce4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_pce4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfc_0_common
// static void setup_open_read_pce4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pce4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pce4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pce4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pcdc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pcdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_pcdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_read_pcdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pcdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pcdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pcdc_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pccc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pccc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_pccc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pcdc_0_common
static void setup_open_read_pccc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pccc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pccc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pccc_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pca_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pca_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_pca_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pca_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pca_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pca_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pca_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pc78_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pc78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_pc78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pcf8_0_common
// static void setup_open_read_pc78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pc78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_pc78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pc78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pc6e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pc6e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_pc6e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfd8_0_common
// static void setup_open_read_pc6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pc6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pc6e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pc6e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pc6a_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pc6a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_pc6a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfd8_0_common
// static void setup_open_read_pc6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_pc6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_pc6a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pc6a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pc64_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pc64_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_pc64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfc_0_common
// static void setup_open_read_pc64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pc64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pc64_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pc64_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pc58_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pc58_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_pc58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pcdc_0_common
// static void setup_open_read_pc58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pc58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pfa_0_proc0
// static void setup_open_read_pc58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pc58_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pc48_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pc48_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
static void setup_open_read_pc48_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_pc48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
static void setup_open_read_pc48_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pc48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pc48_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pc2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_pc2_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_pc2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pca_0_common
// static void setup_open_read_pc2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pc2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pc2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pc2_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pbf0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pbf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_pbf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_pbf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_pbf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pbf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pbf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pbdc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pbdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
static void setup_open_read_pbdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_pbdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pbdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pbdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pbdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pbd4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pbd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_pbd4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_pbd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_pbd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_pbd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pbd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pbc8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pbc8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
static void setup_open_read_pbc8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_pbc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pbc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pbc8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pbc8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pbb8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pbb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_pbb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_open_read_pbb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7389184, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pbb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pbb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pbb8_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pb90_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pb90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
static void setup_open_read_pb90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_open_read_pb90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pb90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pb90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pb90_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pb4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pb4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_open_read_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pb4_0_final(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal
// static void setup_open_read_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_paf0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_paf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_paf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_paf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_paf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_paf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_paf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_padc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_padc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
static void setup_open_read_padc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_padc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_padc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_padc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_padc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pad4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pad4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_pad4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_padc_0_common
// static void setup_open_read_pad4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_pad4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_pad4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pad4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pac8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pac8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_pac8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_pbc8_0_common
// static void setup_open_read_pac8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_pac8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_pac8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_pac8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pab0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pab0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_pab0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_read_pab0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
static void setup_open_read_pab0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_pab0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pa90_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pa90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
static void setup_open_read_pa90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_read_pa90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pa90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pccc_0_proc0
// static void setup_open_read_pa90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_pa90_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_pa4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pdf8_0_0
// static int test_open_read_pa4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_read_pb4_0_common
// static void setup_open_read_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_pa4_0_final(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal
// static void setup_open_read_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p9f0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p9f0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_p9f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_p9f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p9f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p9f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p9dc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p9dc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_p9dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_pbdc_0_common
// static void setup_open_read_p9dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p9dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p9dc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p9dc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p9d4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p9d4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p9d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_pbd4_0_common
// static void setup_open_read_p9d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_p9d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_p9d4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p9d4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p9c8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p9c8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
static void setup_open_read_p9c8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_p9c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p9c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p9c8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p9c8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p9b8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p9b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p9b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_read_pbb8_0_common
static void setup_open_read_p9b8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34291712, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_p9b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p9b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p9b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p990_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p990_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p990_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_read_pb90_0_common
// static void setup_open_read_p990_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pb90_0_proc0
// static void setup_open_read_p990_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p990_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p990_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p94_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p94_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_read_pb4_0_common
// static void setup_open_read_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p94_0_final(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal
// static void setup_open_read_p94_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p8f0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p8f0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_p8f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_p8f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_p8f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p8f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p8dc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p8dc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_p8dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_padc_0_common
// static void setup_open_read_p8dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p8dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p8dc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p8dc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p8d4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p8d4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p8d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_pbdc_0_common
// static void setup_open_read_p8d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_p8d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_p8d4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p8d4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p8c8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p8c8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p8c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_pbc8_0_common
// static void setup_open_read_p8c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p8c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p8c8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p8c8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p8b0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p8b0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p8b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_read_pab0_0_common
// static void setup_open_read_p8b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9981952, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pab0_0_proc1
// static void setup_open_read_p8b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p890_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p890_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_read_pa90_0_common
// static void setup_open_read_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pccc_0_proc0
// static void setup_open_read_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p890_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p84_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_pcf8_0_0
// static int test_open_read_p84_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_read_pb4_0_common
// static void setup_open_read_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p84_0_final(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal
// static void setup_open_read_p84_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
static int test_open_read_p7f0_0_0(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_read_p7f0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p7f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pdf8_0_common
// static void setup_open_read_p7f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_p7f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p7f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p7f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p7dc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p7dc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_p7dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pdee_0_common
// static void setup_open_read_p7dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p7dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p7dc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p7dc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p7d4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p7d4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_p7d4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_p7d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_p7d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_p7d4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p7d4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p7c8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p7c8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p7c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pde4_0_common
// static void setup_open_read_p7c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p7c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p7c8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p7c8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p7bc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p7bc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_p7bc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_read_p7bc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_read_p7bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p7bc_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_read_pdde_0_final
// static void setup_open_read_p7bc_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p7bc_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p7bc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p7bc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pdde_1_common
// static void setup_open_read_p7bc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 23986176, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pdde_1_proc0
// static void setup_open_read_p7bc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p7bc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p7bc_1_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p790_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p790_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p790_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pdde_0_common
// static void setup_open_read_p790_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pdc8_0_proc0
// static void setup_open_read_p790_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p790_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_read_pdde_0_final
// static void setup_open_read_p790_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p74_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pda_0_common
// static void setup_open_read_p74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p74_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p74_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p6f0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p6f0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p6f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pd78_0_common
// static void setup_open_read_p6f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p6f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_p6f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p6f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p6dc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p6dc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_p6dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pd6e_0_common
// static void setup_open_read_p6dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p6dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p6dc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p6dc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p6d4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p6d4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p6d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pd6e_0_common
// static void setup_open_read_p6d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_p6d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_p6d4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p6d4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p6c8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p6c8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
static void setup_open_read_p6c8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_read_p6c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p6c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p6c8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p6c8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p6b8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p6b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p6b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pd5c_0_common
// static void setup_open_read_p6b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p6b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pdc8_0_proc0
// static void setup_open_read_p6b8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_read_pdde_0_final
// static void setup_open_read_p6b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p6b8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p6b8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p6b8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pdde_1_common
// static void setup_open_read_p6b8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p6b8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 2494464, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pd5c_1_proc1
// static void setup_open_read_p6b8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p6b8_1_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p690_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p690_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p690_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pd48_0_common
// static void setup_open_read_p690_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p690_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pdde_0_proc0
// static void setup_open_read_p690_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_read_pdde_0_final
// static void setup_open_read_p690_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p64_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p7f0_0_0
// static int test_open_read_p64_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pca_0_common
// static void setup_open_read_p64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p64_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p64_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
static int test_open_read_p5f_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static int test_open_read_p5f_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p5f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pcf8_0_common
// static void setup_open_read_p5f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_p5f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p5f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p5f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p5dc_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p5dc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_p5dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pd6e_0_common
// static void setup_open_read_p5dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p5dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p5dc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p5dc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p5d4_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p5d4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p5d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pd6e_0_common
// static void setup_open_read_p5d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_p5d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_p5d4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p5d4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p5c8_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p5c8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p5c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfc_0_common
// static void setup_open_read_p5c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p5c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p5c8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p5c8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p5b8_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p5b8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p5b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pcdc_0_common
// static void setup_open_read_p5b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5087232, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pcdc_0_proc0
// static void setup_open_read_p5b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p5b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p5b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p598_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p598_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p598_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pcdc_0_common
// static void setup_open_read_p598_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pccc_0_proc0
// static void setup_open_read_p598_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p598_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p598_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p54_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p54_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pca_0_common
// static void setup_open_read_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p54_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p54_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p4f_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p4f_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p4f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pcf8_0_common
// static void setup_open_read_p4f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p4f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_p4f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p4f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p4dc_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p4dc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_p4dc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfd8_0_common
// static void setup_open_read_p4dc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p4dc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p4dc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p4dc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p4d4_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p4d4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p4d4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfd0_0_common
// static void setup_open_read_p4d4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_p4d4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_p4d4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p4d4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p4c8_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p4c8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p4c8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pfc_0_common
// static void setup_open_read_p4c8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p4c8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p4c8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p4c8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p4b_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p4b_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p4b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pcdc_0_common
// static void setup_open_read_p4b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p4b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pfa_0_proc0
// static void setup_open_read_p4b_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p4b_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p490_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p490_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p490_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pc48_0_common
// static void setup_open_read_p490_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p490_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pc48_0_proc1
// static void setup_open_read_p490_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p490_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p44_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_read_p5f_0_0
// static int test_open_read_p44_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_read_pca_0_common
// static void setup_open_read_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p44_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p44_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
static int test_open_read_p3c_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_open_read_p3c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
static void setup_open_read_p3c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p3b_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p3b_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_p3b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_padc_0_common
// static void setup_open_read_p3b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p3b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p3b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p3b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p3a_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p3a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p3a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_padc_0_common
// static void setup_open_read_p3a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_p3a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_p3a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p3a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p38_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_pbc8_0_common
// static void setup_open_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p34_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_p34_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_open_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pfa_0_proc0
// static void setup_open_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p34_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p30_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
static void setup_open_read_p30_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pf8_0_proc0
// static void setup_open_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p30_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p2_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p2_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_read_pb4_0_common
// static void setup_open_read_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p2_0_final(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal
// static void setup_open_read_p2_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p1c_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p1c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p1c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_p3c_0_common
// static void setup_open_read_p1c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p1c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc0
// static void setup_open_read_p1c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p1c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p1b_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p1b_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd8_0_1
// static void setup_open_read_p1b_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_padc_0_common
// static void setup_open_read_p1b_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p1b_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p1b_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p1b_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p1a_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p1a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
static void setup_open_read_p1a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_read_p1a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc1
// static void setup_open_read_p1a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd0_0_proc0
// static void setup_open_read_p1a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p1a_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p18_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p18_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_read_pbc8_0_common
// static void setup_open_read_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfe_0_proc1
// static void setup_open_read_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_read_pfd8_0_proc0
// static void setup_open_read_p18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_final
// static void setup_open_read_p18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_read_pfe_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p14_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p14_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfd0_0_1
// static void setup_open_read_p14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_read_p34_0_common
// static void setup_open_read_p14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pf8_0_proc0
// static void setup_open_read_p14_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p14_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p10_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p10_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfc_0_1
// static void setup_open_read_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_read_p30_0_common
// static void setup_open_read_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_read_pf8_0_proc0
// static void setup_open_read_p10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_read_pfa_0_final
// static void setup_open_read_p10_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal

/*
 * calls: open read
 */
// static int test_open_read_p0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_read_p3c_0_0
// static int test_open_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_open_read_pfe_0_1
// static void setup_open_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_read_pb4_0_common
// static void setup_open_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_read_pfa_0_proc1
// static void setup_open_read_p0_0_final(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal
// static void setup_open_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_open_read_pfa_0_procfinal


/*
 * calls: open rename
 */
static int test_open_rename_pf8_0_0(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_open_rename_pf8_0_1(void) {
  int r = rename("__f1", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_open_rename_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_open_rename_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_rename_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_rename_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_open_rename_pf8_0_procfinal(void) {
  
}

/*
 * calls: open rename
 */
// static int test_open_rename_pf8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_0
static int test_open_rename_pf8_1_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_open_rename_pf8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pf8_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pf6_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_0
static int test_open_rename_pf6_0_1(void) {
  int r = rename("__f1", "__f2");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_open_rename_pf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pf6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pf6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pf6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pf6_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pf6_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_0
static int test_open_rename_pf6_1_1(void) {
  int r = rename("__f1", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_open_rename_pf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pf8_0_common
// static void setup_open_rename_pf6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pf6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pf6_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pf2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_0
// static int test_open_rename_pf2_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
// static void setup_open_rename_pf2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pf8_0_common
// static void setup_open_rename_pf2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pf2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pf2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pf2_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pe_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_0
static int test_open_rename_pe_0_1(void) {
  int r = rename("__f1", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_open_rename_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pf8_1_common
// static void setup_open_rename_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pe_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
static int test_open_rename_pde_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_rename_pde_0_1(void) {
//   int r = rename("__f1", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_1
// static void setup_open_rename_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pf8_0_common
// static void setup_open_rename_pde_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pde_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pde_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pde_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pde_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_1_1
static void setup_open_rename_pde_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pde_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pde_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pde_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pdb8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pdb8_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
static void setup_open_rename_pdb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pdb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pdb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
static void setup_open_rename_pdb8_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_open_rename_pdb8_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pdb8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pdb8_1_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
static void setup_open_rename_pdb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pdb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pdb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
static void setup_open_rename_pdb8_1_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_open_rename_pdb8_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pdb8_2_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pdb8_2_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_1_1
// static void setup_open_rename_pdb8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pf8_0_common
// static void setup_open_rename_pdb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pdb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pdb8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pdb8_2_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pd98_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pd98_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
static void setup_open_rename_pd98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pd98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pd98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pd98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pd98_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pd4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pd4_0_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_pe_0_1
static void setup_open_rename_pd4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
static int test_open_rename_pce_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
// static int test_open_rename_pce_0_1(void) {
//   int r = rename("__f1", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_1
static void setup_open_rename_pce_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pce_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pce_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pce_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pce_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_pce_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_1_1
static void setup_open_rename_pce_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pce_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pce_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pce_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pce_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pcb8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_pcb8_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
static void setup_open_rename_pcb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pcb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pcb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pcb8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_rename_pdb8_1_final
// static void setup_open_rename_pcb8_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pcb8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_pcb8_1_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
static void setup_open_rename_pcb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pcb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pcb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pcb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pcb8_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pcb8_2_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_pcb8_2_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_1_1
static void setup_open_rename_pcb8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pcb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pcb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pcb8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pcb8_2_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pc98_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_pc98_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
// static void setup_open_rename_pc98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pce_0_common
// static void setup_open_rename_pc98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pc98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pc98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pc98_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pc4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_pc4_0_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_pe_0_1
// static void setup_open_rename_pc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pce_1_common
// static void setup_open_rename_pc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pc4_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pbe_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pbe_0_1(void) {
//   int r = rename("__f1", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_1
static void setup_open_rename_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pbe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pbe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pbe_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pb78_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pb78_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
static void setup_open_rename_pb78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pb78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pb78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pb78_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_rename_pdb8_0_final
// static void setup_open_rename_pb78_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pb78_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pb78_1_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
static void setup_open_rename_pb78_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_pb78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pb78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pb78_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pb78_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pb30_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pb30_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
// static void setup_open_rename_pb30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pbe_0_common
// static void setup_open_rename_pb30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pb30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pb30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_pb30_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_pa8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pde_0_0
// static int test_open_rename_pa8_0_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_pe_0_1
static void setup_open_rename_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_open_rename_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_pa8_0_final(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal
// static void setup_open_rename_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p9e_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_p9e_0_1(void) {
//   int r = rename("__f1", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_1
static void setup_open_rename_p9e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_p9e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p9e_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p9e_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p978_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_p978_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
// static void setup_open_rename_p978_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pb78_0_common
// static void setup_open_rename_p978_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p978_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p978_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_rename_pdb8_0_final
// static void setup_open_rename_p978_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p978_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_p978_1_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
// static void setup_open_rename_p978_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pb78_1_common
// static void setup_open_rename_p978_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p978_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p978_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p978_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p930_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_p930_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
// static void setup_open_rename_p930_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_p9e_0_common
// static void setup_open_rename_p930_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p930_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p930_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p930_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p88_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_pce_0_0
// static int test_open_rename_p88_0_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_pe_0_1
// static void setup_open_rename_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_rename_pa8_0_common
// static void setup_open_rename_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p88_0_final(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal
// static void setup_open_rename_p88_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
static int test_open_rename_p7c_0_0(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_rename_p7c_0_1(void) {
//   int r = rename("__f1", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_1
static void setup_open_rename_p7c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p7c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p7c_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p7c_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_p7c_0_0
// static int test_open_rename_p7c_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_1_1
// static void setup_open_rename_p7c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pf8_1_common
// static void setup_open_rename_p7c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p7c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p7c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p7c_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p770_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_p7c_0_0
// static int test_open_rename_p770_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
static void setup_open_rename_p770_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_p770_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p770_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p770_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_open_rename_pdb8_0_final
// static void setup_open_rename_p770_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p770_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_p7c_0_0
// static int test_open_rename_p770_1_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_1_1
static void setup_open_rename_p770_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_p770_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p770_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p770_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p770_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p730_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_p7c_0_0
// static int test_open_rename_p730_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
static void setup_open_rename_p730_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_p730_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p730_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p730_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p730_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p68_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_p7c_0_0
// static int test_open_rename_p68_0_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_pe_0_1
// static void setup_open_rename_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pde_1_common
// static void setup_open_rename_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p68_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
static int test_open_rename_p5c_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static int test_open_rename_p5c_0_1(void) {
//   int r = rename("__f1", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_1
// static void setup_open_rename_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pce_0_common
// static void setup_open_rename_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p5c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p5c_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_p5c_0_0
// static int test_open_rename_p5c_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_1_1
// static void setup_open_rename_p5c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pce_1_common
// static void setup_open_rename_p5c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p5c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p5c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p5c_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p570_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_p5c_0_0
// static int test_open_rename_p570_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
// static void setup_open_rename_p570_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pcb8_0_common
// static void setup_open_rename_p570_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p570_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p570_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_rename_pdb8_1_final
// static void setup_open_rename_p570_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p570_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_p5c_0_0
// static int test_open_rename_p570_1_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_1_1
// static void setup_open_rename_p570_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pcb8_2_common
// static void setup_open_rename_p570_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p570_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p570_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p570_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p53_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_p5c_0_0
// static int test_open_rename_p53_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
// static void setup_open_rename_p53_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pce_0_common
// static void setup_open_rename_p53_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p53_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p53_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p53_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p48_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_rename_p5c_0_0
// static int test_open_rename_p48_0_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_pe_0_1
// static void setup_open_rename_p48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pce_1_common
// static void setup_open_rename_p48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p48_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
static int test_open_rename_p3_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_open_rename_p3_0_1(void) {
//   int r = rename("__f1", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf8_0_1
// static void setup_open_rename_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pbe_0_common
// static void setup_open_rename_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p3_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p3_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p28_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_p3_0_0
// static int test_open_rename_p28_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
static void setup_open_rename_p28_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_open_rename_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p28_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p20_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_p3_0_0
// static int test_open_rename_p20_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_rename_pf6_0_1
// static void setup_open_rename_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_rename_pbe_0_common
// static void setup_open_rename_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_rename_pf8_0_final
// static void setup_open_rename_p20_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_p3_0_0
// static int test_open_rename_p0_0_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_pe_0_1
// static void setup_open_rename_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_rename_pa8_0_common
// static void setup_open_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p0_0_final(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal
// static void setup_open_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal

/*
 * calls: open rename
 */
// static int test_open_rename_p0_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_rename_p3_0_0
static int test_open_rename_p0_1_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_open_rename_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_rename_pa8_0_common
// static void setup_open_rename_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_rename_pf8_0_proc1
// static void setup_open_rename_p0_1_final(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal
// static void setup_open_rename_p0_1_procfinal(void) {
//   
// }
// ^ See setup_open_rename_pf8_0_procfinal


/*
 * calls: open stat
 */
static int test_open_stat_pf_0_0(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_open_stat_pf_0_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_open_stat_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_open_stat_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_stat_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_stat_pf_0_final(void) {
  unlink("__i0");
}
static void setup_open_stat_pf_0_procfinal(void) {
  
}

/*
 * calls: open stat
 */
// static int test_open_stat_pf_1_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_stat_pf_0_0
static int test_open_stat_pf_1_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_open_stat_pf_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_stat_pf_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pf_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_pf_1_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_pe_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_stat_pf_0_0
static int test_open_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_open_stat_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pf_1_common
// static void setup_open_stat_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_pe_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
static int test_open_stat_pdf8_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
static int test_open_stat_pdf8_0_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_open_stat_pdf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_stat_pdf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pdf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
static void setup_open_stat_pdf8_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_open_stat_pdf8_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_pdf8_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_pdf8_0_0
// static int test_open_stat_pdf8_1_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pf_0_1
// static void setup_open_stat_pdf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pf_0_common
// static void setup_open_stat_pdf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pdf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pdf8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_pdf8_1_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_pdf8_2_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_pdf8_0_0
// static int test_open_stat_pdf8_2_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pf_1_1
// static void setup_open_stat_pdf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pf_1_common
// static void setup_open_stat_pdf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pdf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pdf8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_pdf8_2_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_pd4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_pdf8_0_0
// static int test_open_stat_pd4_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pe_0_1
static void setup_open_stat_pd4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_stat_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
static int test_open_stat_pcc_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
static int test_open_stat_pcc_0_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 24576);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_open_stat_pcc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_stat_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_pcc_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_pcc_0_0
static int test_open_stat_pcc_1_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 24576);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_open_stat_pcc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_stat_pcc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pcc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pcc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_pcc_1_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_pc4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_pcc_0_0
// static int test_open_stat_pc4_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pe_0_1
// static void setup_open_stat_pc4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pcc_1_common
// static void setup_open_stat_pc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_pc4_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_pbc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_pdf8_0_0
static int test_open_stat_pbc_0_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 16384);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_open_stat_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_stat_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_pa8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_pdf8_0_0
// static int test_open_stat_pa8_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pe_0_1
static void setup_open_stat_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_open_stat_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_pa8_0_final(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal
// static void setup_open_stat_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_p9c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_pcc_0_0
// static int test_open_stat_p9c_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 16384);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pbc_0_1
// static void setup_open_stat_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pbc_0_common
// static void setup_open_stat_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_p88_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_pcc_0_0
// static int test_open_stat_p88_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pe_0_1
// static void setup_open_stat_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_stat_pa8_0_common
// static void setup_open_stat_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p88_0_final(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal
// static void setup_open_stat_p88_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
static int test_open_stat_p7f0_0_0(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_stat_p7f0_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pdf8_0_1
// static void setup_open_stat_p7f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pdf8_0_common
// static void setup_open_stat_p7f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p7f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p7f0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_stat_pdf8_0_final
// static void setup_open_stat_p7f0_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_p7f0_1_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_p7f0_0_0
// static int test_open_stat_p7f0_1_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pf_0_1
// static void setup_open_stat_p7f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pf_0_common
// static void setup_open_stat_p7f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p7f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p7f0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_p7f0_1_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_p7f0_2_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_p7f0_0_0
// static int test_open_stat_p7f0_2_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pf_1_1
// static void setup_open_stat_p7f0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pf_1_common
// static void setup_open_stat_p7f0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p7f0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p7f0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_p7f0_2_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_p68_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_p7f0_0_0
// static int test_open_stat_p68_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pe_0_1
// static void setup_open_stat_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pf_1_common
// static void setup_open_stat_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_p68_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
static int test_open_stat_p58_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static int test_open_stat_p58_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 24576);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pcc_0_1
// static void setup_open_stat_p58_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pcc_0_common
// static void setup_open_stat_p58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p58_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_p58_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_p58_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_p58_0_0
// static int test_open_stat_p58_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 24576);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pcc_1_1
// static void setup_open_stat_p58_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pcc_1_common
// static void setup_open_stat_p58_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p58_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p58_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_p58_1_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_p48_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_stat_p58_0_0
// static int test_open_stat_p48_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pe_0_1
// static void setup_open_stat_p48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_stat_pcc_1_common
// static void setup_open_stat_p48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_p48_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
static int test_open_stat_p2_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_open_stat_p2_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pf_0_1
static void setup_open_stat_p2_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_stat_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_stat_pf_0_final
// static void setup_open_stat_p2_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_p0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_stat_p2_0_0
// static int test_open_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_open_stat_pe_0_1
// static void setup_open_stat_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_stat_pa8_0_common
// static void setup_open_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p0_0_final(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal
// static void setup_open_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal

/*
 * calls: open stat
 */
// static int test_open_stat_p0_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_stat_p2_0_0
static int test_open_stat_p0_1_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_open_stat_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_stat_pa8_0_common
// static void setup_open_stat_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_stat_pf_0_proc1
// static void setup_open_stat_p0_1_final(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal
// static void setup_open_stat_p0_1_procfinal(void) {
//   
// }
// ^ See setup_open_stat_pf_0_procfinal


/*
 * calls: open unlink
 */
static int test_open_unlink_pf8_0_0(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_open_unlink_pf8_0_1(void) {
  int r = unlink("__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_open_unlink_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_open_unlink_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_unlink_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_unlink_pf8_0_final(void) {
  unlink("__i0");
}
static void setup_open_unlink_pf8_0_procfinal(void) {
  
}

/*
 * calls: open unlink
 */
// static int test_open_unlink_pe_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pf8_0_0
static int test_open_unlink_pe_0_1(void) {
  int r = unlink("__f1");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_open_unlink_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_unlink_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_pe_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
static int test_open_unlink_pde_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_unlink_pde_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pf8_0_1
static void setup_open_unlink_pde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_unlink_pde_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
static void setup_open_unlink_pde_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_open_unlink_pde_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_pde_1_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_unlink_pde_0_0
// static int test_open_unlink_pde_1_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pf8_0_1
static void setup_open_unlink_pde_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_unlink_pde_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pde_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_pde_1_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_pd4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_unlink_pde_0_0
// static int test_open_unlink_pd4_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pe_0_1
// static void setup_open_unlink_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_unlink_pe_0_common
// static void setup_open_unlink_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
static int test_open_unlink_pce_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
// static int test_open_unlink_pce_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pf8_0_1
static void setup_open_unlink_pce_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_unlink_pce_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pce_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_pce_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_pc4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_unlink_pce_0_0
// static int test_open_unlink_pc4_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pe_0_1
static void setup_open_unlink_pc4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_unlink_pc4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pc4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pc4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_pc4_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_pbc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_unlink_pde_0_0
// static int test_open_unlink_pbc_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pf8_0_1
static void setup_open_unlink_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_unlink_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pbc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_pbc_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_pa8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_unlink_pde_0_0
// static int test_open_unlink_pa8_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pe_0_1
static void setup_open_unlink_pa8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_open_unlink_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_pa8_0_final(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal
// static void setup_open_unlink_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_p9c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_unlink_pce_0_0
// static int test_open_unlink_p9c_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pf8_0_1
static void setup_open_unlink_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_unlink_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_p88_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_unlink_pce_0_0
// static int test_open_unlink_p88_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pe_0_1
// static void setup_open_unlink_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_unlink_pa8_0_common
// static void setup_open_unlink_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p88_0_final(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal
// static void setup_open_unlink_p88_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
static int test_open_unlink_p7c_0_0(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_unlink_p7c_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pf8_0_1
// static void setup_open_unlink_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_unlink_pde_1_common
// static void setup_open_unlink_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p7c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_p7c_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_p68_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_unlink_p7c_0_0
// static int test_open_unlink_p68_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pe_0_1
// static void setup_open_unlink_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_unlink_pe_0_common
// static void setup_open_unlink_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_p68_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
static int test_open_unlink_p5c_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static int test_open_unlink_p5c_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pf8_0_1
// static void setup_open_unlink_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_unlink_pce_0_common
// static void setup_open_unlink_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p5c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_p48_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_unlink_p5c_0_0
// static int test_open_unlink_p48_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pe_0_1
// static void setup_open_unlink_p48_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_unlink_pc4_0_common
// static void setup_open_unlink_p48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_p48_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
static int test_open_unlink_p2_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_open_unlink_p2_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pf8_0_1
static void setup_open_unlink_p2_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_open_unlink_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_unlink_pf8_0_final
// static void setup_open_unlink_p2_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_p0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_unlink_p2_0_0
// static int test_open_unlink_p0_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_unlink_pe_0_1
// static void setup_open_unlink_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_unlink_pa8_0_common
// static void setup_open_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal
// static void setup_open_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal

/*
 * calls: open unlink
 */
// static int test_open_unlink_p0_1_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_unlink_p2_0_0
static int test_open_unlink_p0_1_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_open_unlink_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_unlink_pa8_0_common
// static void setup_open_unlink_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_unlink_pf8_0_proc1
// static void setup_open_unlink_p0_1_final(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal
// static void setup_open_unlink_p0_1_procfinal(void) {
//   
// }
// ^ See setup_open_unlink_pf8_0_procfinal


/*
 * calls: open write
 */
static int test_open_write_pff_0_0(void) {
  int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
  expect_result("r", r, -1);
  expect_errno(17);
  return xerrno(r);
}
static int test_open_write_pff_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_open_write_pff_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_write_pff_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_open_write_pff_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_open_write_pff_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_open_write_pff_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: open write
 */
// static int test_open_write_pfe_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
static int test_open_write_pfe_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_open_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_open_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_open_write_pfe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pfe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pfc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
static int test_open_write_pfc_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_open_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_open_write_pfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pfa_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
// static int test_open_write_pfa_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_write_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_open_write_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_open_write_pfa_0_final(void) {
  unlink("__i0");
}
static void setup_open_write_pfa_0_procfinal(void) {
  
}

/*
 * calls: open write
 */
// static int test_open_write_pf8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
// static int test_open_write_pf8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pfa_0_proc0
// static void setup_open_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pf8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pf8_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pf0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
// static int test_open_write_pf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pfa_0_common
// static void setup_open_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pef_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
// static int test_open_write_pef_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
// static void setup_open_write_pef_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pff_0_common
// static void setup_open_write_pef_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_pef_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_pef_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pef_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pee_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
// static int test_open_write_pee_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_pee_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pfe_0_common
// static void setup_open_write_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_pee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pec_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
// static int test_open_write_pec_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pfc_0_common
// static void setup_open_write_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pea_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
// static int test_open_write_pea_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pfa_0_common
// static void setup_open_write_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pfa_0_proc0
// static void setup_open_write_pea_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pea_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pe8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
// static int test_open_write_pe8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pf8_0_common
// static void setup_open_write_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pfa_0_proc0
// static void setup_open_write_pe8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pe8_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pe0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_EXCL | O_CREAT, 0666);
//   expect_result("r", r, -1);
//   expect_errno(17);
//   return xerrno(r);
// }
// ^ See test_open_write_pff_0_0
// static int test_open_write_pe0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pfa_0_common
// static void setup_open_write_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
static int test_open_write_pdfc_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_write_pdfc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
static void setup_open_write_pdfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pdfc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_pdfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_pdfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pdfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pdf4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pdf4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pdf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pdf4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_pdf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pdf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pdf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pde8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pde8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
static void setup_open_write_pde8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pde8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_pde8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pde8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pde8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pdde_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pdde_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pdde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_write_pdde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_write_pdde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
static void setup_open_write_pdde_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_open_write_pdde_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pda_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pda_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
static void setup_open_write_pda_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pda_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pda_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pda_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pd7c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pd7c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
static void setup_open_write_pd7c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pd7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_pd7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_pd7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pd7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pd74_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pd74_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pd74_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pd74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pd74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_pd74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pd74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pd68_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pd68_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
static void setup_open_write_pd68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pd68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pd68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_pd68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pd68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pd5c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pd5c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pd5c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pd5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pd5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pdde_0_proc0
// static void setup_open_write_pd5c_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_write_pdde_0_final
// static void setup_open_write_pd5c_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pd48_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pd48_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pd48_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pd48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
static void setup_open_write_pd48_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_write_pd48_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_write_pdde_0_final
// static void setup_open_write_pd48_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pd2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pd2_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
static void setup_open_write_pd2_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pd2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pd2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pd2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pd2_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
static int test_open_write_pcfc_0_0(void) {
  int r = open("__f0", O_RDWR | O_CREAT, 0666);
  
  return xerrno(r);
}
// static int test_open_write_pcfc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
static void setup_open_write_pcfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pcfc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_pcfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_pcfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pcfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pcf4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pcf4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_pcf4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pff_0_common
// static void setup_open_write_pcf4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_pcf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pcf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pcf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pce8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pce8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
static void setup_open_write_pce8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pce8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_pce8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pce8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pce8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pcdc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pcdc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pcdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_open_write_pcdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_write_pcdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pcdc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pcdc_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pccc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pccc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pccc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pccc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pcdc_0_proc0
// static void setup_open_write_pccc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pccc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pccc_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pca_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pca_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_pca_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pda_0_common
// static void setup_open_write_pca_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pca_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pca_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pca_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pc7c_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pc7c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
static void setup_open_write_pc7c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pc7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_pc7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_pc7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pc7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pc74_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pc74_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_pc74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pff_0_common
// static void setup_open_write_pc74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pc74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_pc74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pc74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pc68_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pc68_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_pc68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pff_0_common
// static void setup_open_write_pc68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pc68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_pc68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pc68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pc58_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pc58_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pc58_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pc58_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
static void setup_open_write_pc58_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_write_pc58_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pc58_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pc48_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pc48_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pc48_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_pc48_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pc48_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pc58_0_proc1
// static void setup_open_write_pc48_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pc48_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pc2_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_pc2_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_pc2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pda_0_common
// static void setup_open_write_pc2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pc2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pc2_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pc2_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pbf8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pbf8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
static void setup_open_write_pbf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_pbf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_pbf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_pbf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pbf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pbe8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pbe8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pbe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_pbe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_pbe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pbe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pbe8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pbd0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pbd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
static void setup_open_write_pbd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_pbd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_pbd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pbd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pbd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pbb8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pbb8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pbb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_write_pbb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pcdc_0_proc0
// static void setup_open_write_pbb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pbb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pbb8_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pb4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pb4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
static void setup_open_write_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_open_write_pb4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pb4_0_final(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal
// static void setup_open_write_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_paf8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_paf8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
static void setup_open_write_paf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_paf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_paf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_paf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_paf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pae8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pae8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pae8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_pae8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pae8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_pae8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pae8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pad0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pad0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
static void setup_open_write_pad0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_pad0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_pad0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_pad0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pab0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pab0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pab0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_open_write_pab0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pab0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pfa_0_proc0
// static void setup_open_write_pab0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pa90_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pa90_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_pa90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_write_pa90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
static void setup_open_write_pa90_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_open_write_pa90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_pa90_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_pa4_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pdfc_0_0
// static int test_open_write_pa4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_pa4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_write_pb4_0_common
// static void setup_open_write_pa4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pa4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_pa4_0_final(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal
// static void setup_open_write_pa4_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p9f8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p9f8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
static void setup_open_write_p9f8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_p9f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_p9f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_p9f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p9f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p9e8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p9e8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p9e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_write_pbe8_0_common
// static void setup_open_write_p9e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_p9e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p9e8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p9e8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p9d0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p9d0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p9d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_write_pbd0_0_common
// static void setup_open_write_p9d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_p9d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p9d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p9d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p9b8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p9b8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p9b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_write_pbb8_0_common
// static void setup_open_write_p9b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pcdc_0_proc0
// static void setup_open_write_p9b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p9b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p9b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p990_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p990_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_p990_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_write_p990_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pcdc_0_proc0
// static void setup_open_write_p990_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p990_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p990_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p94_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p94_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p94_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_write_pb4_0_common
// static void setup_open_write_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p94_0_final(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal
// static void setup_open_write_p94_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p8f8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p8f8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
static void setup_open_write_p8f8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_p8f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_p8f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_p8f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p8f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p8e8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p8e8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_p8e8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_p8e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p8e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_p8e8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p8e8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p8d0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p8d0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
static void setup_open_write_p8d0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p8d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_p8d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p8d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p8b0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p8b0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_p8b0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_open_write_p8b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p8b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pcdc_0_proc0
// static void setup_open_write_p8b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p8b0_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p890_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p890_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_write_pa90_0_common
// static void setup_open_write_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pa90_0_proc1
// static void setup_open_write_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p890_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p84_0_0(void) {
//   int r = open("__f0", O_RDWR | O_CREAT, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_pcfc_0_0
// static int test_open_write_p84_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p84_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_write_pb4_0_common
// static void setup_open_write_p84_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p84_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p84_0_final(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal
// static void setup_open_write_p84_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
static int test_open_write_p7f8_0_0(void) {
  int r = open("__f0", O_RDWR | O_TRUNC, 0666);
  
  return xerrno(r);
}
// static int test_open_write_p7f8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
// static void setup_open_write_p7f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pdfc_0_common
// static void setup_open_write_p7f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_p7f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_p7f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p7f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p7e8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p7f8_0_0
// static int test_open_write_p7e8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_p7e8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_p7e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_p7e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p7e8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p7e8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p7d0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p7f8_0_0
// static int test_open_write_p7d0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p7d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pd74_0_common
// static void setup_open_write_p7d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_p7d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p7d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p7d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p7bc_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p7f8_0_0
// static int test_open_write_p7bc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_p7bc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_p7bc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pdde_0_proc0
// static void setup_open_write_p7bc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p7bc_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_write_pdde_0_final
// static void setup_open_write_p7bc_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p74_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p7f8_0_0
// static int test_open_write_p74_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pda_0_common
// static void setup_open_write_p74_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p74_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p74_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p6f8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p7f8_0_0
// static int test_open_write_p6f8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
// static void setup_open_write_p6f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pd74_0_common
// static void setup_open_write_p6f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_p6f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_p6f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p6f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p6e8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p7f8_0_0
// static int test_open_write_p6e8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_p6e8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_p6e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p6e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_p6e8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p6e8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p6d0_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p7f8_0_0
// static int test_open_write_p6d0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p6d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pd68_0_common
// static void setup_open_write_p6d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p6d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_p6d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p6d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p6b8_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p7f8_0_0
// static int test_open_write_p6b8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p6b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pd5c_0_common
// static void setup_open_write_p6b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p6b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pdde_0_proc0
// static void setup_open_write_p6b8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_write_pdde_0_final
// static void setup_open_write_p6b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p690_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p7f8_0_0
// static int test_open_write_p690_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_p690_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_p690_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p690_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pdde_0_proc0
// static void setup_open_write_p690_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_open_write_pdde_0_final
// static void setup_open_write_p690_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p64_0_0(void) {
//   int r = open("__f0", O_RDWR | O_TRUNC, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p7f8_0_0
// static int test_open_write_p64_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pd2_0_common
// static void setup_open_write_p64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p64_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p64_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
static int test_open_write_p5f8_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  
  return xerrno(r);
}
// static int test_open_write_p5f8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
static void setup_open_write_p5f8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_open_write_p5f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_p5f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_p5f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p5f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p5e8_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p5e8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p5e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pff_0_common
// static void setup_open_write_p5e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_p5e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p5e8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p5e8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p5d_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p5d_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p5d_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pce8_0_common
// static void setup_open_write_p5d_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_p5d_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p5d_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p5d_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p5b8_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p5b8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p5b8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pcdc_0_common
// static void setup_open_write_p5b8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pcdc_0_proc0
// static void setup_open_write_p5b8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p5b8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p5b8_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p598_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p598_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p598_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pccc_0_common
// static void setup_open_write_p598_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pcdc_0_proc0
// static void setup_open_write_p598_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p598_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p598_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p54_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p54_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p54_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pda_0_common
// static void setup_open_write_p54_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p54_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p54_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p54_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p4f8_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p4f8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
// static void setup_open_write_p4f8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pc7c_0_common
// static void setup_open_write_p4f8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_p4f8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_p4f8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p4f8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p4e8_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p4e8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p4e8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pff_0_common
// static void setup_open_write_p4e8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p4e8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_p4e8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p4e8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p4d_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p4d_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p4d_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pff_0_common
// static void setup_open_write_p4d_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p4d_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_p4d_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p4d_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p4b0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p4b0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p4b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pc58_0_common
// static void setup_open_write_p4b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p4b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pc58_0_proc1
// static void setup_open_write_p4b0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p4b0_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p490_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p490_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p490_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pc48_0_common
// static void setup_open_write_p490_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p490_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pc58_0_proc1
// static void setup_open_write_p490_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p490_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p44_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   
//   return xerrno(r);
// }
// ^ See test_open_write_p5f8_0_0
// static int test_open_write_p44_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p44_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_open_write_pda_0_common
// static void setup_open_write_p44_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p44_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p44_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p44_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
static int test_open_write_p3e_0_0(void) {
  int r = open("__f0", O_RDWR, 0666);
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_open_write_p3e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
static void setup_open_write_p3e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_p3e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_p3e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_p3e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p3e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p3c_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
static void setup_open_write_p3c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p38_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
static void setup_open_write_p38_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_open_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p34_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p34_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_write_pab0_0_common
// static void setup_open_write_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pfa_0_proc0
// static void setup_open_write_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p34_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p34_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p30_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_write_p8b0_0_common
// static void setup_open_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pfa_0_proc0
// static void setup_open_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p30_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p30_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p2_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p2_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p2_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_write_pb4_0_common
// static void setup_open_write_p2_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p2_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p2_0_final(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal
// static void setup_open_write_p2_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p1e_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p1e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pff_0_1
// static void setup_open_write_p1e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_write_p3e_0_common
// static void setup_open_write_p1e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc1
// static void setup_open_write_p1e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pff_0_proc0
// static void setup_open_write_p1e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p1e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p1c_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p1c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p1c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_write_p3c_0_common
// static void setup_open_write_p1c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p1c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc0
// static void setup_open_write_p1c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p1c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p18_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p18_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p18_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_open_write_p38_0_common
// static void setup_open_write_p18_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfe_0_proc1
// static void setup_open_write_p18_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_open_write_pfc_0_proc0
// static void setup_open_write_p18_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_final
// static void setup_open_write_p18_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_open_write_pff_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p14_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p14_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p14_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_open_write_pab0_0_common
// static void setup_open_write_p14_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p14_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pfa_0_proc0
// static void setup_open_write_p14_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p14_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p10_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p10_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfe_0_1
// static void setup_open_write_p10_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_open_write_p8b0_0_common
// static void setup_open_write_p10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_open_write_pfa_0_proc0
// static void setup_open_write_p10_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_open_write_pfa_0_final
// static void setup_open_write_p10_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal

/*
 * calls: open write
 */
// static int test_open_write_p0_0_0(void) {
//   int r = open("__f0", O_RDWR, 0666);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_open_write_p3e_0_0
// static int test_open_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_open_write_pfc_0_1
// static void setup_open_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_open_write_pb4_0_common
// static void setup_open_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_open_write_pfa_0_proc1
// static void setup_open_write_p0_0_final(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal
// static void setup_open_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_open_write_pfa_0_procfinal


/*
 * calls: pipe pipe
 */
static int test_pipe_pipe_p78_0_0(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_pipe_pipe_p78_0_1(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_pipe_pipe_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_pipe_pipe_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_pipe_p78_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_pipe_p78_0_final(void) {
  
}
static void setup_pipe_pipe_p78_0_procfinal(void) {
  
}


/*
 * calls: pipe pread
 */
static int test_pipe_pread_pfc_0_0(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_pipe_pread_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pipe_pread_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pipe_pread_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pipe_pread_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pipe_pread_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pipe_pread_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_pfc_1_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
// static int test_pipe_pread_pfc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_pread_pfc_0_1
// static void setup_pipe_pread_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pipe_pread_pfc_0_common
static void setup_pipe_pread_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pipe_pread_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_pread_pfc_0_proc1
// static void setup_pipe_pread_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pread_pfc_0_final
// static void setup_pipe_pread_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pread_pfc_0_procfinal

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_pdc_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
static int test_pipe_pread_pdc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pipe_pread_pdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pipe_pread_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pipe_pread_pdc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_pread_pdc_0_final(void) {
  unlink("__i0");
}
static void setup_pipe_pread_pdc_0_procfinal(void) {
  
}

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_pdc_1_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
static int test_pipe_pread_pdc_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 5087232);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pipe_pread_pdc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pipe_pread_pdc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pipe_pread_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pread_pdc_0_proc1
// static void setup_pipe_pread_pdc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_pread_pdc_0_final
// static void setup_pipe_pread_pdc_1_procfinal(void) {
//   
// }
// ^ See setup_pipe_pread_pdc_0_procfinal

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_pb0_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
static int test_pipe_pread_pb0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pipe_pread_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pipe_pread_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pread_pdc_0_proc1
// static void setup_pipe_pread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pread_pdc_0_proc1
// static void setup_pipe_pread_pb0_0_final(void) {
//   
// }
// ^ See setup_pipe_pread_pdc_0_procfinal
// static void setup_pipe_pread_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_pread_pdc_0_procfinal

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_p78_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
// static int test_pipe_pread_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_pread_pfc_0_1
static void setup_pipe_pread_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pipe_pread_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_pread_pfc_0_proc1
// static void setup_pipe_pread_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_pread_pfc_0_proc0
// static void setup_pipe_pread_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pread_pfc_0_final
// static void setup_pipe_pread_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pread_pfc_0_procfinal

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_p78_1_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
// static int test_pipe_pread_p78_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_pread_pfc_0_1
// static void setup_pipe_pread_p78_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pipe_pread_p78_0_common
// static void setup_pipe_pread_p78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_pread_pfc_0_proc1
// static void setup_pipe_pread_p78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_pread_pfc_1_proc0
// static void setup_pipe_pread_p78_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pread_pfc_0_final
// static void setup_pipe_pread_p78_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pread_pfc_0_procfinal

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_p5c_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
// static int test_pipe_pread_p5c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_pread_pdc_0_1
// static void setup_pipe_pread_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pipe_pread_pdc_0_common
// static void setup_pipe_pread_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pread_pdc_0_proc1
// static void setup_pipe_pread_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pipe_pread_pdc_0_proc0
// static void setup_pipe_pread_p5c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_pread_pdc_0_final
// static void setup_pipe_pread_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_pread_pdc_0_procfinal

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_p5c_1_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
// static int test_pipe_pread_p5c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5087232);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_pread_pdc_1_1
// static void setup_pipe_pread_p5c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pipe_pread_pdc_1_common
// static void setup_pipe_pread_p5c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pread_pdc_0_proc1
// static void setup_pipe_pread_p5c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5087232, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pipe_pread_pdc_1_proc0
// static void setup_pipe_pread_p5c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_pread_pdc_0_final
// static void setup_pipe_pread_p5c_1_procfinal(void) {
//   
// }
// ^ See setup_pipe_pread_pdc_0_procfinal

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_p4c_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
static int test_pipe_pread_p4c_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pipe_pread_p4c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pipe_pread_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pread_pdc_0_proc1
// static void setup_pipe_pread_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pipe_pread_pdc_0_proc0
// static void setup_pipe_pread_p4c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_pread_pdc_0_final
// static void setup_pipe_pread_p4c_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_pread_pdc_0_procfinal

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_p4c_1_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
static int test_pipe_pread_p4c_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 20480);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_pipe_pread_p4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pipe_pread_pdc_1_common
// static void setup_pipe_pread_p4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pread_pdc_0_proc1
// static void setup_pipe_pread_p4c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pipe_pread_pdc_0_proc0
// static void setup_pipe_pread_p4c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_pread_pdc_0_final
// static void setup_pipe_pread_p4c_1_procfinal(void) {
//   
// }
// ^ See setup_pipe_pread_pdc_0_procfinal

/*
 * calls: pipe pread
 */
// static int test_pipe_pread_p30_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pread_pfc_0_0
// static int test_pipe_pread_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_pread_pb0_0_1
// static void setup_pipe_pread_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pipe_pread_pb0_0_common
// static void setup_pipe_pread_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pread_pdc_0_proc1
// static void setup_pipe_pread_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pread_pdc_0_proc1
// static void setup_pipe_pread_p30_0_final(void) {
//   
// }
// ^ See setup_pipe_pread_pdc_0_procfinal
// static void setup_pipe_pread_p30_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_pread_pdc_0_procfinal


/*
 * calls: pipe pwrite
 */
static int test_pipe_pwrite_pfc_0_0(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_pipe_pwrite_pfc_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_pipe_pwrite_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pipe_pwrite_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pipe_pwrite_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pipe_pwrite_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pipe_pwrite_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_pfc_1_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
// static int test_pipe_pwrite_pfc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_1
// static void setup_pipe_pwrite_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pipe_pwrite_pfc_0_common
static void setup_pipe_pwrite_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pipe_pwrite_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_pwrite_pfc_0_proc1
// static void setup_pipe_pwrite_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pwrite_pfc_0_final
// static void setup_pipe_pwrite_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pwrite_pfc_0_procfinal

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_pdc_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
static int test_pipe_pwrite_pdc_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pipe_pwrite_pdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pipe_pwrite_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1150976, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pipe_pwrite_pdc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_pwrite_pdc_0_final(void) {
  unlink("__i0");
}
static void setup_pipe_pwrite_pdc_0_procfinal(void) {
  
}

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_pdc_1_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
static int test_pipe_pwrite_pdc_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pipe_pwrite_pdc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pipe_pwrite_pdc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pipe_pwrite_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pwrite_pdc_0_proc1
// static void setup_pipe_pwrite_pdc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_pwrite_pdc_0_final
// static void setup_pipe_pwrite_pdc_1_procfinal(void) {
//   
// }
// ^ See setup_pipe_pwrite_pdc_0_procfinal

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_pb0_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
static int test_pipe_pwrite_pb0_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
static void setup_pipe_pwrite_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pipe_pwrite_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pwrite_pdc_0_proc1
// static void setup_pipe_pwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pwrite_pdc_0_proc1
// static void setup_pipe_pwrite_pb0_0_final(void) {
//   
// }
// ^ See setup_pipe_pwrite_pdc_0_procfinal
// static void setup_pipe_pwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_pwrite_pdc_0_procfinal

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_p78_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
// static int test_pipe_pwrite_p78_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_1
static void setup_pipe_pwrite_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pipe_pwrite_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_pwrite_pfc_0_proc1
// static void setup_pipe_pwrite_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_pwrite_pfc_0_proc0
// static void setup_pipe_pwrite_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pwrite_pfc_0_final
// static void setup_pipe_pwrite_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pwrite_pfc_0_procfinal

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_p78_1_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
// static int test_pipe_pwrite_p78_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_1
// static void setup_pipe_pwrite_p78_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pipe_pwrite_p78_0_common
// static void setup_pipe_pwrite_p78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_pwrite_pfc_0_proc1
// static void setup_pipe_pwrite_p78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_pwrite_pfc_1_proc0
// static void setup_pipe_pwrite_p78_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pwrite_pfc_0_final
// static void setup_pipe_pwrite_p78_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_pwrite_pfc_0_procfinal

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_p5c_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
// static int test_pipe_pwrite_p5c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pdc_0_1
// static void setup_pipe_pwrite_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pipe_pwrite_pdc_0_common
// static void setup_pipe_pwrite_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pwrite_pdc_0_proc1
static void setup_pipe_pwrite_p5c_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2494464, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pipe_pwrite_p5c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_pwrite_pdc_0_final
// static void setup_pipe_pwrite_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_pwrite_pdc_0_procfinal

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_p5c_1_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
// static int test_pipe_pwrite_p5c_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pdc_1_1
// static void setup_pipe_pwrite_p5c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pipe_pwrite_pdc_1_common
// static void setup_pipe_pwrite_p5c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pwrite_pdc_0_proc1
// static void setup_pipe_pwrite_p5c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pipe_pwrite_pdc_1_proc0
// static void setup_pipe_pwrite_p5c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_pwrite_pdc_0_final
// static void setup_pipe_pwrite_p5c_1_procfinal(void) {
//   
// }
// ^ See setup_pipe_pwrite_pdc_0_procfinal

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_p4c_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
// static int test_pipe_pwrite_p4c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pdc_0_1
static void setup_pipe_pwrite_p4c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pipe_pwrite_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pwrite_pdc_0_proc1
static void setup_pipe_pwrite_p4c_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pipe_pwrite_p4c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_pwrite_pdc_0_final
// static void setup_pipe_pwrite_p4c_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_pwrite_pdc_0_procfinal

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_p4c_1_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
static int test_pipe_pwrite_p4c_1_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pipe_pwrite_p4c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pipe_pwrite_pdc_1_common
// static void setup_pipe_pwrite_p4c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pwrite_pdc_0_proc1
static void setup_pipe_pwrite_p4c_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pipe_pwrite_p4c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_pwrite_pdc_0_final
// static void setup_pipe_pwrite_p4c_1_procfinal(void) {
//   
// }
// ^ See setup_pipe_pwrite_pdc_0_procfinal

/*
 * calls: pipe pwrite
 */
// static int test_pipe_pwrite_p30_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pfc_0_0
// static int test_pipe_pwrite_p30_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pipe_pwrite_pb0_0_1
// static void setup_pipe_pwrite_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pipe_pwrite_pb0_0_common
// static void setup_pipe_pwrite_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pwrite_pdc_0_proc1
// static void setup_pipe_pwrite_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_pwrite_pdc_0_proc1
// static void setup_pipe_pwrite_p30_0_final(void) {
//   
// }
// ^ See setup_pipe_pwrite_pdc_0_procfinal
// static void setup_pipe_pwrite_p30_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_pwrite_pdc_0_procfinal


/*
 * calls: pipe read
 */
static int test_pipe_read_pfe_0_0(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_pipe_read_pfe_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pipe_read_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pipe_read_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pipe_read_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pipe_read_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pipe_read_pfe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pipe read
 */
// static int test_pipe_read_pf6_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_pf6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_pfe_0_1
static void setup_pipe_read_pf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_pipe_read_pf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_read_pf6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_read_pf6_0_final(void) {
  
}
static void setup_pipe_read_pf6_0_procfinal(void) {
  
}

/*
 * calls: pipe read
 */
// static int test_pipe_read_pef8_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
static int test_pipe_read_pef8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pipe_read_pef8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pipe_read_pef8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pipe_read_pef8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_pfe_0_proc1
// static void setup_pipe_read_pef8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_final
// static void setup_pipe_read_pef8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_peb0_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
static int test_pipe_read_peb0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pipe_read_peb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pipe_read_peb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_pipe_read_peb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pipe_read_peb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_final
// static void setup_pipe_read_peb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_pe6_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
static int test_pipe_read_pe6_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pipe_read_pe6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pipe_read_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_pef8_0_proc0
// static void setup_pipe_read_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_pfe_0_proc1
// static void setup_pipe_read_pe6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_final
// static void setup_pipe_read_pe6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_pdc_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_pdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_peb0_0_1
static void setup_pipe_read_pdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pipe_read_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pipe_read_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_read_pf6_0_proc1
static void setup_pipe_read_pdc_0_final(void) {
  unlink("__i0");
}
// static void setup_pipe_read_pdc_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_read_pf6_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_pcc_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_pcc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_pe6_0_1
static void setup_pipe_read_pcc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pipe_read_pcc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pipe_read_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_read_pf6_0_proc1
// static void setup_pipe_read_pcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_read_pdc_0_final
// static void setup_pipe_read_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_read_pf6_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_pb0_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_pfe_0_1
// static void setup_pipe_read_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pipe_read_pf6_0_common
// static void setup_pipe_read_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_read_pf6_0_proc1
// static void setup_pipe_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_read_pf6_0_proc1
// static void setup_pipe_read_pb0_0_final(void) {
//   
// }
// ^ See setup_pipe_read_pf6_0_procfinal
// static void setup_pipe_read_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_read_pf6_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_p7c_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_p7c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_pfe_0_1
static void setup_pipe_read_p7c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pipe_read_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_pfe_0_proc1
// static void setup_pipe_read_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_pfe_0_proc0
// static void setup_pipe_read_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_final
// static void setup_pipe_read_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_p6f0_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_p6f0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_pef8_0_1
static void setup_pipe_read_p6f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pipe_read_p6f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_pfe_0_proc1
// static void setup_pipe_read_p6f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_pef8_0_proc0
// static void setup_pipe_read_p6f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_final
// static void setup_pipe_read_p6f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_p6b0_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_p6b0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_peb0_0_1
// static void setup_pipe_read_p6b0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pipe_read_pef8_0_common
// static void setup_pipe_read_p6b0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_peb0_0_proc1
// static void setup_pipe_read_p6b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_peb0_0_proc0
// static void setup_pipe_read_p6b0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_final
// static void setup_pipe_read_p6b0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_p66_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_p66_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_pe6_0_1
// static void setup_pipe_read_p66_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pipe_read_pe6_0_common
// static void setup_pipe_read_p66_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_pfe_0_proc1
// static void setup_pipe_read_p66_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_read_pef8_0_proc0
// static void setup_pipe_read_p66_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_final
// static void setup_pipe_read_p66_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_read_pfe_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_p5c_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_p5c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_peb0_0_1
static void setup_pipe_read_p5c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pipe_read_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_read_pf6_0_proc1
// static void setup_pipe_read_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pipe_read_pdc_0_proc0
// static void setup_pipe_read_p5c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_read_pdc_0_final
// static void setup_pipe_read_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_read_pf6_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_p4c_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_p4c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_pe6_0_1
// static void setup_pipe_read_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pipe_read_pcc_0_common
// static void setup_pipe_read_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_read_pf6_0_proc1
// static void setup_pipe_read_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pipe_read_pcc_0_proc0
// static void setup_pipe_read_p4c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_read_pdc_0_final
// static void setup_pipe_read_p4c_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_read_pf6_0_procfinal

/*
 * calls: pipe read
 */
// static int test_pipe_read_p30_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_read_pfe_0_0
// static int test_pipe_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pipe_read_pfe_0_1
// static void setup_pipe_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pipe_read_pf6_0_common
// static void setup_pipe_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_read_pf6_0_proc1
// static void setup_pipe_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_read_pf6_0_proc1
// static void setup_pipe_read_p30_0_final(void) {
//   
// }
// ^ See setup_pipe_read_pf6_0_procfinal
// static void setup_pipe_read_p30_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_read_pf6_0_procfinal


/*
 * calls: pipe rename
 */
static int test_pipe_rename_pf0_0_0(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_pipe_rename_pf0_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_pipe_rename_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pipe_rename_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_rename_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_rename_pf0_0_final(void) {
  unlink("__i0");
}
static void setup_pipe_rename_pf0_0_procfinal(void) {
  
}

/*
 * calls: pipe rename
 */
// static int test_pipe_rename_pb8_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_rename_pf0_0_0
static int test_pipe_rename_pb8_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_pipe_rename_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_pipe_rename_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_rename_pf0_0_proc1
// static void setup_pipe_rename_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_rename_pf0_0_proc1
// static void setup_pipe_rename_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_rename_pf0_0_final
// static void setup_pipe_rename_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_rename_pf0_0_procfinal

/*
 * calls: pipe rename
 */
// static int test_pipe_rename_p98_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_rename_pf0_0_0
// static int test_pipe_rename_p98_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_rename_pb8_0_1
// static void setup_pipe_rename_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pipe_rename_pf0_0_common
// static void setup_pipe_rename_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_rename_pf0_0_proc1
// static void setup_pipe_rename_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_rename_pf0_0_proc1
// static void setup_pipe_rename_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_rename_pf0_0_final
// static void setup_pipe_rename_p98_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_rename_pf0_0_procfinal

/*
 * calls: pipe rename
 */
// static int test_pipe_rename_p6_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_rename_pf0_0_0
static int test_pipe_rename_p6_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_pipe_rename_p6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pipe_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_rename_pf0_0_proc1
// static void setup_pipe_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_rename_pf0_0_proc1
// static void setup_pipe_rename_p6_0_final(void) {
//   
// }
// ^ See setup_pipe_rename_pf0_0_procfinal
// static void setup_pipe_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_rename_pf0_0_procfinal


/*
 * calls: pipe stat
 */
static int test_pipe_stat_pe_0_0(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_pipe_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_pipe_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pipe_stat_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_stat_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_stat_pe_0_final(void) {
  unlink("__i0");
}
static void setup_pipe_stat_pe_0_procfinal(void) {
  
}

/*
 * calls: pipe stat
 */
// static int test_pipe_stat_p6_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_stat_pe_0_0
static int test_pipe_stat_p6_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_pipe_stat_p6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pipe_stat_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_stat_pe_0_proc1
// static void setup_pipe_stat_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_stat_pe_0_proc1
// static void setup_pipe_stat_p6_0_final(void) {
//   
// }
// ^ See setup_pipe_stat_pe_0_procfinal
// static void setup_pipe_stat_p6_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_stat_pe_0_procfinal


/*
 * calls: pipe unlink
 */
static int test_pipe_unlink_pe_0_0(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_pipe_unlink_pe_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_pipe_unlink_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pipe_unlink_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_unlink_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_unlink_pe_0_final(void) {
  unlink("__i0");
}
static void setup_pipe_unlink_pe_0_procfinal(void) {
  
}

/*
 * calls: pipe unlink
 */
// static int test_pipe_unlink_p6_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_unlink_pe_0_0
static int test_pipe_unlink_p6_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_pipe_unlink_p6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pipe_unlink_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_unlink_pe_0_proc1
// static void setup_pipe_unlink_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_unlink_pe_0_proc1
// static void setup_pipe_unlink_p6_0_final(void) {
//   
// }
// ^ See setup_pipe_unlink_pe_0_procfinal
// static void setup_pipe_unlink_p6_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_unlink_pe_0_procfinal


/*
 * calls: pipe write
 */
static int test_pipe_write_pfe_0_0(void) {
  int fds[2];
  int r = pipe(fds);
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_pipe_write_pfe_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pipe_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pipe_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pipe_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pipe_write_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pipe_write_pfe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pipe write
 */
// static int test_pipe_write_pf70_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
static int test_pipe_write_pf70_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pipe_write_pf70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pipe_write_pf70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pipe_write_pf70_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pipe_write_pf70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_write_pfe_0_final
// static void setup_pipe_write_pf70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_write_pfe_0_procfinal

/*
 * calls: pipe write
 */
// static int test_pipe_write_pee_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
static int test_pipe_write_pee_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pipe_write_pee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pipe_write_pee_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pipe_write_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_write_pf70_0_proc1
// static void setup_pipe_write_pee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_write_pfe_0_final
// static void setup_pipe_write_pee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_write_pfe_0_procfinal

/*
 * calls: pipe write
 */
// static int test_pipe_write_pe6_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
// static int test_pipe_write_pe6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pipe_write_pee_0_1
static void setup_pipe_write_pe6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
static void setup_pipe_write_pe6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_write_pe6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pipe_write_pe6_0_final(void) {
  
}
static void setup_pipe_write_pe6_0_procfinal(void) {
  
}

/*
 * calls: pipe write
 */
// static int test_pipe_write_pdc_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
// static int test_pipe_write_pdc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pipe_write_pf70_0_1
static void setup_pipe_write_pdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pipe_write_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pipe_write_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_write_pe6_0_proc1
static void setup_pipe_write_pdc_0_final(void) {
  unlink("__i0");
}
// static void setup_pipe_write_pdc_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_write_pe6_0_procfinal

/*
 * calls: pipe write
 */
// static int test_pipe_write_pcc_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
// static int test_pipe_write_pcc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pipe_write_pf70_0_1
static void setup_pipe_write_pcc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pipe_write_pcc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pipe_write_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_write_pe6_0_proc1
// static void setup_pipe_write_pcc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_write_pdc_0_final
// static void setup_pipe_write_pcc_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_write_pe6_0_procfinal

/*
 * calls: pipe write
 */
// static int test_pipe_write_pb0_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
// static int test_pipe_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pipe_write_pee_0_1
// static void setup_pipe_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pipe_write_pe6_0_common
// static void setup_pipe_write_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_write_pe6_0_proc1
// static void setup_pipe_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_write_pe6_0_proc1
// static void setup_pipe_write_pb0_0_final(void) {
//   
// }
// ^ See setup_pipe_write_pe6_0_procfinal
// static void setup_pipe_write_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_write_pe6_0_procfinal

/*
 * calls: pipe write
 */
// static int test_pipe_write_p7e_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
// static int test_pipe_write_p7e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pipe_write_pfe_0_1
static void setup_pipe_write_p7e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pipe_write_p7e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_write_pfe_0_proc1
// static void setup_pipe_write_p7e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_write_pfe_0_proc0
// static void setup_pipe_write_p7e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_write_pfe_0_final
// static void setup_pipe_write_p7e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_write_pfe_0_procfinal

/*
 * calls: pipe write
 */
// static int test_pipe_write_p76_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
// static int test_pipe_write_p76_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pipe_write_pf70_0_1
static void setup_pipe_write_p76_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pipe_write_p76_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_write_pf70_0_proc1
// static void setup_pipe_write_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_write_pf70_0_proc0
// static void setup_pipe_write_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_write_pfe_0_final
// static void setup_pipe_write_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_write_pfe_0_procfinal

/*
 * calls: pipe write
 */
// static int test_pipe_write_p6c_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
// static int test_pipe_write_p6c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pipe_write_pee_0_1
static void setup_pipe_write_p6c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pipe_write_p6c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_write_pf70_0_proc1
// static void setup_pipe_write_p6c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pipe_write_pee_0_proc0
// static void setup_pipe_write_p6c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_write_pfe_0_final
// static void setup_pipe_write_p6c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pipe_write_pfe_0_procfinal

/*
 * calls: pipe write
 */
// static int test_pipe_write_p5c_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
// static int test_pipe_write_p5c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pipe_write_pf70_0_1
// static void setup_pipe_write_p5c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pipe_write_pdc_0_common
// static void setup_pipe_write_p5c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_write_pe6_0_proc1
// static void setup_pipe_write_p5c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pipe_write_pdc_0_proc0
// static void setup_pipe_write_p5c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_write_pdc_0_final
// static void setup_pipe_write_p5c_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_write_pe6_0_procfinal

/*
 * calls: pipe write
 */
// static int test_pipe_write_p4c_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
// static int test_pipe_write_p4c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pipe_write_pf70_0_1
// static void setup_pipe_write_p4c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pipe_write_pcc_0_common
// static void setup_pipe_write_p4c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_write_pe6_0_proc1
// static void setup_pipe_write_p4c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pipe_write_pcc_0_proc0
// static void setup_pipe_write_p4c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pipe_write_pdc_0_final
// static void setup_pipe_write_p4c_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_write_pe6_0_procfinal

/*
 * calls: pipe write
 */
// static int test_pipe_write_p30_0_0(void) {
//   int fds[2];
//   int r = pipe(fds);
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pipe_write_pfe_0_0
// static int test_pipe_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pipe_write_pee_0_1
// static void setup_pipe_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pipe_write_pe6_0_common
// static void setup_pipe_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_write_pe6_0_proc1
// static void setup_pipe_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pipe_write_pe6_0_proc1
// static void setup_pipe_write_p30_0_final(void) {
//   
// }
// ^ See setup_pipe_write_pe6_0_procfinal
// static void setup_pipe_write_p30_0_procfinal(void) {
//   
// }
// ^ See setup_pipe_write_pe6_0_procfinal


/*
 * calls: pread pread
 */
static int test_pread_pread_pf8_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pread_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pread_pread_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_pread_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_pread_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_pread_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pread_pread_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
static void setup_pread_pread_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pf8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
static void setup_pread_pread_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf8_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pf8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
static void setup_pread_pread_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf8_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pf8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
static void setup_pread_pread_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
static int test_pread_pread_pf4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pread_pread_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_pread_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf4_0_1
// static void setup_pread_pread_pf4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
static void setup_pread_pread_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf4_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pf4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf4_0_1
// static void setup_pread_pread_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
static void setup_pread_pread_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf4_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pf4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf4_0_1
// static void setup_pread_pread_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
static void setup_pread_pread_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
static int test_pread_pread_pf0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pread_pread_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_pread_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf0_0_1
// static void setup_pread_pread_pf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_0_common
static void setup_pread_pread_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf0_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pf0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf0_0_1
static void setup_pread_pread_pf0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_pread_pf0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf4_2_proc0
// static void setup_pread_pread_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pf0_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pf0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf0_0_1
// static void setup_pread_pread_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_2_common
// static void setup_pread_pread_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf4_3_proc0
// static void setup_pread_pread_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
static int test_pread_pread_pe_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_pread_pread_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
// static void setup_pread_pread_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pe_0_1
// static void setup_pread_pread_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
// static void setup_pread_pread_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
// static void setup_pread_pread_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
// static void setup_pread_pread_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pd8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
// static void setup_pread_pread_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd8_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pd8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
// static void setup_pread_pread_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
static int test_pread_pread_pd4_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_pread_pread_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
// static void setup_pread_pread_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
static void setup_pread_pread_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
// static void setup_pread_pread_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd4_0_proc1
// static void setup_pread_pread_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd4_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pd4_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
// static void setup_pread_pread_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
static void setup_pread_pread_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd4_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pd4_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
// static void setup_pread_pread_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd4_2_proc1
// static void setup_pread_pread_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
static int test_pread_pread_pd0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_pread_pread_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_0_common
// static void setup_pread_pread_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
static void setup_pread_pread_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_0_common
// static void setup_pread_pread_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd0_0_proc1
// static void setup_pread_pread_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd0_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pd0_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_2_common
// static void setup_pread_pread_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd4_2_proc1
// static void setup_pread_pread_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pd0_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pd0_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
static void setup_pread_pread_pd0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_pread_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd4_2_proc1
// static void setup_pread_pread_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
static int test_pread_pread_pc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_pread_pread_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
// static void setup_pread_pread_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static int test_pread_pread_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static void setup_pread_pread_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
// static void setup_pread_pread_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pbc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pbc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
static void setup_pread_pread_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pbc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pbc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
static void setup_pread_pread_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pbc_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pbc_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
static void setup_pread_pread_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pbc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pbc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pbc_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pbc_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
static void setup_pread_pread_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_pbc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pbc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pba_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pba_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf4_0_1
static void setup_pread_pread_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pread_pread_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_pread_pba_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pread_pread_pba_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_pread_pread_pba_0_procfinal(void) {
  
}

/*
 * calls: pread pread
 */
// static int test_pread_pread_pba_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pba_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf4_0_1
static void setup_pread_pread_pba_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pread_pread_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
static void setup_pread_pread_pba_1_final(void) {
  unlink("__i0");
}
// static void setup_pread_pread_pba_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pba_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pba_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf4_0_1
// static void setup_pread_pread_pba_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_0_common
static void setup_pread_pread_pba_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pba_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pba_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_pba_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pba_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pba_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf4_0_1
// static void setup_pread_pread_pba_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
static void setup_pread_pread_pba_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pba_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pba_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pba_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pba_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pba_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_pba_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
static void setup_pread_pread_pba_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pba_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pba_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pba_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pba_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pba_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_pba_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
static void setup_pread_pread_pba_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pba_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pba_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pba_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pb8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf0_0_1
static void setup_pread_pread_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pread_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pb8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
static int test_pread_pread_pb8_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pread_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf0_0_1
static void setup_pread_pread_pb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pread_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pb8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_1_0
static int test_pread_pread_pb8_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 8192);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pread_pread_pb8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pread_pb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_0_proc0
// static void setup_pread_pread_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pb8_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pb8_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_1_0
// static int test_pread_pread_pb8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 8192);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_2_1
// static void setup_pread_pread_pb8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_2_common
static void setup_pread_pread_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pb8_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
static int test_pread_pread_pb8_4_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 32768);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pread_pb8_4_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 28672);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pread_pread_pb8_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pread_pb8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pb8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pb8_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_1_0
// static int test_pread_pread_pb8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_pb8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
static void setup_pread_pread_pb8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pb8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pb8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pb8_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pb8_6_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 32768);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_4_0
static int test_pread_pread_pb8_6_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 28672);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_pread_pread_pb8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_4_common
static void setup_pread_pread_pb8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pb8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pb8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pb8_6_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pb8_7_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_1_0
static int test_pread_pread_pb8_7_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pread_pread_pb8_7_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pread_pb8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_3_proc0
// static void setup_pread_pread_pb8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pb8_7_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_pb8_7_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pe_0_1
// static void setup_pread_pread_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
// static void setup_pread_pread_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_4_proc0
// static void setup_pread_pread_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pb0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pe_0_1
// static void setup_pread_pread_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
// static void setup_pread_pread_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pac_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pac_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
// static void setup_pread_pread_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd4_0_proc1
// static void setup_pread_pread_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pac_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pac_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
// static void setup_pread_pread_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd4_0_proc1
// static void setup_pread_pread_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pac_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pac_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
// static void setup_pread_pread_pac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd4_2_proc1
// static void setup_pread_pread_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_pac_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pac_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pac_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pac_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf4_0_common
// static void setup_pread_pread_pac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd4_2_proc1
// static void setup_pread_pread_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_pac_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_pac_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_paa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_paa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_0_common
// static void setup_pread_pread_paa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_4_proc0
static void setup_pread_pread_paa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_paa_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_paa_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_paa_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_paa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_paa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
// static void setup_pread_pread_paa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_4_proc0
// static void setup_pread_pread_paa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_4_proc0
// static void setup_pread_pread_paa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_paa_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_paa_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_paa_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_paa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_0_common
// static void setup_pread_pread_paa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
static void setup_pread_pread_paa_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_paa_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_paa_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_paa_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_paa_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_paa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
// static void setup_pread_pread_paa_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_paa_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_paa_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_paa_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pa8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_0_common
static void setup_pread_pread_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_pread_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pa8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pa8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
static int test_pread_pread_pa8_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pread_pread_pa8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pread_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_pread_pa8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pa8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pa8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_1_0
// static int test_pread_pread_pa8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pa8_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_1_0
// static int test_pread_pread_pa8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
static void setup_pread_pread_pa8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pread_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_pread_pa8_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_pa8_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
static int test_pread_pread_pa8_4_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 8192);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pread_pa8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_pa8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_pa8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_4_proc0
// static void setup_pread_pread_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_4_proc0
// static void setup_pread_pread_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pa8_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pa8_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_pa8_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_0_common
// static void setup_pread_pread_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_paa_2_proc1
// static void setup_pread_pread_pa8_5_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pa0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static void setup_pread_pread_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
// static void setup_pread_pread_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_4_proc0
// static void setup_pread_pread_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_pa0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static int test_pread_pread_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static void setup_pread_pread_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
// static void setup_pread_pread_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p9c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_0_common
static void setup_pread_pread_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9c_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p9c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_0_common
static void setup_pread_pread_p9c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9c_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p9c_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_p9c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_2_common
// static void setup_pread_pread_p9c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pbc_2_proc0
// static void setup_pread_pread_p9c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_p9c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p9c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9c_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p9c_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_p9c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pd0_3_common
// static void setup_pread_pread_p9c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pbc_3_proc0
// static void setup_pread_pread_p9c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_p9c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p9c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9a_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p9a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf4_0_1
static void setup_pread_pread_p9a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pread_pread_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p9a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9a_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
static int test_pread_pread_p9a_1_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 4096);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_pread_pread_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p9a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_proc0
// static void setup_pread_pread_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9a_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
static int test_pread_pread_p9a_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 8192);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pread_pread_p9a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pread_p9a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_2_proc0
// static void setup_pread_pread_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p9a_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9a_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
static int test_pread_pread_p9a_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(11, data, 4096, 32768);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static void setup_pread_pread_p9a_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pread_p9a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p9a_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9a_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p9a_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_p9a_1_1
// static void setup_pread_pread_p9a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p9a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_3_proc0
// static void setup_pread_pread_p9a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p9a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p9a_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9a_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p9a_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_1_0
// static void setup_pread_pread_p9a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p9a_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_p9a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p9a_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p9a_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p9a_6_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p9a_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_1_0
// static void setup_pread_pread_p9a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p9a_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_p9a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p9a_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p9a_6_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p98_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf0_0_1
// static void setup_pread_pread_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_proc0
// static void setup_pread_pread_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p98_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p98_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p98_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p98_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p98_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p98_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf0_0_1
// static void setup_pread_pread_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p98_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_3_proc0
// static void setup_pread_pread_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p98_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p98_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p98_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p98_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p98_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p98_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p90_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pe_0_1
// static void setup_pread_pread_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p90_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pe_0_1
// static void setup_pread_pread_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p8c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p8c_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_0_common
// static void setup_pread_pread_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd0_0_proc1
// static void setup_pread_pread_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p8c_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p8c_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_0_common
// static void setup_pread_pread_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd0_0_proc1
// static void setup_pread_pread_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p8c_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p8c_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_p8c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf0_2_common
// static void setup_pread_pread_p8c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd4_2_proc1
// static void setup_pread_pread_p8c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_p8c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p8c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p8c_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p8c_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_p8c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pd0_3_common
// static void setup_pread_pread_p8c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pd4_2_proc1
// static void setup_pread_pread_p8c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_p8c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p8c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p8a_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p8a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_p9a_0_common
// static void setup_pread_pread_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
static void setup_pread_pread_p8a_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_p8a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p8a_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p8a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pb8_1_0
// static void setup_pread_pread_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
static int test_pread_pread_p8a_2_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pread_p8a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
static void setup_pread_pread_p8a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_pread_pread_p8a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pa8_3_proc0
// static void setup_pread_pread_p8a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pa8_3_proc1
// static void setup_pread_pread_p8a_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
static int test_pread_pread_p8a_3_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 12288);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pread_p8a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pa8_4_0
static void setup_pread_pread_p8a_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pread_p8a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_p8a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_paa_0_proc1
// static void setup_pread_pread_p8a_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pread_pba_0_final
// static void setup_pread_pread_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p8a_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
static int test_pread_pread_p8a_4_1(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 5066752);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static void setup_pread_pread_p8a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
static void setup_pread_pread_p8a_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5066752, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_pread_p8a_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5066752, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_p8a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p8a_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p88_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p88_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p88_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p88_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p88_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p88_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static void setup_pread_pread_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p80_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static int test_pread_pread_p80_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static void setup_pread_pread_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p7_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
static void setup_pread_pread_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p7_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p7_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_1
// static void setup_pread_pread_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
static void setup_pread_pread_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pread_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p68_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf4_0_1
// static void setup_pread_pread_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
static void setup_pread_pread_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p68_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p68_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p68_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf4_0_1
// static void setup_pread_pread_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
static void setup_pread_pread_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p68_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p60_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf0_0_1
// static void setup_pread_pread_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
static void setup_pread_pread_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pread_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p60_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p60_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p60_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf0_0_1
// static void setup_pread_pread_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_p68_1_proc0
// static void setup_pread_pread_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p60_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(11, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pe_0_1
static void setup_pread_pread_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pread_pread_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p4_0_final(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal
// static void setup_pread_pread_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static void setup_pread_pread_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pread_pread_p4_0_common
// static void setup_pread_pread_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p4_1_final(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal
// static void setup_pread_pread_p4_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p3_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p3_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
// static void setup_pread_pread_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_3_proc0
// static void setup_pread_pread_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p3_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p3_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pf8_0_0
// static void setup_pread_pread_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pread_pf8_0_common
// static void setup_pread_pread_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_0_proc1
// static void setup_pread_pread_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pread_pf8_4_proc0
// static void setup_pread_pread_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_final
// static void setup_pread_pread_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pread_pf8_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p28_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
// static void setup_pread_pread_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_4_proc0
// static void setup_pread_pread_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p28_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p28_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p28_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd4_0_1
// static void setup_pread_pread_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_1_common
// static void setup_pread_pread_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p28_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p20_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_5_proc0
// static void setup_pread_pread_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p20_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p20_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p20_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pd0_0_1
// static void setup_pread_pread_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pread_pb8_1_common
// static void setup_pread_pread_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pread_pba_5_proc0
// static void setup_pread_pread_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pread_pba_1_final
// static void setup_pread_pread_p20_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal

/*
 * calls: pread pread
 */
// static int test_pread_pread_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static int test_pread_pread_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pread_pc_0_1
// static void setup_pread_pread_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pread_pread_p4_0_common
// static void setup_pread_pread_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pread_pba_0_proc1
// static void setup_pread_pread_p0_0_final(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal
// static void setup_pread_pread_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pread_pba_0_procfinal


/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_pf8_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pwrite_pf8_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_pread_pwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_pwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_pwrite_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_pwrite_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pread_pwrite_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pf8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
// static void setup_pread_pwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
static void setup_pread_pwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pf8_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
// static void setup_pread_pwrite_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
static void setup_pread_pwrite_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf8_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
static int test_pread_pwrite_pf8_3_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
// static void setup_pread_pwrite_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
static void setup_pread_pwrite_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf8_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pf8_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
static void setup_pread_pwrite_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
static int test_pread_pwrite_pf4_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_pwrite_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pf4_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
static void setup_pread_pwrite_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_pwrite_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf4_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pf4_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
// static void setup_pread_pwrite_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf4_1_common
static void setup_pread_pwrite_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf4_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pf4_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
// static void setup_pread_pwrite_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf4_1_common
static void setup_pread_pwrite_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pf0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
static void setup_pread_pwrite_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_pwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pf0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
static void setup_pread_pwrite_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_pwrite_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf4_1_proc0
// static void setup_pread_pwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf0_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pf0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
// static void setup_pread_pwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf0_1_common
static void setup_pread_pwrite_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pf0_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pf0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
static void setup_pread_pwrite_pf0_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_pwrite_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf4_3_proc0
// static void setup_pread_pwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
static int test_pread_pwrite_pe_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_pread_pwrite_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
// static void setup_pread_pwrite_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pe_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pe_0_1
// static void setup_pread_pwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
// static void setup_pread_pwrite_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
// static void setup_pread_pwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
// static void setup_pread_pwrite_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
// static void setup_pread_pwrite_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd8_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
// static void setup_pread_pwrite_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
static int test_pread_pwrite_pd4_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pread_pwrite_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf4_0_common
// static void setup_pread_pwrite_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
static void setup_pread_pwrite_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf4_1_common
// static void setup_pread_pwrite_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
static void setup_pread_pwrite_pd4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd4_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd4_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf4_1_common
// static void setup_pread_pwrite_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
static void setup_pread_pwrite_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd4_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd4_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf4_0_common
// static void setup_pread_pwrite_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pd4_1_proc1
// static void setup_pread_pwrite_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf0_0_common
// static void setup_pread_pwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
static void setup_pread_pwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf0_1_common
// static void setup_pread_pwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pd4_1_proc1
// static void setup_pread_pwrite_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd0_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf0_1_common
// static void setup_pread_pwrite_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pd4_0_proc1
// static void setup_pread_pwrite_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pd0_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pd0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf0_1_common
// static void setup_pread_pwrite_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pd4_1_proc1
// static void setup_pread_pwrite_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
static int test_pread_pwrite_pc_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_pread_pwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
// static void setup_pread_pwrite_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pf8_0_0
// static int test_pread_pwrite_pc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pc_0_1
// static void setup_pread_pwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
// static void setup_pread_pwrite_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_pbc_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pwrite_pbc_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
static void setup_pread_pwrite_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_pwrite_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pbc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pbc_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
// static void setup_pread_pwrite_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pbc_0_common
static void setup_pread_pwrite_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pbc_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pbc_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
// static void setup_pread_pwrite_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pbc_0_common
static void setup_pread_pwrite_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pbc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pbc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pbc_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pbc_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
// static void setup_pread_pwrite_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pbc_0_common
static void setup_pread_pwrite_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_pbc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pbc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pbb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
static int test_pread_pwrite_pbb0_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_pbb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_pbb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2494464, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2494464, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_pwrite_pbb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pread_pwrite_pbb0_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_pread_pwrite_pbb0_0_procfinal(void) {
  
}

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_pbb0_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pwrite_pbb0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
static void setup_pread_pwrite_pbb0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pread_pwrite_pbb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pbb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
static void setup_pread_pwrite_pbb0_1_final(void) {
  unlink("__i0");
}
// static void setup_pread_pwrite_pbb0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pbb0_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
static int test_pread_pwrite_pbb0_2_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_pbb0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_pbb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pbb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pbb0_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pbb0_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pbb0_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pbb0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
// static void setup_pread_pwrite_pbb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
static void setup_pread_pwrite_pbb0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pbb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pbb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pbb0_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_pbb0_4_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 28672);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pwrite_pbb0_4_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_pbb0_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_pbb0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pbb0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pbb0_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pbb0_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pbb0_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 28672);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_4_0
// static int test_pread_pwrite_pbb0_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pbb0_4_1
// static void setup_pread_pwrite_pbb0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_4_common
static void setup_pread_pwrite_pbb0_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pbb0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pbb0_5_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pbb0_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pbb0_6_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pbb0_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pbb0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
static void setup_pread_pwrite_pbb0_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pbb0_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pbb0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pbb0_6_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pbb0_7_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pbb0_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pbb0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
static void setup_pread_pwrite_pbb0_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pbb0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pbb0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pbb0_7_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pb8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pb8_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
// static void setup_pread_pwrite_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_0_common
static void setup_pread_pwrite_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pb8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pb8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
static int test_pread_pwrite_pb8_1_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_pb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pb8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pb8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
static int test_pread_pwrite_pb8_2_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_pb8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pwrite_pb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_2_proc0
// static void setup_pread_pwrite_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pb8_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pb8_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pb8_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
static void setup_pread_pwrite_pb8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pb8_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pb8_4_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pbb0_2_1
static void setup_pread_pwrite_pb8_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_pb8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pb8_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_pb8_5_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 32768);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pwrite_pb8_5_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pbb0_4_1
static void setup_pread_pwrite_pb8_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_pb8_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pb8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pb8_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pb8_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pb8_6_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pb8_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pb8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_3_common
static void setup_pread_pwrite_pb8_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pb8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pb8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pb8_6_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pb8_7_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 32768);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pb8_5_0
static int test_pread_pwrite_pb8_7_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pread_pwrite_pb8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_5_common
static void setup_pread_pwrite_pb8_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pb8_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pb8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pb8_7_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pb0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pe_0_1
// static void setup_pread_pwrite_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
static void setup_pread_pwrite_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pb0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pb0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pe_0_1
// static void setup_pread_pwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
static void setup_pread_pwrite_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pac_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pac_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pbc_0_common
static void setup_pread_pwrite_pac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pac_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pac_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pbc_0_common
// static void setup_pread_pwrite_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pac_0_proc0
// static void setup_pread_pwrite_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pac_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pac_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pbc_0_common
// static void setup_pread_pwrite_pac_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pd4_1_proc1
// static void setup_pread_pwrite_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_pac_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pac_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pac_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pac_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pbc_0_common
// static void setup_pread_pwrite_pac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pd4_1_proc1
// static void setup_pread_pwrite_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_pac_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_pac_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pab0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pab0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
static void setup_pread_pwrite_pab0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_pread_pwrite_pab0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_6_proc0
static void setup_pread_pwrite_pab0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pab0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pab0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pab0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pab0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
// static void setup_pread_pwrite_pab0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_6_proc0
// static void setup_pread_pwrite_pab0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_6_proc0
// static void setup_pread_pwrite_pab0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pab0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_pab0_2_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 20480);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pwrite_pab0_2_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 16384);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_pab0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_pab0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_pwrite_pab0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pab0_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pab0_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_pab0_3_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 12288);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pwrite_pab0_3_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pread_pwrite_pab0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_0_common
// static void setup_pread_pwrite_pab0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_0_proc0
static void setup_pread_pwrite_pab0_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pab0_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pab0_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_pab0_4_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 8192);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pwrite_pab0_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pab0_3_1
// static void setup_pread_pwrite_pab0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_0_common
// static void setup_pread_pwrite_pab0_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_0_proc0
// static void setup_pread_pwrite_pab0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pab0_3_proc1
// static void setup_pread_pwrite_pab0_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pab0_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pab0_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pab0_4_0
// static int test_pread_pwrite_pab0_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pab0_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
// static void setup_pread_pwrite_pab0_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
// static void setup_pread_pwrite_pab0_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
// static void setup_pread_pwrite_pab0_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pab0_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pab0_6_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pab0_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pab0_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
// static void setup_pread_pwrite_pab0_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
static void setup_pread_pwrite_pab0_6_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pab0_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pab0_6_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pab0_7_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pab0_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pab0_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
// static void setup_pread_pwrite_pab0_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_1_proc0
// static void setup_pread_pwrite_pab0_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
// static void setup_pread_pwrite_pab0_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pab0_7_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pa8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pa8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_0_common
// static void setup_pread_pwrite_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_6_proc0
static void setup_pread_pwrite_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pa8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pa8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pab0_4_0
// static int test_pread_pwrite_pa8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
static void setup_pread_pwrite_pa8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_pwrite_pa8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pa8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pa8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pa8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_3_common
// static void setup_pread_pwrite_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_6_proc0
static void setup_pread_pwrite_pa8_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pa8_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pa8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_0_common
// static void setup_pread_pwrite_pa8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
// static void setup_pread_pwrite_pa8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pab0_2_proc1
// static void setup_pread_pwrite_pa8_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_pa8_4_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pwrite_pa8_4_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_pa8_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_pa8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pa8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pab0_6_proc1
// static void setup_pread_pwrite_pa8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pa8_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pa8_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbb0_1_0
// static int test_pread_pwrite_pa8_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
static void setup_pread_pwrite_pa8_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pwrite_pa8_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
// static void setup_pread_pwrite_pa8_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pa8_1_proc1
// static void setup_pread_pwrite_pa8_5_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_pa8_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pa8_6_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pa8_4_0
// static int test_pread_pwrite_pa8_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pa8_4_1
// static void setup_pread_pwrite_pa8_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pa8_4_common
// static void setup_pread_pwrite_pa8_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 5062656, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pab0_6_proc1
// static void setup_pread_pwrite_pa8_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pa8_4_proc0
// static void setup_pread_pwrite_pa8_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pa8_6_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pa8_7_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 32768);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pb8_5_0
// static int test_pread_pwrite_pa8_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pb8_7_1
// static void setup_pread_pwrite_pa8_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_5_common
// static void setup_pread_pwrite_pa8_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_7_proc0
static void setup_pread_pwrite_pa8_7_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_pa8_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pa8_7_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pa0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pa0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pc_0_1
// static void setup_pread_pwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
// static void setup_pread_pwrite_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_0_proc0
// static void setup_pread_pwrite_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_pa0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_pbc_0_0
// static int test_pread_pwrite_pa0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pc_0_1
// static void setup_pread_pwrite_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
// static void setup_pread_pwrite_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_1_proc0
// static void setup_pread_pwrite_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_p9c_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pwrite_p9c_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
static void setup_pread_pwrite_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_pwrite_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p9c_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p9c_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
// static void setup_pread_pwrite_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_p9c_0_common
static void setup_pread_pwrite_p9c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p9c_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p9c_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
// static void setup_pread_pwrite_p9c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf0_1_common
// static void setup_pread_pwrite_p9c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pbc_2_proc0
// static void setup_pread_pwrite_p9c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_p9c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p9c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p9c_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p9c_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
// static void setup_pread_pwrite_p9c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf0_1_common
// static void setup_pread_pwrite_p9c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pbc_3_proc0
// static void setup_pread_pwrite_p9c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_p9c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p9c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_p9a_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 16384);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pwrite_p9a_0_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_p9a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p9a_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
static int test_pread_pwrite_p9a_1_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_p9a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 77824, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_p9a_2_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pwrite_p9a_2_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_p9a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p9a_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p9a_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p9a_3_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_2_1
static void setup_pread_pwrite_p9a_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pwrite_p9a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_3_proc0
// static void setup_pread_pwrite_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p9a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p9a_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p9a_4_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_1_1
static void setup_pread_pwrite_p9a_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_p9a_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p9a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p9a_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p9a_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p9a_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p9a_5_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_1_1
// static void setup_pread_pwrite_p9a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_4_common
// static void setup_pread_pwrite_p9a_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_2_proc0
// static void setup_pread_pwrite_p9a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p9a_5_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p9a_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p9a_6_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 16384);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_0_0
static int test_pread_pwrite_p9a_6_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pread_pwrite_p9a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_0_common
static void setup_pread_pwrite_p9a_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p9a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p9a_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p9a_6_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p9a_7_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 16384);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_0_0
// static int test_pread_pwrite_p9a_7_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_6_1
// static void setup_pread_pwrite_p9a_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_0_common
// static void setup_pread_pwrite_p9a_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pab0_2_proc0
// static void setup_pread_pwrite_p9a_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p9a_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p9a_7_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_p990_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pwrite_p990_0_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 16384);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_p990_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_p990_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p990_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p990_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_p990_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 8192);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pwrite_p990_1_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_2_1
static void setup_pread_pwrite_p990_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_p990_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 77824, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p990_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p990_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_p990_2_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 20480);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pwrite_p990_2_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 12288);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_p990_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_p990_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 86016, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p990_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p990_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p990_1_0
// static int test_pread_pwrite_p990_3_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_1_1
static void setup_pread_pwrite_p990_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pwrite_p990_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_0_proc0
// static void setup_pread_pwrite_p990_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p990_4_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_2_1
static void setup_pread_pwrite_p990_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pwrite_p990_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_4_proc0
// static void setup_pread_pwrite_p990_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p990_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p990_5_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_2_1
// static void setup_pread_pwrite_p990_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_3_common
static void setup_pread_pwrite_p990_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 77824, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p990_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_6_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p990_6_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_2_1
// static void setup_pread_pwrite_p990_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_3_common
// static void setup_pread_pwrite_p990_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_3_proc0
// static void setup_pread_pwrite_p990_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_6_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_p990_7_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 12288);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_pwrite_p990_7_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 12288);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_p990_7_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_p990_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p990_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_7_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_8_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
static int test_pread_pwrite_p990_8_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pread_pwrite_p990_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_3_common
// static void setup_pread_pwrite_p990_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_6_proc0
// static void setup_pread_pwrite_p990_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_8_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_9_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p990_9_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p990_8_1
// static void setup_pread_pwrite_p990_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_3_common
// static void setup_pread_pwrite_p990_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_0_proc0
// static void setup_pread_pwrite_p990_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_9_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_10_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p990_10_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pbb0_0_1
static void setup_pread_pwrite_p990_10_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_pwrite_p990_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p990_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_10_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_11_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p990_11_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pab0_3_1
// static void setup_pread_pwrite_p990_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_10_common
// static void setup_pread_pwrite_p990_11_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_6_proc0
// static void setup_pread_pwrite_p990_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_11_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_12_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p990_12_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pbb0_0_1
// static void setup_pread_pwrite_p990_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_10_common
static void setup_pread_pwrite_p990_12_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p990_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_12_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_13_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p990_13_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pbb0_0_1
// static void setup_pread_pwrite_p990_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_10_common
// static void setup_pread_pwrite_p990_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_3_proc0
// static void setup_pread_pwrite_p990_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_13_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p990_14_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p990_14_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pab0_3_1
// static void setup_pread_pwrite_p990_14_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_10_common
// static void setup_pread_pwrite_p990_14_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
// static void setup_pread_pwrite_p990_14_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p990_14_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p990_14_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p90_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p90_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pe_0_1
// static void setup_pread_pwrite_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_3_common
// static void setup_pread_pwrite_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pab0_2_proc0
// static void setup_pread_pwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p90_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p90_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pe_0_1
// static void setup_pread_pwrite_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_3_common
// static void setup_pread_pwrite_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_1_proc0
// static void setup_pread_pwrite_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p8c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p8c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_p9c_0_common
static void setup_pread_pwrite_p8c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p8c_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p8c_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_p9c_0_common
// static void setup_pread_pwrite_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_p8c_0_proc0
// static void setup_pread_pwrite_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p8c_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p8c_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_p8c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf0_1_common
// static void setup_pread_pwrite_p8c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pd4_1_proc1
// static void setup_pread_pwrite_p8c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_p8c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p8c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p8c_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p8c_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_p8c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf0_0_common
// static void setup_pread_pwrite_p8c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pd4_1_proc1
// static void setup_pread_pwrite_p8c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_p8c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p8c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p8a_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 16384);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_0_0
// static int test_pread_pwrite_p8a_0_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_6_1
// static void setup_pread_pwrite_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_0_common
// static void setup_pread_pwrite_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_6_proc0
// static void setup_pread_pwrite_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_6_proc0
// static void setup_pread_pwrite_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p8a_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p8a_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p990_8_1
// static void setup_pread_pwrite_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_3_common
// static void setup_pread_pwrite_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
static void setup_pread_pwrite_p8a_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 73728, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p8a_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p8a_2_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p990_8_1
// static void setup_pread_pwrite_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_2_common
// static void setup_pread_pwrite_p8a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
static void setup_pread_pwrite_p8a_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p8a_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p8a_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p990_2_0
static int test_pread_pwrite_p8a_3_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_p8a_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pwrite_p8a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pa8_4_proc0
// static void setup_pread_pwrite_p8a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pa8_4_proc0
// static void setup_pread_pwrite_p8a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p890_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
static int test_pread_pwrite_p890_0_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pread_pwrite_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p9a_3_common
// static void setup_pread_pwrite_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pab0_2_proc0
// static void setup_pread_pwrite_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pab0_2_proc0
// static void setup_pread_pwrite_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p890_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p890_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p890_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p990_8_1
static void setup_pread_pwrite_p890_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pwrite_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_0_proc0
static void setup_pread_pwrite_p890_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 73728, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p890_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p890_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p890_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p890_2_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p990_8_1
// static void setup_pread_pwrite_p890_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p890_1_common
// static void setup_pread_pwrite_p890_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
static void setup_pread_pwrite_p890_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 69632, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p890_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p890_2_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p890_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p890_3_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p990_8_1
// static void setup_pread_pwrite_p890_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p890_1_common
// static void setup_pread_pwrite_p890_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_0_proc0
// static void setup_pread_pwrite_p890_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_p8a_2_proc1
// static void setup_pread_pwrite_p890_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p890_3_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p890_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p890_4_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p9a_6_1
static void setup_pread_pwrite_p890_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pwrite_p890_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
static void setup_pread_pwrite_p890_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p890_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_pwrite_pbb0_0_final
// static void setup_pread_pwrite_p890_4_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p890_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
static int test_pread_pwrite_p890_5_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_p890_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pwrite_p890_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pa8_7_proc1
static void setup_pread_pwrite_p890_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 69632, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p890_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p890_5_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_p890_6_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 28672);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pwrite_p890_6_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_p8a_3_1
// static void setup_pread_pwrite_p890_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p890_5_common
// static void setup_pread_pwrite_p890_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pa8_4_proc0
// static void setup_pread_pwrite_p890_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pa8_4_proc0
// static void setup_pread_pwrite_p890_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p890_6_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p890_7_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p890_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pab0_3_1
// static void setup_pread_pwrite_p890_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_10_common
// static void setup_pread_pwrite_p890_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 9347072, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pa8_1_proc0
// static void setup_pread_pwrite_p890_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_6_proc0
// static void setup_pread_pwrite_p890_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p890_7_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p890_8_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 12288);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p990_7_0
static int test_pread_pwrite_p890_8_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 12288);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pread_pwrite_p890_8_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_pwrite_p890_8_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_0_proc0
static void setup_pread_pwrite_p890_8_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p890_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p890_8_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p890_9_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p890_9_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pab0_3_1
// static void setup_pread_pwrite_p890_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_10_common
// static void setup_pread_pwrite_p890_9_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
// static void setup_pread_pwrite_p890_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 1839104, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_6_proc0
// static void setup_pread_pwrite_p890_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p890_9_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p890_10_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9a_2_0
// static int test_pread_pwrite_p890_10_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pab0_3_1
// static void setup_pread_pwrite_p890_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_p990_10_common
// static void setup_pread_pwrite_p890_10_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
// static void setup_pread_pwrite_p890_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_7_proc0
// static void setup_pread_pwrite_p890_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p890_10_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p80_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pc_0_1
// static void setup_pread_pwrite_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_3_common
// static void setup_pread_pwrite_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pab0_2_proc0
// static void setup_pread_pwrite_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p80_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p9c_0_0
// static int test_pread_pwrite_p80_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pc_0_1
// static void setup_pread_pwrite_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_3_common
// static void setup_pread_pwrite_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_1_proc0
// static void setup_pread_pwrite_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
static int test_pread_pwrite_p7_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_pwrite_p7_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
// static void setup_pread_pwrite_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
static void setup_pread_pwrite_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p7_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p7_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_0_1
// static void setup_pread_pwrite_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
static void setup_pread_pwrite_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_pwrite_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p68_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p68_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
// static void setup_pread_pwrite_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
static void setup_pread_pwrite_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p68_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p68_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p68_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
// static void setup_pread_pwrite_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
static void setup_pread_pwrite_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p68_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p60_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p60_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
// static void setup_pread_pwrite_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_3_common
static void setup_pread_pwrite_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p60_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p60_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p60_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf4_0_1
// static void setup_pread_pwrite_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_3_common
// static void setup_pread_pwrite_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_p68_1_proc0
// static void setup_pread_pwrite_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p60_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p4_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pe_0_1
static void setup_pread_pwrite_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pread_pwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p4_0_final(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal
// static void setup_pread_pwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pc_0_1
// static void setup_pread_pwrite_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pread_pwrite_p4_0_common
// static void setup_pread_pwrite_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p4_1_final(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal
// static void setup_pread_pwrite_p4_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p3_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p3_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
// static void setup_pread_pwrite_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_3_proc0
// static void setup_pread_pwrite_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p3_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p3_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pf8_3_1
// static void setup_pread_pwrite_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_pwrite_pf8_0_common
// static void setup_pread_pwrite_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_0_proc1
// static void setup_pread_pwrite_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_pwrite_pf8_4_proc0
// static void setup_pread_pwrite_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_final
// static void setup_pread_pwrite_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_pwrite_pf8_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p28_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p28_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
// static void setup_pread_pwrite_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pa8_2_proc1
// static void setup_pread_pwrite_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p28_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p28_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p28_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pbb0_1_common
// static void setup_pread_pwrite_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_1_proc0
// static void setup_pread_pwrite_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p28_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p20_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p20_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_3_common
// static void setup_pread_pwrite_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
static void setup_pread_pwrite_p20_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_pwrite_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p20_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p20_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p20_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pd4_0_1
// static void setup_pread_pwrite_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb8_3_common
// static void setup_pread_pwrite_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_pwrite_pb0_1_proc0
// static void setup_pread_pwrite_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_pwrite_pbb0_1_final
// static void setup_pread_pwrite_p20_1_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal

/*
 * calls: pread pwrite
 */
// static int test_pread_pwrite_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_pwrite_p7_0_0
// static int test_pread_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pread_pwrite_pc_0_1
// static void setup_pread_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pread_pwrite_p4_0_common
// static void setup_pread_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_pwrite_pbb0_0_proc1
// static void setup_pread_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal
// static void setup_pread_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_pwrite_pbb0_0_procfinal


/*
 * calls: pread read
 */
static int test_pread_read_pfc_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_read_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pread_read_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_read_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_read_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pread_read_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pread read
 */
// static int test_pread_read_pfc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pfc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
// static void setup_pread_read_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
static void setup_pread_read_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pfc_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
static int test_pread_read_pfc_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_pread_read_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
static void setup_pread_read_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pfb_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
static int test_pread_read_pfb_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pread_read_pfb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pfb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pfb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pfb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pfb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pfb_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pfb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_0_1
// static void setup_pread_read_pfb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfb_0_common
static void setup_pread_read_pfb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pfb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pfb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pfb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pfb_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
static int test_pread_read_pfb_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_pread_read_pfb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfb_0_common
static void setup_pread_read_pfb_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pfb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pfb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pfb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pfa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
static int test_pread_read_pfa_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pread_read_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_pread_read_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_pread_read_pfa_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_pread_read_pfa_0_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: pread read
 */
// static int test_pread_read_pfa_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pfa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
static void setup_pread_read_pfa_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pfa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_0_proc1
// static void setup_pread_read_pfa_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pread_read_pfa_0_final
// static void setup_pread_read_pfa_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pread_read_pfa_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pfa_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pfa_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_pfa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfb_0_common
static void setup_pread_read_pfa_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_pread_read_pfa_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pfa_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pfa_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pfa_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
static int test_pread_read_pfa_3_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pread_read_pfa_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pfa_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pfa_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_2_proc1
// static void setup_pread_read_pfa_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pfa_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pf8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
static int test_pread_read_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pread_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_read_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_0_proc0
// static void setup_pread_read_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pf8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
// static void setup_pread_read_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf8_0_common
// static void setup_pread_read_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_1_proc0
// static void setup_pread_read_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pf8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
static int test_pread_read_pf8_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_pread_read_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf8_0_common
// static void setup_pread_read_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pf4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pf4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
static void setup_pread_read_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pf4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
static void setup_pread_read_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pf0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
static void setup_pread_read_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pf0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
static void setup_pread_read_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
// static void setup_pread_read_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
// static void setup_pread_read_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
// static void setup_pread_read_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
// static void setup_pread_read_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pdc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
// static void setup_pread_read_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pdc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pdc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
// static void setup_pread_read_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pdb_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pdb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_2_1
// static void setup_pread_read_pdb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfb_0_common
// static void setup_pread_read_pdb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pdb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pdb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pdb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pdb_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pdb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_2_1
// static void setup_pread_read_pdb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfb_0_common
// static void setup_pread_read_pdb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pdb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pdb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pdb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pda_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pda_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
static void setup_pread_read_pda_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pda_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_pread_read_pda_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_pread_read_pda_0_final(void) {
  unlink("__i0");
  close(22);
  close(23);
  close(20);
  close(21);
}
static void setup_pread_read_pda_0_procfinal(void) {
  close(22);
  close(23);
  close(20);
  close(21);
}

/*
 * calls: pread read
 */
// static int test_pread_read_pda_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pda_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfa_0_common
static void setup_pread_read_pda_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_pread_read_pda_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pda_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pread_read_pfa_0_final
// static void setup_pread_read_pda_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pread_read_pfa_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pda_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pda_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_pda_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfa_3_common
// static void setup_pread_read_pda_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_3_proc0
// static void setup_pread_read_pda_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_3_proc0
// static void setup_pread_read_pda_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pda_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf8_0_common
// static void setup_pread_read_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pd8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf8_0_common
// static void setup_pread_read_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pd4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf4_0_common
// static void setup_pread_read_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
static void setup_pread_read_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pd4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf4_0_common
// static void setup_pread_read_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pd4_0_proc1
// static void setup_pread_read_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf0_0_common
// static void setup_pread_read_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
static void setup_pread_read_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pd0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf0_0_common
// static void setup_pread_read_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pd0_0_proc1
// static void setup_pread_read_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
// static void setup_pread_read_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_0
// static int test_pread_read_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
// static void setup_pread_read_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
static int test_pread_read_pbe_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_read_pbe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
static void setup_pread_read_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pbe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pbe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
// static void setup_pread_read_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pbe_0_common
static void setup_pread_read_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pbd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pbd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_0_1
// static void setup_pread_read_pbd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
static void setup_pread_read_pbd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pbd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pbd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pbd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
static int test_pread_read_pbd8_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 5087232);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_read_pbd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_0_1
static void setup_pread_read_pbd8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_pbd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pbd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pbd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pbd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pbd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pbd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_pbd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
static void setup_pread_read_pbd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pbd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_2_proc1
// static void setup_pread_read_pbd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pbd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pbd0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5087232);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbd8_1_0
// static int test_pread_read_pbd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_pbd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pbd8_1_common
static void setup_pread_read_pbd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pbd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_2_proc1
// static void setup_pread_read_pbd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pbd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pbc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pbc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
static void setup_pread_read_pbc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_read_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pbd8_0_proc0
// static void setup_pread_read_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pbc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pbc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
// static void setup_pread_read_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pbc_0_common
static void setup_pread_read_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pba_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pba_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
static void setup_pread_read_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pread_read_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_read_pba_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pread_read_pba_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_pread_read_pba_0_procfinal(void) {
  
}

/*
 * calls: pread read
 */
static int test_pread_read_pba_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_read_pba_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
static void setup_pread_read_pba_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pread_read_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
static void setup_pread_read_pba_1_final(void) {
  unlink("__i0");
}
// static void setup_pread_read_pba_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
static int test_pread_read_pba_2_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 28672);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_read_pba_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
static void setup_pread_read_pba_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_read_pba_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pba_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pba_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_pba_2_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pba_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pba_1_0
// static int test_pread_read_pba_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_pba_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
static void setup_pread_read_pba_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pba_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pba_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pba_3_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pba_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pba_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_pba_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
static void setup_pread_read_pba_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pba_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pba_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pba_4_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pba_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pba_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_pba_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
static void setup_pread_read_pba_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pba_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pba_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pba_5_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pba_6_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pba_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_pba_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
static void setup_pread_read_pba_6_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pba_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pba_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pba_6_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pb8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
static void setup_pread_read_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_read_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pb8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pb8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
// static void setup_pread_read_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_0_common
static void setup_pread_read_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pb8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pb8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pba_1_0
// static int test_pread_read_pb8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
static void setup_pread_read_pb8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_read_pb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_5_proc0
// static void setup_pread_read_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pb8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
static int test_pread_read_pb8_3_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 32768);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_read_pb8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
static void setup_pread_read_pb8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_read_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pb8_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pba_1_0
// static int test_pread_read_pb8_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pb8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
// static void setup_pread_read_pb8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pb8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
// static void setup_pread_read_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
static void setup_pread_read_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pb0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
// static void setup_pread_read_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
// static void setup_pread_read_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pae_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pae_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pbe_0_common
static void setup_pread_read_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pae_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pae_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pbe_0_common
// static void setup_pread_read_pae_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pd0_0_proc1
// static void setup_pread_read_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pad8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pad8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_2_1
// static void setup_pread_read_pad8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
// static void setup_pread_read_pad8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pae_0_proc0
// static void setup_pread_read_pad8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pad8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pad8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pad8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5087232);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbd8_1_0
// static int test_pread_read_pad8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_2_1
// static void setup_pread_read_pad8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pbd8_1_common
static void setup_pread_read_pad8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pad8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pad8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pad8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pad0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pad0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_pad0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
static void setup_pread_read_pad0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_3_proc0
// static void setup_pread_read_pad0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pad0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pad0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 5087232);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbd8_1_0
// static int test_pread_read_pad0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_pad0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pbd8_1_common
static void setup_pread_read_pad0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5087232, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_pad0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_3_proc0
// static void setup_pread_read_pad0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pad0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pac_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pac_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pbc_0_common
// static void setup_pread_read_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pae_0_proc0
// static void setup_pread_read_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pac_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pac_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pbc_0_common
// static void setup_pread_read_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pd0_0_proc1
// static void setup_pread_read_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_paa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_paa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_0_common
static void setup_pread_read_paa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_read_paa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_paa_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_paa_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_paa_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_paa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
static void setup_pread_read_paa_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_read_paa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
static void setup_pread_read_paa_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31621120, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_paa_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_paa_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_paa_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_paa_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_paa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
static void setup_pread_read_paa_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_read_paa_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_paa_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_paa_2_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_paa_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_paa_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_paa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
// static void setup_pread_read_paa_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_paa_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_paa_0_proc0
// static void setup_pread_read_paa_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_paa_3_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_paa_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_paa_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_paa_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
// static void setup_pread_read_paa_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_paa_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_paa_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_paa_4_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pa8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_0_common
static void setup_pread_read_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_read_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pa8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pa8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pa8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_0_common
// static void setup_pread_read_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pa8_0_proc1
// static void setup_pread_read_pa8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pa8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pba_1_0
// static int test_pread_read_pa8_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
// static void setup_pread_read_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pa8_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 32768);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pb8_3_0
// static int test_pread_read_pa8_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_3_common
static void setup_pread_read_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_read_pa8_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pa0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
// static void setup_pread_read_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pb0_0_proc0
// static void setup_pread_read_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_pa0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pbe_0_0
// static int test_pread_read_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
// static void setup_pread_read_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
static int test_pread_read_p9e_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_read_p9e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
static void setup_pread_read_p9e_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_p9e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p9e_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p9e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
// static void setup_pread_read_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf0_0_common
// static void setup_pread_read_p9e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pbe_1_proc0
// static void setup_pread_read_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p9e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p9e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p9d8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p9d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_0_1
static void setup_pread_read_p9d8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_p9d8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p9d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p9d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p9d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
static int test_pread_read_p9d8_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_read_p9d8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_0_1
static void setup_pread_read_p9d8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_read_p9d8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p9d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p9d8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p9d8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p9d0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p9d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_p9d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_p9d8_0_common
static void setup_pread_read_p9d0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p9d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_2_proc1
// static void setup_pread_read_p9d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p9d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p9d0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9d8_1_0
// static int test_pread_read_p9d0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_p9d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_p9d8_1_common
static void setup_pread_read_p9d0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p9d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_2_proc1
// static void setup_pread_read_p9d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p9d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p9c0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p9c0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
// static void setup_pread_read_p9c0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf0_1_common
static void setup_pread_read_p9c0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p9c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p9c0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p9c0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p9c0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p9c0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
static void setup_pread_read_p9c0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_read_p9c0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pbc_1_proc0
// static void setup_pread_read_p9c0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p9c0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p9c0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p9a_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p9a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
static void setup_pread_read_p9a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_pread_read_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_0_proc0
// static void setup_pread_read_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p9a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p9a_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p9a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_p9a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
static void setup_pread_read_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p9a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
static int test_pread_read_p9a_2_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_read_p9a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
static void setup_pread_read_p9a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pread_read_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p9a_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
static int test_pread_read_p9a_3_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 20480);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_read_p9a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
static void setup_pread_read_p9a_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_read_p9a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pa8_0_proc0
// static void setup_pread_read_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p9a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p9a_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p9a_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_p9a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
static void setup_pread_read_p9a_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9986048, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_p9a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p9a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p9a_4_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p98_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9d8_1_0
// static int test_pread_read_p98_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
static void setup_pread_read_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_read_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p98_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p98_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9d8_1_0
// static int test_pread_read_p98_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_p98_0_common
// static void setup_pread_read_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pa8_0_proc0
// static void setup_pread_read_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p98_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p90_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
// static void setup_pread_read_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
static void setup_pread_read_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p90_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
// static void setup_pread_read_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
// static void setup_pread_read_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8e_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p8e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_p9e_0_common
static void setup_pread_read_p8e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_p8e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p8e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8e_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p8e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_p8e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf0_0_common
// static void setup_pread_read_p8e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pd0_0_proc1
// static void setup_pread_read_p8e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_p8e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p8e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8d8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p8d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_2_1
// static void setup_pread_read_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_p9d8_0_common
static void setup_pread_read_p8d8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_p8d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p8d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8d8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9d8_1_0
// static int test_pread_read_p8d8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_2_1
// static void setup_pread_read_p8d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_p9d8_1_common
static void setup_pread_read_p8d8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p8d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_p8d8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p8d8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8d0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p8d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_p9d8_0_common
static void setup_pread_read_p8d0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p8d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_3_proc0
// static void setup_pread_read_p8d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p8d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8d0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9d8_1_0
// static int test_pread_read_p8d0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_p8d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_p9d8_1_common
static void setup_pread_read_p8d0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p8d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_3_proc0
// static void setup_pread_read_p8d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p8d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8c0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p8c0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_p8c0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf0_1_common
// static void setup_pread_read_p8c0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_p8e_0_proc0
// static void setup_pread_read_p8c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_p8c0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p8c0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8c0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p8c0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_p8c0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_p9c0_1_common
// static void setup_pread_read_p8c0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pd0_0_proc1
// static void setup_pread_read_p8c0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_p8c0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p8c0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8a_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p8a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_p9a_0_common
// static void setup_pread_read_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_paa_0_proc0
// static void setup_pread_read_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_paa_0_proc1
// static void setup_pread_read_p8a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8a_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p8a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
// static void setup_pread_read_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_paa_2_proc1
// static void setup_pread_read_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_paa_2_proc1
// static void setup_pread_read_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8a_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p8a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
static void setup_pread_read_p8a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_read_p8a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
static void setup_pread_read_p8a_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_p8a_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_read_pba_0_final
// static void setup_pread_read_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p8a_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p8a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
// static void setup_pread_read_p8a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
static void setup_pread_read_p8a_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31621120, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_p8a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p88_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9d8_1_0
// static int test_pread_read_p88_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_p98_0_common
// static void setup_pread_read_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pa8_0_proc0
// static void setup_pread_read_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pa8_0_proc0
// static void setup_pread_read_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p88_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
// static void setup_pread_read_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_p90_0_proc0
// static void setup_pread_read_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p80_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p9e_0_0
// static int test_pread_read_p80_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
// static void setup_pread_read_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
static int test_pread_read_p78_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_read_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
// static void setup_pread_read_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
static void setup_pread_read_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p76_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_0_1
// static void setup_pread_read_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfb_0_common
static void setup_pread_read_p76_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p74_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfa_3_common
static void setup_pread_read_p74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_2_proc1
// static void setup_pread_read_p74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p70_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
// static void setup_pread_read_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf8_0_common
// static void setup_pread_read_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_p76_0_proc0
// static void setup_pread_read_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p68_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_0_1
// static void setup_pread_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
static void setup_pread_read_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p60_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_0_1
// static void setup_pread_read_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
static void setup_pread_read_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p60_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_0_1
static void setup_pread_read_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pread_read_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p4_0_final(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal
// static void setup_pread_read_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pread_read_p4_0_common
// static void setup_pread_read_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p4_1_final(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal
// static void setup_pread_read_p4_1_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p38_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfc_0_common
// static void setup_pread_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_2_proc0
// static void setup_pread_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p36_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfb_2_1
// static void setup_pread_read_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfb_0_common
// static void setup_pread_read_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p34_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pfa_3_common
// static void setup_pread_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_2_proc1
// static void setup_pread_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfa_3_proc0
// static void setup_pread_read_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p30_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_read_pf8_0_common
// static void setup_pread_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfc_0_proc1
// static void setup_pread_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_read_pfb_2_proc0
// static void setup_pread_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_final
// static void setup_pread_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_read_pfc_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p28_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfa_3_1
// static void setup_pread_read_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_read_pba_1_common
// static void setup_pread_read_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_paa_0_proc0
// static void setup_pread_read_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p28_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p20_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pf8_2_1
// static void setup_pread_read_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_read_pb8_2_common
// static void setup_pread_read_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_read_pba_6_proc0
// static void setup_pread_read_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_read_pba_1_final
// static void setup_pread_read_p20_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal

/*
 * calls: pread read
 */
// static int test_pread_read_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_p78_0_0
// static int test_pread_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_read_pfc_2_1
// static void setup_pread_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pread_read_p4_0_common
// static void setup_pread_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_read_pba_0_proc1
// static void setup_pread_read_p0_0_final(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal
// static void setup_pread_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_read_pba_0_procfinal


/*
 * calls: pread rename
 */
static int test_pread_rename_pf_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_rename_pf_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_pread_rename_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pread_rename_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_rename_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_rename_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pread_rename_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pread rename
 */
// static int test_pread_rename_pf_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pf_0_0
// static int test_pread_rename_pf_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pf_0_1
// static void setup_pread_rename_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pf_0_common
static void setup_pread_rename_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_rename_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_0_proc1
// static void setup_pread_rename_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_final
// static void setup_pread_rename_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pe8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pf_0_0
static int test_pread_rename_pe8_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_pread_rename_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_pread_rename_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_0_proc0
// static void setup_pread_rename_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_0_proc1
// static void setup_pread_rename_pe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_final
// static void setup_pread_rename_pe8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pe8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pf_0_0
// static int test_pread_rename_pe8_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pe8_0_common
// static void setup_pread_rename_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_1_proc0
// static void setup_pread_rename_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_0_proc1
// static void setup_pread_rename_pe8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_final
// static void setup_pread_rename_pe8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pe0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pf_0_0
// static int test_pread_rename_pe0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pf_0_common
// static void setup_pread_rename_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_0_proc0
// static void setup_pread_rename_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_0_proc1
// static void setup_pread_rename_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_final
// static void setup_pread_rename_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pe0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pf_0_0
// static int test_pread_rename_pe0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pf_0_common
// static void setup_pread_rename_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_1_proc0
// static void setup_pread_rename_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_0_proc1
// static void setup_pread_rename_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_final
// static void setup_pread_rename_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pf_0_0
static int test_pread_rename_pc_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_pread_rename_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_rename_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_0_proc0
// static void setup_pread_rename_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_0_proc1
// static void setup_pread_rename_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_final
// static void setup_pread_rename_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pf_0_0
// static int test_pread_rename_pc_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pc_0_1
// static void setup_pread_rename_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_rename_pc_0_common
// static void setup_pread_rename_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_1_proc0
// static void setup_pread_rename_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_rename_pf_0_proc1
// static void setup_pread_rename_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_final
// static void setup_pread_rename_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_rename_pf_0_procfinal

/*
 * calls: pread rename
 */
static int test_pread_rename_pb8_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_rename_pb8_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pf_0_1
static void setup_pread_rename_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pread_rename_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_rename_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pread_rename_pb8_0_final(void) {
  unlink("__i0");
}
static void setup_pread_rename_pb8_0_procfinal(void) {
  
}

/*
 * calls: pread rename
 */
// static int test_pread_rename_pb8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pb8_0_0
// static int test_pread_rename_pb8_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pf_0_1
// static void setup_pread_rename_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pb8_0_common
static void setup_pread_rename_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_rename_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pb4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pb8_0_0
// static int test_pread_rename_pb4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
static void setup_pread_rename_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_pread_rename_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_rename_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
static void setup_pread_rename_pb4_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_pread_rename_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
static int test_pread_rename_pb4_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_rename_pb4_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pb4_0_common
static void setup_pread_rename_pb4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_rename_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_pb4_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_rename_pb4_0_final
// static void setup_pread_rename_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pb4_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pb8_0_0
// static int test_pread_rename_pb4_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
static void setup_pread_rename_pb4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_pread_rename_pb4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_rename_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
static void setup_pread_rename_pb4_2_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_pread_rename_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pb4_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pb4_1_0
// static int test_pread_rename_pb4_3_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_pb4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pb4_2_common
// static void setup_pread_rename_pb4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb4_1_proc0
// static void setup_pread_rename_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_pb4_3_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb4_2_final
// static void setup_pread_rename_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pb4_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pb8_0_0
// static int test_pread_rename_pb4_4_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
static void setup_pread_rename_pb4_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_pread_rename_pb4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb4_2_proc0
// static void setup_pread_rename_pb4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_pb4_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_pb4_4_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pb4_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pb8_0_0
// static int test_pread_rename_pb4_5_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_pb4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pb4_4_common
// static void setup_pread_rename_pb4_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_1_proc0
// static void setup_pread_rename_pb4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_pb4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_pb4_5_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pb8_0_0
// static int test_pread_rename_pb0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pb8_0_common
// static void setup_pread_rename_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_0_proc0
// static void setup_pread_rename_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pb0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pb8_0_0
// static int test_pread_rename_pb0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pb8_0_common
// static void setup_pread_rename_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_1_proc0
// static void setup_pread_rename_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pb8_0_0
// static int test_pread_rename_pa_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pc_0_1
static void setup_pread_rename_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_pread_rename_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_0_proc0
// static void setup_pread_rename_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_pa_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_pa_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_pb8_0_0
// static int test_pread_rename_pa_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pc_0_1
// static void setup_pread_rename_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_rename_pa_0_common
// static void setup_pread_rename_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_1_proc0
// static void setup_pread_rename_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_pa_1_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
static int test_pread_rename_p98_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_rename_p98_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pf_0_1
static void setup_pread_rename_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_pread_rename_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_0_proc0
// static void setup_pread_rename_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p98_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p98_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p98_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pf_0_1
// static void setup_pread_rename_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_p98_0_common
// static void setup_pread_rename_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_1_proc0
// static void setup_pread_rename_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p98_1_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p94_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p94_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
static void setup_pread_rename_p94_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_pread_rename_p94_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb4_0_proc0
// static void setup_pread_rename_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p94_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_rename_pb4_0_final
// static void setup_pread_rename_p94_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p94_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p94_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_p94_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_p94_0_common
// static void setup_pread_rename_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_1_proc0
// static void setup_pread_rename_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p94_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_rename_pb4_0_final
// static void setup_pread_rename_p94_1_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p94_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p94_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
static void setup_pread_rename_p94_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_pread_rename_p94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb4_2_proc0
// static void setup_pread_rename_p94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p94_2_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb4_2_final
// static void setup_pread_rename_p94_2_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p94_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p94_3_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
static void setup_pread_rename_p94_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_pread_rename_p94_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_rename_p94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p94_3_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p94_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p94_4_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_p94_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_p94_2_common
// static void setup_pread_rename_p94_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_1_proc0
// static void setup_pread_rename_p94_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p94_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb4_2_final
// static void setup_pread_rename_p94_4_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p94_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p94_5_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_p94_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_p94_3_common
// static void setup_pread_rename_p94_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_1_proc0
// static void setup_pread_rename_p94_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p94_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p94_5_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p90_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p90_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_p98_0_common
// static void setup_pread_rename_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_0_proc0
// static void setup_pread_rename_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p90_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p90_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_p98_0_common
// static void setup_pread_rename_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_1_proc0
// static void setup_pread_rename_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p80_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pc_0_1
static void setup_pread_rename_p80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_rename_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_0_proc0
// static void setup_pread_rename_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p80_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p98_0_0
// static int test_pread_rename_p80_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pc_0_1
// static void setup_pread_rename_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_rename_p80_0_common
// static void setup_pread_rename_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_rename_pb8_1_proc0
// static void setup_pread_rename_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
static int test_pread_rename_p6_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_rename_p6_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pf_0_1
// static void setup_pread_rename_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pb8_0_common
// static void setup_pread_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p50_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p6_0_0
// static int test_pread_rename_p50_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pb4_4_common
// static void setup_pread_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p6_0_0
// static int test_pread_rename_p4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pe8_0_1
// static void setup_pread_rename_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_rename_pb8_0_common
// static void setup_pread_rename_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_rename_pb8_0_final
// static void setup_pread_rename_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal

/*
 * calls: pread rename
 */
// static int test_pread_rename_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_rename_p6_0_0
// static int test_pread_rename_p0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_rename_pc_0_1
static void setup_pread_rename_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pread_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_rename_pb8_0_proc1
// static void setup_pread_rename_p0_0_final(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal
// static void setup_pread_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_rename_pb8_0_procfinal


/*
 * calls: pread stat
 */
static int test_pread_stat_pe_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_pread_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pread_stat_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_stat_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_stat_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pread_stat_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pread stat
 */
// static int test_pread_stat_pe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_pe_0_0
// static int test_pread_stat_pe_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_pe_0_1
// static void setup_pread_stat_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_stat_pe_0_common
static void setup_pread_stat_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_stat_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_stat_pe_0_proc1
// static void setup_pread_stat_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_stat_pe_0_final
// static void setup_pread_stat_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_stat_pe_0_procfinal

/*
 * calls: pread stat
 */
// static int test_pread_stat_pc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_pe_0_0
static int test_pread_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_pread_stat_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_stat_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_stat_pe_0_proc0
// static void setup_pread_stat_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_stat_pe_0_proc1
// static void setup_pread_stat_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_stat_pe_0_final
// static void setup_pread_stat_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_stat_pe_0_procfinal

/*
 * calls: pread stat
 */
// static int test_pread_stat_pc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_pe_0_0
// static int test_pread_stat_pc_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_pc_0_1
// static void setup_pread_stat_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_stat_pc_0_common
// static void setup_pread_stat_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_stat_pe_1_proc0
// static void setup_pread_stat_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_stat_pe_0_proc1
// static void setup_pread_stat_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_stat_pe_0_final
// static void setup_pread_stat_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_stat_pe_0_procfinal

/*
 * calls: pread stat
 */
static int test_pread_stat_pb_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_stat_pb_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_pe_0_1
static void setup_pread_stat_pb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pread_stat_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_stat_pb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pread_stat_pb_0_final(void) {
  unlink("__i0");
}
static void setup_pread_stat_pb_0_procfinal(void) {
  
}

/*
 * calls: pread stat
 */
// static int test_pread_stat_pb_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_pb_0_0
// static int test_pread_stat_pb_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_pe_0_1
// static void setup_pread_stat_pb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_stat_pb_0_common
static void setup_pread_stat_pb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_stat_pb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_pb_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_stat_pb_0_final
// static void setup_pread_stat_pb_1_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal

/*
 * calls: pread stat
 */
// static int test_pread_stat_pa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_pb_0_0
// static int test_pread_stat_pa_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_pc_0_1
static void setup_pread_stat_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_pread_stat_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_stat_pb_0_proc0
// static void setup_pread_stat_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_stat_pb_0_final
// static void setup_pread_stat_pa_0_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal

/*
 * calls: pread stat
 */
// static int test_pread_stat_pa_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_pb_0_0
// static int test_pread_stat_pa_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_pc_0_1
// static void setup_pread_stat_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_stat_pa_0_common
// static void setup_pread_stat_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_stat_pb_1_proc0
// static void setup_pread_stat_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_stat_pb_0_final
// static void setup_pread_stat_pa_1_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal

/*
 * calls: pread stat
 */
static int test_pread_stat_p98_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_stat_p98_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_pread_stat_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pread_stat_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_stat_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
static void setup_pread_stat_p98_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_pread_stat_p98_0_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal

/*
 * calls: pread stat
 */
// static int test_pread_stat_p98_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_p98_0_0
// static int test_pread_stat_p98_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_p98_0_1
static void setup_pread_stat_p98_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_pread_stat_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_stat_pb_0_proc0
// static void setup_pread_stat_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_stat_pb_0_final
// static void setup_pread_stat_p98_1_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal

/*
 * calls: pread stat
 */
// static int test_pread_stat_p98_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_p98_0_0
// static int test_pread_stat_p98_2_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_p98_0_1
// static void setup_pread_stat_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_stat_p98_0_common
// static void setup_pread_stat_p98_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_stat_pb_1_proc0
// static void setup_pread_stat_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_p98_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_stat_p98_0_final
// static void setup_pread_stat_p98_2_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal

/*
 * calls: pread stat
 */
// static int test_pread_stat_p98_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_p98_0_0
// static int test_pread_stat_p98_3_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_p98_0_1
// static void setup_pread_stat_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_stat_p98_1_common
// static void setup_pread_stat_p98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_stat_pb_1_proc0
// static void setup_pread_stat_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_p98_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_stat_pb_0_final
// static void setup_pread_stat_p98_3_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal

/*
 * calls: pread stat
 */
// static int test_pread_stat_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_p98_0_0
// static int test_pread_stat_p80_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_pc_0_1
static void setup_pread_stat_p80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_stat_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_stat_pb_0_proc0
// static void setup_pread_stat_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_stat_pb_0_final
// static void setup_pread_stat_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal

/*
 * calls: pread stat
 */
// static int test_pread_stat_p80_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_p98_0_0
// static int test_pread_stat_p80_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_pc_0_1
// static void setup_pread_stat_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_stat_p80_0_common
// static void setup_pread_stat_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_stat_pb_1_proc0
// static void setup_pread_stat_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_stat_pb_0_final
// static void setup_pread_stat_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal

/*
 * calls: pread stat
 */
static int test_pread_stat_p4_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_pe_0_1
// static void setup_pread_stat_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_stat_pb_0_common
// static void setup_pread_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_stat_pb_0_final
// static void setup_pread_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal

/*
 * calls: pread stat
 */
// static int test_pread_stat_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_stat_p4_0_0
// static int test_pread_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pread_stat_pc_0_1
static void setup_pread_stat_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pread_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_stat_pb_0_proc1
// static void setup_pread_stat_p0_0_final(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal
// static void setup_pread_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_stat_pb_0_procfinal


/*
 * calls: pread unlink
 */
static int test_pread_unlink_pe_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_unlink_pe_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_pread_unlink_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pread_unlink_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_unlink_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_unlink_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pread_unlink_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_pe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_pe_0_0
// static int test_pread_unlink_pe_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pe_0_1
// static void setup_pread_unlink_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_unlink_pe_0_common
static void setup_pread_unlink_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_unlink_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_unlink_pe_0_proc1
// static void setup_pread_unlink_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_unlink_pe_0_final
// static void setup_pread_unlink_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_unlink_pe_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_pc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_pe_0_0
static int test_pread_unlink_pc_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_pread_unlink_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_unlink_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_unlink_pe_0_proc0
// static void setup_pread_unlink_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_unlink_pe_0_proc1
// static void setup_pread_unlink_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_unlink_pe_0_final
// static void setup_pread_unlink_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_unlink_pe_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_pc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_pe_0_0
// static int test_pread_unlink_pc_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pc_0_1
// static void setup_pread_unlink_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_unlink_pc_0_common
// static void setup_pread_unlink_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_unlink_pe_1_proc0
// static void setup_pread_unlink_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_unlink_pe_0_proc1
// static void setup_pread_unlink_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_unlink_pe_0_final
// static void setup_pread_unlink_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_unlink_pe_0_procfinal

/*
 * calls: pread unlink
 */
static int test_pread_unlink_pb0_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_unlink_pb0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pe_0_1
static void setup_pread_unlink_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pread_unlink_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_unlink_pb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pread_unlink_pb0_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_pread_unlink_pb0_0_procfinal(void) {
  
}

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_pb0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_pb0_0_0
// static int test_pread_unlink_pb0_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pe_0_1
// static void setup_pread_unlink_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_unlink_pb0_0_common
static void setup_pread_unlink_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_unlink_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_pb0_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_unlink_pb0_0_final
// static void setup_pread_unlink_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_pb0_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_pb0_0_0
// static int test_pread_unlink_pb0_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pe_0_1
static void setup_pread_unlink_pb0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pread_unlink_pb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_unlink_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
static void setup_pread_unlink_pb0_2_final(void) {
  unlink("__i0");
}
// static void setup_pread_unlink_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_pb0_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_pb0_0_0
// static int test_pread_unlink_pb0_3_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pe_0_1
// static void setup_pread_unlink_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_unlink_pb0_2_common
// static void setup_pread_unlink_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_unlink_pb0_1_proc0
// static void setup_pread_unlink_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_unlink_pb0_2_final
// static void setup_pread_unlink_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_pa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_pb0_0_0
// static int test_pread_unlink_pa_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pc_0_1
static void setup_pread_unlink_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pread_unlink_pa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_unlink_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_unlink_pb0_2_final
// static void setup_pread_unlink_pa_0_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_pa_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_pb0_0_0
// static int test_pread_unlink_pa_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pc_0_1
// static void setup_pread_unlink_pa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_unlink_pa_0_common
// static void setup_pread_unlink_pa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_unlink_pb0_1_proc0
// static void setup_pread_unlink_pa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_pa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_unlink_pb0_2_final
// static void setup_pread_unlink_pa_1_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
static int test_pread_unlink_p90_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_unlink_p90_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pe_0_1
static void setup_pread_unlink_p90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_pread_unlink_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_unlink_pb0_0_proc0
// static void setup_pread_unlink_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_p90_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_unlink_pb0_0_final
// static void setup_pread_unlink_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_p90_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_p90_0_0
// static int test_pread_unlink_p90_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pe_0_1
// static void setup_pread_unlink_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_unlink_p90_0_common
// static void setup_pread_unlink_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_unlink_pb0_1_proc0
// static void setup_pread_unlink_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_p90_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_unlink_pb0_0_final
// static void setup_pread_unlink_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_p90_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_p90_0_0
// static int test_pread_unlink_p90_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pe_0_1
static void setup_pread_unlink_p90_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_pread_unlink_p90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_unlink_pb0_2_proc0
// static void setup_pread_unlink_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_p90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_unlink_pb0_2_final
// static void setup_pread_unlink_p90_2_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_p90_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_p90_0_0
// static int test_pread_unlink_p90_3_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pe_0_1
// static void setup_pread_unlink_p90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_unlink_p90_2_common
// static void setup_pread_unlink_p90_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_unlink_pb0_1_proc0
// static void setup_pread_unlink_p90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_p90_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_unlink_pb0_2_final
// static void setup_pread_unlink_p90_3_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_p90_0_0
// static int test_pread_unlink_p80_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pc_0_1
static void setup_pread_unlink_p80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_unlink_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_unlink_pa_0_proc0
// static void setup_pread_unlink_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_unlink_pb0_2_final
// static void setup_pread_unlink_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_p80_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_p90_0_0
// static int test_pread_unlink_p80_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pc_0_1
// static void setup_pread_unlink_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_unlink_p80_0_common
// static void setup_pread_unlink_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_unlink_pb0_1_proc0
// static void setup_pread_unlink_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_unlink_pb0_2_final
// static void setup_pread_unlink_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
static int test_pread_unlink_p4_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_unlink_p4_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pe_0_1
// static void setup_pread_unlink_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pread_unlink_pb0_2_common
// static void setup_pread_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_unlink_pb0_2_final
// static void setup_pread_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal

/*
 * calls: pread unlink
 */
// static int test_pread_unlink_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_unlink_p4_0_0
// static int test_pread_unlink_p0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pread_unlink_pc_0_1
static void setup_pread_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pread_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_unlink_pb0_0_proc1
// static void setup_pread_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal
// static void setup_pread_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_unlink_pb0_0_procfinal


/*
 * calls: pread write
 */
static int test_pread_write_pfe_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_write_pfe_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pread_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_write_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_pread_write_pfe_0_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: pread write
 */
// static int test_pread_write_pfe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pfe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_0_1
// static void setup_pread_write_pfe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pfe_0_common
static void setup_pread_write_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pfe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_0_proc1
// static void setup_pread_write_pfe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pread_write_pfe_0_final
// static void setup_pread_write_pfe_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pread_write_pfe_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pfe_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pfe_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_0_1
static void setup_pread_write_pfe_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_write_pfe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_write_pfe_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_write_pfe_2_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pread_write_pfe_2_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pread write
 */
// static int test_pread_write_pfe_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
static int test_pread_write_pfe_3_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_pread_write_pfe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pfe_2_common
static void setup_pread_write_pfe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pfe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_2_proc1
// static void setup_pread_write_pfe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pfe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pfc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
static int test_pread_write_pfc_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pread_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_write_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pfc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pfc_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
// static void setup_pread_write_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pfc_0_common
static void setup_pread_write_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pfc_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
static int test_pread_write_pfc_2_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_pread_write_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pfc_0_common
static void setup_pread_write_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pf8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
static int test_pread_write_pf8_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pread_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pf8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pf8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf8_0_common
static void setup_pread_write_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pf8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
static int test_pread_write_pf8_2_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_pread_write_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf8_0_common
static void setup_pread_write_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pf4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pf4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_write_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pf4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pf4_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_write_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pf0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf4_0_proc0
// static void setup_pread_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pf0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pf0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_write_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf4_1_proc0
// static void setup_pread_write_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pe_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf8_0_common
// static void setup_pread_write_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf8_0_common
// static void setup_pread_write_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pde_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pde_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_3_1
static void setup_pread_write_pde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_write_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pread_write_pde_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pread_write_pfe_0_final
// static void setup_pread_write_pde_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pread_write_pfe_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pde_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pde_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_3_1
// static void setup_pread_write_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pde_0_common
static void setup_pread_write_pde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pde_0_proc1
// static void setup_pread_write_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pread_write_pfe_0_final
// static void setup_pread_write_pde_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pread_write_pfe_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pde_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pde_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_3_1
static void setup_pread_write_pde_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_write_pde_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_3_proc0
// static void setup_pread_write_pde_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_3_proc0
// static void setup_pread_write_pde_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pde_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pdc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pdc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pfc_0_common
// static void setup_pread_write_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pdc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pdc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pfc_0_common
// static void setup_pread_write_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf8_0_common
// static void setup_pread_write_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pd8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pd8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf8_0_common
// static void setup_pread_write_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pd4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pd4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf4_0_common
// static void setup_pread_write_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
static void setup_pread_write_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pd4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pd4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf4_0_common
// static void setup_pread_write_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pd4_0_proc1
// static void setup_pread_write_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf0_0_common
// static void setup_pread_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pd4_0_proc1
// static void setup_pread_write_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pd0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pd0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf0_0_common
// static void setup_pread_write_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pd4_0_proc1
// static void setup_pread_write_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf8_0_common
// static void setup_pread_write_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pfe_0_0
// static int test_pread_write_pc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf8_0_common
// static void setup_pread_write_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_pbf_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_write_pbf_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_0_1
static void setup_pread_write_pbf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_write_pbf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pbf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_2_proc1
// static void setup_pread_write_pbf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pbf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pbf_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pbf_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_0_1
// static void setup_pread_write_pbf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pbf_0_common
static void setup_pread_write_pbf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pbf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_2_proc1
// static void setup_pread_write_pbf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pbf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pbe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pbe_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pbe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_write_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pbe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pbe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
// static void setup_pread_write_pbe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pbe_0_common
static void setup_pread_write_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pbc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pbc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pbe_0_common
static void setup_pread_write_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pbc_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pbc_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pbe_0_common
static void setup_pread_write_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pbb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pbb0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pbb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_pbb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_write_pbb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pread_write_pbb0_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_pread_write_pbb0_0_procfinal(void) {
  
}

/*
 * calls: pread write
 */
static int test_pread_write_pbb0_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_write_pbb0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pbb0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pread_write_pbb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pbb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pbb0_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_pbb0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_pbb0_2_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_write_pbb0_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pbb0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pread_write_pbb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pbb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
static void setup_pread_write_pbb0_2_final(void) {
  unlink("__i0");
}
// static void setup_pread_write_pbb0_2_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pbb0_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbb0_2_0
// static int test_pread_write_pbb0_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
// static void setup_pread_write_pbb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_common
static void setup_pread_write_pbb0_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pbb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pbb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pbb0_3_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pbb0_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbb0_2_0
// static int test_pread_write_pbb0_4_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pbb0_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_common
static void setup_pread_write_pbb0_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pbb0_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pbb0_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pbb0_4_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pb8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pb8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pb8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_pb8_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 20480);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_write_pb8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pb8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pb8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbb0_2_0
// static int test_pread_write_pb8_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pb8_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_write_pb8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_proc0
// static void setup_pread_write_pb8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pb8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pb8_2_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_pb8_3_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 32768);
  expect_result("r", r, 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_write_pb8_3_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_pb8_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_pb8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pb8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pb8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pb8_3_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pb8_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbb0_2_0
// static int test_pread_write_pb8_4_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pb8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_2_common
// static void setup_pread_write_pb8_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_pb8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pb8_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pb8_4_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pb0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_common
static void setup_pread_write_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pb0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pb0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_common
// static void setup_pread_write_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_paf_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_paf_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_3_1
// static void setup_pread_write_paf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pbf_0_common
static void setup_pread_write_paf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_paf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_3_proc0
// static void setup_pread_write_paf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_paf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_paf_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_paf_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_3_1
// static void setup_pread_write_paf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pbf_0_common
static void setup_pread_write_paf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_paf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_3_proc0
// static void setup_pread_write_paf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_paf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pae_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pae_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pbe_0_common
static void setup_pread_write_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pae_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pae_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pbe_0_common
// static void setup_pread_write_pae_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pd4_0_proc1
// static void setup_pread_write_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pac_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pac_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pbe_0_common
// static void setup_pread_write_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pae_0_proc0
// static void setup_pread_write_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pac_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pac_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pbe_0_common
// static void setup_pread_write_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pd4_0_proc1
// static void setup_pread_write_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pab0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pab0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pab0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_0_common
static void setup_pread_write_pab0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_write_pab0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pab0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pab0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbb0_2_0
// static int test_pread_write_pab0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pab0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_common
// static void setup_pread_write_pab0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_pab0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_pab0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pab0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pab0_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pab0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
static void setup_pread_write_pab0_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_write_pab0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
static void setup_pread_write_pab0_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pab0_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_pab0_2_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pab0_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbb0_2_0
// static int test_pread_write_pab0_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pab0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_common
// static void setup_pread_write_pab0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pab0_0_proc0
// static void setup_pread_write_pab0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_pab0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pab0_3_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pa8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pa8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_0_common
static void setup_pread_write_pa8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pab0_2_proc1
// static void setup_pread_write_pa8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pa8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pa8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pa8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_0_common
// static void setup_pread_write_pa8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pab0_2_proc1
// static void setup_pread_write_pa8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pa8_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbb0_2_0
// static int test_pread_write_pa8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pa8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_2_common
// static void setup_pread_write_pa8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_pa8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_pa8_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pa8_2_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pa8_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 32768);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pb8_3_0
// static int test_pread_write_pa8_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_pa8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_3_common
static void setup_pread_write_pa8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_write_pa8_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_pa8_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pa8_3_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pa0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_common
// static void setup_pread_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pb0_0_proc0
// static void setup_pread_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_pa0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_pbf_0_0
// static int test_pread_write_pa0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_common
// static void setup_pread_write_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_p9f0_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_write_p9f0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_0_1
static void setup_pread_write_p9f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_write_p9f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pbf_0_proc0
// static void setup_pread_write_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_2_proc1
// static void setup_pread_write_p9f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p9f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p9f0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p9f0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_0_1
static void setup_pread_write_p9f0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pread_write_p9f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pbf_1_proc0
// static void setup_pread_write_p9f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_2_proc1
// static void setup_pread_write_p9f0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p9f0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p9e0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p9e0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_p9e0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pread_write_p9e0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_p9e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_p9e0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p9e0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p9e0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p9e0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
// static void setup_pread_write_p9e0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf0_0_common
// static void setup_pread_write_p9e0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pbe_1_proc0
// static void setup_pread_write_p9e0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_p9e0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p9e0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p9c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p9c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_p9f0_0_common
static void setup_pread_write_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p9c_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p9c_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_p9f0_1_common
// static void setup_pread_write_p9c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pbc_1_proc0
// static void setup_pread_write_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_p9a_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 16384);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_write_p9a_0_1(void) {
  ssize_t r = write(11, dataval1, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pread_write_p9a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 49152, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p9a_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p9a_1_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_0_1
static void setup_pread_write_p9a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p9a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p9a_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p9a_2_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_0_1
static void setup_pread_write_p9a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p9a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_p9a_3_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 20480);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
static int test_pread_write_p9a_3_1(void) {
  ssize_t r = write(10, dataval1, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pread_write_p9a_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_write_p9a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pa8_0_proc0
// static void setup_pread_write_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p9a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p990_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p990_0_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_0_1
static void setup_pread_write_p990_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_p990_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36864, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p990_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p990_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p990_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_p990_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_write_p990_1_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_0_1
static void setup_pread_write_p990_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_p990_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p990_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p990_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_p990_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_p990_2_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 8192);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_write_p990_2_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_0_1
static void setup_pread_write_p990_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_p990_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p990_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p990_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p990_2_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p990_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p990_3_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_0_1
// static void setup_pread_write_p990_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_p990_0_common
// static void setup_pread_write_p990_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_p9a_2_proc0
// static void setup_pread_write_p990_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p990_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p990_3_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p990_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p990_4_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
static void setup_pread_write_p990_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_write_p990_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_proc0
// static void setup_pread_write_p990_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p990_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p990_4_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p990_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p990_2_0
// static int test_pread_write_p990_5_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_3_1
// static void setup_pread_write_p990_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_p990_2_common
static void setup_pread_write_p990_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p990_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p990_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p990_5_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p990_6_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p990_6_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
static void setup_pread_write_p990_6_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_write_p990_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_p990_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p990_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p990_6_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p90_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p90_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_2_common
static void setup_pread_write_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p90_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p90_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_2_common
// static void setup_pread_write_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p8f0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p8f0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_3_1
// static void setup_pread_write_p8f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_p9f0_0_common
// static void setup_pread_write_p8f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_paf_0_proc0
// static void setup_pread_write_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_3_proc0
// static void setup_pread_write_p8f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p8f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p8f0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p8f0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_3_1
// static void setup_pread_write_p8f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_p9f0_1_common
// static void setup_pread_write_p8f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_paf_1_proc0
// static void setup_pread_write_p8f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_3_proc0
// static void setup_pread_write_p8f0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p8f0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p8e0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p8e0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_p8e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_p9e0_0_common
static void setup_pread_write_p8e0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_p8e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_p8e0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p8e0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p8e0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p8e0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_p8e0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf0_0_common
// static void setup_pread_write_p8e0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pd4_0_proc1
// static void setup_pread_write_p8e0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_p8e0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p8e0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p8c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p8c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_p9f0_0_common
// static void setup_pread_write_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_p8e0_0_proc0
// static void setup_pread_write_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p8c_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p8c_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_p9f0_1_common
// static void setup_pread_write_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pd4_0_proc1
// static void setup_pread_write_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p8a_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 16384);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9a_0_0
// static int test_pread_write_p8a_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_3_1
// static void setup_pread_write_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_p9a_0_common
static void setup_pread_write_p8a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 49152, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_p90_0_proc0
// static void setup_pread_write_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_p8a_1_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 24576);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_write_p8a_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_3_1
static void setup_pread_write_p8a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_write_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pa8_3_proc1
static void setup_pread_write_p8a_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p8a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p8a_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 24576);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p8a_1_0
// static int test_pread_write_p8a_2_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_3_1
static void setup_pread_write_p8a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_write_p8a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pa8_0_proc0
// static void setup_pread_write_p8a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_p8a_1_proc1
// static void setup_pread_write_p8a_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p8a_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 20480);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9a_3_0
// static int test_pread_write_p8a_3_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_3_1
// static void setup_pread_write_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_p9a_3_common
// static void setup_pread_write_p8a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_p90_0_proc0
// static void setup_pread_write_p8a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pa8_0_proc0
// static void setup_pread_write_p8a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p890_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p890_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_3_1
// static void setup_pread_write_p890_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_p990_0_common
static void setup_pread_write_p890_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36864, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p890_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pab0_0_proc0
// static void setup_pread_write_p890_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p890_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p890_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p990_2_0
// static int test_pread_write_p890_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_3_1
static void setup_pread_write_p890_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pread_write_p890_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pread_write_p890_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p890_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_p890_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p890_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p990_2_0
// static int test_pread_write_p890_2_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_3_1
static void setup_pread_write_p890_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_write_p890_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pb0_0_proc0
static void setup_pread_write_p890_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p890_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pread_write_pbb0_0_final
// static void setup_pread_write_p890_2_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p890_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p990_2_0
// static int test_pread_write_p890_3_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_3_1
static void setup_pread_write_p890_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pread_write_p890_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pab0_0_proc0
// static void setup_pread_write_p890_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pab0_0_proc0
// static void setup_pread_write_p890_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p890_3_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p890_4_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 8192);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p990_2_0
// static int test_pread_write_p890_4_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_p9a_3_1
// static void setup_pread_write_p890_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_p890_3_common
// static void setup_pread_write_p890_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pb0_0_proc0
// static void setup_pread_write_p890_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pab0_0_proc0
// static void setup_pread_write_p890_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p890_4_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p890_5_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p990_1_0
// static int test_pread_write_p890_5_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_p890_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_p990_4_common
// static void setup_pread_write_p890_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pab0_0_proc0
// static void setup_pread_write_p890_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pab0_0_proc0
// static void setup_pread_write_p890_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p890_5_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p80_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_2_common
// static void setup_pread_write_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_p90_0_proc0
// static void setup_pread_write_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p80_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p9f0_0_0
// static int test_pread_write_p80_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_2_common
// static void setup_pread_write_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
static int test_pread_write_p7c_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = pread(10, data, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return data[0];
}
// static int test_pread_write_p7c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_0_1
// static void setup_pread_write_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pfe_2_common
static void setup_pread_write_p7c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_2_proc1
// static void setup_pread_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p78_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p78_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
// static void setup_pread_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pfc_0_common
static void setup_pread_write_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p70_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p70_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
// static void setup_pread_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf8_0_common
static void setup_pread_write_p70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pread_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p68_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p68_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
// static void setup_pread_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_common
static void setup_pread_write_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pread_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p60_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p60_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_0_1
// static void setup_pread_write_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_2_common
// static void setup_pread_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_p68_0_proc0
// static void setup_pread_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_0_1
static void setup_pread_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pread_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p4_0_final(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal
// static void setup_pread_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pread_write_p4_0_common
// static void setup_pread_write_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p4_1_final(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal
// static void setup_pread_write_p4_1_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p3c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfe_3_1
// static void setup_pread_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pde_2_common
// static void setup_pread_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_2_proc1
// static void setup_pread_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfe_3_proc0
// static void setup_pread_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p38_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pfc_0_common
// static void setup_pread_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_2_proc0
// static void setup_pread_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p30_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pread_write_pf8_0_common
// static void setup_pread_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pfc_0_proc1
// static void setup_pread_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pread_write_pf8_2_proc0
// static void setup_pread_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_final
// static void setup_pread_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pread_write_pfe_2_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p28_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_2_common
// static void setup_pread_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p20_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pfc_2_1
// static void setup_pread_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pread_write_pb8_2_common
// static void setup_pread_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pread_write_pbb0_4_proc0
// static void setup_pread_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pread_write_pbb0_2_final
// static void setup_pread_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal

/*
 * calls: pread write
 */
// static int test_pread_write_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = pread(10, data, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pread_write_p7c_0_0
// static int test_pread_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pread_write_pf8_2_1
// static void setup_pread_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pread_write_p4_0_common
// static void setup_pread_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pread_write_pbb0_0_proc1
// static void setup_pread_write_p0_0_final(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal
// static void setup_pread_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pread_write_pbb0_0_procfinal


/*
 * calls: pwrite pwrite
 */
static int test_pwrite_pwrite_pf8_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static int test_pwrite_pwrite_pf8_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_pwrite_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_pwrite_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_pwrite_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pwrite_pwrite_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf8_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf8_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
static void setup_pwrite_pwrite_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf8_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf8_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
static void setup_pwrite_pwrite_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf8_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_pf8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
static void setup_pwrite_pwrite_pf8_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pf8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf8_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf8_4_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_pf8_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
static void setup_pwrite_pwrite_pf8_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pf8_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf8_4_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf8_4_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
static int test_pwrite_pwrite_pf4_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_pwrite_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf4_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf4_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
static void setup_pwrite_pwrite_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_pwrite_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf4_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf4_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
// static void setup_pwrite_pwrite_pf4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_1_common
static void setup_pwrite_pwrite_pf4_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pf4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf4_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf4_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
// static void setup_pwrite_pwrite_pf4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_1_common
static void setup_pwrite_pwrite_pf4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pf4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
static void setup_pwrite_pwrite_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_pwrite_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
static void setup_pwrite_pwrite_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_pwrite_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf4_1_proc0
// static void setup_pwrite_pwrite_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf0_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf0_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
// static void setup_pwrite_pwrite_pf0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_1_common
static void setup_pwrite_pwrite_pf0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pf0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pf0_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pf0_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
// static void setup_pwrite_pwrite_pf0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_1_common
// static void setup_pwrite_pwrite_pf0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf4_3_proc0
// static void setup_pwrite_pwrite_pf0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pf0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pf0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pe_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
static int test_pwrite_pwrite_pe_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_pwrite_pwrite_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
// static void setup_pwrite_pwrite_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pe_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pe_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pe_0_1
// static void setup_pwrite_pwrite_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
// static void setup_pwrite_pwrite_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd8_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd8_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
// static void setup_pwrite_pwrite_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd8_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd8_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
// static void setup_pwrite_pwrite_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd8_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd8_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_pd8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
// static void setup_pwrite_pwrite_pd8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_pd8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pd8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd8_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd8_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_pd8_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
// static void setup_pwrite_pwrite_pd8_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pd8_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pd8_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd8_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
static int test_pwrite_pwrite_pd4_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pwrite_pwrite_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_0_common
// static void setup_pwrite_pwrite_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
static void setup_pwrite_pwrite_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd4_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_1_common
// static void setup_pwrite_pwrite_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
static void setup_pwrite_pwrite_pd4_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd4_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd4_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_pd4_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_1_common
// static void setup_pwrite_pwrite_pd4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
static void setup_pwrite_pwrite_pd4_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pd4_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd4_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd4_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd4_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_pd4_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_0_common
// static void setup_pwrite_pwrite_pd4_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pd4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pd4_1_proc1
// static void setup_pwrite_pwrite_pd4_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd4_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_0_common
// static void setup_pwrite_pwrite_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
static void setup_pwrite_pwrite_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_1_common
// static void setup_pwrite_pwrite_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pd4_1_proc1
// static void setup_pwrite_pwrite_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd0_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd0_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_pd0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_1_common
// static void setup_pwrite_pwrite_pd0_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pd0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36270080, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pd4_0_proc1
// static void setup_pwrite_pwrite_pd0_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd0_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pd0_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pd0_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_pd0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_1_common
// static void setup_pwrite_pwrite_pd0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pd0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pd4_1_proc1
// static void setup_pwrite_pwrite_pd0_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pd0_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
static int test_pwrite_pwrite_pc_0_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static void setup_pwrite_pwrite_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
// static void setup_pwrite_pwrite_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static int test_pwrite_pwrite_pc_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static void setup_pwrite_pwrite_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
// static void setup_pwrite_pwrite_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pbc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pbc_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_0_common
static void setup_pwrite_pwrite_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pbc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pbc_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_1_common
static void setup_pwrite_pwrite_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pbc_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pbc_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_pbc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_1_common
static void setup_pwrite_pwrite_pbc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pbc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pbc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pbc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pbc_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pbc_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_pbc_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_1_common
static void setup_pwrite_pwrite_pbc_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pbc_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_pbc_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pbc_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pba_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
static int test_pwrite_pwrite_pba_0_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_pwrite_pba_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pwrite_pwrite_pba_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_pwrite_pwrite_pba_0_procfinal(void) {
  
}

/*
 * calls: pwrite pwrite
 */
static int test_pwrite_pwrite_pba_1_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_pwrite_pba_1_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pba_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 102400, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pba_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_pba_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
static int test_pwrite_pwrite_pb90_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 12288);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_pwrite_pb90_0_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 12288);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pb90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_pb90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
static void setup_pwrite_pwrite_pb90_0_final(void) {
  unlink("__i0");
}
// static void setup_pwrite_pwrite_pb90_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pb90_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_0_0
// static int test_pwrite_pwrite_pb90_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_0_0
// static void setup_pwrite_pwrite_pb90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_0_common
static void setup_pwrite_pwrite_pb90_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb90_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
static int test_pwrite_pwrite_pb90_2_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_pwrite_pb90_2_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pb90_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_pb90_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 81920, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb90_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pb90_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
// static int test_pwrite_pwrite_pb90_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_1
// static void setup_pwrite_pwrite_pb90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_2_common
static void setup_pwrite_pwrite_pb90_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb90_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb90_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
static int test_pwrite_pwrite_pb90_4_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_pwrite_pb90_4_1(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pb90_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_pb90_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb90_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb90_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb90_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
static int test_pwrite_pwrite_pb80_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_pwrite_pb80_0_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pb80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_pwrite_pb80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_0_proc0
// static void setup_pwrite_pwrite_pb80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pb80_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_pb80_1_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_0_1
static void setup_pwrite_pwrite_pb80_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_pb80_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 73728, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb80_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_pb80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pb80_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
// static int test_pwrite_pwrite_pb80_2_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_1_1
static void setup_pwrite_pwrite_pb80_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_pb80_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 77824, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb80_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb80_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb80_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pb80_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_0_0
// static int test_pwrite_pwrite_pb80_3_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_1_1
static void setup_pwrite_pwrite_pb80_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_pb80_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb80_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb80_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_pb80_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pb80_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
static int test_pwrite_pwrite_pb80_4_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pb80_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_pb80_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb80_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb80_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_pb80_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pb80_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
// static int test_pwrite_pwrite_pb80_5_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_1_1
// static void setup_pwrite_pwrite_pb80_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_2_common
static void setup_pwrite_pwrite_pb80_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb80_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb80_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb80_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
static int test_pwrite_pwrite_pb80_6_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_pwrite_pb80_6_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 16384);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pb80_6_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_pwrite_pb80_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_pb80_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb80_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb80_6_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pb80_7_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
static int test_pwrite_pwrite_pb80_7_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pwrite_pwrite_pb80_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_2_common
static void setup_pwrite_pwrite_pb80_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb80_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb80_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb80_7_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pb0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pb0_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pe_0_1
static void setup_pwrite_pwrite_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pwrite_pwrite_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pb0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pb0_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pe_0_1
// static void setup_pwrite_pwrite_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_0_common
static void setup_pwrite_pwrite_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pac_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pac_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_0_common
// static void setup_pwrite_pwrite_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pd4_2_proc1
// static void setup_pwrite_pwrite_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pac_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pac_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_1_common
// static void setup_pwrite_pwrite_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pd4_1_proc1
// static void setup_pwrite_pwrite_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pac_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pac_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_pac_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_1_common
static void setup_pwrite_pwrite_pac_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_pac_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pac_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pac_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pac_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pac_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_pac_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf4_0_common
// static void setup_pwrite_pwrite_pac_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pd4_1_proc1
// static void setup_pwrite_pwrite_pac_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_pac_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_pac_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_paa_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
static int test_pwrite_pwrite_paa_0_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 12288);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pwrite_pwrite_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_1_common
// static void setup_pwrite_pwrite_paa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
static void setup_pwrite_pwrite_paa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_paa_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_paa_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_paa_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
static int test_pwrite_pwrite_paa_1_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_paa_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_paa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 102400, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_pwrite_paa_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_paa_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_paa_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_paa_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_1_0
static int test_pwrite_pwrite_paa_2_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_paa_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_paa_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_pwrite_paa_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 102400, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_paa_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_paa_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pa90_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_1_0
// static int test_pwrite_pwrite_pa90_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_1_0
static void setup_pwrite_pwrite_pa90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_pwrite_pa90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_pa90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_pa90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pa90_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pa90_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_0_0
// static int test_pwrite_pwrite_pa90_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_0_0
// static void setup_pwrite_pwrite_pa90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_0_common
static void setup_pwrite_pwrite_pa90_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_pwrite_pa90_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 86016, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pa90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pa90_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pa90_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_0_0
// static int test_pwrite_pwrite_pa90_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_0_0
// static void setup_pwrite_pwrite_pa90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_0_common
// static void setup_pwrite_pwrite_pa90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 12288, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pa90_1_proc0
// static void setup_pwrite_pwrite_pa90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 12288, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pa90_1_proc0
// static void setup_pwrite_pwrite_pa90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pa90_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pa80_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_6_0
// static int test_pwrite_pwrite_pa80_0_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_6_1
// static void setup_pwrite_pwrite_pa80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_6_common
// static void setup_pwrite_pwrite_pa80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_pa80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_pa80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pa80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
static int test_pwrite_pwrite_pa80_1_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_pwrite_pa80_1_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_pa80_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_pa80_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_pwrite_pa80_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 94208, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pa80_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_pa80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pa80_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
// static int test_pwrite_pwrite_pa80_2_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_7_1
// static void setup_pwrite_pwrite_pa80_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_2_common
// static void setup_pwrite_pwrite_pa80_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_4_proc0
// static void setup_pwrite_pwrite_pa80_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 86016, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pa90_1_proc1
// static void setup_pwrite_pwrite_pa80_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pa80_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pa80_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
static int test_pwrite_pwrite_pa80_3_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pwrite_pwrite_pa80_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_1_common
// static void setup_pwrite_pwrite_pa80_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_4_proc0
static void setup_pwrite_pwrite_pa80_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_pa80_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_pa80_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pa80_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_0_0
// static int test_pwrite_pwrite_pa80_4_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pa80_3_1
static void setup_pwrite_pwrite_pa80_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_pwrite_pa80_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 12288, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pa90_1_proc0
// static void setup_pwrite_pwrite_pa80_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_7_proc0
// static void setup_pwrite_pwrite_pa80_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pa80_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pa0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pa0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static void setup_pwrite_pwrite_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_0_common
// static void setup_pwrite_pwrite_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_0_proc0
// static void setup_pwrite_pwrite_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_pa0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_pa0_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static void setup_pwrite_pwrite_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_0_common
// static void setup_pwrite_pwrite_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_1_proc0
// static void setup_pwrite_pwrite_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9c_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p9c_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_0_common
static void setup_pwrite_pwrite_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9c_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p9c_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_1_common
// static void setup_pwrite_pwrite_p9c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pbc_1_proc0
// static void setup_pwrite_pwrite_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9c_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p9c_2_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_p9c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_1_common
static void setup_pwrite_pwrite_p9c_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_p9c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_p9c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p9c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9c_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p9c_3_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
static void setup_pwrite_pwrite_p9c_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_pwrite_p9c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pbc_3_proc0
// static void setup_pwrite_pwrite_p9c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_p9c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p9c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9a_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p9a_0_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_1_1
static void setup_pwrite_pwrite_p9a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_pwrite_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_0_proc0
// static void setup_pwrite_pwrite_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9a_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pa80_1_0
static int test_pwrite_pwrite_p9a_1_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_p9a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 90112, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p9a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9a_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
static int test_pwrite_pwrite_p9a_2_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 12288);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pwrite_pwrite_p9a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_4_common
static void setup_pwrite_pwrite_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 81920, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p9a_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9a_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
// static int test_pwrite_pwrite_p9a_3_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_1_1
static void setup_pwrite_pwrite_p9a_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_p9a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p9a_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9a_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p9a_4_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_1_1
// static void setup_pwrite_pwrite_p9a_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p9a_0_common
static void setup_pwrite_pwrite_p9a_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 77824, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p9a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p9a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p9a_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9a_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p9a_5_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_0_1
// static void setup_pwrite_pwrite_p9a_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_2_common
// static void setup_pwrite_pwrite_p9a_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_3_proc0
// static void setup_pwrite_pwrite_p9a_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p9a_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p9a_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p9a_6_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pa80_1_0
// static int test_pwrite_pwrite_p9a_6_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pa80_1_1
// static void setup_pwrite_pwrite_p9a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_0_common
// static void setup_pwrite_pwrite_p9a_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_p9a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p9a_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p9a_6_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
static int test_pwrite_pwrite_p9a_7_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 16384);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_pwrite_p9a_7_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pwrite_pwrite_p9a_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_6_common
static void setup_pwrite_pwrite_p9a_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p9a_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p9a_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p9a_7_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pa80_1_0
// static int test_pwrite_pwrite_p98_0_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_p9a_2_1
// static void setup_pwrite_pwrite_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_0_common
// static void setup_pwrite_pwrite_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_0_proc0
// static void setup_pwrite_pwrite_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
// static int test_pwrite_pwrite_p98_1_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_p9a_2_1
static void setup_pwrite_pwrite_p98_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 86016, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p98_2_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_4_1
// static void setup_pwrite_pwrite_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_4_common
static void setup_pwrite_pwrite_p98_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p98_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
static int test_pwrite_pwrite_p98_3_1(void) {
  ssize_t r = pwrite(11, dataval1, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_p98_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_pwrite_p98_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_3_proc0
// static void setup_pwrite_pwrite_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p98_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
// static int test_pwrite_pwrite_p98_4_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_p98_3_1
static void setup_pwrite_pwrite_p98_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_p98_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p98_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p98_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p98_5_1(void) {
//   ssize_t r = pwrite(11, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pba_0_1
// static void setup_pwrite_pwrite_p98_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pa80_4_common
// static void setup_pwrite_pwrite_p98_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_5_proc0
// static void setup_pwrite_pwrite_p98_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_6_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p98_6_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pa80_3_1
// static void setup_pwrite_pwrite_p98_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pa80_4_common
// static void setup_pwrite_pwrite_p98_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_p98_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_6_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_7_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_p9a_7_0
// static int test_pwrite_pwrite_p98_7_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_paa_0_1
// static void setup_pwrite_pwrite_p98_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_6_common
static void setup_pwrite_pwrite_p98_7_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p98_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_7_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_8_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
static int test_pwrite_pwrite_p98_8_1(void) {
  ssize_t r = pwrite(11, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static void setup_pwrite_pwrite_p98_8_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_2_common
static void setup_pwrite_pwrite_p98_8_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p98_8_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_8_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_8_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_9_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p98_9_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_p98_8_1
// static void setup_pwrite_pwrite_p98_9_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_2_common
static void setup_pwrite_pwrite_p98_9_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23982080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p98_9_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_9_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_9_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_10_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p98_10_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_p98_8_1
// static void setup_pwrite_pwrite_p98_10_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_2_common
static void setup_pwrite_pwrite_p98_10_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2494464, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p98_10_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_10_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_10_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_11_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p98_11_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static void setup_pwrite_pwrite_p98_11_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_2_common
static void setup_pwrite_pwrite_p98_11_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23982080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p98_11_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_11_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_11_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_12_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p98_12_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_p98_8_1
// static void setup_pwrite_pwrite_p98_12_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_2_common
// static void setup_pwrite_pwrite_p98_12_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_5_proc0
// static void setup_pwrite_pwrite_p98_12_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_12_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_12_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p98_13_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p98_13_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static void setup_pwrite_pwrite_p98_13_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_2_common
// static void setup_pwrite_pwrite_p98_13_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_4_proc0
// static void setup_pwrite_pwrite_p98_13_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p98_13_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p98_13_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p90_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p90_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pe_0_1
static void setup_pwrite_pwrite_p90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p90_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p90_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pe_0_1
// static void setup_pwrite_pwrite_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p90_0_common
// static void setup_pwrite_pwrite_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_1_proc0
// static void setup_pwrite_pwrite_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8c_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p8c_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_0_common
static void setup_pwrite_pwrite_p8c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8c_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p8c_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_1_common
// static void setup_pwrite_pwrite_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pd4_1_proc1
// static void setup_pwrite_pwrite_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8c_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p8c_2_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_p8c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_1_common
// static void setup_pwrite_pwrite_p8c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pd4_2_proc1
// static void setup_pwrite_pwrite_p8c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_p8c_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p8c_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8c_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p8c_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_p8c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf0_1_common
// static void setup_pwrite_pwrite_p8c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pd4_1_proc1
// static void setup_pwrite_pwrite_p8c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_p8c_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p8c_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8a_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p8a_0_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_7_1
// static void setup_pwrite_pwrite_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p9a_0_common
// static void setup_pwrite_pwrite_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8a_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pa80_1_0
// static int test_pwrite_pwrite_p8a_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pa80_1_1
static void setup_pwrite_pwrite_p8a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_p8a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 94208, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pa80_1_proc1
// static void setup_pwrite_pwrite_p8a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8a_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p8a_2_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_7_1
// static void setup_pwrite_pwrite_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p9a_0_common
// static void setup_pwrite_pwrite_p8a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_1_proc0
static void setup_pwrite_pwrite_p8a_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 77824, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p8a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8a_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_0_0
// static int test_pwrite_pwrite_p8a_3_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_paa_2_1
// static void setup_pwrite_pwrite_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_paa_2_common
// static void setup_pwrite_pwrite_p8a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 28672, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p8a_1_proc0
static void setup_pwrite_pwrite_p8a_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p8a_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8a_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_6_0
// static int test_pwrite_pwrite_p8a_4_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_paa_2_1
static void setup_pwrite_pwrite_p8a_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_pwrite_p8a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pa80_1_proc0
// static void setup_pwrite_pwrite_p8a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p9a_7_proc0
// static void setup_pwrite_pwrite_p8a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p8a_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8a_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_p9a_7_0
// static int test_pwrite_pwrite_p8a_5_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_6_1
static void setup_pwrite_pwrite_p8a_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_p8a_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4677632, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_pwrite_p8a_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p8a_5_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p8a_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p8a_6_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_p9a_7_0
// static int test_pwrite_pwrite_p8a_6_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_6_1
// static void setup_pwrite_pwrite_p8a_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p8a_5_common
// static void setup_pwrite_pwrite_p8a_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 16384, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p98_7_proc0
// static void setup_pwrite_pwrite_p8a_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 16384, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p8a_5_proc1
// static void setup_pwrite_pwrite_p8a_6_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p8a_6_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p88_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pa80_1_0
// static int test_pwrite_pwrite_p88_0_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_paa_0_1
// static void setup_pwrite_pwrite_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_0_common
// static void setup_pwrite_pwrite_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_1_proc0
// static void setup_pwrite_pwrite_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p88_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p88_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pa80_1_0
// static int test_pwrite_pwrite_p88_1_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_p9a_7_1
static void setup_pwrite_pwrite_p88_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_pwrite_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p9a_7_proc0
static void setup_pwrite_pwrite_p88_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 81920, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p88_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p88_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_6_0
// static int test_pwrite_pwrite_p88_2_1(void) {
//   ssize_t r = pwrite(10, dataval1, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_6_1
// static void setup_pwrite_pwrite_p88_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p8a_4_common
// static void setup_pwrite_pwrite_p88_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p9a_7_proc0
// static void setup_pwrite_pwrite_p88_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p9a_7_proc0
// static void setup_pwrite_pwrite_p88_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p88_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p88_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_6_0
// static int test_pwrite_pwrite_p88_3_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb80_6_0
static void setup_pwrite_pwrite_p88_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_pwrite_p88_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_pwrite_p88_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 1839104, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p88_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p88_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p88_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
static int test_pwrite_pwrite_p88_4_1(void) {
  ssize_t r = pwrite(10, dataval1, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static void setup_pwrite_pwrite_p88_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_pwrite_p88_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_4_proc0
static void setup_pwrite_pwrite_p88_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p88_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_pwrite_pba_0_final
// static void setup_pwrite_pwrite_p88_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p88_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
// static int test_pwrite_pwrite_p88_5_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_2_0
// static void setup_pwrite_pwrite_p88_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_0_common
// static void setup_pwrite_pwrite_p88_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb80_7_proc0
static void setup_pwrite_pwrite_p88_5_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2494464, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p88_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p88_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p88_6_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p88_6_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static void setup_pwrite_pwrite_p88_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_2_common
// static void setup_pwrite_pwrite_p88_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 2494464, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p88_5_proc1
// static void setup_pwrite_pwrite_p88_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_4_proc0
// static void setup_pwrite_pwrite_p88_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p88_6_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p88_7_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static int test_pwrite_pwrite_p88_7_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pb90_4_1
// static void setup_pwrite_pwrite_p88_7_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_2_common
// static void setup_pwrite_pwrite_p88_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_4_proc0
// static void setup_pwrite_pwrite_p88_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb90_4_proc0
// static void setup_pwrite_pwrite_p88_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p88_7_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p80_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p80_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static void setup_pwrite_pwrite_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p90_0_common
// static void setup_pwrite_pwrite_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p90_0_proc0
// static void setup_pwrite_pwrite_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p80_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static int test_pwrite_pwrite_p80_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static void setup_pwrite_pwrite_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p90_0_common
// static void setup_pwrite_pwrite_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_1_proc0
// static void setup_pwrite_pwrite_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p7_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p7_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_p7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
static void setup_pwrite_pwrite_p7_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_p7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_p7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p7_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p7_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_1
// static void setup_pwrite_pwrite_p7_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
static void setup_pwrite_pwrite_p7_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_pwrite_p7_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_p7_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p7_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p68_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p68_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
// static void setup_pwrite_pwrite_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_0_common
static void setup_pwrite_pwrite_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p68_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p68_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p68_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
// static void setup_pwrite_pwrite_p68_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_0_common
static void setup_pwrite_pwrite_p68_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p68_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p68_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p68_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p60_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p60_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
// static void setup_pwrite_pwrite_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p90_0_common
static void setup_pwrite_pwrite_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p60_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p60_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p60_1_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf4_0_1
// static void setup_pwrite_pwrite_p60_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p90_0_common
// static void setup_pwrite_pwrite_p60_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p68_1_proc0
// static void setup_pwrite_pwrite_p60_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p60_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p60_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p4_0_1(void) {
//   ssize_t r = pwrite(11, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pe_0_1
static void setup_pwrite_pwrite_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pwrite_pwrite_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p4_0_final(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal
// static void setup_pwrite_pwrite_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p4_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p4_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static void setup_pwrite_pwrite_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_p4_0_common
// static void setup_pwrite_pwrite_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p4_1_final(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal
// static void setup_pwrite_pwrite_p4_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p3_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p3_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_p3_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
// static void setup_pwrite_pwrite_p3_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_p3_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_3_proc0
// static void setup_pwrite_pwrite_p3_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p3_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p3_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p3_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pf8_0_0
// static void setup_pwrite_pwrite_p3_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_pwrite_pf8_0_common
// static void setup_pwrite_pwrite_p3_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_0_proc1
// static void setup_pwrite_pwrite_p3_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_pwrite_pf8_4_proc0
// static void setup_pwrite_pwrite_p3_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_final
// static void setup_pwrite_pwrite_p3_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_pwrite_pf8_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p28_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p28_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_0_common
// static void setup_pwrite_pwrite_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
static void setup_pwrite_pwrite_p28_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p28_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p28_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p28_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_p28_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_0_common
// static void setup_pwrite_pwrite_p28_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p28_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_1_proc0
// static void setup_pwrite_pwrite_p28_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p28_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p20_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p20_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p90_0_common
// static void setup_pwrite_pwrite_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
static void setup_pwrite_pwrite_p20_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_pwrite_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p20_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p20_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p20_1_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pd4_0_1
// static void setup_pwrite_pwrite_p20_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_p90_0_common
// static void setup_pwrite_pwrite_p20_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p20_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_pwrite_pb0_1_proc0
// static void setup_pwrite_pwrite_p20_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_pwrite_pb90_0_final
// static void setup_pwrite_pwrite_p20_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal

/*
 * calls: pwrite pwrite
 */
// static int test_pwrite_pwrite_p0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static int test_pwrite_pwrite_p0_0_1(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_pwrite_pc_0_1
// static void setup_pwrite_pwrite_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_p4_0_common
// static void setup_pwrite_pwrite_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_pwrite_pba_0_proc1
// static void setup_pwrite_pwrite_p0_0_final(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal
// static void setup_pwrite_pwrite_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_pwrite_pba_0_procfinal


/*
 * calls: pwrite read
 */
static int test_pwrite_read_pfc_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static int test_pwrite_read_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pwrite_read_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_read_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_read_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pwrite_read_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pfc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pfc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfc_0_common
static void setup_pwrite_read_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pfc_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
static int test_pwrite_read_pfc_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_pwrite_read_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfc_0_common
static void setup_pwrite_read_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pfb_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
static int test_pwrite_read_pfb_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pwrite_read_pfb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pfb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pfb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pfb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pfb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pfb_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pfb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_0_1
// static void setup_pwrite_read_pfb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfb_0_common
static void setup_pwrite_read_pfb_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pfb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pfb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pfb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pfb_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
static int test_pwrite_read_pfb_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_pwrite_read_pfb_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfb_0_common
static void setup_pwrite_read_pfb_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pfb_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pfb_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pfb_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pfa_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
static int test_pwrite_read_pfa_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pwrite_read_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_read_pfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_read_pfa_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_pwrite_read_pfa_0_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pfa_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pfa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
static void setup_pwrite_read_pfa_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_read_pfa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_0_proc0
// static void setup_pwrite_read_pfa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pfa_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pfa_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pfa_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
static int test_pwrite_read_pfa_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_pwrite_read_pfa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfa_1_common
// static void setup_pwrite_read_pfa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pfa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pfa_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pfa_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pfa_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pfa_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
static void setup_pwrite_read_pfa_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pfa_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pfa_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfa_0_proc1
// static void setup_pwrite_read_pfa_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pwrite_read_pfa_0_final
// static void setup_pwrite_read_pfa_3_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pwrite_read_pfa_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pf8_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
static int test_pwrite_read_pf8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pwrite_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_read_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_0_proc0
// static void setup_pwrite_read_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pf8_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pf8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_0_1
// static void setup_pwrite_read_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf8_0_common
// static void setup_pwrite_read_pf8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_1_proc0
// static void setup_pwrite_read_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pf8_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
static int test_pwrite_read_pf8_2_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_pwrite_read_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf8_0_common
// static void setup_pwrite_read_pf8_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pf4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pf4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
static void setup_pwrite_read_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pf4_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pf4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
static void setup_pwrite_read_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pf0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_0_1
static void setup_pwrite_read_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pf0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pf0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_0_1
static void setup_pwrite_read_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pe_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfc_0_common
// static void setup_pwrite_read_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pe_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfc_0_common
// static void setup_pwrite_read_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pdc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfc_0_common
// static void setup_pwrite_read_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pdc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pdc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfc_0_common
// static void setup_pwrite_read_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pdb_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pdb_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_2_1
// static void setup_pwrite_read_pdb_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfb_0_common
// static void setup_pwrite_read_pdb_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pdb_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pdb_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pdb_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pdb_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pdb_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_2_1
// static void setup_pwrite_read_pdb_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfb_0_common
// static void setup_pwrite_read_pdb_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pdb_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pdb_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pdb_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pda_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pda_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
static void setup_pwrite_read_pda_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pda_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_read_pda_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_read_pda_0_final(void) {
  unlink("__i0");
  close(22);
  close(23);
  close(20);
  close(21);
}
static void setup_pwrite_read_pda_0_procfinal(void) {
  close(22);
  close(23);
  close(20);
  close(21);
}

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pda_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pda_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_pda_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfa_3_common
static void setup_pwrite_read_pda_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_read_pda_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pda_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pwrite_read_pfa_0_final
// static void setup_pwrite_read_pda_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pwrite_read_pfa_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pda_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pda_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_pda_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfa_1_common
static void setup_pwrite_read_pda_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_read_pda_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pda_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pda_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pd8_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf8_0_common
// static void setup_pwrite_read_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pd8_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf8_0_common
// static void setup_pwrite_read_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pd4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf4_0_common
// static void setup_pwrite_read_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
static void setup_pwrite_read_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pd4_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pd4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf4_0_common
// static void setup_pwrite_read_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pd4_0_proc1
// static void setup_pwrite_read_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pd0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf0_0_common
// static void setup_pwrite_read_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
static void setup_pwrite_read_pd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pd0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf0_0_common
// static void setup_pwrite_read_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pd0_0_proc1
// static void setup_pwrite_read_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfc_0_common
// static void setup_pwrite_read_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pfc_0_0
// static int test_pwrite_read_pc_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfc_0_common
// static void setup_pwrite_read_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
static int test_pwrite_read_pbe_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_read_pbe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf4_1_common
static void setup_pwrite_read_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pbe_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pbe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
static void setup_pwrite_read_pbe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pbe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pbe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pbe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pbe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
static int test_pwrite_read_pbd8_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_read_pbd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_0_1
static void setup_pwrite_read_pbd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pbd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pbd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pbd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pbd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
static int test_pwrite_read_pbd8_1_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_read_pbd8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_0_1
static void setup_pwrite_read_pbd8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pbd8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pbd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pbd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pbd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pbd0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbd8_0_0
// static int test_pwrite_read_pbd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
// static void setup_pwrite_read_pbd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbd8_0_common
static void setup_pwrite_read_pbd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_read_pbd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pbd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pbd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pbd0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbd8_1_0
// static int test_pwrite_read_pbd0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
// static void setup_pwrite_read_pbd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbd8_1_common
static void setup_pwrite_read_pbd0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pbd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pbd0_0_proc1
// static void setup_pwrite_read_pbd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pbd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pbc0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pbc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_0_1
static void setup_pwrite_read_pbc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_pbc0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pbc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pbc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pbc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pbc0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pbc0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_0_1
// static void setup_pwrite_read_pbc0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbc0_0_common
static void setup_pwrite_read_pbc0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pbc0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_pbc0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pbc0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pba_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pba_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
static void setup_pwrite_read_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36274176, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36274176, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_read_pba_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pwrite_read_pba_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_pwrite_read_pba_0_procfinal(void) {
  
}

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pba_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pba_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
static void setup_pwrite_read_pba_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pwrite_read_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
static void setup_pwrite_read_pba_1_final(void) {
  unlink("__i0");
}
// static void setup_pwrite_read_pba_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pba_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pba_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_pba_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_common
static void setup_pwrite_read_pba_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pba_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pba_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pba_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pba_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pba_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
// static void setup_pwrite_read_pba_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_0_common
static void setup_pwrite_read_pba_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36274176, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pba_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pba_3_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_pba_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pba_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pba_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
// static void setup_pwrite_read_pba_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_common
static void setup_pwrite_read_pba_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pba_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pba_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pba_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
static int test_pwrite_read_pb80_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 12288);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_read_pb80_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 1);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_pwrite_read_pb80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_pb80_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 49152, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pb80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pb80_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_pb80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
static int test_pwrite_read_pb80_1_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_read_pb80_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_0_1
static void setup_pwrite_read_pb80_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_pb80_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 49152, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pb80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pb80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pb80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
static int test_pwrite_read_pb80_2_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_read_pb80_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_0_1
static void setup_pwrite_read_pb80_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_pb80_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pb80_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pb80_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_pb80_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
static int test_pwrite_read_pb80_3_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_read_pb80_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_0_1
static void setup_pwrite_read_pb80_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_pb80_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pb80_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pb80_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pb80_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pb80_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_1_0
static int test_pwrite_read_pb80_4_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 1);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_pwrite_read_pb80_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pb80_1_common
// static void setup_pwrite_read_pb80_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_2_proc0
// static void setup_pwrite_read_pb80_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pb80_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pb80_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pb0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_common
static void setup_pwrite_read_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pb0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pb0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_common
static void setup_pwrite_read_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pae_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pae_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf4_1_common
static void setup_pwrite_read_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pae_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pae_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_pae_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf4_1_common
// static void setup_pwrite_read_pae_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pd0_0_proc1
// static void setup_pwrite_read_pae_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_pae_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pae_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pad8_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbd8_0_0
// static int test_pwrite_read_pad8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_2_1
// static void setup_pwrite_read_pad8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbd8_0_common
static void setup_pwrite_read_pad8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pad8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pad8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pad8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pad8_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbd8_1_0
// static int test_pwrite_read_pad8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_2_1
// static void setup_pwrite_read_pad8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbd8_1_common
static void setup_pwrite_read_pad8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pad8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pad8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pad8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pad0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbd8_0_0
// static int test_pwrite_read_pad0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_pad0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbd8_0_common
static void setup_pwrite_read_pad0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 61440, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pda_2_proc1
// static void setup_pwrite_read_pad0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pad0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pad0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbd8_1_0
// static int test_pwrite_read_pad0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_pad0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbd8_1_common
static void setup_pwrite_read_pad0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pad0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pda_2_proc1
// static void setup_pwrite_read_pad0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pad0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pac0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pac0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_pac0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbc0_0_common
static void setup_pwrite_read_pac0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_pac0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pac0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pac0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pac0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pac0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_pac0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbc0_0_common
// static void setup_pwrite_read_pac0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pd0_0_proc1
// static void setup_pwrite_read_pac0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_pac0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_pac0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_paa_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_paa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_0_common
static void setup_pwrite_read_paa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36274176, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_read_paa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36274176, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_paa_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_paa_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_paa_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_paa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_paa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_common
// static void setup_pwrite_read_paa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_2_proc0
// static void setup_pwrite_read_paa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_2_proc0
// static void setup_pwrite_read_paa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_paa_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_paa_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_paa_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_paa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_0_common
// static void setup_pwrite_read_paa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_paa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 36274176, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_paa_0_proc1
// static void setup_pwrite_read_paa_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_paa_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_paa_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_paa_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_paa_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_common
// static void setup_pwrite_read_paa_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_paa_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_2_proc0
// static void setup_pwrite_read_paa_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_paa_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pa80_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 12288);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_0_0
// static int test_pwrite_read_pa80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
// static void setup_pwrite_read_pa80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pb80_0_common
static void setup_pwrite_read_pa80_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 49152, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_read_pa80_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pa80_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_pa80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pa80_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_1_0
// static int test_pwrite_read_pa80_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
// static void setup_pwrite_read_pa80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pb80_1_common
// static void setup_pwrite_read_pa80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 49152, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pa80_0_proc0
// static void setup_pwrite_read_pa80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_2_proc0
// static void setup_pwrite_read_pa80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pa80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pa80_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_pa80_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
// static void setup_pwrite_read_pa80_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pb80_2_common
// static void setup_pwrite_read_pa80_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_2_proc0
static void setup_pwrite_read_pa80_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pa80_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_pa80_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pa80_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbd8_0_0
// static int test_pwrite_read_pa80_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
static void setup_pwrite_read_pa80_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_pa80_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_read_pa80_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pa80_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pa80_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pa80_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbd8_0_0
// static int test_pwrite_read_pa80_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
// static void setup_pwrite_read_pa80_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pa80_3_common
static void setup_pwrite_read_pa80_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_pa80_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pa80_3_proc1
// static void setup_pwrite_read_pa80_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pa80_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pa0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_common
// static void setup_pwrite_read_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_0_proc0
// static void setup_pwrite_read_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_pa0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_pa0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_common
// static void setup_pwrite_read_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9e_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p9e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf0_0_common
static void setup_pwrite_read_p9e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9e_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p9e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_p9e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf0_1_common
// static void setup_pwrite_read_p9e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pbe_1_proc0
// static void setup_pwrite_read_p9e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p9e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p9e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9d8_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p9d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_0_1
static void setup_pwrite_read_p9d8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_read_p9d8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_p9d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p9d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p9d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
static int test_pwrite_read_p9d8_1_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_read_p9d8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_0_1
// static void setup_pwrite_read_p9d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbd8_0_common
// static void setup_pwrite_read_p9d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pbd8_0_proc0
// static void setup_pwrite_read_p9d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p9d8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p9d8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9d0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p9d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
// static void setup_pwrite_read_p9d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_p9d8_0_common
static void setup_pwrite_read_p9d0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_p9d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pbd0_0_proc1
// static void setup_pwrite_read_p9d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p9d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9d0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p9d8_1_0
// static int test_pwrite_read_p9d0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
// static void setup_pwrite_read_p9d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbd8_0_common
// static void setup_pwrite_read_p9d0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pbd0_0_proc0
// static void setup_pwrite_read_p9d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pbd0_0_proc1
// static void setup_pwrite_read_p9d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p9d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9c0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p9c0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_0_1
static void setup_pwrite_read_p9c0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_read_p9c0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pbc0_0_proc0
// static void setup_pwrite_read_p9c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p9c0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p9c0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9c0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p9c0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_0_1
// static void setup_pwrite_read_p9c0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf0_0_common
// static void setup_pwrite_read_p9c0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pbc0_1_proc0
// static void setup_pwrite_read_p9c0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p9c0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p9c0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9a_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p9a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
static void setup_pwrite_read_p9a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pwrite_read_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p9a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9a_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p9d8_1_0
// static int test_pwrite_read_p9a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
static void setup_pwrite_read_p9a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p9a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9a_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p9a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
static void setup_pwrite_read_p9a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9986048, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9986048, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p9a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9a_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p9a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
// static void setup_pwrite_read_p9a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p9a_2_common
static void setup_pwrite_read_p9a_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7360512, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p9a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p9a_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_3_0
// static int test_pwrite_read_p9a_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
static void setup_pwrite_read_p9a_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_p9a_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36864, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p9a_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p9a_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p9a_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p990_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p990_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_0_1
// static void setup_pwrite_read_p990_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pb80_0_common
static void setup_pwrite_read_p990_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 49152, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p990_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p990_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_p990_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p990_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p990_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_0_1
// static void setup_pwrite_read_p990_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pb80_1_common
static void setup_pwrite_read_p990_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 45056, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p990_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p990_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p990_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p990_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p990_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_0_1
static void setup_pwrite_read_p990_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_p990_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p990_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p990_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_p990_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p990_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p990_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_0_1
static void setup_pwrite_read_p990_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_p990_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p990_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p990_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p990_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p990_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p990_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
// static void setup_pwrite_read_p990_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p990_3_common
// static void setup_pwrite_read_p990_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_p990_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p990_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p990_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p990_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p990_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_0_1
// static void setup_pwrite_read_p990_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p990_3_common
static void setup_pwrite_read_p990_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p990_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p990_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p990_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p990_6_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p990_6_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_0_1
static void setup_pwrite_read_p990_6_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_read_p990_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_proc0
// static void setup_pwrite_read_p990_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p990_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p990_6_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p990_7_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p990_7_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
static void setup_pwrite_read_p990_7_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_read_p990_7_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_p990_7_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p990_7_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p990_7_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p90_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p9a_2_common
static void setup_pwrite_read_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p90_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p90_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p9a_2_common
// static void setup_pwrite_read_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8e_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p8e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf0_0_common
// static void setup_pwrite_read_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pac0_0_proc0
// static void setup_pwrite_read_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_p8e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p8e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8e_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p8e_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_p8e_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf0_1_common
// static void setup_pwrite_read_p8e_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pd0_0_proc1
// static void setup_pwrite_read_p8e_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_p8e_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p8e_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8d8_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p8d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_2_1
// static void setup_pwrite_read_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_p9d8_0_common
static void setup_pwrite_read_p8d8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_p8d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p8d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8d8_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p9d8_1_0
// static int test_pwrite_read_p8d8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_2_1
// static void setup_pwrite_read_p8d8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbd8_0_common
// static void setup_pwrite_read_p8d8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pad8_0_proc0
// static void setup_pwrite_read_p8d8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_p8d8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p8d8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8d0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p8d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_p9d8_0_common
// static void setup_pwrite_read_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 61440, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pad0_0_proc0
// static void setup_pwrite_read_p8d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pda_2_proc1
// static void setup_pwrite_read_p8d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p8d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8d0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p9d8_1_0
// static int test_pwrite_read_p8d0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_p8d0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pbd8_0_common
static void setup_pwrite_read_p8d0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_p8d0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pda_2_proc1
// static void setup_pwrite_read_p8d0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p8d0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8c0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p8c0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_p8c0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_p9c0_0_common
// static void setup_pwrite_read_p8c0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pac0_0_proc0
// static void setup_pwrite_read_p8c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_p8c0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p8c0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8c0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p8c0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_p8c0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf0_1_common
// static void setup_pwrite_read_p8c0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pd0_0_proc1
// static void setup_pwrite_read_p8c0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_p8c0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p8c0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8a_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p8a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_p9a_0_common
static void setup_pwrite_read_p8a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_read_p8a_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p8a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8a_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p8a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
static void setup_pwrite_read_p8a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_read_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
static void setup_pwrite_read_p8a_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36278272, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p8a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8a_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p8a_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p9a_2_common
static void setup_pwrite_read_p8a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9986048, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_read_p8a_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9986048, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p8a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p8a_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p8a_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p9a_2_common
// static void setup_pwrite_read_p8a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
static void setup_pwrite_read_p8a_3_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5066752, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p8a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p890_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p890_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
static void setup_pwrite_read_p890_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_read_p890_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 53248, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_read_p890_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p890_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_p890_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p890_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p890_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
// static void setup_pwrite_read_p890_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pb80_1_common
// static void setup_pwrite_read_p890_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 49152, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pa80_0_proc0
// static void setup_pwrite_read_p890_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_p890_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p890_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p890_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p890_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
static void setup_pwrite_read_p890_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_read_p890_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_2_proc0
static void setup_pwrite_read_p890_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p890_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_read_pba_0_final
// static void setup_pwrite_read_p890_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p890_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p890_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
// static void setup_pwrite_read_p890_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pb80_1_common
// static void setup_pwrite_read_p890_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_p890_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_p890_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p890_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p890_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p890_4_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 1);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pb80_4_1
// static void setup_pwrite_read_p890_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_pb80_1_common
// static void setup_pwrite_read_p890_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_2_proc0
// static void setup_pwrite_read_p890_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_p890_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p890_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p890_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pb80_2_0
// static int test_pwrite_read_p890_5_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_p890_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p990_6_common
// static void setup_pwrite_read_p890_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_2_proc0
// static void setup_pwrite_read_p890_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_2_proc0
// static void setup_pwrite_read_p890_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p890_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p80_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p9a_2_common
// static void setup_pwrite_read_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_p90_0_proc0
// static void setup_pwrite_read_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p80_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_pbe_0_0
// static int test_pwrite_read_p80_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p9a_2_common
// static void setup_pwrite_read_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
static int test_pwrite_read_p78_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_pwrite_read_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
// static void setup_pwrite_read_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfc_0_common
static void setup_pwrite_read_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p76_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_0_1
// static void setup_pwrite_read_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfb_0_common
static void setup_pwrite_read_p76_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p74_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
// static void setup_pwrite_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfa_1_common
static void setup_pwrite_read_p74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pbd0_0_proc1
// static void setup_pwrite_read_p74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p70_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_0_1
// static void setup_pwrite_read_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf8_0_common
// static void setup_pwrite_read_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_p76_0_proc0
// static void setup_pwrite_read_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p68_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_0_1
// static void setup_pwrite_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_common
static void setup_pwrite_read_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p60_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_0_1
// static void setup_pwrite_read_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p9a_2_common
static void setup_pwrite_read_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p60_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_0_1
static void setup_pwrite_read_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pwrite_read_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p4_0_final(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal
// static void setup_pwrite_read_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p4_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pwrite_read_p4_0_common
// static void setup_pwrite_read_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p4_1_final(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal
// static void setup_pwrite_read_p4_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p38_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfc_0_common
// static void setup_pwrite_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_2_proc0
// static void setup_pwrite_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p36_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfb_2_1
// static void setup_pwrite_read_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfb_0_common
// static void setup_pwrite_read_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p34_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pfa_1_common
// static void setup_pwrite_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pbd0_0_proc1
// static void setup_pwrite_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pda_2_proc1
// static void setup_pwrite_read_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p30_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_read_pf8_0_common
// static void setup_pwrite_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfc_0_proc1
// static void setup_pwrite_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_read_pfb_2_proc0
// static void setup_pwrite_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_final
// static void setup_pwrite_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_read_pfc_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p28_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfa_2_1
// static void setup_pwrite_read_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_read_pba_1_common
// static void setup_pwrite_read_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
static void setup_pwrite_read_p28_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_read_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p28_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p20_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pf8_2_1
// static void setup_pwrite_read_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_read_p9a_2_common
// static void setup_pwrite_read_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_read_pb0_1_proc0
// static void setup_pwrite_read_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_read_pba_1_final
// static void setup_pwrite_read_p20_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal

/*
 * calls: pwrite read
 */
// static int test_pwrite_read_p0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_read_p78_0_0
// static int test_pwrite_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_pwrite_read_pfc_2_1
// static void setup_pwrite_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pwrite_read_p4_0_common
// static void setup_pwrite_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_read_pba_0_proc1
// static void setup_pwrite_read_p0_0_final(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal
// static void setup_pwrite_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_read_pba_0_procfinal


/*
 * calls: pwrite rename
 */
static int test_pwrite_rename_pf_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static int test_pwrite_rename_pf_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_pwrite_rename_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_rename_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_rename_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_rename_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pwrite_rename_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pf_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_0
// static int test_pwrite_rename_pf_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_1
// static void setup_pwrite_rename_pf_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pf_0_common
static void setup_pwrite_rename_pf_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_rename_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_0_proc1
// static void setup_pwrite_rename_pf_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_final
// static void setup_pwrite_rename_pf_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pe8_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_0
static int test_pwrite_rename_pe8_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_pwrite_rename_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_pwrite_rename_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_0_proc0
// static void setup_pwrite_rename_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_0_proc1
// static void setup_pwrite_rename_pe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_final
// static void setup_pwrite_rename_pe8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pe8_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_0
// static int test_pwrite_rename_pe8_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_pe8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pe8_0_common
// static void setup_pwrite_rename_pe8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_1_proc0
// static void setup_pwrite_rename_pe8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_0_proc1
// static void setup_pwrite_rename_pe8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_final
// static void setup_pwrite_rename_pe8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pe0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_0
// static int test_pwrite_rename_pe0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pf_0_common
// static void setup_pwrite_rename_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_0_proc0
// static void setup_pwrite_rename_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_0_proc1
// static void setup_pwrite_rename_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_final
// static void setup_pwrite_rename_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pe0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_0
// static int test_pwrite_rename_pe0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_pe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pf_0_common
// static void setup_pwrite_rename_pe0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_1_proc0
// static void setup_pwrite_rename_pe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_0_proc1
// static void setup_pwrite_rename_pe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_final
// static void setup_pwrite_rename_pe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_0
static int test_pwrite_rename_pc_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_pwrite_rename_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_rename_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_0_proc0
// static void setup_pwrite_rename_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_0_proc1
// static void setup_pwrite_rename_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_final
// static void setup_pwrite_rename_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_0
// static int test_pwrite_rename_pc_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pc_0_1
// static void setup_pwrite_rename_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_rename_pc_0_common
// static void setup_pwrite_rename_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_1_proc0
// static void setup_pwrite_rename_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_rename_pf_0_proc1
// static void setup_pwrite_rename_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_final
// static void setup_pwrite_rename_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_rename_pf_0_procfinal

/*
 * calls: pwrite rename
 */
static int test_pwrite_rename_pb8_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_rename_pb8_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_1
static void setup_pwrite_rename_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_rename_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_rename_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pwrite_rename_pb8_0_final(void) {
  unlink("__i0");
}
static void setup_pwrite_rename_pb8_0_procfinal(void) {
  
}

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pb8_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pb8_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_1
// static void setup_pwrite_rename_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pb8_0_common
static void setup_pwrite_rename_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_rename_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pb4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pb4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
static void setup_pwrite_rename_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_rename_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2191360, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_rename_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
static void setup_pwrite_rename_pb4_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_pwrite_rename_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pb4_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pb4_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_pb4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pb4_0_common
// static void setup_pwrite_rename_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_pb4_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_rename_pb4_0_final
// static void setup_pwrite_rename_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pb4_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pb4_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
static void setup_pwrite_rename_pb4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_pwrite_rename_pb4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 2191360, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb4_0_proc0
// static void setup_pwrite_rename_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
static void setup_pwrite_rename_pb4_2_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_pwrite_rename_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pb4_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pb4_3_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
static void setup_pwrite_rename_pb4_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_rename_pb4_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23973888, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_rename_pb4_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_pb4_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_pb4_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pb4_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pb4_4_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_pb4_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pb4_2_common
// static void setup_pwrite_rename_pb4_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_pb4_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_pb4_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb4_2_final
// static void setup_pwrite_rename_pb4_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pb4_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pb4_5_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_pb4_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pb4_3_common
// static void setup_pwrite_rename_pb4_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_pb4_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_pb4_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_pb4_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pb0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pb0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pb8_0_common
// static void setup_pwrite_rename_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_0_proc0
// static void setup_pwrite_rename_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pb0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pb0_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pb8_0_common
// static void setup_pwrite_rename_pb0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pa0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pa0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pc_0_1
static void setup_pwrite_rename_pa0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_pwrite_rename_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_0_proc0
// static void setup_pwrite_rename_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_pa0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_pa0_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pc_0_1
// static void setup_pwrite_rename_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pa0_0_common
// static void setup_pwrite_rename_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p98_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p98_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_1
static void setup_pwrite_rename_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_rename_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_rename_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p98_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p98_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p98_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_1
// static void setup_pwrite_rename_p98_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_p98_0_common
// static void setup_pwrite_rename_p98_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p98_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p94_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p94_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
static void setup_pwrite_rename_p94_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_rename_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_rename_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p94_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_rename_pb4_0_final
// static void setup_pwrite_rename_p94_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p94_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p94_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
static void setup_pwrite_rename_p94_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_pwrite_rename_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_p94_0_proc0
// static void setup_pwrite_rename_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p94_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb4_2_final
// static void setup_pwrite_rename_p94_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p94_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p94_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_p94_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_p94_0_common
// static void setup_pwrite_rename_p94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_p94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p94_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_rename_pb4_0_final
// static void setup_pwrite_rename_p94_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p94_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p94_3_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
static void setup_pwrite_rename_p94_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_pwrite_rename_p94_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_p94_0_proc0
// static void setup_pwrite_rename_p94_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p94_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p94_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p94_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p94_4_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_p94_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i1", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_p94_1_common
// static void setup_pwrite_rename_p94_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_p94_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p94_4_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb4_2_final
// static void setup_pwrite_rename_p94_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p94_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p94_5_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_p94_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_p94_3_common
// static void setup_pwrite_rename_p94_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_p94_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p94_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p94_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p90_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p90_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_p98_0_common
// static void setup_pwrite_rename_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_p98_0_proc0
// static void setup_pwrite_rename_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p90_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p90_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_p98_0_common
// static void setup_pwrite_rename_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p80_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p80_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pc_0_1
static void setup_pwrite_rename_p80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_rename_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_p98_0_proc0
// static void setup_pwrite_rename_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p80_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pb8_0_0
// static int test_pwrite_rename_p80_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pc_0_1
// static void setup_pwrite_rename_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_rename_p80_0_common
// static void setup_pwrite_rename_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_rename_pb8_1_proc0
// static void setup_pwrite_rename_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
static int test_pwrite_rename_p6_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_pwrite_rename_p6_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pf_0_1
// static void setup_pwrite_rename_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pb8_0_common
// static void setup_pwrite_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p50_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_p6_0_0
// static int test_pwrite_rename_p50_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pb4_3_common
// static void setup_pwrite_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_p6_0_0
// static int test_pwrite_rename_p4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pe8_0_1
// static void setup_pwrite_rename_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_rename_pb8_0_common
// static void setup_pwrite_rename_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_rename_pb8_0_final
// static void setup_pwrite_rename_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal

/*
 * calls: pwrite rename
 */
// static int test_pwrite_rename_p0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_p6_0_0
// static int test_pwrite_rename_p0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_rename_pc_0_1
static void setup_pwrite_rename_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pwrite_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_rename_pb8_0_proc1
// static void setup_pwrite_rename_p0_0_final(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal
// static void setup_pwrite_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_rename_pb8_0_procfinal


/*
 * calls: pwrite stat
 */
static int test_pwrite_stat_pe_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static int test_pwrite_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_pwrite_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_stat_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_stat_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_stat_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pwrite_stat_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_pe_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pe_0_0
// static int test_pwrite_stat_pe_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_pe_0_1
// static void setup_pwrite_stat_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_stat_pe_0_common
static void setup_pwrite_stat_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_stat_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_stat_pe_0_proc1
// static void setup_pwrite_stat_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_stat_pe_0_final
// static void setup_pwrite_stat_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_stat_pe_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_pc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pe_0_0
static int test_pwrite_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_pwrite_stat_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_stat_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_stat_pe_0_proc0
// static void setup_pwrite_stat_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_stat_pe_0_proc1
// static void setup_pwrite_stat_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_stat_pe_0_final
// static void setup_pwrite_stat_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_stat_pe_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_pc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pe_0_0
// static int test_pwrite_stat_pc_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_pc_0_1
// static void setup_pwrite_stat_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_stat_pc_0_common
// static void setup_pwrite_stat_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_stat_pe_1_proc0
// static void setup_pwrite_stat_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_stat_pe_0_proc1
// static void setup_pwrite_stat_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_stat_pe_0_final
// static void setup_pwrite_stat_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_stat_pe_0_procfinal

/*
 * calls: pwrite stat
 */
static int test_pwrite_stat_pb8_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_stat_pb8_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 28672);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_pwrite_stat_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_stat_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23973888, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_stat_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pwrite_stat_pb8_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_pwrite_stat_pb8_0_procfinal(void) {
  
}

/*
 * calls: pwrite stat
 */
static int test_pwrite_stat_pb8_1_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_stat_pb8_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_pe_0_1
static void setup_pwrite_stat_pb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_stat_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_stat_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_pb8_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_stat_pb8_0_final
// static void setup_pwrite_stat_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_pa0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pb8_0_0
// static int test_pwrite_stat_pa0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_pc_0_1
static void setup_pwrite_stat_pa0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pwrite_stat_pa0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_stat_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
static void setup_pwrite_stat_pa0_0_final(void) {
  unlink("__i0");
}
// static void setup_pwrite_stat_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_pa0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pb8_0_0
// static int test_pwrite_stat_pa0_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_pc_0_1
// static void setup_pwrite_stat_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_stat_pa0_0_common
static void setup_pwrite_stat_pa0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_stat_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_stat_pa0_0_final
// static void setup_pwrite_stat_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_p9c_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pb8_0_0
static int test_pwrite_stat_p9c_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_pwrite_stat_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_pwrite_stat_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_stat_pa0_0_proc0
// static void setup_pwrite_stat_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_p9c_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_stat_pb8_0_final
// static void setup_pwrite_stat_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_p9c_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pb8_0_0
// static int test_pwrite_stat_p9c_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_p9c_0_1
static void setup_pwrite_stat_p9c_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_stat_p9c_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_stat_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_p9c_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_stat_pa0_0_final
// static void setup_pwrite_stat_p9c_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_p9c_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pb8_0_0
// static int test_pwrite_stat_p9c_2_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_p9c_0_1
// static void setup_pwrite_stat_p9c_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_stat_p9c_0_common
// static void setup_pwrite_stat_p9c_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_stat_pa0_1_proc0
// static void setup_pwrite_stat_p9c_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_p9c_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_stat_pb8_0_final
// static void setup_pwrite_stat_p9c_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_p9c_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pb8_0_0
// static int test_pwrite_stat_p9c_3_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_p9c_0_1
// static void setup_pwrite_stat_p9c_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_stat_p9c_1_common
// static void setup_pwrite_stat_p9c_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_stat_pa0_1_proc0
// static void setup_pwrite_stat_p9c_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_p9c_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_stat_pa0_0_final
// static void setup_pwrite_stat_p9c_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_p80_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pb8_0_0
// static int test_pwrite_stat_p80_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_pc_0_1
static void setup_pwrite_stat_p80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_stat_p80_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_stat_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_stat_pa0_0_final
// static void setup_pwrite_stat_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_p80_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_pb8_0_0
// static int test_pwrite_stat_p80_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_pc_0_1
// static void setup_pwrite_stat_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_stat_p80_0_common
// static void setup_pwrite_stat_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_stat_pa0_1_proc0
// static void setup_pwrite_stat_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_stat_pa0_0_final
// static void setup_pwrite_stat_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal

/*
 * calls: pwrite stat
 */
static int test_pwrite_stat_p4_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_pwrite_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_pe_0_1
static void setup_pwrite_stat_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_pwrite_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_stat_pa0_0_final
// static void setup_pwrite_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal

/*
 * calls: pwrite stat
 */
// static int test_pwrite_stat_p0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_stat_p4_0_0
// static int test_pwrite_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_pwrite_stat_pc_0_1
static void setup_pwrite_stat_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pwrite_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_stat_pb8_0_proc1
// static void setup_pwrite_stat_p0_0_final(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal
// static void setup_pwrite_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_stat_pb8_0_procfinal


/*
 * calls: pwrite unlink
 */
static int test_pwrite_unlink_pe_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static int test_pwrite_unlink_pe_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_pwrite_unlink_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_unlink_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_unlink_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_unlink_pe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pwrite_unlink_pe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_pe_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_0
// static int test_pwrite_unlink_pe_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_1
// static void setup_pwrite_unlink_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_unlink_pe_0_common
static void setup_pwrite_unlink_pe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_unlink_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_unlink_pe_0_proc1
// static void setup_pwrite_unlink_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_unlink_pe_0_final
// static void setup_pwrite_unlink_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_unlink_pe_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_pc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_0
static int test_pwrite_unlink_pc_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_pwrite_unlink_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_unlink_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_unlink_pe_0_proc0
// static void setup_pwrite_unlink_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_unlink_pe_0_proc1
// static void setup_pwrite_unlink_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_unlink_pe_0_final
// static void setup_pwrite_unlink_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_unlink_pe_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_pc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_0
// static int test_pwrite_unlink_pc_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pc_0_1
// static void setup_pwrite_unlink_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_unlink_pc_0_common
// static void setup_pwrite_unlink_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_unlink_pe_1_proc0
// static void setup_pwrite_unlink_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_unlink_pe_0_proc1
// static void setup_pwrite_unlink_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_unlink_pe_0_final
// static void setup_pwrite_unlink_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_unlink_pe_0_procfinal

/*
 * calls: pwrite unlink
 */
static int test_pwrite_unlink_pb0_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_unlink_pb0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_1
static void setup_pwrite_unlink_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_unlink_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2191360, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_unlink_pb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pwrite_unlink_pb0_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_pwrite_unlink_pb0_0_procfinal(void) {
  
}

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_pb0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_pb0_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_1
static void setup_pwrite_unlink_pb0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_unlink_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 23973888, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_unlink_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
static void setup_pwrite_unlink_pb0_1_final(void) {
  unlink("__i0");
}
// static void setup_pwrite_unlink_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_pb0_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_pb0_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_1
// static void setup_pwrite_unlink_pb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_unlink_pb0_0_common
static void setup_pwrite_unlink_pb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_unlink_pb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_pb0_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_unlink_pb0_0_final
// static void setup_pwrite_unlink_pb0_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_pb0_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_pb0_3_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_1
// static void setup_pwrite_unlink_pb0_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_unlink_pb0_1_common
// static void setup_pwrite_unlink_pb0_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_unlink_pb0_2_proc0
// static void setup_pwrite_unlink_pb0_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_pb0_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_unlink_pb0_1_final
// static void setup_pwrite_unlink_pb0_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_pa0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_pa0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pc_0_1
static void setup_pwrite_unlink_pa0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pwrite_unlink_pa0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_unlink_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_unlink_pb0_1_final
// static void setup_pwrite_unlink_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_pa0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_pa0_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pc_0_1
// static void setup_pwrite_unlink_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_unlink_pa0_0_common
// static void setup_pwrite_unlink_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_unlink_pb0_2_proc0
// static void setup_pwrite_unlink_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_unlink_pb0_1_final
// static void setup_pwrite_unlink_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_p90_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_p90_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_1
static void setup_pwrite_unlink_p90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_pwrite_unlink_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_unlink_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_p90_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_unlink_pb0_0_final
// static void setup_pwrite_unlink_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_p90_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_p90_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_1
static void setup_pwrite_unlink_p90_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_pwrite_unlink_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_unlink_p90_0_proc0
// static void setup_pwrite_unlink_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_unlink_pb0_1_final
// static void setup_pwrite_unlink_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_p90_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_p90_2_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_1
// static void setup_pwrite_unlink_p90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i1", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_unlink_p90_0_common
// static void setup_pwrite_unlink_p90_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_unlink_pb0_2_proc0
// static void setup_pwrite_unlink_p90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_p90_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_unlink_pb0_0_final
// static void setup_pwrite_unlink_p90_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_p90_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_p90_3_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_1
// static void setup_pwrite_unlink_p90_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_unlink_p90_1_common
// static void setup_pwrite_unlink_p90_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_unlink_pb0_2_proc0
// static void setup_pwrite_unlink_p90_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_p90_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_unlink_pb0_1_final
// static void setup_pwrite_unlink_p90_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_p80_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_p80_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pc_0_1
static void setup_pwrite_unlink_p80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_unlink_p80_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_unlink_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_unlink_pb0_1_final
// static void setup_pwrite_unlink_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_p80_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pb0_0_0
// static int test_pwrite_unlink_p80_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pc_0_1
// static void setup_pwrite_unlink_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_unlink_p80_0_common
// static void setup_pwrite_unlink_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_unlink_pb0_2_proc0
// static void setup_pwrite_unlink_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_unlink_pb0_1_final
// static void setup_pwrite_unlink_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
static int test_pwrite_unlink_p4_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_pwrite_unlink_p4_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pe_0_1
// static void setup_pwrite_unlink_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_pwrite_unlink_pb0_1_common
// static void setup_pwrite_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_unlink_pb0_1_final
// static void setup_pwrite_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal

/*
 * calls: pwrite unlink
 */
// static int test_pwrite_unlink_p0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_p4_0_0
// static int test_pwrite_unlink_p0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_pwrite_unlink_pc_0_1
static void setup_pwrite_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pwrite_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_unlink_pb0_0_proc1
// static void setup_pwrite_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal
// static void setup_pwrite_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_unlink_pb0_0_procfinal


/*
 * calls: pwrite write
 */
static int test_pwrite_write_pfe_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(29);
  return xerrno(r);
}
static int test_pwrite_write_pfe_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pwrite_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_write_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_pwrite_write_pfe_0_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pfe_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pfe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_0_1
// static void setup_pwrite_write_pfe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pfe_0_common
static void setup_pwrite_write_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pfe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_0_proc1
// static void setup_pwrite_write_pfe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pwrite_write_pfe_0_final
// static void setup_pwrite_write_pfe_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pwrite_write_pfe_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pfe_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pfe_2_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_0_1
static void setup_pwrite_write_pfe_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_write_pfe_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_write_pfe_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_write_pfe_2_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_pwrite_write_pfe_2_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pfe_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
static int test_pwrite_write_pfe_3_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_pwrite_write_pfe_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pfe_2_common
static void setup_pwrite_write_pfe_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pfe_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_2_proc1
// static void setup_pwrite_write_pfe_3_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pfe_3_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pfc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
static int test_pwrite_write_pfc_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pwrite_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_write_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pfc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pfc_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
// static void setup_pwrite_write_pfc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pfc_0_common
static void setup_pwrite_write_pfc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pfc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pfc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pfc_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
static int test_pwrite_write_pfc_2_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_pwrite_write_pfc_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pfc_0_common
static void setup_pwrite_write_pfc_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pfc_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pfc_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pfc_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pf8_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
static int test_pwrite_write_pf8_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pwrite_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pf8_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pf8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
// static void setup_pwrite_write_pf8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf8_0_common
static void setup_pwrite_write_pf8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pf8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pf8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pf8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pf8_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
static int test_pwrite_write_pf8_2_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_pwrite_write_pf8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf8_0_common
static void setup_pwrite_write_pf8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pf8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pf8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pf8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pf4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pf4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
static void setup_pwrite_write_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_write_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pf4_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pf4_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
static void setup_pwrite_write_pf4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_write_pf4_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pf4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pf4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pf4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pf0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
static void setup_pwrite_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf4_0_proc0
// static void setup_pwrite_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pf0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pf0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
static void setup_pwrite_write_pf0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_write_pf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf4_1_proc0
// static void setup_pwrite_write_pf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pe_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pe_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
// static void setup_pwrite_write_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf8_0_common
// static void setup_pwrite_write_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pe_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pe_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
// static void setup_pwrite_write_pe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf8_0_common
// static void setup_pwrite_write_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pde_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pde_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_3_1
static void setup_pwrite_write_pde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_write_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_pwrite_write_pde_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pwrite_write_pfe_0_final
// static void setup_pwrite_write_pde_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pwrite_write_pfe_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pde_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pde_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_3_1
// static void setup_pwrite_write_pde_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pde_0_common
static void setup_pwrite_write_pde_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pde_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pde_0_proc1
// static void setup_pwrite_write_pde_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pwrite_write_pfe_0_final
// static void setup_pwrite_write_pde_1_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_pwrite_write_pfe_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pde_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pde_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_3_1
static void setup_pwrite_write_pde_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_pwrite_write_pde_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_3_proc0
// static void setup_pwrite_write_pde_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_3_proc0
// static void setup_pwrite_write_pde_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pde_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pdc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pdc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pfc_0_common
// static void setup_pwrite_write_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pdc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pdc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pfc_0_common
// static void setup_pwrite_write_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pd8_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf8_0_common
// static void setup_pwrite_write_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pd8_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pd8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_pd8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf8_0_common
// static void setup_pwrite_write_pd8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_pd8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_pd8_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pd8_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pd4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pd4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
// static void setup_pwrite_write_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
static void setup_pwrite_write_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pd4_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pd4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pd4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
// static void setup_pwrite_write_pd4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_pd4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pd4_0_proc1
// static void setup_pwrite_write_pd4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pd4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pd0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf0_0_common
// static void setup_pwrite_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pd4_0_proc1
// static void setup_pwrite_write_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pd0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pd0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pd0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf0_0_common
// static void setup_pwrite_write_pd0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_pd0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pd4_0_proc1
// static void setup_pwrite_write_pd0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pd0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf8_0_common
// static void setup_pwrite_write_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(29);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pfe_0_0
// static int test_pwrite_write_pc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_pc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf8_0_common
// static void setup_pwrite_write_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
static int test_pwrite_write_pbf0_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_write_pbf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_0_1
// static void setup_pwrite_write_pbf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
static void setup_pwrite_write_pbf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pbf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_2_proc1
// static void setup_pwrite_write_pbf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pbf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pbf0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pbf0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_0_1
// static void setup_pwrite_write_pbf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
static void setup_pwrite_write_pbf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pbf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_2_proc1
// static void setup_pwrite_write_pbf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pbf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pbe0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pbe0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
// static void setup_pwrite_write_pbe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
static void setup_pwrite_write_pbe0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2494464, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pbe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pbe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pbe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pbe0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pbe0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
// static void setup_pwrite_write_pbe0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
static void setup_pwrite_write_pbe0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pbe0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pbe0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pbe0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pbc_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pbc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
// static void setup_pwrite_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
static void setup_pwrite_write_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pbc_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pbc_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
// static void setup_pwrite_write_pbc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_1_common
static void setup_pwrite_write_pbc_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pbc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_pbc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pbc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
static int test_pwrite_write_pba_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 32768);
  expect_result("r", r, 4096);
  return xerrno(r);
}
static int test_pwrite_write_pba_0_1(void) {
  ssize_t r = write(11, dataval1, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_pwrite_write_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 65536, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_write_pba_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_pwrite_write_pba_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_pwrite_write_pba_0_procfinal(void) {
  
}

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pba_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pba_1_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
static void setup_pwrite_write_pba_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pba_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_write_pba_0_final
// static void setup_pwrite_write_pba_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pb90_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pba_0_0
// static int test_pwrite_write_pb90_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
static void setup_pwrite_write_pb90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_pb90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 53248, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pb90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
static void setup_pwrite_write_pb90_0_final(void) {
  unlink("__i0");
}
// static void setup_pwrite_write_pb90_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
static int test_pwrite_write_pb90_1_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 4096);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_write_pb90_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
static void setup_pwrite_write_pb90_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_pb90_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pb90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pb90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pb90_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pb90_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_pb90_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pb90_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_1_common
static void setup_pwrite_write_pb90_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pb90_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pb90_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pb90_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
static int test_pwrite_write_pb80_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 20480);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_write_pb80_0_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
static void setup_pwrite_write_pb80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_pb80_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 57344, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pb80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pb80_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_write_pba_0_final
// static void setup_pwrite_write_pb80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pb80_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb80_0_0
// static int test_pwrite_write_pb80_1_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
static void setup_pwrite_write_pb80_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_pb80_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 53248, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 16384, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pb80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pb80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pb80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pb80_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_pb80_2_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
static void setup_pwrite_write_pb80_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_pb80_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pb80_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pb80_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_write_pba_0_final
// static void setup_pwrite_write_pb80_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
static int test_pwrite_write_pb80_3_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 8192);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_write_pb80_3_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
static void setup_pwrite_write_pb80_3_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_write_pb80_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_1_proc0
// static void setup_pwrite_write_pb80_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pb80_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pb80_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pb80_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb80_3_0
// static int test_pwrite_write_pb80_4_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
// static void setup_pwrite_write_pb80_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pb80_3_common
static void setup_pwrite_write_pb80_4_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pb80_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pb80_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pb80_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pb80_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb80_0_0
static int test_pwrite_write_pb80_5_1(void) {
  ssize_t r = write(10, dataval1, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_pwrite_write_pb80_5_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pb80_1_common
static void setup_pwrite_write_pb80_5_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pb80_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pb80_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pb80_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pb0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pb0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
static void setup_pwrite_write_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pwrite_write_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pb0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pb0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
// static void setup_pwrite_write_pb0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_0_common
static void setup_pwrite_write_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pb0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_paf0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_paf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_3_1
// static void setup_pwrite_write_paf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
static void setup_pwrite_write_paf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_paf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_3_proc0
// static void setup_pwrite_write_paf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_paf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_paf0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_paf0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_3_1
// static void setup_pwrite_write_paf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
static void setup_pwrite_write_paf0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_paf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_3_proc0
// static void setup_pwrite_write_paf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_paf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pae0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pae0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pae0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
static void setup_pwrite_write_pae0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2494464, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pae0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_pae0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pae0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pae0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pae0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pae0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
// static void setup_pwrite_write_pae0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pd4_0_proc1
// static void setup_pwrite_write_pae0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_pae0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pae0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pac_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pac_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
static void setup_pwrite_write_pac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 34263040, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pac_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pac_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_pac_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf4_0_common
// static void setup_pwrite_write_pac_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pd4_0_proc1
// static void setup_pwrite_write_pac_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_pac_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_pac_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_paa_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb80_3_0
// static int test_pwrite_write_paa_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
static void setup_pwrite_write_paa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_pwrite_write_paa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 53248, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_write_paa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_paa_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_write_pba_0_final
// static void setup_pwrite_write_paa_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_paa_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb80_3_0
// static int test_pwrite_write_paa_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
// static void setup_pwrite_write_paa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_write_paa_0_common
static void setup_pwrite_write_paa_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_paa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_paa_0_proc1
// static void setup_pwrite_write_paa_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_write_pba_0_final
// static void setup_pwrite_write_paa_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pa90_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pba_0_0
// static int test_pwrite_write_pa90_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pa90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_0_common
static void setup_pwrite_write_pa90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 49152, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_write_pa90_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pa90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pa90_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pa90_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 32768);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pba_0_0
// static int test_pwrite_write_pa90_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_pa90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_0_common
// static void setup_pwrite_write_pa90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa90_0_proc1
// static void setup_pwrite_write_pa90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa90_0_proc1
// static void setup_pwrite_write_pa90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pa90_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
static int test_pwrite_write_pa80_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 28672);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_write_pa80_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
static void setup_pwrite_write_pa80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_write_pa80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 49152, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa90_0_proc0
static void setup_pwrite_write_pa80_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pa80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pa80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pa80_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_pa80_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
// static void setup_pwrite_write_pa80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pb80_2_common
// static void setup_pwrite_write_pa80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_2_proc0
static void setup_pwrite_write_pa80_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pa80_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_write_pba_0_final
// static void setup_pwrite_write_pa80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
static int test_pwrite_write_pa80_2_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 24576);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_write_pa80_2_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
static void setup_pwrite_write_pa80_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_write_pa80_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa80_0_proc1
static void setup_pwrite_write_pa80_2_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_pa80_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pa80_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pa0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_0_common
// static void setup_pwrite_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 34263040, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_0_proc0
// static void setup_pwrite_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_pa0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_pa0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_pa0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_0_common
// static void setup_pwrite_write_pa0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_1_proc0
// static void setup_pwrite_write_pa0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_pa0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_pa0_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p9f0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p9f0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_0_1
static void setup_pwrite_write_p9f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_pwrite_write_p9f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_2_proc1
// static void setup_pwrite_write_p9f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p9f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p9f0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p9f0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_0_1
// static void setup_pwrite_write_p9f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf0_0_common
// static void setup_pwrite_write_p9f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pbf0_1_proc0
// static void setup_pwrite_write_p9f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_2_proc1
// static void setup_pwrite_write_p9f0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p9f0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p9e0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p9e0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
// static void setup_pwrite_write_p9e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf0_0_common
static void setup_pwrite_write_p9e0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_p9e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_p9e0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p9e0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p9e0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p9e0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
// static void setup_pwrite_write_p9e0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf0_0_common
// static void setup_pwrite_write_p9e0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pbe0_1_proc0
// static void setup_pwrite_write_p9e0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_p9e0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p9e0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p9c_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p9c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
// static void setup_pwrite_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_p9f0_0_common
static void setup_pwrite_write_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p9c_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p9c_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
// static void setup_pwrite_write_p9c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf0_0_common
// static void setup_pwrite_write_p9c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pbc_1_proc0
// static void setup_pwrite_write_p9c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_p9c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p9c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
static int test_pwrite_write_p9a_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 16384);
  expect_result("r", r, 4096);
  return xerrno(r);
}
// static int test_pwrite_write_p9a_0_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
// static void setup_pwrite_write_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pb80_1_common
static void setup_pwrite_write_p9a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 53248, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p9a_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb80_3_0
// static int test_pwrite_write_p9a_1_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
static void setup_pwrite_write_p9a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_p9a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p9a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p9a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_write_pba_0_final
// static void setup_pwrite_write_p9a_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p9a_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p9a_2_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
static void setup_pwrite_write_p9a_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_p9a_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p9a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p9a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p9a_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p9a_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p9a_0_0
// static int test_pwrite_write_p9a_3_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
// static void setup_pwrite_write_p9a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pb80_1_common
// static void setup_pwrite_write_p9a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa80_2_proc1
// static void setup_pwrite_write_p9a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p9a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p9a_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p98_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb80_3_0
// static int test_pwrite_write_p98_0_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
static void setup_pwrite_write_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 45056, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p98_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p98_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 24576);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pa80_2_0
// static int test_pwrite_write_p98_1_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
static void setup_pwrite_write_p98_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p98_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p98_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_p98_2_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
// static void setup_pwrite_write_p98_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval3, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pb80_0_common
static void setup_pwrite_write_p98_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p98_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p98_2_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_write_pba_0_final
// static void setup_pwrite_write_p98_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p98_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_p98_3_1(void) {
//   ssize_t r = write(11, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pba_0_1
// static void setup_pwrite_write_p98_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p98_0_common
static void setup_pwrite_write_p98_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p98_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p98_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p98_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p98_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_p98_4_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
// static void setup_pwrite_write_p98_4_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p98_0_common
// static void setup_pwrite_write_p98_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_paa_1_proc0
// static void setup_pwrite_write_p98_4_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p98_4_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p98_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p98_5_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_p98_5_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
static void setup_pwrite_write_p98_5_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_write_p98_5_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_1_proc0
// static void setup_pwrite_write_p98_5_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p98_5_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p98_5_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p98_6_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_p98_6_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_p98_6_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p98_5_common
// static void setup_pwrite_write_p98_6_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_2_proc0
// static void setup_pwrite_write_p98_6_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p98_6_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p98_6_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p90_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p90_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
static void setup_pwrite_write_p90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_p90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p90_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p90_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p90_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
// static void setup_pwrite_write_p90_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p90_0_common
// static void setup_pwrite_write_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_1_proc0
// static void setup_pwrite_write_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p90_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8f0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p8f0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_3_1
// static void setup_pwrite_write_p8f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_p9f0_0_common
static void setup_pwrite_write_p8f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_3_proc0
// static void setup_pwrite_write_p8f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p8f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8f0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p8f0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_3_1
// static void setup_pwrite_write_p8f0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf0_0_common
// static void setup_pwrite_write_p8f0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_paf0_1_proc0
// static void setup_pwrite_write_p8f0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_3_proc0
// static void setup_pwrite_write_p8f0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p8f0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8e0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p8e0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_p8e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf0_0_common
static void setup_pwrite_write_p8e0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9347072, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_p8e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_p8e0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p8e0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8e0_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p8e0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_p8e0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf0_0_common
// static void setup_pwrite_write_p8e0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pd4_0_proc1
// static void setup_pwrite_write_p8e0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_p8e0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p8e0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8c_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p8c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_p9f0_0_common
static void setup_pwrite_write_p8c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7356416, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8c_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p8c_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_p8c_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf0_0_common
// static void setup_pwrite_write_p8c_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pd4_0_proc1
// static void setup_pwrite_write_p8c_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_p8c_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p8c_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8a_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 16384);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p9a_0_0
// static int test_pwrite_write_p8a_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
// static void setup_pwrite_write_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pb80_1_common
// static void setup_pwrite_write_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 53248, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_paa_0_proc0
// static void setup_pwrite_write_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa80_2_proc1
// static void setup_pwrite_write_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8a_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_p8a_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
static void setup_pwrite_write_p8a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_pwrite_write_p8a_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_pwrite_write_p8a_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p8a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_write_pba_0_final
// static void setup_pwrite_write_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8a_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 28672);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pa80_0_0
// static int test_pwrite_write_p8a_2_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
// static void setup_pwrite_write_p8a_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p98_1_common
// static void setup_pwrite_write_p8a_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa90_0_proc1
// static void setup_pwrite_write_p8a_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 32768, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa90_0_proc1
// static void setup_pwrite_write_p8a_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p8a_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8a_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb80_0_0
// static int test_pwrite_write_p8a_3_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
// static void setup_pwrite_write_p8a_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pa80_2_common
// static void setup_pwrite_write_p8a_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa80_2_proc1
// static void setup_pwrite_write_p8a_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa80_0_proc1
// static void setup_pwrite_write_p8a_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p8a_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p8a_4_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_p8a_4_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
static void setup_pwrite_write_p8a_4_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_pwrite_write_p8a_4_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_2_proc0
static void setup_pwrite_write_p8a_4_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p8a_4_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_pwrite_write_pba_0_final
// static void setup_pwrite_write_p8a_4_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p88_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 8192);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb80_3_0
// static int test_pwrite_write_p88_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
// static void setup_pwrite_write_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p98_1_common
// static void setup_pwrite_write_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 49152, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa90_0_proc0
// static void setup_pwrite_write_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_2_proc0
// static void setup_pwrite_write_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p88_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p88_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 20480);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb80_0_0
// static int test_pwrite_write_p88_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pb80_5_1
// static void setup_pwrite_write_p88_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_pa80_0_common
// static void setup_pwrite_write_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 20480, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa80_2_proc1
// static void setup_pwrite_write_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pa80_0_proc1
// static void setup_pwrite_write_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p88_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p88_2_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_p88_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_p88_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p98_5_common
static void setup_pwrite_write_p88_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 2494464, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p88_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_2_proc0
// static void setup_pwrite_write_p88_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p88_2_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p88_3_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 4096);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pb90_1_0
// static int test_pwrite_write_p88_3_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_p88_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p98_5_common
// static void setup_pwrite_write_p88_3_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_2_proc0
// static void setup_pwrite_write_p88_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb90_2_proc0
// static void setup_pwrite_write_p88_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p88_3_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p80_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p80_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p90_0_common
// static void setup_pwrite_write_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 7356416, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_p90_0_proc0
// static void setup_pwrite_write_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p80_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p80_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, 4096);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_pbf0_0_0
// static int test_pwrite_write_p80_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_p80_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p90_0_common
// static void setup_pwrite_write_p80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_1_proc0
// static void setup_pwrite_write_p80_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p80_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p80_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
static int test_pwrite_write_p7c_0_0(void) {
  ssize_t r = pwrite(10, dataval0, 4096, 0);
  expect_result("r", r, -1);
  expect_errno(9);
  return xerrno(r);
}
// static int test_pwrite_write_p7c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_0_1
// static void setup_pwrite_write_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pfe_2_common
static void setup_pwrite_write_p7c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_2_proc1
// static void setup_pwrite_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p78_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p78_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
// static void setup_pwrite_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pfc_0_common
static void setup_pwrite_write_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p70_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p70_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
// static void setup_pwrite_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf8_0_common
static void setup_pwrite_write_p70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_pwrite_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p68_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p68_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
// static void setup_pwrite_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_0_common
static void setup_pwrite_write_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_pwrite_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p60_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p60_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_0_1
// static void setup_pwrite_write_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p90_0_common
// static void setup_pwrite_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_p68_0_proc0
// static void setup_pwrite_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p4_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_0_1
static void setup_pwrite_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_pwrite_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p4_0_final(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal
// static void setup_pwrite_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p4_1_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pwrite_write_p4_0_common
// static void setup_pwrite_write_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p4_1_final(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal
// static void setup_pwrite_write_p4_1_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p3c_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfe_3_1
// static void setup_pwrite_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pde_2_common
// static void setup_pwrite_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_2_proc1
// static void setup_pwrite_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfe_3_proc0
// static void setup_pwrite_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p38_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pfc_0_common
// static void setup_pwrite_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_2_proc0
// static void setup_pwrite_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p30_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_pwrite_write_pf8_0_common
// static void setup_pwrite_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pfc_0_proc1
// static void setup_pwrite_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_pwrite_write_pf8_2_proc0
// static void setup_pwrite_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_final
// static void setup_pwrite_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_pwrite_write_pfe_2_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p28_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_0_common
// static void setup_pwrite_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_1_proc0
// static void setup_pwrite_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p20_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pfc_2_1
// static void setup_pwrite_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_pwrite_write_p90_0_common
// static void setup_pwrite_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_pwrite_write_pb0_1_proc0
// static void setup_pwrite_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_pwrite_write_pb90_0_final
// static void setup_pwrite_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal

/*
 * calls: pwrite write
 */
// static int test_pwrite_write_p0_0_0(void) {
//   ssize_t r = pwrite(10, dataval0, 4096, 0);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   return xerrno(r);
// }
// ^ See test_pwrite_write_p7c_0_0
// static int test_pwrite_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_pwrite_write_pf8_2_1
// static void setup_pwrite_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_pwrite_write_p4_0_common
// static void setup_pwrite_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_pwrite_write_pba_0_proc1
// static void setup_pwrite_write_p0_0_final(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal
// static void setup_pwrite_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_pwrite_write_pba_0_procfinal


/*
 * calls: read read
 */
static int test_read_read_pfe_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static int test_read_read_pfe_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_read_read_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_read_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_read_read_pfe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: read read
 */
// static int test_read_read_pfe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_pfe_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pfe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfe_0_common
static void setup_read_read_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pfe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pfe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pfe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pfd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
static int test_read_read_pfd8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_read_read_pfd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_read_pfd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pfd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pfd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pfd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pfd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
static int test_read_read_pfd0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_read_read_pfd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_read_pfd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pfd0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pfd0_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_read_read_pfd0_0_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: read read
 */
// static int test_read_read_pfc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
static int test_read_read_pfc_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(11, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
static void setup_read_read_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_read_pfc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfd8_0_proc0
// static void setup_read_read_pfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pfa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_pfa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
static void setup_read_read_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_read_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pfa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pfa_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pfa_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pf8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_pf8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
static void setup_read_read_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_read_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pf0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_pf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfe_0_common
// static void setup_read_read_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
// static void setup_read_read_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pee_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_pee_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pee_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfe_0_common
// static void setup_read_read_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
// static void setup_read_read_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
// static void setup_read_read_pee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_ped8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
static int test_read_read_ped8_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_read_read_ped8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd8_0_common
// static void setup_read_read_ped8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
static void setup_read_read_ped8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_ped8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_ped8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_ped0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
static int test_read_read_ped0_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_read_read_ped0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd0_0_common
static void setup_read_read_ped0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_ped0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_ped0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_ped0_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pec_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
static int test_read_read_pec_0_1(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static void setup_read_read_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfc_0_common
// static void setup_read_read_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
// static void setup_read_read_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pea_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_pea_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfa_0_common
// static void setup_read_read_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
static void setup_read_read_pea_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pea_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pea_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pe8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_pe8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pf8_0_common
// static void setup_read_read_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
static void setup_read_read_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pe8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pe0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_pe0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfe_0_common
// static void setup_read_read_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
// static void setup_read_read_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdf8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdf8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_pdf8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd8_0_common
static void setup_read_read_pdf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pdf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pdf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pdf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdf6_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdf6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd8_0_1
static void setup_read_read_pdf6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_read_pdf6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pdf6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pdf6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pdf6_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdf6_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdf6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd8_0_1
// static void setup_read_read_pdf6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd8_0_common
static void setup_read_read_pdf6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pdf6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pdf6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pdf6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdf6_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdf6_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static void setup_read_read_pdf6_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd8_0_common
// static void setup_read_read_pdf6_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pdf6_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pdf6_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pdf6_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdf4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdf4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
// static void setup_read_read_pdf4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd0_0_common
static void setup_read_read_pdf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pdf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfd0_0_proc1
// static void setup_read_read_pdf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pdf4_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdf0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdf0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
static void setup_read_read_pdf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_read_pdf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(22, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdf6_0_proc0
// static void setup_read_read_pdf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdf6_0_proc1
// static void setup_read_read_pdf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pdf0_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pde8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pde8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
static void setup_read_read_pde8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_read_pde8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pde8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pde8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pde8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pde0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pde0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
static void setup_read_read_pde0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_read_pde0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pde0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pde0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pde0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd8_0_common
// static void setup_read_read_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdb8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pdb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd8_0_common
// static void setup_read_read_pdb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pdb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
// static void setup_read_read_pdb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pdb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdb6_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdb6_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static void setup_read_read_pdb6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pdf6_0_common
static void setup_read_read_pdb6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pdb6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pdb6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pdb6_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdb6_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdb6_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static void setup_read_read_pdb6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd8_0_common
// static void setup_read_read_pdb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pdb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pdb6_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pdb6_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdb4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdb4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_pdb4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd0_0_common
static void setup_read_read_pdb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pdb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped0_0_proc1
// static void setup_read_read_pdb4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pdb4_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pdb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pdb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_pdb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pdf0_0_common
// static void setup_read_read_pdb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdb6_0_proc0
// static void setup_read_read_pdb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdb6_0_proc1
// static void setup_read_read_pdb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pdb0_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pda8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pda8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_pda8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pde8_0_common
// static void setup_read_read_pda8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pda8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pea_0_proc1
// static void setup_read_read_pda8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pda8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pda0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pda0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_pda0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pde0_0_common
// static void setup_read_read_pda0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
static void setup_read_read_pda0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pda0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pda0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static int test_read_read_pd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd8_0_common
// static void setup_read_read_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd78_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_pd78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pdf6_0_common
static void setup_read_read_pd78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pd78_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pd78_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd76_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd8_0_1
// static void setup_read_read_pd76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd0_0_common
static void setup_read_read_pd76_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd78_0_proc1
// static void setup_read_read_pd76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pd76_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd74_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
// static void setup_read_read_pd74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd0_0_common
static void setup_read_read_pd74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pd74_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pd74_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd74_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd74_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
static void setup_read_read_pd74_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_read_pd74_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pd74_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd74_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pd74_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd74_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd74_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_pd74_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pd74_1_common
static void setup_read_read_pd74_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd74_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_1_proc1
// static void setup_read_read_pd74_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pd74_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd70_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
static void setup_read_read_pd70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_read_pd70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(22, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd76_0_proc0
// static void setup_read_read_pd70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd78_0_proc1
// static void setup_read_read_pd70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pd70_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd68_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
// static void setup_read_read_pd68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfe_0_common
static void setup_read_read_pd68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_1_proc1
// static void setup_read_read_pd68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pd68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd60_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
// static void setup_read_read_pd60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pde0_0_common
static void setup_read_read_pd60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_1_proc1
// static void setup_read_read_pd60_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pd60_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pd74_1_common
// static void setup_read_read_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_2_proc0
// static void setup_read_read_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_1_proc1
// static void setup_read_read_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd38_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pd38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd0_0_common
static void setup_read_read_pd38_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pd38_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pd38_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd36_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static void setup_read_read_pd36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd0_0_common
// static void setup_read_read_pd36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd38_0_proc0
static void setup_read_read_pd36_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pd36_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd34_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_pd34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd0_0_common
static void setup_read_read_pd34_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_read_pd34_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pd34_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd34_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd34_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_pd34_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pd74_1_common
// static void setup_read_read_pd34_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_2_proc0
// static void setup_read_read_pd34_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_2_proc0
// static void setup_read_read_pd34_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pd34_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd30_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_pd30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pd70_0_common
// static void setup_read_read_pd30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd38_0_proc0
// static void setup_read_read_pd30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd36_0_proc1
// static void setup_read_read_pd30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pd30_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd28_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_pd28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfe_0_common
// static void setup_read_read_pd28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_2_proc0
static void setup_read_read_pd28_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd28_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pd28_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd20_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_pd20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pde0_0_common
// static void setup_read_read_pd20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_2_proc0
static void setup_read_read_pd20_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pd20_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pd20_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pd74_1_common
// static void setup_read_read_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_2_proc0
// static void setup_read_read_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_1_proc1
// static void setup_read_read_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pcf_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pcf_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_pcf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfc_0_common
// static void setup_read_read_pcf_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdf8_0_proc0
// static void setup_read_read_pcf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pcf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pcf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pcee_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pcee_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd8_0_1
static void setup_read_read_pcee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_read_pcee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(22, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdf6_0_proc0
// static void setup_read_read_pcee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdf6_0_proc1
// static void setup_read_read_pcee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pcee_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pcea_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pcea_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
// static void setup_read_read_pcea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pcee_0_common
// static void setup_read_read_pcea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(22, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdf4_0_proc0
// static void setup_read_read_pcea_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfd0_0_proc1
// static void setup_read_read_pcea_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pcea_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pce4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pce4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
static void setup_read_read_pce4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_read_pce4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdf6_1_proc0
// static void setup_read_read_pce4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pce4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pce4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pce4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pce4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_pce4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pce4_0_common
// static void setup_read_read_pce4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pce4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pce4_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pce4_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pcd_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pcd_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
static void setup_read_read_pcd_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_read_pcd_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pde8_0_proc0
// static void setup_read_read_pcd_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pcd_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pcd_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pcc0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pcc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
static void setup_read_read_pcc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_read_pcc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pde0_0_proc0
// static void setup_read_read_pcc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pcc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pcc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pc8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pc8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfc_0_common
// static void setup_read_read_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pc8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pc8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pc7_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pc7_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pc7_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfc_0_common
// static void setup_read_read_pc7_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pc7_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
// static void setup_read_read_pc7_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pc7_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pc6e_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pc6e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static void setup_read_read_pc6e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pcee_0_common
// static void setup_read_read_pc6e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdb6_0_proc0
// static void setup_read_read_pc6e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdb6_0_proc1
// static void setup_read_read_pc6e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pc6e_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pc6a_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pc6a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
static void setup_read_read_pc6a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_read_pc6a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pdb4_0_proc0
// static void setup_read_read_pc6a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(22, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped0_0_proc1
// static void setup_read_read_pc6a_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_final
// static void setup_read_read_pc6a_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_read_pfd0_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pc64_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pc64_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_pc64_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pce4_0_common
// static void setup_read_read_pc64_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pc64_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pc64_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pc64_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pc5_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pc5_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_pc5_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pcd_0_common
// static void setup_read_read_pc5_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pc5_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pea_0_proc1
// static void setup_read_read_pc5_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pc5_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pc40_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pc40_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_pc40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pcc0_0_common
// static void setup_read_read_pc40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pc40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pda0_0_proc1
// static void setup_read_read_pc40_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pc40_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pc0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_pc0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfc_0_common
// static void setup_read_read_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pbe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pbe_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfa_0_common
static void setup_read_read_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pbd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pbd8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd8_0_1
// static void setup_read_read_pbd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pde8_0_common
static void setup_read_read_pbd8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pbd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pbd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pbd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pbd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pbd0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
// static void setup_read_read_pbd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfe_0_common
static void setup_read_read_pbd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_pbd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_1_proc1
// static void setup_read_read_pbd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pbd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pbc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pbc_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
// static void setup_read_read_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pcd_0_common
// static void setup_read_read_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pbd8_0_proc0
// static void setup_read_read_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pba_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pba_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
static void setup_read_read_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_read_read_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_read_read_pba_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_read_read_pba_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_read_read_pba_0_procfinal(void) {
  
}

/*
 * calls: read read
 */
// static int test_read_read_pba_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pba_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
static void setup_read_read_pba_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_read_read_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
static void setup_read_read_pba_1_final(void) {
  unlink("__i0");
}
// static void setup_read_read_pba_1_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pba_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pba_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
// static void setup_read_read_pba_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_read_pba_1_common
static void setup_read_read_pba_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_pba_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_pba_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_pba_2_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pba_3_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pba_3_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_pba_3_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_read_pba_1_common
static void setup_read_read_pba_3_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_pba_3_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_pba_3_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_pba_3_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pb8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pb8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
static void setup_read_read_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_read_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 9981952, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_pb8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_read_read_pba_0_final
// static void setup_read_read_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pb8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pb8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
static void setup_read_read_pb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_read_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5091328, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pb0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_read_pba_1_common
static void setup_read_read_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pae_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pae_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfa_0_common
// static void setup_read_read_pae_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pea_0_proc1
// static void setup_read_read_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
// static void setup_read_read_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pad8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pad8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static void setup_read_read_pad8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pde8_0_common
// static void setup_read_read_pad8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pea_0_proc1
// static void setup_read_read_pad8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pad8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pad8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pad0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pad0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_pad0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfe_0_common
// static void setup_read_read_pad0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd28_0_proc1
// static void setup_read_read_pad0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_2_proc0
// static void setup_read_read_pad0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pad0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pac_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pac_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pcd_0_common
// static void setup_read_read_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pea_0_proc1
// static void setup_read_read_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_paa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_paa_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_read_pba_0_common
// static void setup_read_read_paa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pb0_0_proc0
static void setup_read_read_paa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31617024, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_paa_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_read_read_pba_0_final
// static void setup_read_read_paa_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_paa_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_paa_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_paa_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_read_pba_1_common
// static void setup_read_read_paa_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pb0_0_proc0
// static void setup_read_read_paa_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pba_3_proc0
// static void setup_read_read_paa_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_paa_1_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_paa_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_paa_2_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_paa_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_read_pba_1_common
// static void setup_read_read_paa_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pba_3_proc0
// static void setup_read_read_paa_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pba_3_proc0
// static void setup_read_read_paa_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_paa_2_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pa8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pa8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_read_pb8_0_common
// static void setup_read_read_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pb0_0_proc0
static void setup_read_read_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_pa8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_read_read_pba_0_final
// static void setup_read_read_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pa8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pa8_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
static void setup_read_read_pa8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_read_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 159744, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_read_read_pa8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_pa0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static int test_read_read_pa0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_read_pba_1_common
// static void setup_read_read_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pb0_0_proc0
// static void setup_read_read_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p9e_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p9e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pf8_0_common
static void setup_read_read_p9e_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p9d8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p9d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd8_0_1
// static void setup_read_read_p9d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pde0_0_common
static void setup_read_read_p9d8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_p9d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_p9d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p9d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p9d0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p9d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
// static void setup_read_read_p9d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pde0_0_common
static void setup_read_read_p9d0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_p9d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_1_proc1
// static void setup_read_read_p9d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p9d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p9c0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p9c0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
static void setup_read_read_p9c0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_read_p9c0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_p9c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_p9c0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p9c0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p9b0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p9b0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
static void setup_read_read_p9b0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_read_read_p9b0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_p9b0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
static void setup_read_read_p9b0_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_read_read_p9b0_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p9b0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p9b0_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
static void setup_read_read_p9b0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_read_p9b0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36294656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_p9b0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p9b0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_p9b0_1_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p990_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p990_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
static void setup_read_read_p990_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_read_p990_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_p990_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p990_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_p990_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p90_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p90_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_read_pa8_1_common
// static void setup_read_read_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pa8_1_proc1
// static void setup_read_read_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_p90_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p8e_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p8e_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pf8_0_common
// static void setup_read_read_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pe8_0_proc1
// static void setup_read_read_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
// static void setup_read_read_p8e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p8e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p8d8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p8d8_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static void setup_read_read_p8d8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pde0_0_common
// static void setup_read_read_p8d8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pda0_0_proc1
// static void setup_read_read_p8d8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_p8d8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p8d8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p8d0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p8d0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_p8d0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pde0_0_common
// static void setup_read_read_p8d0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd20_0_proc1
// static void setup_read_read_p8d0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_2_proc0
// static void setup_read_read_p8d0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p8d0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p8c0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p8c0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_p8c0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_p9c0_0_common
// static void setup_read_read_p8c0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pe8_0_proc1
// static void setup_read_read_p8c0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_p8c0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p8c0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p8a_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p8a_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
static void setup_read_read_p8a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_read_read_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pa8_1_proc1
// static void setup_read_read_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 31617024, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_paa_0_proc1
// static void setup_read_read_p8a_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_read_read_pba_0_final
// static void setup_read_read_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p8a_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p8a_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_p8a_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_read_pa8_1_common
// static void setup_read_read_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pa8_1_proc1
static void setup_read_read_p8a_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 31621120, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_p8a_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p88_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p88_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
static void setup_read_read_p88_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_read_p88_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_read_read_p88_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_p88_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static int test_read_read_p80_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_read_pa8_1_common
// static void setup_read_read_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pa8_1_proc1
// static void setup_read_read_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_p80_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p78_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p78_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
// static void setup_read_read_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfe_0_common
static void setup_read_read_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p76_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p76_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd8_0_1
// static void setup_read_read_p76_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd8_0_common
static void setup_read_read_p76_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_p76_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_p76_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p76_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p74_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p74_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
// static void setup_read_read_p74_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pd74_1_common
static void setup_read_read_p74_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_read_p74_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_1_proc1
// static void setup_read_read_p74_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p74_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p70_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p70_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
// static void setup_read_read_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfc_0_common
// static void setup_read_read_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_p76_0_proc0
// static void setup_read_read_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p68_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p68_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfd0_0_1
// static void setup_read_read_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_read_pba_1_common
static void setup_read_read_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_p68_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p60_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p60_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfc_0_1
// static void setup_read_read_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_read_pa8_1_common
static void setup_read_read_p60_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_read_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_p60_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p4_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(11, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_1
static void setup_read_read_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_read_read_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p4_0_final(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal
// static void setup_read_read_p4_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p4_1_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_read_read_p4_0_common
// static void setup_read_read_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p4_1_final(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal
// static void setup_read_read_p4_1_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p38_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p38_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfe_0_common
// static void setup_read_read_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_1_proc0
// static void setup_read_read_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p36_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p36_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped8_0_1
// static void setup_read_read_p36_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfd8_0_common
// static void setup_read_read_p36_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_p36_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_p36_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p36_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p34_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p34_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_p34_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pd74_1_common
// static void setup_read_read_p34_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_1_proc1
// static void setup_read_read_p34_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pd74_2_proc0
// static void setup_read_read_p34_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p34_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p30_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p30_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_read_pfc_0_common
// static void setup_read_read_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_pfe_0_proc1
// static void setup_read_read_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_read_ped8_0_proc1
// static void setup_read_read_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_final
// static void setup_read_read_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_read_pfe_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p28_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p28_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_ped0_0_1
// static void setup_read_read_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_read_pba_1_common
// static void setup_read_read_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pb0_0_proc0
// static void setup_read_read_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_p28_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p20_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p20_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pec_0_1
// static void setup_read_read_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_read_pa8_1_common
// static void setup_read_read_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_read_pa8_1_proc1
// static void setup_read_read_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_read_pba_1_final
// static void setup_read_read_p20_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal

/*
 * calls: read read
 */
// static int test_read_read_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static int test_read_read_p0_0_1(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_read_pfe_0_0
// static void setup_read_read_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_read_read_p4_0_common
// static void setup_read_read_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_read_pba_0_proc1
// static void setup_read_read_p0_0_final(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal
// static void setup_read_read_p0_0_procfinal(void) {
//   
// }
// ^ See setup_read_read_pba_0_procfinal


/*
 * calls: read rename
 */
static int test_read_rename_pf8_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static int test_read_rename_pf8_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_read_rename_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_rename_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_rename_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_rename_pf8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_read_rename_pf8_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: read rename
 */
// static int test_read_rename_pf4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pf8_0_0
static int test_read_rename_pf4_0_1(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_read_rename_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_read_rename_pf4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc0
// static void setup_read_rename_pf4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pf4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pf4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pf0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pf8_0_0
// static int test_read_rename_pf0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
// static void setup_read_rename_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_rename_pf8_0_common
// static void setup_read_rename_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc0
// static void setup_read_rename_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pf8_0_0
static int test_read_rename_pe_0_1(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_read_rename_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_rename_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc0
// static void setup_read_rename_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
static int test_read_rename_pde_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_rename_pde_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf8_0_1
static void setup_read_rename_pde_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_rename_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_rename_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pdd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pde_0_0
// static int test_read_rename_pdd0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
static void setup_read_rename_pdd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_read_rename_pdd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pde_0_proc0
// static void setup_read_rename_pdd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pdd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pdd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pdc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pde_0_0
// static int test_read_rename_pdc_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
// static void setup_read_rename_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_rename_pde_0_common
// static void setup_read_rename_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pde_0_proc0
// static void setup_read_rename_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pde_0_0
// static int test_read_rename_pd8_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_rename_pe_0_1
static void setup_read_rename_pd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_rename_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pde_0_proc0
// static void setup_read_rename_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
static int test_read_rename_pd6_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_rename_pd6_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf8_0_1
static void setup_read_rename_pd6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_rename_pd6_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_read_rename_pd6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_rename_pd6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pd6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pd50_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pd6_0_0
// static int test_read_rename_pd50_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
static void setup_read_rename_pd50_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_read_rename_pd50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pd6_0_proc0
// static void setup_read_rename_pd50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pd6_0_proc1
// static void setup_read_rename_pd50_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pd50_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pd4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pd6_0_0
// static int test_read_rename_pd4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
// static void setup_read_rename_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_rename_pd6_0_common
// static void setup_read_rename_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pd6_0_proc0
// static void setup_read_rename_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pd6_0_proc1
// static void setup_read_rename_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pd6_0_0
// static int test_read_rename_pd0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_rename_pe_0_1
static void setup_read_rename_pd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_rename_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pd6_0_proc0
// static void setup_read_rename_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pd6_0_proc1
// static void setup_read_rename_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
static int test_read_rename_pcc_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_rename_pcc_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf8_0_1
static void setup_read_rename_pcc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_read_rename_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pde_0_proc0
// static void setup_read_rename_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pcc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pcc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pca_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pcc_0_0
// static int test_read_rename_pca_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
static void setup_read_rename_pca_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_read_rename_pca_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pde_0_proc0
// static void setup_read_rename_pca_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pca_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pca_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pc8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pcc_0_0
// static int test_read_rename_pc8_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
// static void setup_read_rename_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_rename_pcc_0_common
// static void setup_read_rename_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pde_0_proc0
// static void setup_read_rename_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pc8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pc8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pc0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pcc_0_0
// static int test_read_rename_pc0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_rename_pe_0_1
static void setup_read_rename_pc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_rename_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pde_0_proc0
// static void setup_read_rename_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_rename_pf8_0_proc1
// static void setup_read_rename_pc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_final
// static void setup_read_rename_pc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_rename_pf8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pb8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pd6_0_0
// static int test_read_rename_pb8_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf8_0_1
static void setup_read_rename_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_rename_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_read_rename_pb8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_read_rename_pb8_0_final(void) {
  unlink("__i0");
}
static void setup_read_rename_pb8_0_procfinal(void) {
  
}

/*
 * calls: read rename
 */
// static int test_read_rename_pb4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pd6_0_0
// static int test_read_rename_pb4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
static void setup_read_rename_pb4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_read_rename_pb4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_rename_pb4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
static void setup_read_rename_pb4_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_read_rename_pb4_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pb4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pd6_0_0
// static int test_read_rename_pb4_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
static void setup_read_rename_pb4_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_read_rename_pb4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_rename_pb8_0_proc0
// static void setup_read_rename_pb4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_pb4_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb4_0_final
// static void setup_read_rename_pb4_1_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pb4_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pd6_0_0
// static int test_read_rename_pb4_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
static void setup_read_rename_pb4_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_read_rename_pb4_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_rename_pb8_0_proc0
// static void setup_read_rename_pb4_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_pb4_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb8_0_final
// static void setup_read_rename_pb4_2_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pd6_0_0
// static int test_read_rename_pb0_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
// static void setup_read_rename_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_rename_pb8_0_common
// static void setup_read_rename_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_rename_pb8_0_proc0
// static void setup_read_rename_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb8_0_final
// static void setup_read_rename_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_pa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pd6_0_0
// static int test_read_rename_pa_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_rename_pe_0_1
static void setup_read_rename_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_read_rename_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_rename_pb8_0_proc0
// static void setup_read_rename_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb8_0_final
// static void setup_read_rename_pa_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_p98_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pcc_0_0
// static int test_read_rename_p98_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf8_0_1
static void setup_read_rename_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_rename_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_rename_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb8_0_final
// static void setup_read_rename_p98_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_p94_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pcc_0_0
// static int test_read_rename_p94_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
static void setup_read_rename_p94_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_read_rename_p94_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_rename_p94_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p94_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb4_0_final
// static void setup_read_rename_p94_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_p94_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pcc_0_0
// static int test_read_rename_p94_1_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
static void setup_read_rename_p94_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_read_rename_p94_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_rename_p98_0_proc0
// static void setup_read_rename_p94_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p94_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb4_0_final
// static void setup_read_rename_p94_1_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_p94_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pcc_0_0
// static int test_read_rename_p94_2_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
static void setup_read_rename_p94_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_read_rename_p94_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_rename_p98_0_proc0
// static void setup_read_rename_p94_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p94_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb8_0_final
// static void setup_read_rename_p94_2_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_p90_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pcc_0_0
// static int test_read_rename_p90_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
// static void setup_read_rename_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_rename_p98_0_common
// static void setup_read_rename_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_rename_p98_0_proc0
// static void setup_read_rename_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb8_0_final
// static void setup_read_rename_p90_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pcc_0_0
// static int test_read_rename_p80_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_rename_pe_0_1
static void setup_read_rename_p80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_read_rename_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_rename_p98_0_proc0
// static void setup_read_rename_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb8_0_final
// static void setup_read_rename_p80_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_p6_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pf8_0_0
// static int test_read_rename_p6_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf8_0_1
// static void setup_read_rename_p6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_rename_pb8_0_common
// static void setup_read_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb8_0_final
// static void setup_read_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_p50_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pf8_0_0
// static int test_read_rename_p50_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
// static void setup_read_rename_p50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_rename_pb4_2_common
// static void setup_read_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb8_0_final
// static void setup_read_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_p4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pf8_0_0
// static int test_read_rename_p4_0_1(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_rename_pf4_0_1
// static void setup_read_rename_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_rename_pb8_0_common
// static void setup_read_rename_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_rename_pb8_0_final
// static void setup_read_rename_p4_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal

/*
 * calls: read rename
 */
// static int test_read_rename_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_rename_pf8_0_0
// static int test_read_rename_p0_0_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_rename_pe_0_1
static void setup_read_rename_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_read_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_rename_pb8_0_proc1
// static void setup_read_rename_p0_0_final(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal
// static void setup_read_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_read_rename_pb8_0_procfinal


/*
 * calls: read stat
 */
static int test_read_stat_pf_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static int test_read_stat_pf_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_read_stat_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_stat_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_stat_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_stat_pf_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_read_stat_pf_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: read stat
 */
// static int test_read_stat_pe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pf_0_0
static int test_read_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_read_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_stat_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pf_0_proc0
// static void setup_read_stat_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pf_0_proc1
// static void setup_read_stat_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_final
// static void setup_read_stat_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_procfinal

/*
 * calls: read stat
 */
static int test_read_stat_pdc_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
static int test_read_stat_pdc_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_read_stat_pdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_stat_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_stat_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pf_0_proc1
// static void setup_read_stat_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_final
// static void setup_read_stat_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_procfinal

/*
 * calls: read stat
 */
// static int test_read_stat_pd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pdc_0_0
// static int test_read_stat_pd8_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_pe_0_1
static void setup_read_stat_pd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_stat_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pdc_0_proc0
// static void setup_read_stat_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pf_0_proc1
// static void setup_read_stat_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_final
// static void setup_read_stat_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_procfinal

/*
 * calls: read stat
 */
static int test_read_stat_pd4_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_stat_pd4_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_pdc_0_1
// static void setup_read_stat_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_stat_pdc_0_common
static void setup_read_stat_pd4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_read_stat_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_stat_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_final
// static void setup_read_stat_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_procfinal

/*
 * calls: read stat
 */
// static int test_read_stat_pd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pd4_0_0
// static int test_read_stat_pd0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_pe_0_1
// static void setup_read_stat_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_stat_pd8_0_common
// static void setup_read_stat_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pd4_0_proc0
// static void setup_read_stat_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pd4_0_proc1
// static void setup_read_stat_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_final
// static void setup_read_stat_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_procfinal

/*
 * calls: read stat
 */
static int test_read_stat_pc8_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_stat_pc8_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_pdc_0_1
static void setup_read_stat_pc8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_read_stat_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pdc_0_proc0
// static void setup_read_stat_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pf_0_proc1
// static void setup_read_stat_pc8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_final
// static void setup_read_stat_pc8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_procfinal

/*
 * calls: read stat
 */
// static int test_read_stat_pc0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pc8_0_0
// static int test_read_stat_pc0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_pe_0_1
static void setup_read_stat_pc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_stat_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pdc_0_proc0
// static void setup_read_stat_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_stat_pf_0_proc1
// static void setup_read_stat_pc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_final
// static void setup_read_stat_pc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_stat_pf_0_procfinal

/*
 * calls: read stat
 */
// static int test_read_stat_pb_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pd4_0_0
// static int test_read_stat_pb_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_pf_0_1
static void setup_read_stat_pb_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_stat_pb_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_read_stat_pb_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_read_stat_pb_0_final(void) {
  unlink("__i0");
}
static void setup_read_stat_pb_0_procfinal(void) {
  
}

/*
 * calls: read stat
 */
// static int test_read_stat_pa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pd4_0_0
// static int test_read_stat_pa_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_pe_0_1
static void setup_read_stat_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_read_stat_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_stat_pb_0_proc0
// static void setup_read_stat_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_stat_pb_0_proc1
// static void setup_read_stat_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_stat_pb_0_final
// static void setup_read_stat_pa_0_procfinal(void) {
//   
// }
// ^ See setup_read_stat_pb_0_procfinal

/*
 * calls: read stat
 */
// static int test_read_stat_p98_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pc8_0_0
static int test_read_stat_p98_0_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_read_stat_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_stat_p98_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_stat_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_stat_pb_0_proc1
static void setup_read_stat_p98_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_read_stat_p98_0_procfinal(void) {
//   
// }
// ^ See setup_read_stat_pb_0_procfinal

/*
 * calls: read stat
 */
// static int test_read_stat_p98_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pc8_0_0
// static int test_read_stat_p98_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_p98_0_1
static void setup_read_stat_p98_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_stat_p98_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_stat_p98_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_stat_pb_0_proc1
// static void setup_read_stat_p98_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_stat_pb_0_final
// static void setup_read_stat_p98_1_procfinal(void) {
//   
// }
// ^ See setup_read_stat_pb_0_procfinal

/*
 * calls: read stat
 */
// static int test_read_stat_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pc8_0_0
// static int test_read_stat_p80_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_pe_0_1
static void setup_read_stat_p80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_read_stat_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_stat_p98_1_proc0
// static void setup_read_stat_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_stat_pb_0_proc1
// static void setup_read_stat_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_stat_pb_0_final
// static void setup_read_stat_p80_0_procfinal(void) {
//   
// }
// ^ See setup_read_stat_pb_0_procfinal

/*
 * calls: read stat
 */
// static int test_read_stat_p4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pf_0_0
// static int test_read_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_pf_0_1
// static void setup_read_stat_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_stat_pb_0_common
// static void setup_read_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_stat_pb_0_proc1
// static void setup_read_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_stat_pb_0_proc1
// static void setup_read_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_stat_pb_0_final
// static void setup_read_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_read_stat_pb_0_procfinal

/*
 * calls: read stat
 */
// static int test_read_stat_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_stat_pf_0_0
// static int test_read_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_read_stat_pe_0_1
static void setup_read_stat_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_read_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_stat_pb_0_proc1
// static void setup_read_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_stat_pb_0_proc1
// static void setup_read_stat_p0_0_final(void) {
//   
// }
// ^ See setup_read_stat_pb_0_procfinal
// static void setup_read_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_read_stat_pb_0_procfinal


/*
 * calls: read unlink
 */
static int test_read_unlink_pf0_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static int test_read_unlink_pf0_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_read_unlink_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_unlink_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_unlink_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_unlink_pf0_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_read_unlink_pf0_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: read unlink
 */
// static int test_read_unlink_pe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pf0_0_0
static int test_read_unlink_pe_0_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_read_unlink_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_unlink_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pf0_0_proc0
// static void setup_read_unlink_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pf0_0_proc1
// static void setup_read_unlink_pe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_final
// static void setup_read_unlink_pe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_procfinal

/*
 * calls: read unlink
 */
static int test_read_unlink_pdc_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_unlink_pdc_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pf0_0_1
static void setup_read_unlink_pdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_unlink_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_unlink_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pf0_0_proc1
// static void setup_read_unlink_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_final
// static void setup_read_unlink_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_procfinal

/*
 * calls: read unlink
 */
// static int test_read_unlink_pd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pdc_0_0
// static int test_read_unlink_pd8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pe_0_1
static void setup_read_unlink_pd8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_unlink_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pdc_0_proc0
// static void setup_read_unlink_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pf0_0_proc1
// static void setup_read_unlink_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_final
// static void setup_read_unlink_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_procfinal

/*
 * calls: read unlink
 */
static int test_read_unlink_pd4_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_unlink_pd4_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pf0_0_1
static void setup_read_unlink_pd4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_unlink_pd4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_read_unlink_pd4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_unlink_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_final
// static void setup_read_unlink_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_procfinal

/*
 * calls: read unlink
 */
// static int test_read_unlink_pd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pd4_0_0
// static int test_read_unlink_pd0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pe_0_1
static void setup_read_unlink_pd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_unlink_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pd4_0_proc0
// static void setup_read_unlink_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pd4_0_proc1
// static void setup_read_unlink_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_final
// static void setup_read_unlink_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_procfinal

/*
 * calls: read unlink
 */
static int test_read_unlink_pc8_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_unlink_pc8_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pf0_0_1
static void setup_read_unlink_pc8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_read_unlink_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pdc_0_proc0
// static void setup_read_unlink_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pf0_0_proc1
// static void setup_read_unlink_pc8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_final
// static void setup_read_unlink_pc8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_procfinal

/*
 * calls: read unlink
 */
// static int test_read_unlink_pc0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pc8_0_0
// static int test_read_unlink_pc0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pe_0_1
static void setup_read_unlink_pc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_unlink_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pdc_0_proc0
// static void setup_read_unlink_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_unlink_pf0_0_proc1
// static void setup_read_unlink_pc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_final
// static void setup_read_unlink_pc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_unlink_pf0_0_procfinal

/*
 * calls: read unlink
 */
// static int test_read_unlink_pb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pd4_0_0
// static int test_read_unlink_pb0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pf0_0_1
static void setup_read_unlink_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_unlink_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_read_unlink_pb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_read_unlink_pb0_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
static void setup_read_unlink_pb0_0_procfinal(void) {
  
}

/*
 * calls: read unlink
 */
// static int test_read_unlink_pb0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pd4_0_0
// static int test_read_unlink_pb0_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pf0_0_1
static void setup_read_unlink_pb0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_read_unlink_pb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_unlink_pb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_unlink_pb0_0_proc1
static void setup_read_unlink_pb0_1_final(void) {
  unlink("__i0");
}
// static void setup_read_unlink_pb0_1_procfinal(void) {
//   
// }
// ^ See setup_read_unlink_pb0_0_procfinal

/*
 * calls: read unlink
 */
// static int test_read_unlink_pa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pd4_0_0
// static int test_read_unlink_pa_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pe_0_1
static void setup_read_unlink_pa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_read_unlink_pa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_unlink_pb0_1_proc0
// static void setup_read_unlink_pa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_unlink_pb0_0_proc1
// static void setup_read_unlink_pa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_unlink_pb0_1_final
// static void setup_read_unlink_pa_0_procfinal(void) {
//   
// }
// ^ See setup_read_unlink_pb0_0_procfinal

/*
 * calls: read unlink
 */
// static int test_read_unlink_p90_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pc8_0_0
// static int test_read_unlink_p90_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pf0_0_1
static void setup_read_unlink_p90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_read_unlink_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_unlink_pb0_0_proc0
// static void setup_read_unlink_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_unlink_pb0_0_proc1
// static void setup_read_unlink_p90_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_read_unlink_pb0_0_final
// static void setup_read_unlink_p90_0_procfinal(void) {
//   
// }
// ^ See setup_read_unlink_pb0_0_procfinal

/*
 * calls: read unlink
 */
// static int test_read_unlink_p90_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pc8_0_0
// static int test_read_unlink_p90_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pf0_0_1
static void setup_read_unlink_p90_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_read_unlink_p90_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_unlink_pb0_1_proc0
// static void setup_read_unlink_p90_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_unlink_pb0_0_proc1
// static void setup_read_unlink_p90_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_unlink_pb0_1_final
// static void setup_read_unlink_p90_1_procfinal(void) {
//   
// }
// ^ See setup_read_unlink_pb0_0_procfinal

/*
 * calls: read unlink
 */
// static int test_read_unlink_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pc8_0_0
// static int test_read_unlink_p80_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pe_0_1
static void setup_read_unlink_p80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_read_unlink_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_unlink_pb0_1_proc0
// static void setup_read_unlink_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_unlink_pb0_0_proc1
// static void setup_read_unlink_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_unlink_pb0_1_final
// static void setup_read_unlink_p80_0_procfinal(void) {
//   
// }
// ^ See setup_read_unlink_pb0_0_procfinal

/*
 * calls: read unlink
 */
// static int test_read_unlink_p4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pf0_0_0
// static int test_read_unlink_p4_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pf0_0_1
// static void setup_read_unlink_p4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_read_unlink_pb0_1_common
// static void setup_read_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_unlink_pb0_0_proc1
// static void setup_read_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_unlink_pb0_0_proc1
// static void setup_read_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_unlink_pb0_1_final
// static void setup_read_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_read_unlink_pb0_0_procfinal

/*
 * calls: read unlink
 */
// static int test_read_unlink_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_unlink_pf0_0_0
// static int test_read_unlink_p0_0_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_read_unlink_pe_0_1
static void setup_read_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_read_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_unlink_pb0_0_proc1
// static void setup_read_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_unlink_pb0_0_proc1
// static void setup_read_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_read_unlink_pb0_0_procfinal
// static void setup_read_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_read_unlink_pb0_0_procfinal


/*
 * calls: read write
 */
static int test_read_write_pff_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r < 0) return xerrno(r);
  return data[0];
}
static int test_read_write_pff_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_read_write_pff_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pff_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pff_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pff_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_read_write_pff_0_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: read write
 */
// static int test_read_write_pff_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_pff_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_0_1
static void setup_read_write_pff_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pff_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pff_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pff_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_read_write_pff_1_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: read write
 */
// static int test_read_write_pff_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
static int test_read_write_pff_2_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_read_write_pff_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pff_1_common
static void setup_read_write_pff_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pff_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_1_proc1
// static void setup_read_write_pff_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pff_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pfe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
static int test_read_write_pfe_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_read_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pfe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pfe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pfe_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
static int test_read_write_pfe_1_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_read_write_pfe_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfe_0_common
static void setup_read_write_pfe_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pfe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pfe_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pfe_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pfc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
static int test_read_write_pfc_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_read_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pfa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_pfa_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pfa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pfa_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pfa_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pf8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_pf8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_write_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfa_0_proc0
// static void setup_read_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pf0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_pf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
// static void setup_read_write_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfc_0_common
// static void setup_read_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
// static void setup_read_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pef_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_pef_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_2_1
static void setup_read_write_pef_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pef_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pef_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pef_0_final(void) {
  unlink("__i0");
  close(22);
  close(23);
  close(20);
  close(21);
}
static void setup_read_write_pef_0_procfinal(void) {
  close(22);
  close(23);
  close(20);
  close(21);
}

/*
 * calls: read write
 */
// static int test_read_write_pef_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_pef_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_2_1
static void setup_read_write_pef_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_write_pef_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_2_proc0
// static void setup_read_write_pef_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_2_proc0
// static void setup_read_write_pef_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pef_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pee_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_pee_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pee_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfe_0_common
// static void setup_read_write_pee_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
// static void setup_read_write_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
// static void setup_read_write_pee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pec_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
static int test_read_write_pec_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_read_write_pec_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfc_0_common
// static void setup_read_write_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
static void setup_read_write_pec_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pec_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pec_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pea_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_pea_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pea_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfa_0_common
// static void setup_read_write_pea_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
static void setup_read_write_pea_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pea_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pea_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pe8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_pe8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pf8_0_common
// static void setup_read_write_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
// static void setup_read_write_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pea_0_proc1
// static void setup_read_write_pe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pe8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pe0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_pe0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfc_0_common
// static void setup_read_write_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
// static void setup_read_write_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
static int test_read_write_pdfc_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, -1);
  expect_errno(11);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_write_pdfc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_0_1
static void setup_read_write_pdfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pdfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pdfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_0_proc1
// static void setup_read_write_pdfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pdfc_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pdfa_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pdfa_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pdfa_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pdfa_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pdfa_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pdfa_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pdfa_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pdf0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pdf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
// static void setup_read_write_pdf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfe_0_common
static void setup_read_write_pdf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pdf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pdf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pdf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pdf0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pdf0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pdf0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfe_0_common
// static void setup_read_write_pdf0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pdf0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pdf0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pdf0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pde8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pde8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pde8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pde8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pde8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pde8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pde8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pde0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pde0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pde0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_write_pde0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pde8_0_proc0
// static void setup_read_write_pde0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pde0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pde0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pdc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pdc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
// static void setup_read_write_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfe_0_common
// static void setup_read_write_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pdbc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pdbc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_2_1
// static void setup_read_write_pdbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pdfc_0_common
static void setup_read_write_pdbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pdbc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pdbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pdbc_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pdba_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pdba_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pdba_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pdfa_0_common
static void setup_read_write_pdba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pdba_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pdba_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pdba_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pdb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pdb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pdb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfe_0_common
// static void setup_read_write_pdb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pdb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pdb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pdb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pda8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pda8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pda8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pde8_0_common
// static void setup_read_write_pda8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
static void setup_read_write_pda8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pda8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pda8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pda0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pda0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pda0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pde0_0_common
// static void setup_read_write_pda0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pda0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pda8_0_proc1
// static void setup_read_write_pda0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pda0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(11);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pdfc_0_0
// static int test_read_write_pd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfe_0_common
// static void setup_read_write_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
static int test_read_write_pd7c_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_write_pd7c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_0_1
static void setup_read_write_pd7c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pd7c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pd7c_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pd7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pd7c_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd78_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd78_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pd78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pd78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pd78_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pd78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pd78_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd70_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd70_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
static void setup_read_write_pd70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pd70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pd70_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pd70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pd70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd70_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd70_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pd70_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfe_0_common
static void setup_read_write_pd70_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pd70_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_0_proc1
// static void setup_read_write_pd70_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pd70_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd68_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd68_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
// static void setup_read_write_pd68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pde8_0_common
static void setup_read_write_pd68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pd68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_0_proc1
// static void setup_read_write_pd68_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pd68_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd60_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd60_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
// static void setup_read_write_pd60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pde0_0_common
// static void setup_read_write_pd60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd68_0_proc0
// static void setup_read_write_pd60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_0_proc1
// static void setup_read_write_pd60_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pd60_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
// static void setup_read_write_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pd70_0_common
// static void setup_read_write_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_1_proc0
// static void setup_read_write_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_0_proc1
// static void setup_read_write_pd4_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pd4_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd3c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_2_1
// static void setup_read_write_pd3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pdfc_0_common
static void setup_read_write_pd3c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pd3c_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pd3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pd3c_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd38_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pd38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pd78_0_common
static void setup_read_write_pd38_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pd38_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pd38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pd38_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd30_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pd30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pdfc_0_common
static void setup_read_write_pd30_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
}
static void setup_read_write_pd30_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pd30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pd30_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd30_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd30_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pd30_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pd70_0_common
// static void setup_read_write_pd30_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_1_proc0
// static void setup_read_write_pd30_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_1_proc0
// static void setup_read_write_pd30_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pd30_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd28_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pd28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pde8_0_common
// static void setup_read_write_pd28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_1_proc0
static void setup_read_write_pd28_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pd28_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pd28_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd20_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pd20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pde0_0_common
// static void setup_read_write_pd20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_1_proc0
// static void setup_read_write_pd20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd28_0_proc1
// static void setup_read_write_pd20_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pd20_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pd70_0_common
// static void setup_read_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_1_proc0
// static void setup_read_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pd70_0_proc1
// static void setup_read_write_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
static int test_read_write_pcf8_0_0(void) {
  char *data = datavalbuf;
  ssize_t r = read(10, data, 4096);
  expect_result("r", r, 4096);
  expect_result("data[0]", data[0], 0);
  if (r < 0) return xerrno(r);
  return data[0];
}
// static int test_read_write_pcf8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_0_1
static void setup_read_write_pcf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_write_pcf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(23, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pdfc_0_proc0
// static void setup_read_write_pcf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_0_proc1
// static void setup_read_write_pcf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pcf8_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pcf0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
static int test_read_write_pcf0_0_1(void) {
  ssize_t r = write(11, dataval1, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_read_write_pcf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pcf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pcf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pcf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pcf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pce_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_pce_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
static void setup_read_write_pce_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_write_pce_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pdf0_0_proc0
// static void setup_read_write_pce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pce_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pce_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pce_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_pce_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pce_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pce_0_common
// static void setup_read_write_pce_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pce_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pce_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pce_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pcd0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_pcd0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pcd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pcd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pcd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pcd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pcd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pcc0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_pcc0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pcc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_write_pcc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pde8_0_proc0
// static void setup_read_write_pcc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pcc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pcc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pc8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_pc8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
// static void setup_read_write_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pce_0_common
// static void setup_read_write_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pc8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pc8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pc78_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_pc78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_2_1
static void setup_read_write_pc78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_read_write_pc78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pdbc_0_proc0
// static void setup_read_write_pc78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pdbc_0_proc1
// static void setup_read_write_pc78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_final
// static void setup_read_write_pc78_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_read_write_pff_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pc70_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
static int test_read_write_pc70_0_1(void) {
  ssize_t r = write(10, dataval1, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_read_write_pc70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pcf0_0_common
// static void setup_read_write_pc70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pc70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
// static void setup_read_write_pc70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pc70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pc6_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_pc6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pc6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pce_0_common
// static void setup_read_write_pc6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pc6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pc6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pc6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pc50_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_pc50_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pc50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pcd0_0_common
// static void setup_read_write_pc50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pc50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pea_0_proc1
// static void setup_read_write_pc50_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pc50_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pc40_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_pc40_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pc40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pcc0_0_common
// static void setup_read_write_pc40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pc40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pda8_0_proc1
// static void setup_read_write_pc40_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pc40_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pc0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_pc0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pce_0_common
// static void setup_read_write_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pbf_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pbf_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_0_1
static void setup_read_write_pbf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_pbf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pbf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_1_proc1
// static void setup_read_write_pbf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pbf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pbe_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pbe_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
// static void setup_read_write_pbe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfa_0_common
static void setup_read_write_pbe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pbe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pbe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pbe_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pbc_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pbc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
// static void setup_read_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pbf_0_common
static void setup_read_write_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pbb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pbb0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pbb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_write_pbb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_read_write_pbb0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_read_write_pbb0_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_read_write_pbb0_0_procfinal(void) {
  
}

/*
 * calls: read write
 */
// static int test_read_write_pbb0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pbb0_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pbb0_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_read_write_pbb0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_pbb0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
static void setup_read_write_pbb0_1_final(void) {
  unlink("__i0");
}
// static void setup_read_write_pbb0_1_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pbb0_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pbb0_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pbb0_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_1_common
static void setup_read_write_pbb0_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_pbb0_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_pbb0_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_pbb0_2_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pb8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pb8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_write_pb8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 36270080, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_pb8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_read_write_pbb0_0_final
// static void setup_read_write_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pb8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pb8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
static void setup_read_write_pb8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_write_pb8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 10010624, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pb0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pb0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
// static void setup_read_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_1_common
static void setup_read_write_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_paf_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_paf_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_2_1
// static void setup_read_write_paf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pbf_0_common
static void setup_read_write_paf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_paf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_2_proc0
// static void setup_read_write_paf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_paf_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pae_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pae_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pae_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfa_0_common
static void setup_read_write_pae_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 5062656, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pae_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
// static void setup_read_write_pae_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pae_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pac_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pac_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pbf_0_common
static void setup_read_write_pac_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 155648, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pab0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pab0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
static void setup_read_write_pab0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_write_pab0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 7360512, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_read_write_pab0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_pab0_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_read_write_pbb0_0_final
// static void setup_read_write_pab0_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pab0_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pab0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pab0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_1_common
static void setup_read_write_pab0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_pab0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_2_proc0
// static void setup_read_write_pab0_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_pab0_1_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pa8_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pa8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_write_pb8_0_common
// static void setup_read_write_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pb0_0_proc0
static void setup_read_write_pa8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_pa8_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_read_write_pbb0_0_final
// static void setup_read_write_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pa8_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pa8_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
static void setup_read_write_pa8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_write_pa8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 159744, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_pa8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_2_proc0
// static void setup_read_write_pa8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_pa8_1_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_pa0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pd7c_0_0
// static int test_read_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_1_common
// static void setup_read_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 155648, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pb0_0_proc0
// static void setup_read_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p9f0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p9f0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_0_1
static void setup_read_write_p9f0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_read_write_p9f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_1_proc1
// static void setup_read_write_p9f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p9f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p9e0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p9e0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
// static void setup_read_write_p9e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pf8_0_common
static void setup_read_write_p9e0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_p9e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_p9e0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p9e0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p9c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p9c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
// static void setup_read_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_p9f0_0_common
static void setup_read_write_p9c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p90_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p90_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
// static void setup_read_write_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_write_pa8_1_common
// static void setup_read_write_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_2_proc0
// static void setup_read_write_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_p90_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p8f0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p8f0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_2_1
// static void setup_read_write_p8f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_p9f0_0_common
static void setup_read_write_p8f0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_2_proc0
// static void setup_read_write_p8f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p8f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p8e0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p8e0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_p8e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pf8_0_common
// static void setup_read_write_p8e0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pea_0_proc1
// static void setup_read_write_p8e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
// static void setup_read_write_p8e0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p8e0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p8c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p8c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_p9f0_0_common
// static void setup_read_write_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pea_0_proc1
// static void setup_read_write_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p8a_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p8a_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pc70_0_1
static void setup_read_write_p8a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_write_p8a_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 28672, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_read_write_p8a_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 32768, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p8a_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p8a_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pc70_0_1
static void setup_read_write_p8a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_read_write_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pab0_1_proc0
static void setup_read_write_p8a_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_p8a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_read_write_pbb0_0_final
// static void setup_read_write_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p890_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p890_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pc70_0_1
static void setup_read_write_p890_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_read_write_p890_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pab0_1_proc0
static void setup_read_write_p890_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_p890_0_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_read_write_pbb0_0_final
// static void setup_read_write_p890_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p890_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p890_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pc70_0_1
static void setup_read_write_p890_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_read_write_p890_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_read_write_p890_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_p890_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_p890_1_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p890_2_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p890_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
static void setup_read_write_p890_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_read_write_p890_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pab0_1_proc0
// static void setup_read_write_p890_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pab0_1_proc0
// static void setup_read_write_p890_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_p890_2_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p80_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, 4096);
//   expect_result("data[0]", data[0], 0);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pcf8_0_0
// static int test_read_write_p80_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_write_pa8_1_common
// static void setup_read_write_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_2_proc0
// static void setup_read_write_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_p80_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p7c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p7c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_0_1
// static void setup_read_write_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pff_1_common
static void setup_read_write_p7c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_1_proc1
// static void setup_read_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p78_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p78_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
// static void setup_read_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfe_0_common
static void setup_read_write_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p70_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p70_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
// static void setup_read_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfc_0_common
static void setup_read_write_p70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_read_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p68_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p68_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
// static void setup_read_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_1_common
static void setup_read_write_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_read_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p60_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p60_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_0_1
// static void setup_read_write_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_write_pa8_1_common
// static void setup_read_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_p68_0_proc0
// static void setup_read_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p4_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfc_0_1
static void setup_read_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_read_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p4_0_final(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal
// static void setup_read_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p4_1_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_read_write_p4_0_common
// static void setup_read_write_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p4_1_final(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal
// static void setup_read_write_p4_1_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p3c_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pff_2_1
// static void setup_read_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pef_1_common
// static void setup_read_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_1_proc1
// static void setup_read_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pff_2_proc0
// static void setup_read_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p38_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfe_0_common
// static void setup_read_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_1_proc0
// static void setup_read_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p30_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_read_write_pfc_0_common
// static void setup_read_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pfe_0_proc1
// static void setup_read_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_read_write_pec_0_proc1
// static void setup_read_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_final
// static void setup_read_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_read_write_pff_1_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p28_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_1_common
// static void setup_read_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_2_proc0
// static void setup_read_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p20_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pfe_1_1
// static void setup_read_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_read_write_pa8_1_common
// static void setup_read_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_read_write_pbb0_2_proc0
// static void setup_read_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_read_write_pbb0_1_final
// static void setup_read_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal

/*
 * calls: read write
 */
// static int test_read_write_p0_0_0(void) {
//   char *data = datavalbuf;
//   ssize_t r = read(10, data, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r < 0) return xerrno(r);
//   return data[0];
// }
// ^ See test_read_write_pff_0_0
// static int test_read_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_read_write_pec_0_1
// static void setup_read_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_read_write_p4_0_common
// static void setup_read_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_read_write_pbb0_0_proc1
// static void setup_read_write_p0_0_final(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal
// static void setup_read_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_read_write_pbb0_0_procfinal


/*
 * calls: rename rename
 */
static int test_rename_rename_pf_0_0(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_rename_rename_pf_0_1(void) {
  int r = rename("__f1", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_rename_rename_pf_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_rename_rename_pf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_rename_rename_pf_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_rename_rename_pf_0_final(void) {
  unlink("__i0");
}
static void setup_rename_rename_pf_0_procfinal(void) {
  
}

/*
 * calls: rename rename
 */
// static int test_rename_rename_pf_1_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pf_0_0
// static int test_rename_rename_pf_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pf_0_0
static void setup_rename_rename_pf_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_pf_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pf_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pf_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_pf_1_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_pec_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pf_0_0
static int test_rename_rename_pec_0_1(void) {
  int r = rename("__f1", "__f2");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_rename_rename_pec_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_pec_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pec_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pec_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_pec_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_pec_1_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pf_0_0
static int test_rename_rename_pec_1_1(void) {
  int r = rename("__f1", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_rename_rename_pec_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_pf_0_common
// static void setup_rename_rename_pec_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pec_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pec_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_pec_1_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_pe4_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pf_0_0
// static int test_rename_rename_pe4_0_1(void) {
//   int r = rename("__f1", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pec_0_1
// static void setup_rename_rename_pe4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_pf_0_common
// static void setup_rename_rename_pe4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pe4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pe4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_pe4_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_pc_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pf_0_0
static int test_rename_rename_pc_0_1(void) {
  int r = rename("__f1", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_rename_rename_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_pf_1_common
// static void setup_rename_rename_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_pc_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
static int test_rename_rename_pb8_0_0(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_rename_rename_pb8_0_1(void) {
  int r = rename("__f2", "__f2");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static void setup_rename_rename_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_pec_0_common
// static void setup_rename_rename_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_pb8_1_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
// static int test_rename_rename_pb8_1_1(void) {
//   int r = rename("__f1", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pf_0_1
// static void setup_rename_rename_pb8_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_pf_0_common
// static void setup_rename_rename_pb8_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pb8_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pb8_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_pb8_1_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_pb6_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
static int test_rename_rename_pb6_0_1(void) {
  int r = rename("__f2", "__f3");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_rename_rename_pb6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i2", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i2", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i2", "__f2");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f3");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_pb6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pb6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
static void setup_rename_rename_pb6_0_final(void) {
  unlink("__i1");
  unlink("__i2");
  unlink("__i0");
}
// static void setup_rename_rename_pb6_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_pb6_1_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
static int test_rename_rename_pb6_1_1(void) {
  int r = rename("__f2", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_rename_rename_pb6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_pb6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pb6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pb6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_pb6_1_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_pb10_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
// static int test_rename_rename_pb10_0_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_0_1
static void setup_rename_rename_pb10_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_pb10_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pb10_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
static void setup_rename_rename_pb10_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_rename_rename_pb10_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_pb10_1_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
// static int test_rename_rename_pb10_1_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_0_1
// static void setup_rename_rename_pb10_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_pec_0_common
// static void setup_rename_rename_pb10_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pb10_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pb10_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_pb10_1_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_pa0_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
static int test_rename_rename_pa0_0_1(void) {
  int r = rename("__f2", "__f2");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_rename_rename_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_pf_0_common
// static void setup_rename_rename_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p9c_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
// static int test_rename_rename_p9c_0_1(void) {
//   int r = rename("__f2", "__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_1
static void setup_rename_rename_p9c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p9c_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_p9c_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p970_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
// static int test_rename_rename_p970_0_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_0_1
static void setup_rename_rename_p970_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f2");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f3");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_p970_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p970_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
static void setup_rename_rename_p970_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
// static void setup_rename_rename_p970_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p970_1_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
// static int test_rename_rename_p970_1_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_0_1
static void setup_rename_rename_p970_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f3");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_p970_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p970_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p970_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pb10_0_final
// static void setup_rename_rename_p970_1_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p970_2_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
// static int test_rename_rename_p970_2_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_0_1
static void setup_rename_rename_p970_2_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f3");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_p970_2_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p970_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p970_2_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_p970_2_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p960_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
// static int test_rename_rename_p960_0_1(void) {
//   int r = rename("__f2", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_1_1
// static void setup_rename_rename_p960_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_p9c_0_common
// static void setup_rename_rename_p960_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p960_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p960_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_p960_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p92_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
// static int test_rename_rename_p92_0_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_0_1
// static void setup_rename_rename_p92_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_p9c_0_common
// static void setup_rename_rename_p92_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p92_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p92_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_p92_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p80_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb8_0_0
// static int test_rename_rename_p80_0_1(void) {
//   int r = rename("__f2", "__f2");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pa0_0_1
// static void setup_rename_rename_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_pf_1_common
// static void setup_rename_rename_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_p80_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
static int test_rename_rename_p6_0_0(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_rename_rename_p6_0_1(void) {
//   int r = rename("__f1", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pf_0_1
static void setup_rename_rename_p6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_p6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p6_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_p6_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
static int test_rename_rename_p50_0_0(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_rename_rename_p50_0_1(void) {
//   int r = rename("__f2", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_1_1
static void setup_rename_rename_p50_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_p50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p50_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p50_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_p50_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p50_1_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_rename_p50_0_0
// static int test_rename_rename_p50_1_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_0_1
static void setup_rename_rename_p50_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f3");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_p50_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p50_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p50_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_p50_1_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p40_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_rename_p50_0_0
// static int test_rename_rename_p40_0_1(void) {
//   int r = rename("__f2", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_1_1
static void setup_rename_rename_p40_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_rename_p40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p40_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_p40_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p40_1_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_rename_p50_0_0
// static int test_rename_rename_p40_1_1(void) {
//   int r = rename("__f2", "__f3");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pb6_0_1
// static void setup_rename_rename_p40_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f2");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_rename_p50_0_common
// static void setup_rename_rename_p40_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p40_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p40_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_rename_pf_0_final
// static void setup_rename_rename_p40_1_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p0_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_rename_p6_0_0
// static int test_rename_rename_p0_0_1(void) {
//   int r = rename("__f1", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_rename_pc_0_1
static void setup_rename_rename_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_rename_rename_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p0_0_final(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal
// static void setup_rename_rename_p0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal

/*
 * calls: rename rename
 */
// static int test_rename_rename_p0_1_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_rename_p6_0_0
// static int test_rename_rename_p0_1_1(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_rename_p6_0_0
// static void setup_rename_rename_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_rename_rename_p0_0_common
// static void setup_rename_rename_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_rename_pf_0_proc1
// static void setup_rename_rename_p0_1_final(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal
// static void setup_rename_rename_p0_1_procfinal(void) {
//   
// }
// ^ See setup_rename_rename_pf_0_procfinal


/*
 * calls: rename stat
 */
static int test_rename_stat_pe_0_0(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_rename_stat_pe_0_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_rename_stat_pe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_rename_stat_pe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_rename_stat_pe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_rename_stat_pe_0_final(void) {
  unlink("__i0");
}
static void setup_rename_stat_pe_0_procfinal(void) {
  
}

/*
 * calls: rename stat
 */
// static int test_rename_stat_pe_1_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_stat_pe_0_0
static int test_rename_stat_pe_1_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_rename_stat_pe_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_rename_stat_pe_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_pe_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_pe_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_stat_pe_0_final
// static void setup_rename_stat_pe_1_procfinal(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal

/*
 * calls: rename stat
 */
// static int test_rename_stat_pc_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_stat_pe_0_0
static int test_rename_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_rename_stat_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_stat_pe_1_common
// static void setup_rename_stat_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_stat_pe_0_final
// static void setup_rename_stat_pc_0_procfinal(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal

/*
 * calls: rename stat
 */
static int test_rename_stat_pbfc_0_0(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_rename_stat_pbfc_0_1(void) {
  struct stat st;
  int r = stat("__f2", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_rename_stat_pbfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i1", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_stat_pbfc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_pbfc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
static void setup_rename_stat_pbfc_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
// static void setup_rename_stat_pbfc_0_procfinal(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal

/*
 * calls: rename stat
 */
// static int test_rename_stat_pbfc_1_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_stat_pbfc_0_0
// static int test_rename_stat_pbfc_1_1(void) {
//   struct stat st;
//   int r = stat("__f2", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_rename_stat_pbfc_0_1
static void setup_rename_stat_pbfc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_stat_pbfc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_pbfc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_pbfc_1_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_rename_stat_pbfc_0_final
// static void setup_rename_stat_pbfc_1_procfinal(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal

/*
 * calls: rename stat
 */
// static int test_rename_stat_pa0_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_stat_pbfc_0_0
static int test_rename_stat_pa0_0_1(void) {
  struct stat st;
  int r = stat("__f2", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_rename_stat_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_stat_pe_0_common
// static void setup_rename_stat_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_stat_pe_0_final
// static void setup_rename_stat_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal

/*
 * calls: rename stat
 */
// static int test_rename_stat_p98_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_stat_pbfc_0_0
static int test_rename_stat_p98_0_1(void) {
  struct stat st;
  int r = stat("__f2", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_rename_stat_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_stat_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_stat_pe_0_final
// static void setup_rename_stat_p98_0_procfinal(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal

/*
 * calls: rename stat
 */
// static int test_rename_stat_p80_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_stat_pbfc_0_0
// static int test_rename_stat_p80_0_1(void) {
//   struct stat st;
//   int r = stat("__f2", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_rename_stat_pa0_0_1
// static void setup_rename_stat_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_stat_pe_1_common
// static void setup_rename_stat_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_stat_pe_0_final
// static void setup_rename_stat_p80_0_procfinal(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal

/*
 * calls: rename stat
 */
static int test_rename_stat_p4_0_0(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_rename_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_rename_stat_pe_0_1
static void setup_rename_stat_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_rename_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_stat_pe_0_final
// static void setup_rename_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal

/*
 * calls: rename stat
 */
// static int test_rename_stat_p0_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_stat_p4_0_0
// static int test_rename_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_rename_stat_pc_0_1
static void setup_rename_stat_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_rename_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_p0_0_final(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal
// static void setup_rename_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal

/*
 * calls: rename stat
 */
// static int test_rename_stat_p0_1_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_stat_p4_0_0
static int test_rename_stat_p0_1_1(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_rename_stat_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_rename_stat_p0_0_common
// static void setup_rename_stat_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_stat_pe_0_proc1
// static void setup_rename_stat_p0_1_final(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal
// static void setup_rename_stat_p0_1_procfinal(void) {
//   
// }
// ^ See setup_rename_stat_pe_0_procfinal


/*
 * calls: rename unlink
 */
static int test_rename_unlink_pf0_0_0(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_rename_unlink_pf0_0_1(void) {
  int r = unlink("__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_rename_unlink_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_rename_unlink_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_rename_unlink_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_rename_unlink_pf0_0_final(void) {
  unlink("__i0");
}
static void setup_rename_unlink_pf0_0_procfinal(void) {
  
}

/*
 * calls: rename unlink
 */
// static int test_rename_unlink_pc_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_unlink_pf0_0_0
static int test_rename_unlink_pc_0_1(void) {
  int r = unlink("__f1");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_rename_unlink_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_rename_unlink_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_unlink_pf0_0_final
// static void setup_rename_unlink_pc_0_procfinal(void) {
//   
// }
// ^ See setup_rename_unlink_pf0_0_procfinal

/*
 * calls: rename unlink
 */
static int test_rename_unlink_pb8_0_0(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_rename_unlink_pb8_0_1(void) {
  int r = unlink("__f2");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_rename_unlink_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_unlink_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_unlink_pf0_0_final
// static void setup_rename_unlink_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_rename_unlink_pf0_0_procfinal

/*
 * calls: rename unlink
 */
// static int test_rename_unlink_pa0_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_unlink_pb8_0_0
static int test_rename_unlink_pa0_0_1(void) {
  int r = unlink("__f2");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_rename_unlink_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_unlink_pf0_0_common
// static void setup_rename_unlink_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_unlink_pf0_0_final
// static void setup_rename_unlink_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_unlink_pf0_0_procfinal

/*
 * calls: rename unlink
 */
// static int test_rename_unlink_p98_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_unlink_pb8_0_0
// static int test_rename_unlink_p98_0_1(void) {
//   int r = unlink("__f2");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_unlink_pb8_0_1
static void setup_rename_unlink_p98_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f2");
  if (r < 0) setup_error("link");
}
// static void setup_rename_unlink_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_unlink_pf0_0_final
// static void setup_rename_unlink_p98_0_procfinal(void) {
//   
// }
// ^ See setup_rename_unlink_pf0_0_procfinal

/*
 * calls: rename unlink
 */
// static int test_rename_unlink_p80_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_unlink_pb8_0_0
// static int test_rename_unlink_p80_0_1(void) {
//   int r = unlink("__f2");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_unlink_pa0_0_1
// static void setup_rename_unlink_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_unlink_pc_0_common
// static void setup_rename_unlink_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_unlink_pf0_0_final
// static void setup_rename_unlink_p80_0_procfinal(void) {
//   
// }
// ^ See setup_rename_unlink_pf0_0_procfinal

/*
 * calls: rename unlink
 */
static int test_rename_unlink_p4_0_0(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_rename_unlink_p4_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_unlink_pf0_0_1
static void setup_rename_unlink_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_rename_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_unlink_pf0_0_final
// static void setup_rename_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_rename_unlink_pf0_0_procfinal

/*
 * calls: rename unlink
 */
// static int test_rename_unlink_p0_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_unlink_p4_0_0
// static int test_rename_unlink_p0_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_unlink_pc_0_1
static void setup_rename_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_rename_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_rename_unlink_pf0_0_procfinal
// static void setup_rename_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_unlink_pf0_0_procfinal

/*
 * calls: rename unlink
 */
// static int test_rename_unlink_p0_1_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_unlink_p4_0_0
static int test_rename_unlink_p0_1_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_rename_unlink_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_rename_unlink_p0_0_common
// static void setup_rename_unlink_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_unlink_pf0_0_proc1
// static void setup_rename_unlink_p0_1_final(void) {
//   
// }
// ^ See setup_rename_unlink_pf0_0_procfinal
// static void setup_rename_unlink_p0_1_procfinal(void) {
//   
// }
// ^ See setup_rename_unlink_pf0_0_procfinal


/*
 * calls: rename write
 */
static int test_rename_write_pfe_0_0(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_rename_write_pfe_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_rename_write_pfe_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_rename_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_rename_write_pfe_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_rename_write_pfe_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_rename_write_pfe_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: rename write
 */
// static int test_rename_write_pfc_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
static int test_rename_write_pfc_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_rename_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_rename_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_rename_write_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_rename_write_pfc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_pfc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pf8_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
static int test_rename_write_pf8_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_rename_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_rename_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_rename_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pf4_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
// static int test_rename_write_pf4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
static void setup_rename_write_pf4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_rename_write_pf4_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_rename_write_pf4_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_rename_write_pf4_0_final(void) {
  unlink("__i0");
}
static void setup_rename_write_pf4_0_procfinal(void) {
  
}

/*
 * calls: rename write
 */
// static int test_rename_write_pf0_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
// static int test_rename_write_pf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
static void setup_rename_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_rename_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pf0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_pf0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pe_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
// static int test_rename_write_pe_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_pe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf4_0_common
// static void setup_rename_write_pe_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pe_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_pe_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pde_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
// static int test_rename_write_pde_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfe_0_1
// static void setup_rename_write_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pfe_0_common
// static void setup_rename_write_pde_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc1
// static void setup_rename_write_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc0
// static void setup_rename_write_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pdc_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
// static int test_rename_write_pdc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_pdc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pfc_0_common
// static void setup_rename_write_pdc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc0
// static void setup_rename_write_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pd8_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
// static int test_rename_write_pd8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf8_0_common
// static void setup_rename_write_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pf8_0_proc0
// static void setup_rename_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pd4_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
// static int test_rename_write_pd4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_pd4_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf4_0_common
// static void setup_rename_write_pd4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pd4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_pd4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_pd4_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pd0_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
// static int test_rename_write_pd0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf0_0_common
// static void setup_rename_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_pd0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_pd0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pc_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pfe_0_0
// static int test_rename_write_pc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_pc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf4_0_common
// static void setup_rename_write_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_pc_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
static int test_rename_write_pbf0_0_0(void) {
  int r = rename("__f0", "__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
// static int test_rename_write_pbf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfe_0_1
static void setup_rename_write_pbf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_rename_write_pbf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc0
// static void setup_rename_write_pbf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc1
// static void setup_rename_write_pbf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_pbf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pbe0_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_pbe0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
static void setup_rename_write_pbe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_rename_write_pbe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc0
// static void setup_rename_write_pbe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_pbe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_pbe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pbc_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_pbc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pbe0_0_common
// static void setup_rename_write_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pf8_0_proc0
// static void setup_rename_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pba_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_pba_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
static void setup_rename_write_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_rename_write_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_rename_write_pba_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pba_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_pba_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pb8_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_pb8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
static void setup_rename_write_pb8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_rename_write_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pba_0_proc0
// static void setup_rename_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pb8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_pb8_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pb0_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
static void setup_rename_write_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_rename_write_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_paf0_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_paf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfe_0_1
// static void setup_rename_write_paf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pbf0_0_common
// static void setup_rename_write_paf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc1
// static void setup_rename_write_paf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc0
// static void setup_rename_write_paf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_paf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pae0_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_pae0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_pae0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pbe0_0_common
// static void setup_rename_write_pae0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_pae0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc0
// static void setup_rename_write_pae0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_pae0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pac_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_pac_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pbe0_0_common
// static void setup_rename_write_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pf8_0_proc0
// static void setup_rename_write_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_paa_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_paa_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_paa_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pba_0_common
// static void setup_rename_write_paa_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_paa_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pba_0_proc0
// static void setup_rename_write_paa_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_paa_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pa8_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_pa8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pb8_0_common
// static void setup_rename_write_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pba_0_proc0
// static void setup_rename_write_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_pa0_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
//   r = link("__i0", "__f1");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pb0_0_common
// static void setup_rename_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p9f_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p9f_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfe_0_1
// static void setup_rename_write_p9f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pfe_0_common
// static void setup_rename_write_p9f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc0
// static void setup_rename_write_p9f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc1
// static void setup_rename_write_p9f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p9f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p9e_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p9e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_p9e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pfc_0_common
// static void setup_rename_write_p9e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc0
// static void setup_rename_write_p9e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_p9e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p9e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p9c_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p9c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf8_0_common
// static void setup_rename_write_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pf8_0_proc0
// static void setup_rename_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p9a_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p9a_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_p9a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf4_0_common
// static void setup_rename_write_p9a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_p9a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p9a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_p9a_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p98_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p98_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_p98_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf0_0_common
// static void setup_rename_write_p98_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_p98_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p98_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_p98_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p90_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p90_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_p90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf4_0_common
// static void setup_rename_write_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_p90_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p8f_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p8f_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfe_0_1
// static void setup_rename_write_p8f_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pfe_0_common
// static void setup_rename_write_p8f_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc1
// static void setup_rename_write_p8f_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc0
// static void setup_rename_write_p8f_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p8f_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p8e_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p8e_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_p8e_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pfc_0_common
// static void setup_rename_write_p8e_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_p8e_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc0
// static void setup_rename_write_p8e_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p8e_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p8c_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p8c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf8_0_common
// static void setup_rename_write_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pf8_0_proc0
// static void setup_rename_write_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p8a_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p8a_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_p8a_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf4_0_common
// static void setup_rename_write_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p88_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p88_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf0_0_common
// static void setup_rename_write_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_p88_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p80_0_0(void) {
//   int r = rename("__f0", "__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_rename_write_pbf0_0_0
// static int test_rename_write_p80_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_rename_write_pf4_0_common
// static void setup_rename_write_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_p80_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
static int test_rename_write_p7c_0_0(void) {
  int r = rename("__f0", "__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_rename_write_p7c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfe_0_1
static void setup_rename_write_p7c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_rename_write_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc0
// static void setup_rename_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc1
// static void setup_rename_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p78_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
static void setup_rename_write_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_rename_write_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc0
// static void setup_rename_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p70_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
static void setup_rename_write_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_rename_write_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pf8_0_proc0
// static void setup_rename_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p68_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p68_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
static void setup_rename_write_p68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_rename_write_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p60_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p60_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
static void setup_rename_write_p60_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_rename_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p4_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
static void setup_rename_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_rename_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p4_0_final(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal
// static void setup_rename_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p3c_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfe_0_1
// static void setup_rename_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_rename_write_p7c_0_common
// static void setup_rename_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc1
// static void setup_rename_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfe_0_proc0
// static void setup_rename_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p38_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_rename_write_p78_0_common
// static void setup_rename_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc0
// static void setup_rename_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p30_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_rename_write_p70_0_common
// static void setup_rename_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pfc_0_proc1
// static void setup_rename_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_rename_write_pf8_0_proc0
// static void setup_rename_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_final
// static void setup_rename_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_rename_write_pfe_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p28_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_rename_write_p68_0_common
// static void setup_rename_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p20_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pfc_0_1
// static void setup_rename_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_rename_write_p60_0_common
// static void setup_rename_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_rename_write_pf4_0_proc0
// static void setup_rename_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_rename_write_pf4_0_final
// static void setup_rename_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal

/*
 * calls: rename write
 */
// static int test_rename_write_p0_0_0(void) {
//   int r = rename("__f0", "__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_rename_write_p7c_0_0
// static int test_rename_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_rename_write_pf8_0_1
// static void setup_rename_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_rename_write_p4_0_common
// static void setup_rename_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_rename_write_pf4_0_proc1
// static void setup_rename_write_p0_0_final(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal
// static void setup_rename_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_rename_write_pf4_0_procfinal


/*
 * calls: stat stat
 */
static int test_stat_stat_pc_0_0(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_stat_stat_pc_0_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static void setup_stat_stat_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_stat_stat_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_stat_stat_pc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_stat_stat_pc_0_final(void) {
  unlink("__i0");
}
static void setup_stat_stat_pc_0_procfinal(void) {
  
}

/*
 * calls: stat stat
 */
// static int test_stat_stat_pc_1_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_stat_pc_0_0
// static int test_stat_stat_pc_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_stat_pc_0_0
static void setup_stat_stat_pc_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_stat_stat_pc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_stat_pc_0_proc1
// static void setup_stat_stat_pc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_stat_pc_0_proc1
// static void setup_stat_stat_pc_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_stat_pc_0_final
// static void setup_stat_stat_pc_1_procfinal(void) {
//   
// }
// ^ See setup_stat_stat_pc_0_procfinal

/*
 * calls: stat stat
 */
// static int test_stat_stat_p8_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_stat_pc_0_0
static int test_stat_stat_p8_0_1(void) {
  struct stat st;
  int r = stat("__f1", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static void setup_stat_stat_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_stat_stat_pc_1_common
// static void setup_stat_stat_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_stat_pc_0_proc1
// static void setup_stat_stat_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_stat_pc_0_proc1
// static void setup_stat_stat_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_stat_pc_0_final
// static void setup_stat_stat_p8_0_procfinal(void) {
//   
// }
// ^ See setup_stat_stat_pc_0_procfinal

/*
 * calls: stat stat
 */
static int test_stat_stat_p4_0_0(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_stat_stat_p4_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_stat_pc_0_1
static void setup_stat_stat_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_stat_stat_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_stat_pc_0_proc1
// static void setup_stat_stat_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_stat_pc_0_proc1
// static void setup_stat_stat_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_stat_pc_0_final
// static void setup_stat_stat_p4_0_procfinal(void) {
//   
// }
// ^ See setup_stat_stat_pc_0_procfinal

/*
 * calls: stat stat
 */
// static int test_stat_stat_p0_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_stat_p4_0_0
// static int test_stat_stat_p0_0_1(void) {
//   struct stat st;
//   int r = stat("__f1", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_stat_p8_0_1
static void setup_stat_stat_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_stat_stat_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_stat_pc_0_proc1
// static void setup_stat_stat_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_stat_pc_0_proc1
// static void setup_stat_stat_p0_0_final(void) {
//   
// }
// ^ See setup_stat_stat_pc_0_procfinal
// static void setup_stat_stat_p0_0_procfinal(void) {
//   
// }
// ^ See setup_stat_stat_pc_0_procfinal

/*
 * calls: stat stat
 */
// static int test_stat_stat_p0_1_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_stat_p4_0_0
// static int test_stat_stat_p0_1_1(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_stat_p4_0_0
// static void setup_stat_stat_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_stat_stat_p0_0_common
// static void setup_stat_stat_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_stat_pc_0_proc1
// static void setup_stat_stat_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_stat_pc_0_proc1
// static void setup_stat_stat_p0_1_final(void) {
//   
// }
// ^ See setup_stat_stat_pc_0_procfinal
// static void setup_stat_stat_p0_1_procfinal(void) {
//   
// }
// ^ See setup_stat_stat_pc_0_procfinal


/*
 * calls: stat unlink
 */
static int test_stat_unlink_pf0_0_0(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 12288);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_stat_unlink_pf0_0_1(void) {
  int r = unlink("__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_stat_unlink_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i1", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_stat_unlink_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_stat_unlink_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_stat_unlink_pf0_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
static void setup_stat_unlink_pf0_0_procfinal(void) {
  
}

/*
 * calls: stat unlink
 */
static int test_stat_unlink_p8_0_0(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_stat_unlink_p8_0_1(void) {
  int r = unlink("__f1");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_stat_unlink_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_stat_unlink_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_unlink_pf0_0_proc1
// static void setup_stat_unlink_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_unlink_pf0_0_proc1
static void setup_stat_unlink_p8_0_final(void) {
  unlink("__i0");
}
// static void setup_stat_unlink_p8_0_procfinal(void) {
//   
// }
// ^ See setup_stat_unlink_pf0_0_procfinal

/*
 * calls: stat unlink
 */
static int test_stat_unlink_p4_0_0(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_stat_unlink_p4_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_stat_unlink_pf0_0_1
static void setup_stat_unlink_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_stat_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_unlink_pf0_0_proc1
// static void setup_stat_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_unlink_pf0_0_proc1
// static void setup_stat_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_unlink_p8_0_final
// static void setup_stat_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_stat_unlink_pf0_0_procfinal

/*
 * calls: stat unlink
 */
// static int test_stat_unlink_p0_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_unlink_p4_0_0
// static int test_stat_unlink_p0_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_stat_unlink_p8_0_1
static void setup_stat_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_stat_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_unlink_pf0_0_proc1
// static void setup_stat_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_unlink_pf0_0_proc1
// static void setup_stat_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_stat_unlink_pf0_0_procfinal
// static void setup_stat_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_stat_unlink_pf0_0_procfinal

/*
 * calls: stat unlink
 */
// static int test_stat_unlink_p0_1_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_unlink_p4_0_0
static int test_stat_unlink_p0_1_1(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static void setup_stat_unlink_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_stat_unlink_p0_0_common
// static void setup_stat_unlink_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_unlink_pf0_0_proc1
// static void setup_stat_unlink_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_unlink_pf0_0_proc1
// static void setup_stat_unlink_p0_1_final(void) {
//   
// }
// ^ See setup_stat_unlink_pf0_0_procfinal
// static void setup_stat_unlink_p0_1_procfinal(void) {
//   
// }
// ^ See setup_stat_unlink_pf0_0_procfinal


/*
 * calls: stat write
 */
static int test_stat_write_pfc_0_0(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 8192);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_stat_write_pfc_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_stat_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_stat_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_stat_write_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_stat_write_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_stat_write_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: stat write
 */
// static int test_stat_write_pf8_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_pfc_0_0
static int test_stat_write_pf8_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_stat_write_pf8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_stat_write_pf8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_stat_write_pf8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_stat_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
static int test_stat_write_pf0_0_0(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 0);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
static int test_stat_write_pf0_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_stat_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_stat_write_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_stat_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf8_0_proc1
// static void setup_stat_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
static int test_stat_write_pec_0_0(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 28672);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_stat_write_pec_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
static void setup_stat_write_pec_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_stat_write_pec_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_stat_write_pec_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_stat_write_pec_0_final(void) {
  unlink("__i1");
  unlink("__i0");
}
static void setup_stat_write_pec_0_procfinal(void) {
  
}

/*
 * calls: stat write
 */
static int test_stat_write_pe6_0_0(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, 0);
  expect_result("st.st_size", st.st_size, 4096);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_stat_write_pe6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
static void setup_stat_write_pe6_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_stat_write_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_stat_write_pec_0_proc0
// static void setup_stat_write_pe6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_pe6_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_stat_write_pec_0_final
// static void setup_stat_write_pe6_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_pe6_1_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_pe6_0_0
// static int test_stat_write_pe6_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
static void setup_stat_write_pe6_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_stat_write_pe6_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_stat_write_pe6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
static void setup_stat_write_pe6_1_final(void) {
  unlink("__i0");
}
// static void setup_stat_write_pe6_1_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_pc_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_pf0_0_0
// static int test_stat_write_pc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf0_0_1
static void setup_stat_write_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_stat_write_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_write_pe6_1_final
// static void setup_stat_write_pc_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_pbc_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_pfc_0_0
// static int test_stat_write_pbc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pfc_0_1
// static void setup_stat_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_stat_write_pfc_0_common
// static void setup_stat_write_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pfc_0_proc1
// static void setup_stat_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pfc_0_proc0
// static void setup_stat_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_pb8_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 8192);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_pfc_0_0
// static int test_stat_write_pb8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
// static void setup_stat_write_pb8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_stat_write_pf8_0_common
// static void setup_stat_write_pb8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf8_0_proc1
// static void setup_stat_write_pb8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf8_0_proc0
// static void setup_stat_write_pb8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_pb8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_pb0_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_pf0_0_0
// static int test_stat_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf0_0_1
// static void setup_stat_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_stat_write_pf0_0_common
// static void setup_stat_write_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf8_0_proc1
// static void setup_stat_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf0_0_proc0
// static void setup_stat_write_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_pac_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 28672);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_pec_0_0
// static int test_stat_write_pac_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
// static void setup_stat_write_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_stat_write_pec_0_common
// static void setup_stat_write_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_stat_write_pec_0_proc0
// static void setup_stat_write_pac_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_stat_write_pec_0_final
// static void setup_stat_write_pac_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_pa6_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_pe6_0_0
// static int test_stat_write_pa6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
// static void setup_stat_write_pa6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i1", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_stat_write_pe6_0_common
// static void setup_stat_write_pa6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_pa6_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_stat_write_pec_0_proc0
// static void setup_stat_write_pa6_0_final(void) {
//   unlink("__i1");
//   unlink("__i0");
// }
// ^ See setup_stat_write_pec_0_final
// static void setup_stat_write_pa6_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_pa6_1_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 4096);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_pe6_0_0
// static int test_stat_write_pa6_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
// static void setup_stat_write_pa6_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_stat_write_pe6_1_common
// static void setup_stat_write_pa6_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_pa6_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_stat_write_pe6_1_proc0
// static void setup_stat_write_pa6_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_write_pe6_1_final
// static void setup_stat_write_pa6_1_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p8_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, 0);
//   expect_result("st.st_size", st.st_size, 0);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_pf0_0_0
// static int test_stat_write_p8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf0_0_1
// static void setup_stat_write_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_stat_write_pc_0_common
// static void setup_stat_write_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_write_pe6_1_final
// static void setup_stat_write_p8_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
static int test_stat_write_p7c_0_0(void) {
  struct stat st;
  int r = stat("__f0", &st);
  expect_result("r", r, -1);
  expect_errno(2);
  if (r < 0) return xerrno(r);
  /* Hack, to test for approximate equality */
  return st.st_ino ^ st.st_nlink ^ st.st_size;
}
// static int test_stat_write_p7c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pfc_0_1
static void setup_stat_write_p7c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_stat_write_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pfc_0_proc0
// static void setup_stat_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pfc_0_proc1
// static void setup_stat_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p78_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
static void setup_stat_write_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_stat_write_p78_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf8_0_proc0
// static void setup_stat_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf8_0_proc1
// static void setup_stat_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p70_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf0_0_1
static void setup_stat_write_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_stat_write_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf0_0_proc0
// static void setup_stat_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf8_0_proc1
// static void setup_stat_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p68_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p68_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
static void setup_stat_write_p68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
// static void setup_stat_write_p68_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_stat_write_pe6_1_proc0
// static void setup_stat_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_write_pe6_1_final
// static void setup_stat_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p60_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p60_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
static void setup_stat_write_p60_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_stat_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_stat_write_pe6_1_proc0
// static void setup_stat_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_write_pe6_1_final
// static void setup_stat_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p4_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf0_0_1
static void setup_stat_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_stat_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_p4_0_final(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal
// static void setup_stat_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p3c_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pfc_0_1
// static void setup_stat_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_stat_write_p7c_0_common
// static void setup_stat_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pfc_0_proc1
// static void setup_stat_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pfc_0_proc0
// static void setup_stat_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p38_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
// static void setup_stat_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_stat_write_p78_0_common
// static void setup_stat_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf8_0_proc1
// static void setup_stat_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf8_0_proc0
// static void setup_stat_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p30_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf0_0_1
// static void setup_stat_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_stat_write_p70_0_common
// static void setup_stat_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf8_0_proc1
// static void setup_stat_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_stat_write_pf0_0_proc0
// static void setup_stat_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_final
// static void setup_stat_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_stat_write_pfc_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p28_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
// static void setup_stat_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_stat_write_p68_0_common
// static void setup_stat_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_stat_write_pe6_1_proc0
// static void setup_stat_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_write_pe6_1_final
// static void setup_stat_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p20_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf8_0_1
// static void setup_stat_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_stat_write_p60_0_common
// static void setup_stat_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_stat_write_pe6_1_proc0
// static void setup_stat_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_stat_write_pe6_1_final
// static void setup_stat_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal

/*
 * calls: stat write
 */
// static int test_stat_write_p0_0_0(void) {
//   struct stat st;
//   int r = stat("__f0", &st);
//   expect_result("r", r, -1);
//   expect_errno(2);
//   if (r < 0) return xerrno(r);
//   /* Hack, to test for approximate equality */
//   return st.st_ino ^ st.st_nlink ^ st.st_size;
// }
// ^ See test_stat_write_p7c_0_0
// static int test_stat_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_stat_write_pf0_0_1
// static void setup_stat_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_stat_write_p4_0_common
// static void setup_stat_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_stat_write_pec_0_proc1
// static void setup_stat_write_p0_0_final(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal
// static void setup_stat_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_stat_write_pec_0_procfinal


/*
 * calls: unlink unlink
 */
static int test_unlink_unlink_pc_0_0(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_unlink_unlink_pc_0_1(void) {
  int r = unlink("__f1");
  expect_result("r", r, 0);
  return xerrno(r);
}
static void setup_unlink_unlink_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
static void setup_unlink_unlink_pc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_unlink_unlink_pc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_unlink_unlink_pc_0_final(void) {
  unlink("__i0");
}
static void setup_unlink_unlink_pc_0_procfinal(void) {
  
}

/*
 * calls: unlink unlink
 */
// static int test_unlink_unlink_p8_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_unlink_pc_0_0
static int test_unlink_unlink_p8_0_1(void) {
  int r = unlink("__f1");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
static void setup_unlink_unlink_p8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_unlink_unlink_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_unlink_pc_0_proc1
// static void setup_unlink_unlink_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_unlink_pc_0_proc1
// static void setup_unlink_unlink_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_unlink_pc_0_final
// static void setup_unlink_unlink_p8_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_unlink_pc_0_procfinal

/*
 * calls: unlink unlink
 */
static int test_unlink_unlink_p4_0_0(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_unlink_unlink_p4_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_unlink_pc_0_1
static void setup_unlink_unlink_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f1");
  if (r < 0) setup_error("link");
}
// static void setup_unlink_unlink_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_unlink_pc_0_proc1
// static void setup_unlink_unlink_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_unlink_pc_0_proc1
// static void setup_unlink_unlink_p4_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_unlink_pc_0_final
// static void setup_unlink_unlink_p4_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_unlink_pc_0_procfinal

/*
 * calls: unlink unlink
 */
// static int test_unlink_unlink_p0_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_unlink_p4_0_0
// static int test_unlink_unlink_p0_0_1(void) {
//   int r = unlink("__f1");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_unlink_p8_0_1
static void setup_unlink_unlink_p0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_unlink_unlink_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_unlink_pc_0_proc1
// static void setup_unlink_unlink_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_unlink_pc_0_proc1
// static void setup_unlink_unlink_p0_0_final(void) {
//   
// }
// ^ See setup_unlink_unlink_pc_0_procfinal
// static void setup_unlink_unlink_p0_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_unlink_pc_0_procfinal

/*
 * calls: unlink unlink
 */
// static int test_unlink_unlink_p0_1_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_unlink_p4_0_0
// static int test_unlink_unlink_p0_1_1(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_unlink_p4_0_0
// static void setup_unlink_unlink_p0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_unlink_unlink_p0_0_common
// static void setup_unlink_unlink_p0_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_unlink_pc_0_proc1
// static void setup_unlink_unlink_p0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_unlink_pc_0_proc1
// static void setup_unlink_unlink_p0_1_final(void) {
//   
// }
// ^ See setup_unlink_unlink_pc_0_procfinal
// static void setup_unlink_unlink_p0_1_procfinal(void) {
//   
// }
// ^ See setup_unlink_unlink_pc_0_procfinal


/*
 * calls: unlink write
 */
static int test_unlink_write_pfc_0_0(void) {
  int r = unlink("__f0");
  expect_result("r", r, 0);
  return xerrno(r);
}
static int test_unlink_write_pfc_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_unlink_write_pfc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_unlink_write_pfc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_unlink_write_pfc_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_unlink_write_pfc_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_unlink_write_pfc_0_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: unlink write
 */
// static int test_unlink_write_pf0_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_write_pfc_0_0
static int test_unlink_write_pf0_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_unlink_write_pf0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_unlink_write_pf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_unlink_write_pf0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_unlink_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_final
// static void setup_unlink_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_pe8_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_write_pfc_0_0
static int test_unlink_write_pe8_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_unlink_write_pe8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
static void setup_unlink_write_pe8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_unlink_write_pe8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_unlink_write_pe8_0_final(void) {
  unlink("__i0");
}
static void setup_unlink_write_pe8_0_procfinal(void) {
  
}

/*
 * calls: unlink write
 */
// static int test_unlink_write_pe0_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_write_pfc_0_0
// static int test_unlink_write_pe0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pe8_0_1
static void setup_unlink_write_pe0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_unlink_write_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_unlink_write_pe8_0_proc0
// static void setup_unlink_write_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_pe0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_write_pe8_0_final
// static void setup_unlink_write_pe0_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_pc_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_write_pfc_0_0
// static int test_unlink_write_pc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pf0_0_1
static void setup_unlink_write_pc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = link("__i0", "__f0");
  if (r < 0) setup_error("link");
}
// static void setup_unlink_write_pc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_pc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_pc_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_write_pe8_0_final
// static void setup_unlink_write_pc_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_pbc_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_write_pfc_0_0
// static int test_unlink_write_pbc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pfc_0_1
// static void setup_unlink_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_unlink_write_pfc_0_common
// static void setup_unlink_write_pbc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pfc_0_proc1
// static void setup_unlink_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pfc_0_proc0
// static void setup_unlink_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_final
// static void setup_unlink_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_pb0_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_write_pfc_0_0
// static int test_unlink_write_pb0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pf0_0_1
// static void setup_unlink_write_pb0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_unlink_write_pf0_0_common
// static void setup_unlink_write_pb0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pf0_0_proc1
// static void setup_unlink_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pf0_0_proc0
// static void setup_unlink_write_pb0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_final
// static void setup_unlink_write_pb0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_pa8_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_write_pfc_0_0
// static int test_unlink_write_pa8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pe8_0_1
// static void setup_unlink_write_pa8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_unlink_write_pe8_0_common
// static void setup_unlink_write_pa8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_pa8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_unlink_write_pe8_0_proc0
// static void setup_unlink_write_pa8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_write_pe8_0_final
// static void setup_unlink_write_pa8_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_pa0_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_write_pfc_0_0
// static int test_unlink_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pe8_0_1
// static void setup_unlink_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_unlink_write_pe0_0_common
// static void setup_unlink_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_unlink_write_pe8_0_proc0
// static void setup_unlink_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_write_pe8_0_final
// static void setup_unlink_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p8_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, 0);
//   return xerrno(r);
// }
// ^ See test_unlink_write_pfc_0_0
// static int test_unlink_write_p8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pf0_0_1
// static void setup_unlink_write_p8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = link("__i0", "__f0");
//   if (r < 0) setup_error("link");
// }
// ^ See setup_unlink_write_pc_0_common
// static void setup_unlink_write_p8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_p8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_p8_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_write_pe8_0_final
// static void setup_unlink_write_p8_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal

/*
 * calls: unlink write
 */
static int test_unlink_write_p7c_0_0(void) {
  int r = unlink("__f0");
  expect_result("r", r, -1);
  expect_errno(2);
  return xerrno(r);
}
// static int test_unlink_write_p7c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pfc_0_1
static void setup_unlink_write_p7c_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_unlink_write_p7c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pfc_0_proc0
// static void setup_unlink_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pfc_0_proc1
// static void setup_unlink_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_final
// static void setup_unlink_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p78_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pe8_0_1
static void setup_unlink_write_p78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_unlink_write_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_unlink_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pf0_0_proc1
// static void setup_unlink_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_final
// static void setup_unlink_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p70_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pf0_0_1
static void setup_unlink_write_p70_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_unlink_write_p70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pf0_0_proc0
// static void setup_unlink_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pf0_0_proc1
// static void setup_unlink_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_final
// static void setup_unlink_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p68_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p68_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pe8_0_1
static void setup_unlink_write_p68_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_unlink_write_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_unlink_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_write_pe8_0_final
// static void setup_unlink_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p60_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p60_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pe8_0_1
static void setup_unlink_write_p60_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_unlink_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_unlink_write_p68_0_proc0
// static void setup_unlink_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_write_pe8_0_final
// static void setup_unlink_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p4_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p4_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pf0_0_1
static void setup_unlink_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_unlink_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_p4_0_final(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal
// static void setup_unlink_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p3c_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pfc_0_1
// static void setup_unlink_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_unlink_write_p7c_0_common
// static void setup_unlink_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pfc_0_proc1
// static void setup_unlink_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pfc_0_proc0
// static void setup_unlink_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_final
// static void setup_unlink_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p38_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pe8_0_1
// static void setup_unlink_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_unlink_write_p78_0_common
// static void setup_unlink_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pf0_0_proc1
// static void setup_unlink_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_p78_0_proc0
// static void setup_unlink_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_final
// static void setup_unlink_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p30_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pf0_0_1
// static void setup_unlink_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_unlink_write_p70_0_common
// static void setup_unlink_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pf0_0_proc1
// static void setup_unlink_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_unlink_write_pf0_0_proc0
// static void setup_unlink_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_final
// static void setup_unlink_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_unlink_write_pfc_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p28_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pe8_0_1
// static void setup_unlink_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_unlink_write_p68_0_common
// static void setup_unlink_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_unlink_write_p68_0_proc0
// static void setup_unlink_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_write_pe8_0_final
// static void setup_unlink_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p20_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pe8_0_1
// static void setup_unlink_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_unlink_write_p60_0_common
// static void setup_unlink_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_unlink_write_p68_0_proc0
// static void setup_unlink_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_unlink_write_pe8_0_final
// static void setup_unlink_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal

/*
 * calls: unlink write
 */
// static int test_unlink_write_p0_0_0(void) {
//   int r = unlink("__f0");
//   expect_result("r", r, -1);
//   expect_errno(2);
//   return xerrno(r);
// }
// ^ See test_unlink_write_p7c_0_0
// static int test_unlink_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_unlink_write_pf0_0_1
// static void setup_unlink_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_unlink_write_p4_0_common
// static void setup_unlink_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_unlink_write_pe8_0_proc1
// static void setup_unlink_write_p0_0_final(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal
// static void setup_unlink_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_unlink_write_pe8_0_procfinal


/*
 * calls: write write
 */
static int test_write_write_pff8_0_0(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static int test_write_write_pff8_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(32);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_write_write_pff8_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_write_write_pff8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_write_write_pff8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_write_write_pff8_0_final(void) {
  unlink("__i0");
  close(20);
  close(21);
  close(22);
  close(23);
}
static void setup_write_write_pff8_0_procfinal(void) {
  close(20);
  close(21);
  close(22);
  close(23);
}

/*
 * calls: write write
 */
// static int test_write_write_pff8_1_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static int test_write_write_pff8_1_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_1
static void setup_write_write_pff8_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_write_write_pff8_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_write_write_pff8_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_write_write_pff8_1_final(void) {
  unlink("__i0");
  close(20);
  close(21);
}
static void setup_write_write_pff8_1_procfinal(void) {
  close(20);
  close(21);
}

/*
 * calls: write write
 */
// static int test_write_write_pff8_2_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static int test_write_write_pff8_2_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static void setup_write_write_pff8_2_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pff8_1_common
static void setup_write_write_pff8_2_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pff8_2_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_1_proc1
// static void setup_write_write_pff8_2_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pff8_2_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pff0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
static int test_write_write_pff0_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_write_write_pff0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_write_write_pff0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_write_write_pff0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pff0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_final
// static void setup_write_write_pff0_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pfe_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
static int test_write_write_pfe_0_1(void) {
  ssize_t r = write(11, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_write_write_pfe_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pff8_0_common
static void setup_write_write_pfe_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(22, 11);
  if (r < 0) setup_error("dup2");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pfe_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff0_0_proc1
// static void setup_write_write_pfe_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_final
// static void setup_write_write_pfe_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pfd0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static int test_write_write_pfd0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
static void setup_write_write_pfd0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_write_write_pfd0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pfd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_1_proc1
// static void setup_write_write_pfd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pfd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pfc0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static int test_write_write_pfc0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
static void setup_write_write_pfc0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_write_write_pfc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pfd0_0_proc0
// static void setup_write_write_pfc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_1_proc1
// static void setup_write_write_pfc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pfc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pf8_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static int test_write_write_pf8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
// static void setup_write_write_pf8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pff8_1_common
// static void setup_write_write_pf8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_2_proc0
// static void setup_write_write_pf8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_1_proc1
// static void setup_write_write_pf8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pf8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pf78_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static int test_write_write_pf78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
static void setup_write_write_pf78_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 22);
  if (r != 22) setup_error("dup2");
  r = dup2(fds[1], 23);
  if (r != 23) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_write_write_pf78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_write_write_pf78_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pf78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_final
// static void setup_write_write_pf78_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pf78_1_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static int test_write_write_pf78_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
static void setup_write_write_pf78_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
// static void setup_write_write_pf78_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_2_proc0
// static void setup_write_write_pf78_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_2_proc0
// static void setup_write_write_pf78_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pf78_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pf70_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
static int test_write_write_pf70_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_write_write_pf70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pff0_0_common
static void setup_write_write_pf70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
static void setup_write_write_pf70_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pf70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_final
// static void setup_write_write_pf70_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pf6_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
static int test_write_write_pf6_0_1(void) {
  ssize_t r = write(10, dataval0, 4096);
  expect_result("r", r, -1);
  expect_errno(9);
  if (r <= 0) return xerrno(r);
  return r;
}
// static void setup_write_write_pf6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pf78_0_common
// static void setup_write_write_pf6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
//   r = dup(22);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pf70_0_proc0
static void setup_write_write_pf6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(22, 10);
  if (r < 0) setup_error("dup2");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
  r = dup(22);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pf6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_final
// static void setup_write_write_pf6_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pf50_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static int test_write_write_pf50_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_pf50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfd0_0_common
// static void setup_write_write_pf50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_2_proc0
static void setup_write_write_pf50_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pf50_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pf50_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pf40_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static int test_write_write_pf40_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_pf40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfc0_0_common
// static void setup_write_write_pf40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_2_proc0
// static void setup_write_write_pf40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pf50_0_proc1
// static void setup_write_write_pf40_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pf40_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pf0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static int test_write_write_pf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_pf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pf78_1_common
// static void setup_write_write_pf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_2_proc0
// static void setup_write_write_pf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_1_proc1
// static void setup_write_write_pf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pef8_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pef8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_1
// static void setup_write_write_pef8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pff0_0_common
static void setup_write_write_pef8_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_write_write_pef8_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pef8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_final
// static void setup_write_write_pef8_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pef0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pef0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
static void setup_write_write_pef0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  r = write(fds[1], dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fds[1], dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fds[0]);
  close(fds[1]);
}
static void setup_write_write_pef0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_write_write_pef0_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pef0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pef0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pef0_1_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pef0_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_pef0_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pef0_0_common
static void setup_write_write_pef0_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pef0_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pef0_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pef0_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pee_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pee_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
static void setup_write_write_pee_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_write_write_pee_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pee_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pee_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pee_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_ped0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_ped0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
static void setup_write_write_ped0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_write_write_ped0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_ped0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_ped0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_ped0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pec0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pec0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
static void setup_write_write_pec0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
// static void setup_write_write_pec0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_ped0_0_proc0
// static void setup_write_write_pec0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pec0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pec0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pe8_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pe8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
// static void setup_write_write_pe8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pee_0_common
// static void setup_write_write_pe8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
// static void setup_write_write_pe8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pe8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pe8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pe78_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pe78_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static void setup_write_write_pe78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pff0_0_common
static void setup_write_write_pe78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
static void setup_write_write_pe78_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(23, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pe78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_final
// static void setup_write_write_pe78_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pe70_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pe70_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_pe70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pef0_0_common
// static void setup_write_write_pe70_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
// static void setup_write_write_pe70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
// static void setup_write_write_pe70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pe70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pe6_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pe6_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_pe6_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pee_0_common
// static void setup_write_write_pe6_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
static void setup_write_write_pe6_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pe6_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pe6_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pe50_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pe50_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_pe50_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_ped0_0_common
// static void setup_write_write_pe50_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
static void setup_write_write_pe50_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pe50_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pe50_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pe40_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pe40_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_pe40_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pec0_0_common
// static void setup_write_write_pe40_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
// static void setup_write_write_pe40_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 24576, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe50_0_proc1
// static void setup_write_write_pe40_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pe40_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pe0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pe0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_pe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pee_0_common
// static void setup_write_write_pe0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
// static void setup_write_write_pe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pdf_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pdf_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_1
// static void setup_write_write_pdf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pff8_0_common
static void setup_write_write_pdf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(23, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pdf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef8_0_proc1
// static void setup_write_write_pdf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_final
// static void setup_write_write_pdf_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pde_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pde_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
// static void setup_write_write_pde_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pee_0_common
static void setup_write_write_pde_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pde_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pde_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pde_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pdc_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pdc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
static void setup_write_write_pdc_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
  r = pipe2(fds, O_NONBLOCK);
  if (r != 0) setup_error("pipe => %d", r);
  r = dup2(fds[0], 20);
  if (r != 20) setup_error("dup2");
  r = dup2(fds[1], 21);
  if (r != 21) setup_error("dup2");
  close(fds[0]);
  close(fds[1]);
}
static void setup_write_write_pdc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pdc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pdc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pdc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pdc_1_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pdc_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_pdc_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pdc_0_common
// static void setup_write_write_pdc_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
// static void setup_write_write_pdc_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pdc_1_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pdc_1_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pda_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pda_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
// static void setup_write_write_pda_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfd0_0_common
static void setup_write_write_pda_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pda_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pda_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pda_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pd8_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pd8_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
// static void setup_write_write_pd8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfc0_0_common
// static void setup_write_write_pd8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pda_0_proc0
// static void setup_write_write_pd8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pd8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pd8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pd0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pd0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
// static void setup_write_write_pd0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pdc_0_common
// static void setup_write_write_pd0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
// static void setup_write_write_pd0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pd0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pd0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pcf_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pcf_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static void setup_write_write_pcf_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 22);
//   if (r != 22) setup_error("dup2");
//   r = dup2(fds[1], 23);
//   if (r != 23) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pf78_0_common
static void setup_write_write_pcf_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 10);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(23);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pcf_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(23, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(23);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe78_0_proc1
// static void setup_write_write_pcf_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_final
// static void setup_write_write_pcf_0_procfinal(void) {
//   close(20);
//   close(21);
//   close(22);
//   close(23);
// }
// ^ See setup_write_write_pff8_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pce_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pce_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_pce_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pee_0_common
// static void setup_write_write_pce_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
// static void setup_write_write_pce_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
// static void setup_write_write_pce_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pce_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pcc_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pcc_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_pcc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pdc_0_common
// static void setup_write_write_pcc_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
// static void setup_write_write_pcc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
// static void setup_write_write_pcc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pcc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pca_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pca_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_pca_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfd0_0_common
// static void setup_write_write_pca_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
static void setup_write_write_pca_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pca_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pca_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pc8_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pc8_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_pc8_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfc0_0_common
// static void setup_write_write_pc8_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
// static void setup_write_write_pc8_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pca_0_proc1
// static void setup_write_write_pc8_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pc8_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pc0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_pc0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_pc0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pdc_0_common
// static void setup_write_write_pc0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
// static void setup_write_write_pc0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pc0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pc0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pbf0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pbf0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_1
// static void setup_write_write_pbf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfd0_0_common
static void setup_write_write_pbf0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pbf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_1_proc1
// static void setup_write_write_pbf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pbf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pbe0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pbe0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
// static void setup_write_write_pbe0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfd0_0_common
static void setup_write_write_pbe0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pbe0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pbe0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pbe0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pbc_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pbc_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
// static void setup_write_write_pbc_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfd0_0_common
static void setup_write_write_pbc_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_pbc_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_pbc_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pbc_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pba_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
static int test_write_write_pba_0_1(void) {
  ssize_t r = write(11, dataval1, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_write_write_pba_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_write_write_pba_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_write_write_pba_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
}
static void setup_write_write_pba_0_final(void) {
  unlink("__i0");
  unlink("__i1");
}
static void setup_write_write_pba_0_procfinal(void) {
  
}

/*
 * calls: write write
 */
// static int test_write_write_pba_1_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pba_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
static void setup_write_write_pba_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_write_write_pba_1_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_write_write_pba_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
static void setup_write_write_pba_1_final(void) {
  unlink("__i0");
}
// static void setup_write_write_pba_1_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pb90_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pb90_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
// static void setup_write_write_pb90_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_write_write_pba_1_common
static void setup_write_write_pb90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_write_write_pb90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_pb90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_pb90_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pb0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pb0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
static void setup_write_write_pb0_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  close(fd);
}
static void setup_write_write_pb0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_write_write_pb0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_pb0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_pb0_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_paf0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_paf0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static void setup_write_write_paf0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfd0_0_common
// static void setup_write_write_paf0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pf50_0_proc1
// static void setup_write_write_paf0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_2_proc0
// static void setup_write_write_paf0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_paf0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pae0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pae0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_pae0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfd0_0_common
// static void setup_write_write_pae0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pca_0_proc1
// static void setup_write_write_pae0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
// static void setup_write_write_pae0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pae0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pac_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pac_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_pac_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfd0_0_common
// static void setup_write_write_pac_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pca_0_proc1
// static void setup_write_write_pac_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
// static void setup_write_write_pac_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_pac_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pa90_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pa90_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
static void setup_write_write_pa90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_write_write_pa90_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_write_write_pa90_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 12288, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_write_write_pa90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_pa90_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pa80_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
static int test_write_write_pa80_0_1(void) {
  ssize_t r = write(10, dataval1, 4096);
  expect_result("r", r, 4096);
  if (r <= 0) return xerrno(r);
  return r;
}
static void setup_write_write_pa80_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
static void setup_write_write_pa80_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 24576, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
static void setup_write_write_pa80_0_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 20480, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_write_write_pa80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_pa80_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pa80_1_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pa80_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pa80_0_1
static void setup_write_write_pa80_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_write_write_pa80_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pba_1_proc0
static void setup_write_write_pa80_1_proc1(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i1", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 4096, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_write_write_pa80_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_write_write_pba_0_final
// static void setup_write_write_pa80_1_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_pa0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_pa0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_pa0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_write_write_pb0_0_common
// static void setup_write_write_pa0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pb0_0_proc0
// static void setup_write_write_pa0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_pa0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_pa0_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p9f0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p9f0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_1
// static void setup_write_write_p9f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfc0_0_common
// static void setup_write_write_p9f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pbf0_0_proc0
// static void setup_write_write_p9f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_1_proc1
// static void setup_write_write_p9f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p9f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p9e0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p9e0_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
// static void setup_write_write_p9e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfc0_0_common
// static void setup_write_write_p9e0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(21, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pbe0_0_proc0
// static void setup_write_write_p9e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_p9e0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p9e0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p9c_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p9c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
// static void setup_write_write_p9c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfc0_0_common
// static void setup_write_write_p9c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup2(20, 11);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pbc_0_proc0
// static void setup_write_write_p9c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_p9c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p9c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p9a0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p9a0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_p9a0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval1, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_write_write_pa90_0_common
static void setup_write_write_p9a0_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 8192, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 10);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_write_write_p9a0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p9a0_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_p9a0_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p90_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p90_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
static void setup_write_write_p90_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval0, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_write_write_p90_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pb0_0_proc0
// static void setup_write_write_p90_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p90_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_p90_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p8f0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p8f0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static void setup_write_write_p8f0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfc0_0_common
// static void setup_write_write_p8f0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pf50_0_proc1
// static void setup_write_write_p8f0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_2_proc0
// static void setup_write_write_p8f0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p8f0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p8e0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p8e0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_p8e0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfc0_0_common
// static void setup_write_write_p8e0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pca_0_proc1
// static void setup_write_write_p8e0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
// static void setup_write_write_p8e0_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p8e0_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p8c_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p8c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_p8c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pfc0_0_common
// static void setup_write_write_p8c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pca_0_proc1
// static void setup_write_write_p8c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
// static void setup_write_write_p8c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p8c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p8a_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p8a_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pa80_0_1
static void setup_write_write_p8a_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_write_write_p8a_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_p9a0_0_proc0
// static void setup_write_write_p8a_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 12288, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pa90_0_proc1
// static void setup_write_write_p8a_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_p8a_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p8a_1_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p8a_1_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pa80_0_1
static void setup_write_write_p8a_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval2, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
  fd = open("__i1", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i1", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval3, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_write_write_p8a_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pba_1_proc0
// static void setup_write_write_p8a_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i1", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pa80_1_proc1
// static void setup_write_write_p8a_1_final(void) {
//   unlink("__i0");
//   unlink("__i1");
// }
// ^ See setup_write_write_pba_0_final
// static void setup_write_write_p8a_1_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p88_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p88_0_1(void) {
//   ssize_t r = write(10, dataval1, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pa80_0_1
// static void setup_write_write_p88_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval2, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_write_write_p8a_0_common
// static void setup_write_write_p88_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 8192, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_p9a0_0_proc0
// static void setup_write_write_p88_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pba_1_proc0
// static void setup_write_write_p88_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_p88_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p88_1_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p88_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
static void setup_write_write_p88_1_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
  fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
  if (fd < 0) setup_error("open");
  write(fd, "x", 1);
  close(fd);
  fd = open("__i0", O_TRUNC | O_RDWR);
  if (fd < 0) setup_error("open");
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  r = write(fd, dataval1, 4096);
  if (r != 4096) setup_error("write => %d", r);
  close(fd);
}
// static void setup_write_write_p88_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pba_1_proc0
// static void setup_write_write_p88_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 4096, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pba_1_proc0
// static void setup_write_write_p88_1_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_p88_1_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p80_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static int test_write_write_p80_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_p80_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_write_write_p90_0_common
// static void setup_write_write_p80_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pb0_0_proc0
// static void setup_write_write_p80_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p80_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_p80_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p7c_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p7c_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_1
// static void setup_write_write_p7c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pff8_1_common
static void setup_write_write_p7c_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_p7c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_1_proc1
// static void setup_write_write_p7c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p7c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p78_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p78_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
// static void setup_write_write_p78_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pee_0_common
static void setup_write_write_p78_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(21, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_p78_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_p78_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p78_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p70_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p70_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
// static void setup_write_write_p70_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pdc_0_common
static void setup_write_write_p70_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  r = dup2(20, 11);
  if (r < 0) setup_error("dup2");
  r = dup(20);
  if (r < 0) setup_error("dup");
  r = dup(21);
  if (r < 0) setup_error("dup");
}
// static void setup_write_write_p70_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_p70_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p70_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p68_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p68_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
// static void setup_write_write_p68_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_write_write_pb0_0_common
static void setup_write_write_p68_0_proc0(void) {
  int fd __attribute__((unused));
  int r __attribute__((unused));
  fd = open("__i0", O_RDWR);
  if (fd < 0) setup_error("open");
  r = lseek(fd, 0, SEEK_SET);
  if (fd >= 0 && r < 0) setup_error("lseek");
  r = dup2(fd, 11);
  if (fd >= 0 && r < 0) setup_error("dup2");
  close(fd);
}
// static void setup_write_write_p68_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p68_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_p68_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p60_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p60_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff0_0_1
// static void setup_write_write_p60_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_write_write_p90_0_common
// static void setup_write_write_p60_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 11);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_p68_0_proc0
// static void setup_write_write_p60_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p60_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_p60_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p4_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p4_0_1(void) {
//   ssize_t r = write(11, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pfe_0_1
static void setup_write_write_p4_0_common(void) {
  int fd __attribute__((unused));
  int fds[2] __attribute__((unused));
  int r __attribute__((unused));
  char c __attribute__((unused));
}
// static void setup_write_write_p4_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p4_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p4_0_final(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal
// static void setup_write_write_p4_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p4_1_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p4_1_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_p4_1_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_write_write_p4_0_common
// static void setup_write_write_p4_1_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p4_1_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p4_1_final(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal
// static void setup_write_write_p4_1_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p3c_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p3c_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(32);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pff8_0_0
// static void setup_write_write_p3c_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fds[1], dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pf78_1_common
// static void setup_write_write_p3c_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_1_proc1
// static void setup_write_write_p3c_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pff8_2_proc0
// static void setup_write_write_p3c_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p3c_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p38_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p38_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_p38_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pee_0_common
// static void setup_write_write_p38_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_p38_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(21, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_1_proc0
// static void setup_write_write_p38_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p38_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p30_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p30_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_p30_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
//   r = pipe2(fds, O_NONBLOCK);
//   if (r != 0) setup_error("pipe => %d", r);
//   r = dup2(fds[0], 20);
//   if (r != 20) setup_error("dup2");
//   r = dup2(fds[1], 21);
//   if (r != 21) setup_error("dup2");
//   close(fds[0]);
//   close(fds[1]);
// }
// ^ See setup_write_write_pdc_0_common
// static void setup_write_write_p30_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pef0_0_proc1
// static void setup_write_write_p30_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   r = dup2(20, 10);
//   if (r < 0) setup_error("dup2");
//   r = dup(20);
//   if (r < 0) setup_error("dup");
//   r = dup(21);
//   if (r < 0) setup_error("dup");
// }
// ^ See setup_write_write_pe6_0_proc1
// static void setup_write_write_p30_0_final(void) {
//   unlink("__i0");
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_final
// static void setup_write_write_p30_0_procfinal(void) {
//   close(20);
//   close(21);
// }
// ^ See setup_write_write_pff8_1_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p28_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p28_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_p28_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   close(fd);
// }
// ^ See setup_write_write_pb0_0_common
// static void setup_write_write_p28_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p28_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pb0_0_proc0
// static void setup_write_write_p28_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_p28_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p20_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p20_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, 4096);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf70_0_1
// static void setup_write_write_p20_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
//   fd = open("__i0", O_CREAT | O_TRUNC | O_RDWR, 0666);
//   if (fd < 0) setup_error("open");
//   write(fd, "x", 1);
//   close(fd);
//   fd = open("__i0", O_TRUNC | O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = write(fd, dataval0, 4096);
//   if (r != 4096) setup_error("write => %d", r);
//   close(fd);
// }
// ^ See setup_write_write_p90_0_common
// static void setup_write_write_p20_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p20_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
//   fd = open("__i0", O_RDWR);
//   if (fd < 0) setup_error("open");
//   r = lseek(fd, 0, SEEK_SET);
//   if (fd >= 0 && r < 0) setup_error("lseek");
//   r = dup2(fd, 10);
//   if (fd >= 0 && r < 0) setup_error("dup2");
//   close(fd);
// }
// ^ See setup_write_write_pb0_0_proc0
// static void setup_write_write_p20_0_final(void) {
//   unlink("__i0");
// }
// ^ See setup_write_write_pba_1_final
// static void setup_write_write_p20_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

/*
 * calls: write write
 */
// static int test_write_write_p0_0_0(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static int test_write_write_p0_0_1(void) {
//   ssize_t r = write(10, dataval0, 4096);
//   expect_result("r", r, -1);
//   expect_errno(9);
//   if (r <= 0) return xerrno(r);
//   return r;
// }
// ^ See test_write_write_pf6_0_1
// static void setup_write_write_p0_0_common(void) {
//   int fd __attribute__((unused));
//   int fds[2] __attribute__((unused));
//   int r __attribute__((unused));
//   char c __attribute__((unused));
// }
// ^ See setup_write_write_p4_0_common
// static void setup_write_write_p0_0_proc0(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p0_0_proc1(void) {
//   int fd __attribute__((unused));
//   int r __attribute__((unused));
// }
// ^ See setup_write_write_pba_0_proc1
// static void setup_write_write_p0_0_final(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal
// static void setup_write_write_p0_0_procfinal(void) {
//   
// }
// ^ See setup_write_write_pba_0_procfinal

static void cleanup(void) {
  unlink("__f0");
  unlink("__f1");
  unlink("__f2");
  unlink("__f3");
  unlink("__f4");
  unlink("__f5");
}

struct fstest fstests[] = {
  { "fs-close_close_pe_0",
    &setup_close_close_pe_0_common,
    { { &setup_close_close_pe_0_proc0 }, { &setup_close_close_pe_0_proc1 } },
    &setup_close_close_pe_0_procfinal,
    &setup_close_close_pe_0_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pe_1",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pe_1_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pe_2",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pe_2_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pe_3",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pe_3_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pe_4",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pe_4_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pe_5",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pe_5_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pe_6",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pe_6_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pe_7",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pe_7_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pe_8",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pe_8_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pc_0",
    &setup_close_close_pe_0_common,
    { { &setup_close_close_pc_0_proc0 }, { &setup_close_close_pe_0_proc1 } },
    &setup_close_close_pe_0_procfinal,
    &setup_close_close_pe_0_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pc_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pc_1",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pc_1_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pc_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pc_2",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pc_2_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pc_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_pa_0",
    &setup_close_close_pe_0_common,
    { { &setup_close_close_pc_0_proc0 }, { &setup_close_close_pc_0_proc0 } },
    &setup_close_close_pe_0_procfinal,
    &setup_close_close_pe_0_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_pa_1",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pc_1_proc0 }, { &setup_close_close_pa_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_pa_2",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pa_1_proc1 }, { &setup_close_close_pc_1_proc0 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_pa_3",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pc_1_proc0 }, { &setup_close_close_pc_1_proc0 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_pa_4",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pc_2_proc0 }, { &setup_close_close_pa_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_pa_5",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pc_2_proc0 }, { &setup_close_close_pc_1_proc0 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_pa_6",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pa_1_proc1 }, { &setup_close_close_pc_2_proc0 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_pa_7",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pc_1_proc0 }, { &setup_close_close_pc_2_proc0 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_pa_8",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pc_2_proc0 }, { &setup_close_close_pc_2_proc0 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_p8_0",
    &setup_close_close_pe_0_common,
    { { &setup_close_close_pc_0_proc0 }, { &setup_close_close_pe_0_proc1 } },
    &setup_close_close_pe_0_procfinal,
    &setup_close_close_pe_0_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_p8_0_1, 1, "close" } },
    &cleanup },
  { "fs-close_close_p8_1",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pc_1_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_p8_0_1, 1, "close" } },
    &cleanup },
  { "fs-close_close_p8_2",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pc_2_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_pe_0_0, 0, "close" },
      { &test_close_close_p8_0_1, 1, "close" } },
    &cleanup },
  { "fs-close_close_p6_0",
    &setup_close_close_pe_0_common,
    { { &setup_close_close_p6_0_proc0 }, { &setup_close_close_pe_0_proc1 } },
    &setup_close_close_pe_0_procfinal,
    &setup_close_close_pe_0_final,
    { { &test_close_close_p8_0_1, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_p6_1",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_p6_1_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_p8_0_1, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_p6_2",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_p6_2_proc0 }, { &setup_close_close_pe_1_proc1 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_p8_0_1, 0, "close" },
      { &test_close_close_pe_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_p4_0",
    &setup_close_close_p4_0_common,
    { { &setup_close_close_pe_0_proc1 }, { &setup_close_close_pe_0_proc1 } },
    &setup_close_close_pe_0_procfinal,
    &setup_close_close_pe_0_procfinal,
    { { &test_close_close_p8_0_1, 0, "close" },
      { &test_close_close_pc_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_p4_1",
    &setup_close_close_p4_0_common,
    { { &setup_close_close_pe_0_proc1 }, { &setup_close_close_pe_0_proc1 } },
    &setup_close_close_pe_0_procfinal,
    &setup_close_close_pe_0_procfinal,
    { { &test_close_close_p8_0_1, 0, "close" },
      { &test_close_close_p8_0_1, 0, "close" } },
    &cleanup },
  { "fs-close_close_p2_0",
    &setup_close_close_pe_0_common,
    { { &setup_close_close_pe_0_proc1 }, { &setup_close_close_pc_0_proc0 } },
    &setup_close_close_pe_0_procfinal,
    &setup_close_close_pe_0_final,
    { { &test_close_close_p8_0_1, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_p2_1",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pe_1_proc1 }, { &setup_close_close_pc_1_proc0 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_p8_0_1, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_p2_2",
    &setup_close_close_pe_1_common,
    { { &setup_close_close_pe_1_proc1 }, { &setup_close_close_pc_2_proc0 } },
    &setup_close_close_pe_1_procfinal,
    &setup_close_close_pe_1_final,
    { { &test_close_close_p8_0_1, 0, "close" },
      { &test_close_close_pe_0_0, 1, "close" } },
    &cleanup },
  { "fs-close_close_p0_0",
    &setup_close_close_p4_0_common,
    { { &setup_close_close_pe_0_proc1 }, { &setup_close_close_pe_0_proc1 } },
    &setup_close_close_pe_0_procfinal,
    &setup_close_close_pe_0_procfinal,
    { { &test_close_close_p8_0_1, 0, "close" },
      { &test_close_close_p8_0_1, 1, "close" } },
    &cleanup },
  { "fs-close_fstat_pf_0",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pf_0_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pf_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pf_1",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pf_1_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pf_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pf_2",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pf_2_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pf_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pf_3",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pf_3_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pf_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pf_4",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pf_4_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pf_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pf_5",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pf_5_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pf_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pe_0",
    &setup_close_fstat_pe_0_common,
    { { &setup_close_fstat_pe_0_proc0 }, { &setup_close_fstat_pe_0_proc1 } },
    &setup_close_fstat_pe_0_procfinal,
    &setup_close_fstat_pe_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pe_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pe_1",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pe_1_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pe_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pe_2",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pe_2_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pe_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pc_0",
    &setup_close_fstat_pe_0_common,
    { { &setup_close_fstat_pc_0_proc0 }, { &setup_close_fstat_pe_0_proc1 } },
    &setup_close_fstat_pe_0_procfinal,
    &setup_close_fstat_pe_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pc_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pc_1",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pc_1_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pc_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pc_2",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pc_2_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pc_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pb_0",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pb_0_proc0 }, { &setup_close_fstat_pc_1_proc0 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pb_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pb_1",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pb_0_proc0 }, { &setup_close_fstat_pc_2_proc0 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pb_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pb_2",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pc_1_proc0 }, { &setup_close_fstat_pc_1_proc0 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pb_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pb_3",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pc_2_proc0 }, { &setup_close_fstat_pc_1_proc0 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pb_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pb_4",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pc_1_proc0 }, { &setup_close_fstat_pc_2_proc0 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pb_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pb_5",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pc_2_proc0 }, { &setup_close_fstat_pc_2_proc0 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pb_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pa_0",
    &setup_close_fstat_pe_0_common,
    { { &setup_close_fstat_pc_0_proc0 }, { &setup_close_fstat_pc_0_proc0 } },
    &setup_close_fstat_pe_0_procfinal,
    &setup_close_fstat_pe_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pa_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pa_1",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pc_1_proc0 }, { &setup_close_fstat_pb_0_proc0 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pa_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_pa_2",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pc_2_proc0 }, { &setup_close_fstat_pb_0_proc0 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_pa_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p8_0",
    &setup_close_fstat_pe_0_common,
    { { &setup_close_fstat_pc_0_proc0 }, { &setup_close_fstat_pe_0_proc1 } },
    &setup_close_fstat_pe_0_procfinal,
    &setup_close_fstat_pe_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_p8_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p8_1",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pc_1_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_p8_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p8_2",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pc_2_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_pf_0_0, 0, "close" },
      { &test_close_fstat_p8_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p7_0",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_p7_0_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_p7_0_0, 0, "close" },
      { &test_close_fstat_pf_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p7_1",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_p7_1_proc0 }, { &setup_close_fstat_pf_0_proc1 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_p7_0_0, 0, "close" },
      { &test_close_fstat_pf_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p6_0",
    &setup_close_fstat_pe_0_common,
    { { &setup_close_fstat_p6_0_proc0 }, { &setup_close_fstat_pe_0_proc1 } },
    &setup_close_fstat_pe_0_procfinal,
    &setup_close_fstat_pe_0_final,
    { { &test_close_fstat_p7_0_0, 0, "close" },
      { &test_close_fstat_pe_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p4_0",
    &setup_close_fstat_p4_0_common,
    { { &setup_close_fstat_pe_0_proc1 }, { &setup_close_fstat_pe_0_proc1 } },
    &setup_close_fstat_pe_0_procfinal,
    &setup_close_fstat_pe_0_procfinal,
    { { &test_close_fstat_p7_0_0, 0, "close" },
      { &test_close_fstat_pc_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p4_1",
    &setup_close_fstat_p4_0_common,
    { { &setup_close_fstat_pe_0_proc1 }, { &setup_close_fstat_pe_0_proc1 } },
    &setup_close_fstat_pe_0_procfinal,
    &setup_close_fstat_pe_0_procfinal,
    { { &test_close_fstat_p7_0_0, 0, "close" },
      { &test_close_fstat_p8_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p3_0",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pf_0_proc1 }, { &setup_close_fstat_pc_1_proc0 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_p7_0_0, 0, "close" },
      { &test_close_fstat_pb_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p3_1",
    &setup_close_fstat_pf_0_common,
    { { &setup_close_fstat_pf_0_proc1 }, { &setup_close_fstat_pc_2_proc0 } },
    &setup_close_fstat_pf_0_procfinal,
    &setup_close_fstat_pf_0_final,
    { { &test_close_fstat_p7_0_0, 0, "close" },
      { &test_close_fstat_pb_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p2_0",
    &setup_close_fstat_pe_0_common,
    { { &setup_close_fstat_pe_0_proc1 }, { &setup_close_fstat_pc_0_proc0 } },
    &setup_close_fstat_pe_0_procfinal,
    &setup_close_fstat_pe_0_final,
    { { &test_close_fstat_p7_0_0, 0, "close" },
      { &test_close_fstat_pa_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_fstat_p0_0",
    &setup_close_fstat_p4_0_common,
    { { &setup_close_fstat_pe_0_proc1 }, { &setup_close_fstat_pe_0_proc1 } },
    &setup_close_fstat_pe_0_procfinal,
    &setup_close_fstat_pe_0_procfinal,
    { { &test_close_fstat_p7_0_0, 0, "close" },
      { &test_close_fstat_p8_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-close_link_pe_0",
    &setup_close_link_pe_0_common,
    { { &setup_close_link_pe_0_proc0 }, { &setup_close_link_pe_0_proc1 } },
    &setup_close_link_pe_0_procfinal,
    &setup_close_link_pe_0_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_pe_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_pe_1",
    &setup_close_link_pe_1_common,
    { { &setup_close_link_pe_1_proc0 }, { &setup_close_link_pe_1_proc1 } },
    &setup_close_link_pe_1_procfinal,
    &setup_close_link_pe_1_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_pe_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_pe_2",
    &setup_close_link_pe_2_common,
    { { &setup_close_link_pe_0_proc0 }, { &setup_close_link_pe_0_proc1 } },
    &setup_close_link_pe_0_procfinal,
    &setup_close_link_pe_0_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_pe_2_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_pe_3",
    &setup_close_link_pe_3_common,
    { { &setup_close_link_pe_1_proc0 }, { &setup_close_link_pe_1_proc1 } },
    &setup_close_link_pe_1_procfinal,
    &setup_close_link_pe_1_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_pe_2_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_pe_4",
    &setup_close_link_pe_1_common,
    { { &setup_close_link_pe_4_proc0 }, { &setup_close_link_pe_1_proc1 } },
    &setup_close_link_pe_1_procfinal,
    &setup_close_link_pe_1_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_pe_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_pe_5",
    &setup_close_link_pe_3_common,
    { { &setup_close_link_pe_4_proc0 }, { &setup_close_link_pe_1_proc1 } },
    &setup_close_link_pe_1_procfinal,
    &setup_close_link_pe_1_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_pe_2_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_pc_0",
    &setup_close_link_pe_2_common,
    { { &setup_close_link_pc_0_proc0 }, { &setup_close_link_pe_0_proc1 } },
    &setup_close_link_pe_0_procfinal,
    &setup_close_link_pe_0_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_pc_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_pc_1",
    &setup_close_link_pc_1_common,
    { { &setup_close_link_pe_1_proc0 }, { &setup_close_link_pe_1_proc1 } },
    &setup_close_link_pe_1_procfinal,
    &setup_close_link_pe_1_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_pc_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_pc_2",
    &setup_close_link_pc_1_common,
    { { &setup_close_link_pe_4_proc0 }, { &setup_close_link_pe_1_proc1 } },
    &setup_close_link_pe_1_procfinal,
    &setup_close_link_pe_1_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_pc_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_p8_0",
    &setup_close_link_p8_0_common,
    { { &setup_close_link_pe_0_proc0 }, { &setup_close_link_pe_0_proc1 } },
    &setup_close_link_pe_0_procfinal,
    &setup_close_link_pe_0_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_p8_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_p8_1",
    &setup_close_link_p8_1_common,
    { { &setup_close_link_pe_1_proc0 }, { &setup_close_link_pe_1_proc1 } },
    &setup_close_link_pe_1_procfinal,
    &setup_close_link_pe_1_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_p8_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_p8_2",
    &setup_close_link_p8_1_common,
    { { &setup_close_link_pe_4_proc0 }, { &setup_close_link_pe_1_proc1 } },
    &setup_close_link_pe_1_procfinal,
    &setup_close_link_pe_1_final,
    { { &test_close_link_pe_0_0, 0, "close" },
      { &test_close_link_p8_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_p6_0",
    &setup_close_link_pe_0_common,
    { { &setup_close_link_pe_0_proc1 }, { &setup_close_link_pe_0_proc1 } },
    &setup_close_link_pe_0_procfinal,
    &setup_close_link_pe_0_final,
    { { &test_close_link_p6_0_0, 0, "close" },
      { &test_close_link_pe_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_p6_1",
    &setup_close_link_pe_2_common,
    { { &setup_close_link_pe_0_proc1 }, { &setup_close_link_pe_0_proc1 } },
    &setup_close_link_pe_0_procfinal,
    &setup_close_link_pe_0_final,
    { { &test_close_link_p6_0_0, 0, "close" },
      { &test_close_link_pe_2_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_p4_0",
    &setup_close_link_pe_2_common,
    { { &setup_close_link_pe_0_proc1 }, { &setup_close_link_pe_0_proc1 } },
    &setup_close_link_pe_0_procfinal,
    &setup_close_link_pe_0_final,
    { { &test_close_link_p6_0_0, 0, "close" },
      { &test_close_link_pc_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_link_p0_0",
    &setup_close_link_p0_0_common,
    { { &setup_close_link_pe_0_proc1 }, { &setup_close_link_pe_0_proc1 } },
    &setup_close_link_pe_0_procfinal,
    &setup_close_link_pe_0_procfinal,
    { { &test_close_link_p6_0_0, 0, "close" },
      { &test_close_link_p8_0_1, 0, "link" } },
    &cleanup },
  { "fs-close_lseek_pf_0",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pf_0_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pf_1",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pf_1_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pf_2",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pf_2_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pf_3",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pf_3_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pf_4",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pf_4_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pf_5",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pf_5_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pec_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pec_0_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pec_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pec_1",
    &setup_close_lseek_pec_1_common,
    { { &setup_close_lseek_pec_1_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pec_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pec_2",
    &setup_close_lseek_pec_1_common,
    { { &setup_close_lseek_pec_2_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pec_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe8_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pe8_0_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe8_1",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pe8_1_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe8_2",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pe8_2_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe8_3",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pe8_3_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe8_4",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pe8_4_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe8_5",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pe8_5_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe6_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pe8_5_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe6_1",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pe8_3_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe6_2",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pe8_4_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe4_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pe8_5_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe4_1",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pe8_3_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe4_2",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pe8_4_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe3_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pe8_0_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe3_1",
    &setup_close_lseek_pe3_1_common,
    { { &setup_close_lseek_pe8_1_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe3_2",
    &setup_close_lseek_pe3_1_common,
    { { &setup_close_lseek_pe8_2_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe2_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pe8_0_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe2_1",
    &setup_close_lseek_pe3_1_common,
    { { &setup_close_lseek_pe8_1_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe2_2",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pe8_5_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe2_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe2_3",
    &setup_close_lseek_pe3_1_common,
    { { &setup_close_lseek_pe8_2_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe2_4",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pe8_3_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe2_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe2_5",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pe8_4_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pe2_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe0_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pe8_5_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe0_1",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pe8_3_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pe0_2",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pe8_4_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pc_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pc_0_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pc_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pc_1",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pc_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pc_2",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pc_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pb_0",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pb_0_proc0 }, { &setup_close_lseek_pc_1_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pb_1",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pb_0_proc0 }, { &setup_close_lseek_pc_2_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pb_2",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pc_1_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pb_3",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pc_1_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pb_4",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pc_2_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pb_5",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pc_2_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pac_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pac_0_proc0 }, { &setup_close_lseek_pac_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pac_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pac_1",
    &setup_close_lseek_pac_1_common,
    { { &setup_close_lseek_pc_0_proc0 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pac_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pac_2",
    &setup_close_lseek_pac_2_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pac_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pac_3",
    &setup_close_lseek_pec_1_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pac_3_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pac_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa8_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pa8_0_proc0 }, { &setup_close_lseek_pa8_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa8_1",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pa8_1_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa8_2",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pc_0_proc0 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa8_3",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pa8_1_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa8_4",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa8_5",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa6_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pc_0_proc0 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa6_1",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa6_2",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa4_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pc_0_proc0 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa4_1",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa4_2",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa3_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pa8_0_proc1 }, { &setup_close_lseek_pa8_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa3_1",
    &setup_close_lseek_pe3_1_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pa8_1_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa3_2",
    &setup_close_lseek_pe3_1_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pa8_1_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa2_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pa8_0_proc1 }, { &setup_close_lseek_pa8_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa2_1",
    &setup_close_lseek_pe3_1_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pa8_1_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa2_2",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pc_0_proc0 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa2_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa2_3",
    &setup_close_lseek_pe3_1_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pa8_1_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa2_4",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa2_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa2_5",
    &setup_close_lseek_pe8_1_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pa2_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa0_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pc_0_proc0 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa0_1",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_pa0_2",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pb_0_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p8_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pc_0_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_p8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p8_1",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pc_1_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_p8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p8_2",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pc_2_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_pf_0_0, 0, "close" },
      { &test_close_lseek_p8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p7_0",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_p7_0_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p7_1",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_p7_1_proc0 }, { &setup_close_lseek_pf_0_proc1 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p6c_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_p6c_0_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pec_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p68_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_p68_0_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pe8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p68_1",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_p68_1_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pe8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p66_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_p68_1_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pe6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p64_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_p68_1_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pe4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p63_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_p68_0_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pe3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p62_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_p68_0_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pe2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p62_1",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_p68_1_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pe2_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p60_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_p68_1_proc0 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pf_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p4_0",
    &setup_close_lseek_p4_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_procfinal,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pc_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p4_1",
    &setup_close_lseek_p4_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_procfinal,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_p8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p3_0",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pf_0_proc1 }, { &setup_close_lseek_pc_1_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p3_1",
    &setup_close_lseek_pf_0_common,
    { { &setup_close_lseek_pf_0_proc1 }, { &setup_close_lseek_pc_2_proc0 } },
    &setup_close_lseek_pf_0_procfinal,
    &setup_close_lseek_pf_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p2c_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pac_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pac_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p28_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pa8_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pa8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p28_1",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pa8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p26_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pa6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p24_0",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pa4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p23_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pa8_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pa3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p22_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pa8_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pa2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p22_1",
    &setup_close_lseek_pec_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pa2_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p20_0",
    &setup_close_lseek_pe3_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pc_0_proc0 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_final,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_pb_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_lseek_p0_0",
    &setup_close_lseek_p4_0_common,
    { { &setup_close_lseek_pec_0_proc1 }, { &setup_close_lseek_pec_0_proc1 } },
    &setup_close_lseek_pec_0_procfinal,
    &setup_close_lseek_pec_0_procfinal,
    { { &test_close_lseek_p7_0_0, 0, "close" },
      { &test_close_lseek_p8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-close_memread_pf_0",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pf_0_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pf_1",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pf_1_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pf_2",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pf_2_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pf_3",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pf_3_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pf_4",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pf_4_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pf_5",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pf_5_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe8_0",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pe8_0_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe8_1",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pe8_1_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe8_2",
    &setup_close_memread_pe8_2_common,
    { { &setup_close_memread_pe8_2_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe8_3",
    &setup_close_memread_pe8_2_common,
    { { &setup_close_memread_pe8_3_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe8_4",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pe8_4_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe8_5",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pe8_5_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe8_6",
    &setup_close_memread_pe8_2_common,
    { { &setup_close_memread_pe8_6_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe8_7",
    &setup_close_memread_pe8_2_common,
    { { &setup_close_memread_pe8_7_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe0_0",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pe8_0_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe0_1",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pe8_1_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe0_2",
    &setup_close_memread_pe0_2_common,
    { { &setup_close_memread_pe8_2_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe0_3",
    &setup_close_memread_pe0_2_common,
    { { &setup_close_memread_pe8_3_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe0_4",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pe8_4_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe0_5",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pe8_5_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe0_6",
    &setup_close_memread_pe0_2_common,
    { { &setup_close_memread_pe8_6_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pe0_7",
    &setup_close_memread_pe0_2_common,
    { { &setup_close_memread_pe8_7_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pc_0",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pc_0_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pc_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pc_1",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pc_1_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pc_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pc_2",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pc_2_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pc_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_pb_0",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pc_0_proc0 }, { &setup_close_memread_pb_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pb_1",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pc_0_proc0 }, { &setup_close_memread_pb_1_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pb_2",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pc_1_proc0 }, { &setup_close_memread_pb_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pb_3",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pc_2_proc0 }, { &setup_close_memread_pb_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pb_4",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pc_1_proc0 }, { &setup_close_memread_pb_4_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pb_5",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pc_2_proc0 }, { &setup_close_memread_pb_4_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa8_0",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pa8_0_proc0 }, { &setup_close_memread_pa8_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa8_1",
    &setup_close_memread_pa8_1_common,
    { { &setup_close_memread_pc_1_proc0 }, { &setup_close_memread_pa8_1_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa8_2",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pa8_2_proc0 }, { &setup_close_memread_pa8_2_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa8_3",
    &setup_close_memread_pa8_1_common,
    { { &setup_close_memread_pc_2_proc0 }, { &setup_close_memread_pa8_1_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa8_4",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pa8_4_proc0 }, { &setup_close_memread_pa8_4_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa8_5",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pa8_2_proc0 }, { &setup_close_memread_pa8_5_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa8_6",
    &setup_close_memread_pa8_1_common,
    { { &setup_close_memread_pc_1_proc0 }, { &setup_close_memread_pa8_6_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa8_7",
    &setup_close_memread_pa8_1_common,
    { { &setup_close_memread_pc_2_proc0 }, { &setup_close_memread_pa8_6_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa0_0",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pa0_0_proc0 }, { &setup_close_memread_pa0_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa0_1",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pa0_0_proc0 }, { &setup_close_memread_pa0_1_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa0_2",
    &setup_close_memread_pe0_2_common,
    { { &setup_close_memread_pc_1_proc0 }, { &setup_close_memread_pa0_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa0_3",
    &setup_close_memread_pe0_2_common,
    { { &setup_close_memread_pc_1_proc0 }, { &setup_close_memread_pa0_3_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa0_4",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pc_0_proc0 }, { &setup_close_memread_pa0_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa0_5",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pc_0_proc0 }, { &setup_close_memread_pa0_1_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa0_6",
    &setup_close_memread_pe0_2_common,
    { { &setup_close_memread_pc_2_proc0 }, { &setup_close_memread_pa0_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_pa0_7",
    &setup_close_memread_pe0_2_common,
    { { &setup_close_memread_pc_2_proc0 }, { &setup_close_memread_pa0_3_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_p8_0",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pc_0_proc0 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_p8_1",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pc_1_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_p8_2",
    &setup_close_memread_pf_2_common,
    { { &setup_close_memread_pc_2_proc0 }, { &setup_close_memread_pf_2_proc1 } },
    &setup_close_memread_pf_2_procfinal,
    &setup_close_memread_pf_2_final,
    { { &test_close_memread_pf_0_0, 0, "close" },
      { &test_close_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_p7_0",
    &setup_close_memread_p7_0_common,
    { { &setup_close_memread_pb_0_proc1 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_procfinal,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_p7_1",
    &setup_close_memread_p7_0_common,
    { { &setup_close_memread_pb_1_proc1 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_procfinal,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_p68_0",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pa0_0_proc1 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_p68_1",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pa0_1_proc1 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_p60_0",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pa0_0_proc1 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_p60_1",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pa0_1_proc1 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_p4_0",
    &setup_close_memread_p7_0_common,
    { { &setup_close_memread_pf_0_proc1 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_procfinal,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pc_0_1, 0, "memread" } },
    &cleanup },
  { "fs-close_memread_p3_0",
    &setup_close_memread_p7_0_common,
    { { &setup_close_memread_pf_0_proc1 }, { &setup_close_memread_pb_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_procfinal,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_p3_1",
    &setup_close_memread_p7_0_common,
    { { &setup_close_memread_pf_0_proc1 }, { &setup_close_memread_pb_1_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_procfinal,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_p28_0",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pf_0_proc1 }, { &setup_close_memread_pa8_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_p28_1",
    &setup_close_memread_pf_0_common,
    { { &setup_close_memread_pf_0_proc1 }, { &setup_close_memread_p28_1_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pe8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_p20_0",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pf_0_proc1 }, { &setup_close_memread_pa0_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_p20_1",
    &setup_close_memread_pe0_0_common,
    { { &setup_close_memread_pf_0_proc1 }, { &setup_close_memread_pa0_1_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_final,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pf_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memread_p0_0",
    &setup_close_memread_p7_0_common,
    { { &setup_close_memread_pf_0_proc1 }, { &setup_close_memread_pf_0_proc1 } },
    &setup_close_memread_pf_0_procfinal,
    &setup_close_memread_pf_0_procfinal,
    { { &test_close_memread_p7_0_0, 0, "close" },
      { &test_close_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-close_memwrite_pf8_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pf8_0_proc0 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pf8_1",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pf8_1_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pf8_2",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pf8_2_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pf4_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pf4_0_proc0 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf4_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pf4_1",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pf4_1_proc0 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf4_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pf4_2",
    &setup_close_memwrite_pf4_2_common,
    { { &setup_close_memwrite_pf4_2_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf4_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pf4_3",
    &setup_close_memwrite_pf4_2_common,
    { { &setup_close_memwrite_pf4_3_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf4_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pf0_0",
    &setup_close_memwrite_pf0_0_common,
    { { &setup_close_memwrite_pf0_0_proc0 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pf0_1",
    &setup_close_memwrite_pf0_1_common,
    { { &setup_close_memwrite_pf0_1_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pf0_2",
    &setup_close_memwrite_pf0_0_common,
    { { &setup_close_memwrite_pf0_2_proc0 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pf0_3",
    &setup_close_memwrite_pf0_1_common,
    { { &setup_close_memwrite_pf0_3_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pe_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pe_0_proc0 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pe_1",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pe_1_proc0 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pe_2",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pe_2_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pe_3",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pe_3_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pe_4",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pe_4_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pe_5",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pe_5_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pc_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pc_0_proc0 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pc_1",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pc_1_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pc_2",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pc_2_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb8_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pc_0_proc0 }, { &setup_close_memwrite_pb8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb8_1",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pc_1_proc0 }, { &setup_close_memwrite_pb8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb8_2",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pc_2_proc0 }, { &setup_close_memwrite_pb8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb4_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pb4_0_proc0 }, { &setup_close_memwrite_pb4_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf4_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb4_1",
    &setup_close_memwrite_pb4_1_common,
    { { &setup_close_memwrite_pc_1_proc0 }, { &setup_close_memwrite_pb4_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf4_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb4_2",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pc_0_proc0 }, { &setup_close_memwrite_pb4_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf4_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb4_3",
    &setup_close_memwrite_pb4_1_common,
    { { &setup_close_memwrite_pc_2_proc0 }, { &setup_close_memwrite_pb4_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf4_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb0_0",
    &setup_close_memwrite_pf0_0_common,
    { { &setup_close_memwrite_pb4_0_proc0 }, { &setup_close_memwrite_pb4_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb0_1",
    &setup_close_memwrite_pf0_1_common,
    { { &setup_close_memwrite_pc_1_proc0 }, { &setup_close_memwrite_pb4_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb0_2",
    &setup_close_memwrite_pf0_0_common,
    { { &setup_close_memwrite_pc_0_proc0 }, { &setup_close_memwrite_pb4_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pb0_3",
    &setup_close_memwrite_pf0_1_common,
    { { &setup_close_memwrite_pc_2_proc0 }, { &setup_close_memwrite_pb4_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pa_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pc_0_proc0 }, { &setup_close_memwrite_pa_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pa_1",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pc_0_proc0 }, { &setup_close_memwrite_pa_1_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pa_2",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pc_1_proc0 }, { &setup_close_memwrite_pa_2_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pa_3",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pc_2_proc0 }, { &setup_close_memwrite_pa_2_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pa_4",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pc_1_proc0 }, { &setup_close_memwrite_pa_4_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_pa_5",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pc_2_proc0 }, { &setup_close_memwrite_pa_4_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p8_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pc_0_proc0 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p8_1",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pc_1_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p8_2",
    &setup_close_memwrite_pf8_1_common,
    { { &setup_close_memwrite_pc_2_proc0 }, { &setup_close_memwrite_pf8_1_proc1 } },
    &setup_close_memwrite_pf8_1_procfinal,
    &setup_close_memwrite_pf8_1_final,
    { { &test_close_memwrite_pf8_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p78_0",
    &setup_close_memwrite_p78_0_common,
    { { &setup_close_memwrite_pb8_0_proc1 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_procfinal,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p74_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_p74_0_proc0 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pf4_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p70_0",
    &setup_close_memwrite_pf0_0_common,
    { { &setup_close_memwrite_pb4_0_proc1 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p6_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pa_0_proc1 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p6_1",
    &setup_close_memwrite_p78_0_common,
    { { &setup_close_memwrite_pa_1_proc1 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_procfinal,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p4_0",
    &setup_close_memwrite_p78_0_common,
    { { &setup_close_memwrite_pf8_0_proc1 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_procfinal,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p38_0",
    &setup_close_memwrite_p78_0_common,
    { { &setup_close_memwrite_pf8_0_proc1 }, { &setup_close_memwrite_pb8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_procfinal,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p34_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pf8_0_proc1 }, { &setup_close_memwrite_pb4_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pf4_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p30_0",
    &setup_close_memwrite_pf0_0_common,
    { { &setup_close_memwrite_pf8_0_proc1 }, { &setup_close_memwrite_pb4_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pf8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p2_0",
    &setup_close_memwrite_pf8_0_common,
    { { &setup_close_memwrite_pf8_0_proc1 }, { &setup_close_memwrite_pa_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_final,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p2_1",
    &setup_close_memwrite_p78_0_common,
    { { &setup_close_memwrite_pf8_0_proc1 }, { &setup_close_memwrite_pa_1_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_procfinal,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_memwrite_p0_0",
    &setup_close_memwrite_p78_0_common,
    { { &setup_close_memwrite_pf8_0_proc1 }, { &setup_close_memwrite_pf8_0_proc1 } },
    &setup_close_memwrite_pf8_0_procfinal,
    &setup_close_memwrite_pf8_0_procfinal,
    { { &test_close_memwrite_p78_0_0, 0, "close" },
      { &test_close_memwrite_pe_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-close_mmap_pf0_0",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pf0_1",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pf0_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pf0_3",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pf0_4",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pf0_5",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pec_0",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_0_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pec_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_1_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pec_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pec_3",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_3_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pec_4",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pec_5",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_5_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pe8_0",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pe8_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pe8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pe8_1",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pe8_1_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pe8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pe8_2",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pe8_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pe8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pe0_0",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pe0_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pe0_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_0",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_1",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_3",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_4",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_5",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_6",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pd8_6_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_7",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_0_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_8",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_9",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_10",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pd8_11",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pcc_0",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_0_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pcc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pcc_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_1_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pcc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pcc_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pcc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pcc_3",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_3_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pcc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pcc_4",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pcc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pcc_5",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pec_5_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pcc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_0",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pe8_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_1",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pe8_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_2",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pd8_6_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_3",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pd8_6_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_4",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pe8_1_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_5",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pe8_1_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_6",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pca_6_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_7",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pe8_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_8",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pca_8_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_9",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pca_6_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_10",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pe8_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pca_11",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pca_8_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pca_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pc0_0",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pc0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pc0_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pc0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pc0_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pc0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pb0_0",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pb0_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pb0_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pac_0",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pac_0_proc0 }, { &setup_close_mmap_pf0_2_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pac_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pac_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pac_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pac_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pac_0_proc0 }, { &setup_close_mmap_pf0_4_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pac_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pac_3",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_4_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pac_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pac_4",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pac_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pac_5",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_4_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pac_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pa8_0",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pa8_0_proc0 }, { &setup_close_mmap_pa8_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pa8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pa8_1",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pa8_1_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pa8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pa8_2",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pa8_1_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pa8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pa0_0",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pa0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pa0_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pa0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_pa0_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pa0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p98_0",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p98_1",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p98_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p98_3",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p98_4",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p98_5",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_pd8_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8c_0",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pac_0_proc0 }, { &setup_close_mmap_pf0_2_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8c_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8c_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8c_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8c_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pac_0_proc0 }, { &setup_close_mmap_pf0_4_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8c_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8c_3",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_4_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8c_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8c_4",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8c_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8c_5",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_4_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8c_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_0",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pa8_0_proc1 }, { &setup_close_mmap_pa8_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_1",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pa8_0_proc1 }, { &setup_close_mmap_pa8_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_2",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pa8_1_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_3",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pac_0_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_4",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pa8_1_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_5",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pac_0_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_6",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pa8_1_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_7",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pac_0_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_8",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pa8_1_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_9",
    &setup_close_mmap_pe8_1_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pac_0_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_10",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc0 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p8a_11",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc0 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p8a_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p80_0",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_pf0_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p80_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p80_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p80_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p80_2",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_4_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_pf0_0_0, 0, "close" },
      { &test_close_mmap_p80_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p70_0",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p70_1",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_p70_1_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p6c_0",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_p6c_0_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p6c_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_p6c_1_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p68_0",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_p68_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pe8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p60_0",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p60_1",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pa0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p58_0",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pd8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p58_1",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pd8_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p58_2",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_p70_1_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pd8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p58_3",
    &setup_close_mmap_pf0_0_common,
    { { &setup_close_mmap_p70_1_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pd8_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p4c_0",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_p6c_0_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pcc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p4c_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_p6c_1_proc0 }, { &setup_close_mmap_pf0_2_proc1 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pcc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p4a_0",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_p68_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pca_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p4a_1",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_p68_0_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pca_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p4a_2",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_p70_1_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pca_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p4a_3",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_p70_1_proc0 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pca_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p40_0",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pc0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p40_1",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_p80_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p30_0",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p2c_0",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc1 }, { &setup_close_mmap_pf0_2_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pac_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p2c_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc1 }, { &setup_close_mmap_pf0_4_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pac_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p28_0",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pa8_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pa8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p20_0",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pa0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p18_0",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pd8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p18_1",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_pd8_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p0c_0",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc1 }, { &setup_close_mmap_pf0_2_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_p8c_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p0c_1",
    &setup_close_mmap_pf0_2_common,
    { { &setup_close_mmap_pf0_2_proc1 }, { &setup_close_mmap_pf0_4_proc0 } },
    &setup_close_mmap_pf0_2_procfinal,
    &setup_close_mmap_pf0_2_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_p8c_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p0a_0",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pa8_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_p8a_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p0a_1",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pa8_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_p8a_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p0a_2",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc0 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_p8a_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p0a_3",
    &setup_close_mmap_pe8_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc0 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_final,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_p8a_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mmap_p00_0",
    &setup_close_mmap_p70_0_common,
    { { &setup_close_mmap_pf0_0_proc1 }, { &setup_close_mmap_pf0_0_proc1 } },
    &setup_close_mmap_pf0_0_procfinal,
    &setup_close_mmap_pf0_0_procfinal,
    { { &test_close_mmap_p70_0_0, 0, "close" },
      { &test_close_mmap_p80_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-close_mprotect_pe_0",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pe_0_proc0 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_1",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pe_1_proc0 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_2",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pe_2_proc0 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_3",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pe_3_proc0 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_4",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pe_4_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_5",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pe_5_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_6",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pe_6_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_7",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pe_7_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_8",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pe_8_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_9",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pe_9_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_10",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pe_10_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pe_11",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pe_11_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pc_0",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pc_0_proc0 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pc_1",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_1_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pc_2",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_2_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_0",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pc_0_proc0 }, { &setup_close_mprotect_pa_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_1",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pc_0_proc0 }, { &setup_close_mprotect_pa_1_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_2",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_1_proc0 }, { &setup_close_mprotect_pa_2_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_3",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_1_proc0 }, { &setup_close_mprotect_pa_3_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_4",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pc_0_proc0 }, { &setup_close_mprotect_pa_4_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_5",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_1_proc0 }, { &setup_close_mprotect_pa_5_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_6",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pc_0_proc0 }, { &setup_close_mprotect_pa_6_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_7",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_1_proc0 }, { &setup_close_mprotect_pa_7_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_8",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_2_proc0 }, { &setup_close_mprotect_pa_2_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_9",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_2_proc0 }, { &setup_close_mprotect_pa_5_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_10",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_2_proc0 }, { &setup_close_mprotect_pa_3_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_pa_11",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_2_proc0 }, { &setup_close_mprotect_pa_7_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p8_0",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pc_0_proc0 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p8_1",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_1_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p8_2",
    &setup_close_mprotect_pe_4_common,
    { { &setup_close_mprotect_pc_2_proc0 }, { &setup_close_mprotect_pe_4_proc1 } },
    &setup_close_mprotect_pe_4_procfinal,
    &setup_close_mprotect_pe_4_final,
    { { &test_close_mprotect_pe_0_0, 0, "close" },
      { &test_close_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p6_0",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pa_0_proc1 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_p6_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p6_1",
    &setup_close_mprotect_p6_1_common,
    { { &setup_close_mprotect_pa_1_proc1 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_procfinal,
    { { &test_close_mprotect_p6_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p6_2",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pa_4_proc1 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_p6_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p6_3",
    &setup_close_mprotect_p6_1_common,
    { { &setup_close_mprotect_pa_6_proc1 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_procfinal,
    { { &test_close_mprotect_p6_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p4_0",
    &setup_close_mprotect_p6_1_common,
    { { &setup_close_mprotect_pe_0_proc1 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_procfinal,
    { { &test_close_mprotect_p6_0_0, 0, "close" },
      { &test_close_mprotect_pc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p2_0",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pe_0_proc1 }, { &setup_close_mprotect_pa_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_p6_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p2_1",
    &setup_close_mprotect_p6_1_common,
    { { &setup_close_mprotect_pe_0_proc1 }, { &setup_close_mprotect_pa_1_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_procfinal,
    { { &test_close_mprotect_p6_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p2_2",
    &setup_close_mprotect_pe_0_common,
    { { &setup_close_mprotect_pe_0_proc1 }, { &setup_close_mprotect_pa_4_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_final,
    { { &test_close_mprotect_p6_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p2_3",
    &setup_close_mprotect_p6_1_common,
    { { &setup_close_mprotect_pe_0_proc1 }, { &setup_close_mprotect_pa_6_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_procfinal,
    { { &test_close_mprotect_p6_0_0, 0, "close" },
      { &test_close_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_mprotect_p0_0",
    &setup_close_mprotect_p6_1_common,
    { { &setup_close_mprotect_pe_0_proc1 }, { &setup_close_mprotect_pe_0_proc1 } },
    &setup_close_mprotect_pe_0_procfinal,
    &setup_close_mprotect_pe_0_procfinal,
    { { &test_close_mprotect_p6_0_0, 0, "close" },
      { &test_close_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-close_munmap_pc_0",
    &setup_close_munmap_pc_0_common,
    { { &setup_close_munmap_pc_0_proc0 }, { &setup_close_munmap_pc_0_proc1 } },
    &setup_close_munmap_pc_0_procfinal,
    &setup_close_munmap_pc_0_final,
    { { &test_close_munmap_pc_0_0, 0, "close" },
      { &test_close_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-close_munmap_pc_1",
    &setup_close_munmap_pc_1_common,
    { { &setup_close_munmap_pc_1_proc0 }, { &setup_close_munmap_pc_1_proc1 } },
    &setup_close_munmap_pc_1_procfinal,
    &setup_close_munmap_pc_1_final,
    { { &test_close_munmap_pc_0_0, 0, "close" },
      { &test_close_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-close_munmap_pc_2",
    &setup_close_munmap_pc_1_common,
    { { &setup_close_munmap_pc_2_proc0 }, { &setup_close_munmap_pc_1_proc1 } },
    &setup_close_munmap_pc_1_procfinal,
    &setup_close_munmap_pc_1_final,
    { { &test_close_munmap_pc_0_0, 0, "close" },
      { &test_close_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-close_munmap_p8_0",
    &setup_close_munmap_pc_0_common,
    { { &setup_close_munmap_pc_0_proc0 }, { &setup_close_munmap_pc_0_proc1 } },
    &setup_close_munmap_pc_0_procfinal,
    &setup_close_munmap_pc_0_final,
    { { &test_close_munmap_pc_0_0, 0, "close" },
      { &test_close_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-close_munmap_p8_1",
    &setup_close_munmap_pc_1_common,
    { { &setup_close_munmap_pc_1_proc0 }, { &setup_close_munmap_pc_1_proc1 } },
    &setup_close_munmap_pc_1_procfinal,
    &setup_close_munmap_pc_1_final,
    { { &test_close_munmap_pc_0_0, 0, "close" },
      { &test_close_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-close_munmap_p8_2",
    &setup_close_munmap_pc_1_common,
    { { &setup_close_munmap_pc_2_proc0 }, { &setup_close_munmap_pc_1_proc1 } },
    &setup_close_munmap_pc_1_procfinal,
    &setup_close_munmap_pc_1_final,
    { { &test_close_munmap_pc_0_0, 0, "close" },
      { &test_close_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-close_munmap_p4_0",
    &setup_close_munmap_p4_0_common,
    { { &setup_close_munmap_pc_0_proc1 }, { &setup_close_munmap_pc_0_proc1 } },
    &setup_close_munmap_pc_0_procfinal,
    &setup_close_munmap_pc_0_procfinal,
    { { &test_close_munmap_p4_0_0, 0, "close" },
      { &test_close_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-close_munmap_p0_0",
    &setup_close_munmap_p4_0_common,
    { { &setup_close_munmap_pc_0_proc1 }, { &setup_close_munmap_pc_0_proc1 } },
    &setup_close_munmap_pc_0_procfinal,
    &setup_close_munmap_pc_0_procfinal,
    { { &test_close_munmap_p4_0_0, 0, "close" },
      { &test_close_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-close_open_pf_0",
    &setup_close_open_pf_0_common,
    { { &setup_close_open_pf_0_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pf_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pf_1",
    &setup_close_open_pf_1_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pf_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pf_2",
    &setup_close_open_pf_1_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pf_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pee_0",
    &setup_close_open_pee_0_common,
    { { &setup_close_open_pee_0_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pee_1",
    &setup_close_open_pee_1_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pee_2",
    &setup_close_open_pee_1_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pea_0",
    &setup_close_open_pea_0_common,
    { { &setup_close_open_pea_0_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pea_1",
    &setup_close_open_pea_1_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pea_2",
    &setup_close_open_pea_2_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pe6_0",
    &setup_close_open_pe6_0_common,
    { { &setup_close_open_pe6_0_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pe6_1",
    &setup_close_open_pe6_1_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pe6_2",
    &setup_close_open_pe6_1_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pe2_0",
    &setup_close_open_pe6_0_common,
    { { &setup_close_open_pe6_0_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pe2_1",
    &setup_close_open_pe6_1_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pe2_2",
    &setup_close_open_pe6_1_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pdc_0",
    &setup_close_open_pdc_0_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pdc_1",
    &setup_close_open_pdc_1_common,
    { { &setup_close_open_pdc_1_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pdc_2",
    &setup_close_open_pdc_0_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pd4_0",
    &setup_close_open_pdc_0_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pd4_1",
    &setup_close_open_pd4_1_common,
    { { &setup_close_open_pdc_1_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pd4_2",
    &setup_close_open_pdc_0_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pcc_0",
    &setup_close_open_pdc_0_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pcc_1",
    &setup_close_open_pdc_1_common,
    { { &setup_close_open_pdc_1_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pcc_2",
    &setup_close_open_pcc_2_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pc4_0",
    &setup_close_open_pdc_0_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pc4_1",
    &setup_close_open_pd4_1_common,
    { { &setup_close_open_pdc_1_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pc4_2",
    &setup_close_open_pcc_2_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pbc_0",
    &setup_close_open_pee_0_common,
    { { &setup_close_open_pee_0_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pbc_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pbc_1",
    &setup_close_open_pee_1_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pbc_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pbc_2",
    &setup_close_open_pee_1_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pbc_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pb4_0",
    &setup_close_open_pea_0_common,
    { { &setup_close_open_pea_0_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pbc_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pb4_1",
    &setup_close_open_pea_2_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pbc_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pb4_2",
    &setup_close_open_pea_2_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pbc_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pac_0",
    &setup_close_open_pe6_0_common,
    { { &setup_close_open_pe6_0_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pac_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pac_1",
    &setup_close_open_pe6_1_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pac_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pac_2",
    &setup_close_open_pe6_1_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pac_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_pa4_0",
    &setup_close_open_pe6_0_common,
    { { &setup_close_open_pe6_0_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pac_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pa4_1",
    &setup_close_open_pe6_1_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pac_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_pa4_2",
    &setup_close_open_pe6_1_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_pac_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_p8_0",
    &setup_close_open_p8_0_common,
    { { &setup_close_open_pf_0_proc0 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_p8_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_p8_1",
    &setup_close_open_p8_1_common,
    { { &setup_close_open_pf_1_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_p8_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_p8_2",
    &setup_close_open_p8_1_common,
    { { &setup_close_open_pf_2_proc0 }, { &setup_close_open_pf_1_proc1 } },
    &setup_close_open_pf_1_procfinal,
    &setup_close_open_pf_1_final,
    { { &test_close_open_pf_0_0, 0, "close" },
      { &test_close_open_p8_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_p7_0",
    &setup_close_open_pf_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pf_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_p6d0_0",
    &setup_close_open_pf_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_p6a_0",
    &setup_close_open_pea_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_p65_0",
    &setup_close_open_pe6_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_p62_0",
    &setup_close_open_pe6_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_p5a_0",
    &setup_close_open_p5a_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_procfinal,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_p54_0",
    &setup_close_open_p5a_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_procfinal,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_p4a_0",
    &setup_close_open_p5a_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_procfinal,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_p44_0",
    &setup_close_open_p5a_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_procfinal,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_p3a_0",
    &setup_close_open_pf_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pbc_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_p34_0",
    &setup_close_open_pea_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pbc_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_p2a_0",
    &setup_close_open_pe6_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pac_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_open_p24_0",
    &setup_close_open_pe6_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_final,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_pac_0_1, 1, "open" } },
    &cleanup },
  { "fs-close_open_p0_0",
    &setup_close_open_p5a_0_common,
    { { &setup_close_open_pf_0_proc1 }, { &setup_close_open_pf_0_proc1 } },
    &setup_close_open_pf_0_procfinal,
    &setup_close_open_pf_0_procfinal,
    { { &test_close_open_p7_0_0, 0, "close" },
      { &test_close_open_p8_0_1, 0, "open" } },
    &cleanup },
  { "fs-close_pipe_pf0_0",
    &setup_close_pipe_pf0_0_common,
    { { &setup_close_pipe_pf0_0_proc0 }, { &setup_close_pipe_pf0_0_proc1 } },
    &setup_close_pipe_pf0_0_procfinal,
    &setup_close_pipe_pf0_0_final,
    { { &test_close_pipe_pf0_0_0, 0, "close" },
      { &test_close_pipe_pf0_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-close_pipe_pf0_1",
    &setup_close_pipe_pf0_1_common,
    { { &setup_close_pipe_pf0_1_proc0 }, { &setup_close_pipe_pf0_1_proc1 } },
    &setup_close_pipe_pf0_1_procfinal,
    &setup_close_pipe_pf0_1_final,
    { { &test_close_pipe_pf0_0_0, 0, "close" },
      { &test_close_pipe_pf0_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-close_pipe_pf0_2",
    &setup_close_pipe_pf0_0_common,
    { { &setup_close_pipe_pf0_2_proc0 }, { &setup_close_pipe_pf0_0_proc1 } },
    &setup_close_pipe_pf0_0_procfinal,
    &setup_close_pipe_pf0_0_final,
    { { &test_close_pipe_pf0_0_0, 0, "close" },
      { &test_close_pipe_pf0_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-close_pipe_pb0_0",
    &setup_close_pipe_pb0_0_common,
    { { &setup_close_pipe_pb0_0_proc0 }, { &setup_close_pipe_pf0_1_proc1 } },
    &setup_close_pipe_pf0_1_procfinal,
    &setup_close_pipe_pf0_1_final,
    { { &test_close_pipe_pf0_0_0, 0, "close" },
      { &test_close_pipe_pf0_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-close_pipe_pb0_1",
    &setup_close_pipe_pb0_1_common,
    { { &setup_close_pipe_pf0_0_proc0 }, { &setup_close_pipe_pf0_0_proc1 } },
    &setup_close_pipe_pf0_0_procfinal,
    &setup_close_pipe_pf0_0_final,
    { { &test_close_pipe_pf0_0_0, 0, "close" },
      { &test_close_pipe_pf0_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-close_pipe_pb0_2",
    &setup_close_pipe_pb0_1_common,
    { { &setup_close_pipe_pf0_2_proc0 }, { &setup_close_pipe_pf0_0_proc1 } },
    &setup_close_pipe_pf0_0_procfinal,
    &setup_close_pipe_pf0_0_final,
    { { &test_close_pipe_pf0_0_0, 0, "close" },
      { &test_close_pipe_pf0_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-close_pipe_p58_0",
    &setup_close_pipe_p58_0_common,
    { { &setup_close_pipe_pf0_1_proc1 }, { &setup_close_pipe_pf0_1_proc1 } },
    &setup_close_pipe_pf0_1_procfinal,
    &setup_close_pipe_pf0_1_procfinal,
    { { &test_close_pipe_p58_0_0, 0, "close" },
      { &test_close_pipe_pf0_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-close_pipe_p30_0",
    &setup_close_pipe_p58_0_common,
    { { &setup_close_pipe_pf0_1_proc1 }, { &setup_close_pipe_pf0_1_proc1 } },
    &setup_close_pipe_pf0_1_procfinal,
    &setup_close_pipe_pf0_1_procfinal,
    { { &test_close_pipe_p58_0_0, 0, "close" },
      { &test_close_pipe_pf0_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-close_pread_pf_0",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pf_0_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pf_1",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pf_1_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pf_2",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pf_2_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pf_3",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pf_3_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pf_4",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pf_4_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pf_5",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pf_5_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe8_0",
    &setup_close_pread_pe8_0_common,
    { { &setup_close_pread_pe8_0_proc0 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe8_1",
    &setup_close_pread_pe8_1_common,
    { { &setup_close_pread_pe8_1_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe8_2",
    &setup_close_pread_pe8_0_common,
    { { &setup_close_pread_pe8_2_proc0 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe8_3",
    &setup_close_pread_pe8_1_common,
    { { &setup_close_pread_pe8_3_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe8_4",
    &setup_close_pread_pe8_1_common,
    { { &setup_close_pread_pe8_4_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe8_5",
    &setup_close_pread_pe8_1_common,
    { { &setup_close_pread_pe8_5_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe0_0",
    &setup_close_pread_pe0_0_common,
    { { &setup_close_pread_pe0_0_proc0 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe0_1",
    &setup_close_pread_pe0_1_common,
    { { &setup_close_pread_pe0_1_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe0_2",
    &setup_close_pread_pe0_2_common,
    { { &setup_close_pread_pe8_4_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe0_3",
    &setup_close_pread_pe0_3_common,
    { { &setup_close_pread_pe0_3_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe0_4",
    &setup_close_pread_pe0_2_common,
    { { &setup_close_pread_pe8_5_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pe0_5",
    &setup_close_pread_pe0_0_common,
    { { &setup_close_pread_pe8_2_proc0 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pc_0",
    &setup_close_pread_pe8_0_common,
    { { &setup_close_pread_pc_0_proc0 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pc_1",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pc_1_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pc_2",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pc_2_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_pb_0",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pb_0_proc0 }, { &setup_close_pread_pc_1_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pb_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pb_1",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pb_0_proc0 }, { &setup_close_pread_pc_2_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pb_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pb_2",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pc_1_proc0 }, { &setup_close_pread_pc_1_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pb_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pb_3",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pc_2_proc0 }, { &setup_close_pread_pc_1_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pb_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pb_4",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pc_1_proc0 }, { &setup_close_pread_pc_2_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pb_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pb_5",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pc_2_proc0 }, { &setup_close_pread_pc_2_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pb_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa8_0",
    &setup_close_pread_pe8_0_common,
    { { &setup_close_pread_pa8_0_proc0 }, { &setup_close_pread_pa8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa8_1",
    &setup_close_pread_pe8_1_common,
    { { &setup_close_pread_pc_1_proc0 }, { &setup_close_pread_pa8_1_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa8_2",
    &setup_close_pread_pe8_0_common,
    { { &setup_close_pread_pc_0_proc0 }, { &setup_close_pread_pc_0_proc0 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa8_3",
    &setup_close_pread_pe8_1_common,
    { { &setup_close_pread_pc_2_proc0 }, { &setup_close_pread_pa8_1_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa8_4",
    &setup_close_pread_pe8_1_common,
    { { &setup_close_pread_pc_1_proc0 }, { &setup_close_pread_pb_0_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa8_5",
    &setup_close_pread_pe8_1_common,
    { { &setup_close_pread_pc_2_proc0 }, { &setup_close_pread_pb_0_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa0_0",
    &setup_close_pread_pe0_0_common,
    { { &setup_close_pread_pa0_0_proc0 }, { &setup_close_pread_pa0_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa0_1",
    &setup_close_pread_pe0_1_common,
    { { &setup_close_pread_pc_1_proc0 }, { &setup_close_pread_pa0_1_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa0_2",
    &setup_close_pread_pe0_2_common,
    { { &setup_close_pread_pc_1_proc0 }, { &setup_close_pread_pb_0_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa0_3",
    &setup_close_pread_pe0_3_common,
    { { &setup_close_pread_pc_2_proc0 }, { &setup_close_pread_pa0_1_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa0_4",
    &setup_close_pread_pe0_2_common,
    { { &setup_close_pread_pc_2_proc0 }, { &setup_close_pread_pb_0_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_pa0_5",
    &setup_close_pread_pe0_0_common,
    { { &setup_close_pread_pc_0_proc0 }, { &setup_close_pread_pc_0_proc0 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_pa0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_p8_0",
    &setup_close_pread_pe8_0_common,
    { { &setup_close_pread_pc_0_proc0 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_p8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_p8_1",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pc_1_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_p8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_p8_2",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pc_2_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_pf_0_0, 0, "close" },
      { &test_close_pread_p8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_p7_0",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_p7_0_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_p7_1",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_p7_1_proc0 }, { &setup_close_pread_pf_0_proc1 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_p68_0",
    &setup_close_pread_pe8_0_common,
    { { &setup_close_pread_p68_0_proc0 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_p68_1",
    &setup_close_pread_pe8_0_common,
    { { &setup_close_pread_p68_1_proc0 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_p60_0",
    &setup_close_pread_pe0_0_common,
    { { &setup_close_pread_p60_0_proc0 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_p60_1",
    &setup_close_pread_pe0_0_common,
    { { &setup_close_pread_p68_1_proc0 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_p4_0",
    &setup_close_pread_p4_0_common,
    { { &setup_close_pread_pe8_0_proc1 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_procfinal,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_p4_1",
    &setup_close_pread_p4_0_common,
    { { &setup_close_pread_pe8_0_proc1 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_procfinal,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_p8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-close_pread_p3_0",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pf_0_proc1 }, { &setup_close_pread_pc_1_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pb_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_p3_1",
    &setup_close_pread_pf_0_common,
    { { &setup_close_pread_pf_0_proc1 }, { &setup_close_pread_pc_2_proc0 } },
    &setup_close_pread_pf_0_procfinal,
    &setup_close_pread_pf_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pb_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_p28_0",
    &setup_close_pread_pe8_0_common,
    { { &setup_close_pread_pe8_0_proc1 }, { &setup_close_pread_pa8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pa8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_p28_1",
    &setup_close_pread_pe8_0_common,
    { { &setup_close_pread_pe8_0_proc1 }, { &setup_close_pread_pc_0_proc0 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pa8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_p20_0",
    &setup_close_pread_pe0_0_common,
    { { &setup_close_pread_pe8_0_proc1 }, { &setup_close_pread_pa0_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pa0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_p20_1",
    &setup_close_pread_pe0_0_common,
    { { &setup_close_pread_pe8_0_proc1 }, { &setup_close_pread_pc_0_proc0 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_final,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_pa0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pread_p0_0",
    &setup_close_pread_p4_0_common,
    { { &setup_close_pread_pe8_0_proc1 }, { &setup_close_pread_pe8_0_proc1 } },
    &setup_close_pread_pe8_0_procfinal,
    &setup_close_pread_pe8_0_procfinal,
    { { &test_close_pread_p7_0_0, 0, "close" },
      { &test_close_pread_p8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-close_pwrite_pf_0",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pf_0_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pf_1",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pf_1_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pf_2",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pf_2_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pf_3",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pf_3_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pf_4",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pf_4_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pf_5",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pf_5_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe8_0",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_pe8_0_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe8_1",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_pe8_1_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe8_2",
    &setup_close_pwrite_pe8_2_common,
    { { &setup_close_pwrite_pe8_2_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe8_3",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_pe8_3_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe8_4",
    &setup_close_pwrite_pe8_2_common,
    { { &setup_close_pwrite_pe8_4_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe8_5",
    &setup_close_pwrite_pe8_2_common,
    { { &setup_close_pwrite_pe8_5_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe8_6",
    &setup_close_pwrite_pe8_2_common,
    { { &setup_close_pwrite_pe8_6_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe0_0",
    &setup_close_pwrite_pe0_0_common,
    { { &setup_close_pwrite_pe0_0_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe0_1",
    &setup_close_pwrite_pe0_0_common,
    { { &setup_close_pwrite_pe8_3_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe0_2",
    &setup_close_pwrite_pe0_2_common,
    { { &setup_close_pwrite_pe0_2_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe0_3",
    &setup_close_pwrite_pe0_2_common,
    { { &setup_close_pwrite_pe0_3_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe0_4",
    &setup_close_pwrite_pe0_4_common,
    { { &setup_close_pwrite_pe8_5_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pe0_5",
    &setup_close_pwrite_pe0_4_common,
    { { &setup_close_pwrite_pe8_6_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pc_0",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_pc_0_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pc_1",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pc_1_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pc_2",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pc_2_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pb_0",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pb_0_proc0 }, { &setup_close_pwrite_pc_1_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pb_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pb_1",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pb_0_proc0 }, { &setup_close_pwrite_pc_2_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pb_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pb_2",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pc_1_proc0 }, { &setup_close_pwrite_pc_1_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pb_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pb_3",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pc_2_proc0 }, { &setup_close_pwrite_pc_1_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pb_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pb_4",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pc_1_proc0 }, { &setup_close_pwrite_pc_2_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pb_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pb_5",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pc_2_proc0 }, { &setup_close_pwrite_pc_2_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pb_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa8_0",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_pa8_0_proc0 }, { &setup_close_pwrite_pa8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa8_1",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_pa8_0_proc0 }, { &setup_close_pwrite_pa8_0_proc0 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa8_2",
    &setup_close_pwrite_pe0_2_common,
    { { &setup_close_pwrite_pc_1_proc0 }, { &setup_close_pwrite_pa8_2_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa8_3",
    &setup_close_pwrite_pa8_3_common,
    { { &setup_close_pwrite_pa8_3_proc0 }, { &setup_close_pwrite_pa8_3_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa8_4",
    &setup_close_pwrite_pa8_4_common,
    { { &setup_close_pwrite_pc_2_proc0 }, { &setup_close_pwrite_pa8_4_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa8_5",
    &setup_close_pwrite_pa8_4_common,
    { { &setup_close_pwrite_pc_2_proc0 }, { &setup_close_pwrite_pb_0_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa8_6",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_pc_0_proc0 }, { &setup_close_pwrite_pc_0_proc0 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa0_0",
    &setup_close_pwrite_pe0_0_common,
    { { &setup_close_pwrite_pa0_0_proc0 }, { &setup_close_pwrite_pa0_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa0_1",
    &setup_close_pwrite_pe0_0_common,
    { { &setup_close_pwrite_pa8_0_proc0 }, { &setup_close_pwrite_pa8_0_proc0 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa0_2",
    &setup_close_pwrite_pa0_2_common,
    { { &setup_close_pwrite_pc_1_proc0 }, { &setup_close_pwrite_pb_0_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa0_3",
    &setup_close_pwrite_pa0_3_common,
    { { &setup_close_pwrite_pa0_3_proc0 }, { &setup_close_pwrite_pa0_3_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa0_4",
    &setup_close_pwrite_pe0_2_common,
    { { &setup_close_pwrite_pc_2_proc0 }, { &setup_close_pwrite_pa0_4_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa0_5",
    &setup_close_pwrite_pe0_0_common,
    { { &setup_close_pwrite_pc_0_proc0 }, { &setup_close_pwrite_pc_0_proc0 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_pa0_6",
    &setup_close_pwrite_pe0_4_common,
    { { &setup_close_pwrite_pc_2_proc0 }, { &setup_close_pwrite_pb_0_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p8_0",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_pc_0_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_p8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p8_1",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pc_1_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_p8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p8_2",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pc_2_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_pf_0_0, 0, "close" },
      { &test_close_pwrite_p8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p7_0",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_p7_0_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p7_1",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_p7_1_proc0 }, { &setup_close_pwrite_pf_0_proc1 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p68_0",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_p68_0_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p68_1",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_p68_1_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p60_0",
    &setup_close_pwrite_pe0_0_common,
    { { &setup_close_pwrite_p60_0_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p60_1",
    &setup_close_pwrite_pe0_0_common,
    { { &setup_close_pwrite_p68_1_proc0 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p4_0",
    &setup_close_pwrite_p4_0_common,
    { { &setup_close_pwrite_pe8_0_proc1 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_procfinal,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p4_1",
    &setup_close_pwrite_p4_0_common,
    { { &setup_close_pwrite_pe8_0_proc1 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_procfinal,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_p8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p3_0",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pf_0_proc1 }, { &setup_close_pwrite_pc_1_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pb_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p3_1",
    &setup_close_pwrite_pf_0_common,
    { { &setup_close_pwrite_pf_0_proc1 }, { &setup_close_pwrite_pc_2_proc0 } },
    &setup_close_pwrite_pf_0_procfinal,
    &setup_close_pwrite_pf_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pb_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p28_0",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_pe8_0_proc1 }, { &setup_close_pwrite_pa8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p28_1",
    &setup_close_pwrite_pe8_0_common,
    { { &setup_close_pwrite_pe8_0_proc1 }, { &setup_close_pwrite_pc_0_proc0 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p20_0",
    &setup_close_pwrite_pe0_0_common,
    { { &setup_close_pwrite_pe8_0_proc1 }, { &setup_close_pwrite_pa0_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p20_1",
    &setup_close_pwrite_pe0_0_common,
    { { &setup_close_pwrite_pe8_0_proc1 }, { &setup_close_pwrite_pc_0_proc0 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_final,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_pa8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_pwrite_p0_0",
    &setup_close_pwrite_p4_0_common,
    { { &setup_close_pwrite_pe8_0_proc1 }, { &setup_close_pwrite_pe8_0_proc1 } },
    &setup_close_pwrite_pe8_0_procfinal,
    &setup_close_pwrite_pe8_0_procfinal,
    { { &test_close_pwrite_p7_0_0, 0, "close" },
      { &test_close_pwrite_p8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-close_read_pf8_0",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pf8_0_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf8_1",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pf8_1_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf8_2",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pf8_2_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf6_0",
    &setup_close_read_pf6_0_common,
    { { &setup_close_read_pf6_0_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf6_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf6_1",
    &setup_close_read_pf6_0_common,
    { { &setup_close_read_pf6_1_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf6_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf6_2",
    &setup_close_read_pf6_0_common,
    { { &setup_close_read_pf6_2_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf6_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf4_0",
    &setup_close_read_pf4_0_common,
    { { &setup_close_read_pf4_0_proc0 }, { &setup_close_read_pf4_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf4_1",
    &setup_close_read_pf4_1_common,
    { { &setup_close_read_pf4_1_proc0 }, { &setup_close_read_pf4_1_proc1 } },
    &setup_close_read_pf4_1_procfinal,
    &setup_close_read_pf4_1_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf4_2",
    &setup_close_read_pf4_0_common,
    { { &setup_close_read_pf6_1_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf4_3",
    &setup_close_read_pf4_1_common,
    { { &setup_close_read_pf4_3_proc0 }, { &setup_close_read_pf4_1_proc1 } },
    &setup_close_read_pf4_1_procfinal,
    &setup_close_read_pf4_1_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf0_0",
    &setup_close_read_pf0_0_common,
    { { &setup_close_read_pf6_1_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf0_1",
    &setup_close_read_pf0_0_common,
    { { &setup_close_read_pf6_2_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pf0_2",
    &setup_close_read_pf0_0_common,
    { { &setup_close_read_pf6_0_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pe8_0",
    &setup_close_read_pe8_0_common,
    { { &setup_close_read_pe8_0_proc0 }, { &setup_close_read_pe8_0_proc1 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pe8_1",
    &setup_close_read_pe8_1_common,
    { { &setup_close_read_pe8_1_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pe8_2",
    &setup_close_read_pe8_1_common,
    { { &setup_close_read_pe8_2_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pe0_0",
    &setup_close_read_pe0_0_common,
    { { &setup_close_read_pe8_0_proc0 }, { &setup_close_read_pe8_0_proc1 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pe0_1",
    &setup_close_read_pe0_1_common,
    { { &setup_close_read_pe8_1_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pe0_2",
    &setup_close_read_pe0_1_common,
    { { &setup_close_read_pe8_2_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pdc_0",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pdc_0_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pdc_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pc_0",
    &setup_close_read_pe8_0_common,
    { { &setup_close_read_pc_0_proc0 }, { &setup_close_read_pe8_0_proc1 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pc_1",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pc_1_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pc_2",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pdc_0_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_pb8_0",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pb8_0_proc0 }, { &setup_close_read_pdc_0_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pdc_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb8_1",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pc_1_proc0 }, { &setup_close_read_pdc_0_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pdc_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb8_2",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pdc_0_proc0 }, { &setup_close_read_pdc_0_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pdc_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb6_0",
    &setup_close_read_pf6_0_common,
    { { &setup_close_read_pdc_0_proc0 }, { &setup_close_read_pc_1_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb6_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb6_1",
    &setup_close_read_pf6_0_common,
    { { &setup_close_read_pc_1_proc0 }, { &setup_close_read_pc_1_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb6_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb6_2",
    &setup_close_read_pf6_0_common,
    { { &setup_close_read_pb6_2_proc0 }, { &setup_close_read_pc_1_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb6_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb4_0",
    &setup_close_read_pf4_0_common,
    { { &setup_close_read_pb4_0_proc0 }, { &setup_close_read_pb4_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb4_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb4_1",
    &setup_close_read_pb4_1_common,
    { { &setup_close_read_pb4_1_proc0 }, { &setup_close_read_pb4_1_proc1 } },
    &setup_close_read_pb4_1_procfinal,
    &setup_close_read_pb4_1_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb4_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb4_2",
    &setup_close_read_pb4_2_common,
    { { &setup_close_read_pb4_2_proc0 }, { &setup_close_read_pb4_2_proc1 } },
    &setup_close_read_pf4_1_procfinal,
    &setup_close_read_pf4_1_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb4_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb4_3",
    &setup_close_read_pf4_0_common,
    { { &setup_close_read_pb4_0_proc1 }, { &setup_close_read_pb4_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb4_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb0_0",
    &setup_close_read_pf0_0_common,
    { { &setup_close_read_pb6_2_proc0 }, { &setup_close_read_pc_1_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb0_1",
    &setup_close_read_pf0_0_common,
    { { &setup_close_read_pc_1_proc0 }, { &setup_close_read_pc_1_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pb0_2",
    &setup_close_read_pf0_0_common,
    { { &setup_close_read_pdc_0_proc0 }, { &setup_close_read_pc_1_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pa8_0",
    &setup_close_read_pe8_0_common,
    { { &setup_close_read_pc_0_proc0 }, { &setup_close_read_pc_0_proc0 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb4_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pa8_1",
    &setup_close_read_pe8_1_common,
    { { &setup_close_read_pc_1_proc0 }, { &setup_close_read_pb8_0_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb4_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pa8_2",
    &setup_close_read_pe8_1_common,
    { { &setup_close_read_pdc_0_proc0 }, { &setup_close_read_pb8_0_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb4_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pa0_0",
    &setup_close_read_pe0_0_common,
    { { &setup_close_read_pc_0_proc0 }, { &setup_close_read_pc_0_proc0 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pa0_1",
    &setup_close_read_pe0_1_common,
    { { &setup_close_read_pc_1_proc0 }, { &setup_close_read_pb8_0_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_pa0_2",
    &setup_close_read_pe0_1_common,
    { { &setup_close_read_pdc_0_proc0 }, { &setup_close_read_pb8_0_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_p8_0",
    &setup_close_read_pe8_0_common,
    { { &setup_close_read_pc_0_proc0 }, { &setup_close_read_pe8_0_proc1 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pdc_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_p8_1",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pc_1_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pdc_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_p8_2",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pdc_0_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_pf8_0_0, 0, "close" },
      { &test_close_read_pdc_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_p78_0",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_p78_0_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_p76_0",
    &setup_close_read_pf6_0_common,
    { { &setup_close_read_p76_0_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pf6_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_p74_0",
    &setup_close_read_pf6_0_common,
    { { &setup_close_read_p74_0_proc0 }, { &setup_close_read_pf4_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_p70_0",
    &setup_close_read_pf0_0_common,
    { { &setup_close_read_p76_0_proc0 }, { &setup_close_read_pf8_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_p68_0",
    &setup_close_read_pe8_0_common,
    { { &setup_close_read_p68_0_proc0 }, { &setup_close_read_pe8_0_proc1 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_p60_0",
    &setup_close_read_pe0_0_common,
    { { &setup_close_read_p68_0_proc0 }, { &setup_close_read_pe8_0_proc1 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_p4_0",
    &setup_close_read_p4_0_common,
    { { &setup_close_read_pe8_0_proc1 }, { &setup_close_read_pe8_0_proc1 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_procfinal,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_p4_1",
    &setup_close_read_p4_0_common,
    { { &setup_close_read_pe8_0_proc1 }, { &setup_close_read_pe8_0_proc1 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_procfinal,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pdc_0_1, 0, "read" } },
    &cleanup },
  { "fs-close_read_p38_0",
    &setup_close_read_pf8_0_common,
    { { &setup_close_read_pf8_0_proc1 }, { &setup_close_read_pdc_0_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pdc_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_p36_0",
    &setup_close_read_pf6_0_common,
    { { &setup_close_read_pf8_0_proc1 }, { &setup_close_read_pc_1_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pb6_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_p34_0",
    &setup_close_read_pf4_0_common,
    { { &setup_close_read_pf4_0_proc1 }, { &setup_close_read_pb4_0_proc1 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pb4_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_p30_0",
    &setup_close_read_pf0_0_common,
    { { &setup_close_read_pf8_0_proc1 }, { &setup_close_read_pc_1_proc0 } },
    &setup_close_read_pf8_0_procfinal,
    &setup_close_read_pf8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_p28_0",
    &setup_close_read_pe8_0_common,
    { { &setup_close_read_pe8_0_proc1 }, { &setup_close_read_pc_0_proc0 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pb4_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_p20_0",
    &setup_close_read_pe0_0_common,
    { { &setup_close_read_pe8_0_proc1 }, { &setup_close_read_pc_0_proc0 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_final,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_read_p0_0",
    &setup_close_read_p4_0_common,
    { { &setup_close_read_pe8_0_proc1 }, { &setup_close_read_pe8_0_proc1 } },
    &setup_close_read_pe8_0_procfinal,
    &setup_close_read_pe8_0_procfinal,
    { { &test_close_read_p78_0_0, 0, "close" },
      { &test_close_read_pdc_0_1, 1, "read" } },
    &cleanup },
  { "fs-close_rename_pe_0",
    &setup_close_rename_pe_0_common,
    { { &setup_close_rename_pe_0_proc0 }, { &setup_close_rename_pe_0_proc1 } },
    &setup_close_rename_pe_0_procfinal,
    &setup_close_rename_pe_0_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_pe_1",
    &setup_close_rename_pe_1_common,
    { { &setup_close_rename_pe_1_proc0 }, { &setup_close_rename_pe_1_proc1 } },
    &setup_close_rename_pe_1_procfinal,
    &setup_close_rename_pe_1_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_pe_2",
    &setup_close_rename_pe_1_common,
    { { &setup_close_rename_pe_2_proc0 }, { &setup_close_rename_pe_1_proc1 } },
    &setup_close_rename_pe_1_procfinal,
    &setup_close_rename_pe_1_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_pd0_0",
    &setup_close_rename_pd0_0_common,
    { { &setup_close_rename_pd0_0_proc0 }, { &setup_close_rename_pe_0_proc1 } },
    &setup_close_rename_pe_0_procfinal,
    &setup_close_rename_pe_0_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_pd0_1",
    &setup_close_rename_pd0_1_common,
    { { &setup_close_rename_pe_1_proc0 }, { &setup_close_rename_pe_1_proc1 } },
    &setup_close_rename_pe_1_procfinal,
    &setup_close_rename_pe_1_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_pd0_2",
    &setup_close_rename_pd0_1_common,
    { { &setup_close_rename_pe_2_proc0 }, { &setup_close_rename_pe_1_proc1 } },
    &setup_close_rename_pe_1_procfinal,
    &setup_close_rename_pe_1_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_pc_0",
    &setup_close_rename_pe_0_common,
    { { &setup_close_rename_pe_0_proc0 }, { &setup_close_rename_pe_0_proc1 } },
    &setup_close_rename_pe_0_procfinal,
    &setup_close_rename_pe_0_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_pc_1",
    &setup_close_rename_pe_1_common,
    { { &setup_close_rename_pe_1_proc0 }, { &setup_close_rename_pe_1_proc1 } },
    &setup_close_rename_pe_1_procfinal,
    &setup_close_rename_pe_1_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_pc_2",
    &setup_close_rename_pe_1_common,
    { { &setup_close_rename_pe_2_proc0 }, { &setup_close_rename_pe_1_proc1 } },
    &setup_close_rename_pe_1_procfinal,
    &setup_close_rename_pe_1_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_p8_0",
    &setup_close_rename_p8_0_common,
    { { &setup_close_rename_pe_0_proc0 }, { &setup_close_rename_pe_0_proc1 } },
    &setup_close_rename_pe_0_procfinal,
    &setup_close_rename_pe_0_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_p8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_p8_1",
    &setup_close_rename_p8_1_common,
    { { &setup_close_rename_pe_1_proc0 }, { &setup_close_rename_pe_1_proc1 } },
    &setup_close_rename_pe_1_procfinal,
    &setup_close_rename_pe_1_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_p8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_p8_2",
    &setup_close_rename_p8_1_common,
    { { &setup_close_rename_pe_2_proc0 }, { &setup_close_rename_pe_1_proc1 } },
    &setup_close_rename_pe_1_procfinal,
    &setup_close_rename_pe_1_final,
    { { &test_close_rename_pe_0_0, 0, "close" },
      { &test_close_rename_p8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_p6_0",
    &setup_close_rename_pe_0_common,
    { { &setup_close_rename_pe_0_proc1 }, { &setup_close_rename_pe_0_proc1 } },
    &setup_close_rename_pe_0_procfinal,
    &setup_close_rename_pe_0_final,
    { { &test_close_rename_p6_0_0, 0, "close" },
      { &test_close_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_p50_0",
    &setup_close_rename_pd0_0_common,
    { { &setup_close_rename_pe_0_proc1 }, { &setup_close_rename_pe_0_proc1 } },
    &setup_close_rename_pe_0_procfinal,
    &setup_close_rename_pe_0_final,
    { { &test_close_rename_p6_0_0, 0, "close" },
      { &test_close_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_p4_0",
    &setup_close_rename_pe_0_common,
    { { &setup_close_rename_pe_0_proc1 }, { &setup_close_rename_pe_0_proc1 } },
    &setup_close_rename_pe_0_procfinal,
    &setup_close_rename_pe_0_final,
    { { &test_close_rename_p6_0_0, 0, "close" },
      { &test_close_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_rename_p0_0",
    &setup_close_rename_p0_0_common,
    { { &setup_close_rename_pe_0_proc1 }, { &setup_close_rename_pe_0_proc1 } },
    &setup_close_rename_pe_0_procfinal,
    &setup_close_rename_pe_0_procfinal,
    { { &test_close_rename_p6_0_0, 0, "close" },
      { &test_close_rename_p8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-close_stat_pc_0",
    &setup_close_stat_pc_0_common,
    { { &setup_close_stat_pc_0_proc0 }, { &setup_close_stat_pc_0_proc1 } },
    &setup_close_stat_pc_0_procfinal,
    &setup_close_stat_pc_0_final,
    { { &test_close_stat_pc_0_0, 0, "close" },
      { &test_close_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-close_stat_pc_1",
    &setup_close_stat_pc_1_common,
    { { &setup_close_stat_pc_1_proc0 }, { &setup_close_stat_pc_1_proc1 } },
    &setup_close_stat_pc_1_procfinal,
    &setup_close_stat_pc_1_final,
    { { &test_close_stat_pc_0_0, 0, "close" },
      { &test_close_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-close_stat_pc_2",
    &setup_close_stat_pc_1_common,
    { { &setup_close_stat_pc_2_proc0 }, { &setup_close_stat_pc_1_proc1 } },
    &setup_close_stat_pc_1_procfinal,
    &setup_close_stat_pc_1_final,
    { { &test_close_stat_pc_0_0, 0, "close" },
      { &test_close_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-close_stat_p8_0",
    &setup_close_stat_p8_0_common,
    { { &setup_close_stat_pc_0_proc0 }, { &setup_close_stat_pc_0_proc1 } },
    &setup_close_stat_pc_0_procfinal,
    &setup_close_stat_pc_0_final,
    { { &test_close_stat_pc_0_0, 0, "close" },
      { &test_close_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-close_stat_p8_1",
    &setup_close_stat_p8_1_common,
    { { &setup_close_stat_pc_1_proc0 }, { &setup_close_stat_pc_1_proc1 } },
    &setup_close_stat_pc_1_procfinal,
    &setup_close_stat_pc_1_final,
    { { &test_close_stat_pc_0_0, 0, "close" },
      { &test_close_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-close_stat_p8_2",
    &setup_close_stat_p8_1_common,
    { { &setup_close_stat_pc_2_proc0 }, { &setup_close_stat_pc_1_proc1 } },
    &setup_close_stat_pc_1_procfinal,
    &setup_close_stat_pc_1_final,
    { { &test_close_stat_pc_0_0, 0, "close" },
      { &test_close_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-close_stat_p4_0",
    &setup_close_stat_pc_0_common,
    { { &setup_close_stat_pc_0_proc1 }, { &setup_close_stat_pc_0_proc1 } },
    &setup_close_stat_pc_0_procfinal,
    &setup_close_stat_pc_0_final,
    { { &test_close_stat_p4_0_0, 0, "close" },
      { &test_close_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-close_stat_p0_0",
    &setup_close_stat_p0_0_common,
    { { &setup_close_stat_pc_0_proc1 }, { &setup_close_stat_pc_0_proc1 } },
    &setup_close_stat_pc_0_procfinal,
    &setup_close_stat_pc_0_procfinal,
    { { &test_close_stat_p4_0_0, 0, "close" },
      { &test_close_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-close_unlink_pc_0",
    &setup_close_unlink_pc_0_common,
    { { &setup_close_unlink_pc_0_proc0 }, { &setup_close_unlink_pc_0_proc1 } },
    &setup_close_unlink_pc_0_procfinal,
    &setup_close_unlink_pc_0_final,
    { { &test_close_unlink_pc_0_0, 0, "close" },
      { &test_close_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-close_unlink_pc_1",
    &setup_close_unlink_pc_1_common,
    { { &setup_close_unlink_pc_1_proc0 }, { &setup_close_unlink_pc_1_proc1 } },
    &setup_close_unlink_pc_1_procfinal,
    &setup_close_unlink_pc_1_final,
    { { &test_close_unlink_pc_0_0, 0, "close" },
      { &test_close_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-close_unlink_pc_2",
    &setup_close_unlink_pc_1_common,
    { { &setup_close_unlink_pc_2_proc0 }, { &setup_close_unlink_pc_1_proc1 } },
    &setup_close_unlink_pc_1_procfinal,
    &setup_close_unlink_pc_1_final,
    { { &test_close_unlink_pc_0_0, 0, "close" },
      { &test_close_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-close_unlink_p8_0",
    &setup_close_unlink_p8_0_common,
    { { &setup_close_unlink_p8_0_proc0 }, { &setup_close_unlink_pc_0_proc1 } },
    &setup_close_unlink_pc_0_procfinal,
    &setup_close_unlink_pc_0_final,
    { { &test_close_unlink_pc_0_0, 0, "close" },
      { &test_close_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-close_unlink_p8_1",
    &setup_close_unlink_p8_1_common,
    { { &setup_close_unlink_pc_1_proc0 }, { &setup_close_unlink_pc_1_proc1 } },
    &setup_close_unlink_pc_1_procfinal,
    &setup_close_unlink_pc_1_final,
    { { &test_close_unlink_pc_0_0, 0, "close" },
      { &test_close_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-close_unlink_p8_2",
    &setup_close_unlink_p8_1_common,
    { { &setup_close_unlink_pc_2_proc0 }, { &setup_close_unlink_pc_1_proc1 } },
    &setup_close_unlink_pc_1_procfinal,
    &setup_close_unlink_pc_1_final,
    { { &test_close_unlink_pc_0_0, 0, "close" },
      { &test_close_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-close_unlink_p4_0",
    &setup_close_unlink_pc_0_common,
    { { &setup_close_unlink_pc_0_proc1 }, { &setup_close_unlink_pc_0_proc1 } },
    &setup_close_unlink_pc_0_procfinal,
    &setup_close_unlink_pc_0_final,
    { { &test_close_unlink_p4_0_0, 0, "close" },
      { &test_close_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-close_unlink_p0_0",
    &setup_close_unlink_p0_0_common,
    { { &setup_close_unlink_pc_0_proc1 }, { &setup_close_unlink_pc_0_proc1 } },
    &setup_close_unlink_pc_0_procfinal,
    &setup_close_unlink_pc_0_procfinal,
    { { &test_close_unlink_p4_0_0, 0, "close" },
      { &test_close_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-close_write_pfe_0",
    &setup_close_write_pfe_0_common,
    { { &setup_close_write_pfe_0_proc0 }, { &setup_close_write_pfe_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pfe_1",
    &setup_close_write_pfe_1_common,
    { { &setup_close_write_pfe_1_proc0 }, { &setup_close_write_pfe_1_proc1 } },
    &setup_close_write_pfe_1_procfinal,
    &setup_close_write_pfe_1_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pfe_2",
    &setup_close_write_pfe_1_common,
    { { &setup_close_write_pfe_2_proc0 }, { &setup_close_write_pfe_1_proc1 } },
    &setup_close_write_pfe_1_procfinal,
    &setup_close_write_pfe_1_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pfe_3",
    &setup_close_write_pfe_0_common,
    { { &setup_close_write_pfe_3_proc0 }, { &setup_close_write_pfe_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pf8_0",
    &setup_close_write_pf8_0_common,
    { { &setup_close_write_pf8_0_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pf8_1",
    &setup_close_write_pf8_0_common,
    { { &setup_close_write_pf8_1_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pf8_2",
    &setup_close_write_pf8_0_common,
    { { &setup_close_write_pf8_2_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pf0_0",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pf0_0_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pf0_1",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pf0_1_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pf0_2",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pf0_2_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pe8_0",
    &setup_close_write_pe8_0_common,
    { { &setup_close_write_pe8_0_proc0 }, { &setup_close_write_pe8_0_proc1 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pe8_1",
    &setup_close_write_pe8_1_common,
    { { &setup_close_write_pe8_1_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pe8_2",
    &setup_close_write_pe8_1_common,
    { { &setup_close_write_pe8_2_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pe0_0",
    &setup_close_write_pe0_0_common,
    { { &setup_close_write_pe8_0_proc0 }, { &setup_close_write_pe8_0_proc1 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pe0_1",
    &setup_close_write_pe0_1_common,
    { { &setup_close_write_pe8_1_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pe0_2",
    &setup_close_write_pe0_1_common,
    { { &setup_close_write_pe8_2_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pd8_0",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pd8_0_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pd8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pc_0",
    &setup_close_write_pe8_0_common,
    { { &setup_close_write_pc_0_proc0 }, { &setup_close_write_pe8_0_proc1 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pc_1",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pd8_0_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pc_2",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pc_2_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_pbe_0",
    &setup_close_write_pbe_0_common,
    { { &setup_close_write_pbe_0_proc0 }, { &setup_close_write_pbe_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pbe_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pbe_1",
    &setup_close_write_pbe_1_common,
    { { &setup_close_write_pbe_1_proc0 }, { &setup_close_write_pbe_1_proc1 } },
    &setup_close_write_pfe_1_procfinal,
    &setup_close_write_pfe_1_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pbe_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pbe_2",
    &setup_close_write_pbe_1_common,
    { { &setup_close_write_pbe_2_proc0 }, { &setup_close_write_pbe_1_proc1 } },
    &setup_close_write_pfe_1_procfinal,
    &setup_close_write_pfe_1_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pbe_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pbe_3",
    &setup_close_write_pbe_0_common,
    { { &setup_close_write_pbe_0_proc1 }, { &setup_close_write_pbe_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pbe_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pb8_0",
    &setup_close_write_pf8_0_common,
    { { &setup_close_write_pd8_0_proc0 }, { &setup_close_write_pc_2_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pb8_1",
    &setup_close_write_pf8_0_common,
    { { &setup_close_write_pb8_1_proc0 }, { &setup_close_write_pc_2_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pb8_2",
    &setup_close_write_pf8_0_common,
    { { &setup_close_write_pc_2_proc0 }, { &setup_close_write_pc_2_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pb0_0",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pb0_0_proc0 }, { &setup_close_write_pd8_0_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pd8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pb0_1",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pd8_0_proc0 }, { &setup_close_write_pd8_0_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pd8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pb0_2",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pc_2_proc0 }, { &setup_close_write_pd8_0_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pd8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pa8_0",
    &setup_close_write_pe8_0_common,
    { { &setup_close_write_pc_0_proc0 }, { &setup_close_write_pc_0_proc0 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pa8_1",
    &setup_close_write_pe8_1_common,
    { { &setup_close_write_pd8_0_proc0 }, { &setup_close_write_pb0_0_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pa8_2",
    &setup_close_write_pe8_1_common,
    { { &setup_close_write_pc_2_proc0 }, { &setup_close_write_pb0_0_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pa0_0",
    &setup_close_write_pe0_0_common,
    { { &setup_close_write_pc_0_proc0 }, { &setup_close_write_pc_0_proc0 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pa0_1",
    &setup_close_write_pe0_1_common,
    { { &setup_close_write_pd8_0_proc0 }, { &setup_close_write_pb0_0_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_pa0_2",
    &setup_close_write_pe0_1_common,
    { { &setup_close_write_pc_2_proc0 }, { &setup_close_write_pb0_0_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_p8_0",
    &setup_close_write_pe8_0_common,
    { { &setup_close_write_pc_0_proc0 }, { &setup_close_write_pe8_0_proc1 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pd8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_p8_1",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pd8_0_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pd8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_p8_2",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pc_2_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_pfe_0_0, 0, "close" },
      { &test_close_write_pd8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_p7c_0",
    &setup_close_write_pfe_0_common,
    { { &setup_close_write_p7c_0_proc0 }, { &setup_close_write_pfe_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_p78_0",
    &setup_close_write_pf8_0_common,
    { { &setup_close_write_p78_0_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_p70_0",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_p70_0_proc0 }, { &setup_close_write_pf8_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_p68_0",
    &setup_close_write_pe8_0_common,
    { { &setup_close_write_p68_0_proc0 }, { &setup_close_write_pe8_0_proc1 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_final,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_p60_0",
    &setup_close_write_pe0_0_common,
    { { &setup_close_write_p68_0_proc0 }, { &setup_close_write_pe8_0_proc1 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_final,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_p4_0",
    &setup_close_write_p4_0_common,
    { { &setup_close_write_pe8_0_proc1 }, { &setup_close_write_pe8_0_proc1 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_procfinal,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_p4_1",
    &setup_close_write_p4_0_common,
    { { &setup_close_write_pe8_0_proc1 }, { &setup_close_write_pe8_0_proc1 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_procfinal,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pd8_0_1, 0, "write" } },
    &cleanup },
  { "fs-close_write_p3c_0",
    &setup_close_write_pbe_0_common,
    { { &setup_close_write_pfe_0_proc1 }, { &setup_close_write_pbe_0_proc1 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pbe_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_p38_0",
    &setup_close_write_pf8_0_common,
    { { &setup_close_write_pf8_0_proc1 }, { &setup_close_write_pc_2_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_p30_0",
    &setup_close_write_pf0_0_common,
    { { &setup_close_write_pf8_0_proc1 }, { &setup_close_write_pd8_0_proc0 } },
    &setup_close_write_pfe_0_procfinal,
    &setup_close_write_pfe_0_final,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pd8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_p28_0",
    &setup_close_write_pe8_0_common,
    { { &setup_close_write_pe8_0_proc1 }, { &setup_close_write_pc_0_proc0 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_final,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_p20_0",
    &setup_close_write_pe0_0_common,
    { { &setup_close_write_pe8_0_proc1 }, { &setup_close_write_pc_0_proc0 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_final,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pb8_0_1, 1, "write" } },
    &cleanup },
  { "fs-close_write_p0_0",
    &setup_close_write_p4_0_common,
    { { &setup_close_write_pe8_0_proc1 }, { &setup_close_write_pe8_0_proc1 } },
    &setup_close_write_pe8_0_procfinal,
    &setup_close_write_pe8_0_procfinal,
    { { &test_close_write_p7c_0_0, 0, "close" },
      { &test_close_write_pd8_0_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_fstat_pf8_0",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_0_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pf8_1",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_1_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pf8_2",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_2_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pf8_3",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_3_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_0, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pf8_4",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_4_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pf8_5",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_5_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_0, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pf0_0",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf0_0_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf0_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pf0_1",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf0_1_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf0_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pe_0",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_3_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pe_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pe_1",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_5_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pe_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pd8_0",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_3_proc0 }, { &setup_fstat_fstat_pf8_3_proc0 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_0, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pd8_1",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_5_proc0 }, { &setup_fstat_fstat_pf8_3_proc0 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_0, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pd8_2",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_3_proc0 }, { &setup_fstat_fstat_pf8_5_proc0 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_0, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pd8_3",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_5_proc0 }, { &setup_fstat_fstat_pf8_5_proc0 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_0, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pd0_0",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_3_proc0 }, { &setup_fstat_fstat_pd0_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pd0_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pd0_1",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_5_proc0 }, { &setup_fstat_fstat_pd0_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pd0_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pc_0",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_3_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pc_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pc_1",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_5_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pf8_0_0, 0, "fstat" },
      { &test_fstat_fstat_pc_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pb8_0",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pb8_0_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pd0_0_1, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pb8_1",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pb8_1_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pd0_0_1, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pb0_0",
    &setup_fstat_fstat_pb0_0_common,
    { { &setup_fstat_fstat_pb0_0_proc0 }, { &setup_fstat_fstat_pb0_0_proc1 } },
    &setup_fstat_fstat_pb0_0_procfinal,
    &setup_fstat_fstat_pb0_0_final,
    { { &test_fstat_fstat_pd0_0_1, 0, "fstat" },
      { &test_fstat_fstat_pf0_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pb0_1",
    &setup_fstat_fstat_pb0_0_common,
    { { &setup_fstat_fstat_pb0_1_proc0 }, { &setup_fstat_fstat_pb0_0_proc1 } },
    &setup_fstat_fstat_pb0_0_procfinal,
    &setup_fstat_fstat_pb0_0_final,
    { { &test_fstat_fstat_pd0_0_1, 0, "fstat" },
      { &test_fstat_fstat_pd0_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_pa_0",
    &setup_fstat_fstat_pb0_0_common,
    { { &setup_fstat_fstat_pb0_1_proc0 }, { &setup_fstat_fstat_pb0_0_proc1 } },
    &setup_fstat_fstat_pb0_0_procfinal,
    &setup_fstat_fstat_pb0_0_final,
    { { &test_fstat_fstat_pd0_0_1, 0, "fstat" },
      { &test_fstat_fstat_pe_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p98_0",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pd0_0_proc1 }, { &setup_fstat_fstat_pf8_3_proc0 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pd0_0_1, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_0, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p98_1",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pd0_0_proc1 }, { &setup_fstat_fstat_pf8_5_proc0 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pd0_0_1, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_0, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p90_0",
    &setup_fstat_fstat_pb0_0_common,
    { { &setup_fstat_fstat_pb0_1_proc0 }, { &setup_fstat_fstat_pb0_1_proc0 } },
    &setup_fstat_fstat_pb0_0_procfinal,
    &setup_fstat_fstat_pb0_0_final,
    { { &test_fstat_fstat_pd0_0_1, 0, "fstat" },
      { &test_fstat_fstat_pd0_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p8_0",
    &setup_fstat_fstat_pb0_0_common,
    { { &setup_fstat_fstat_pb0_1_proc0 }, { &setup_fstat_fstat_pb0_0_proc1 } },
    &setup_fstat_fstat_pb0_0_procfinal,
    &setup_fstat_fstat_pb0_0_final,
    { { &test_fstat_fstat_pd0_0_1, 0, "fstat" },
      { &test_fstat_fstat_pc_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p7_0",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_p7_0_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pc_0_1, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p7_1",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_p7_1_proc0 }, { &setup_fstat_fstat_pf8_0_proc1 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pc_0_1, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p6_0",
    &setup_fstat_fstat_pb0_0_common,
    { { &setup_fstat_fstat_p6_0_proc0 }, { &setup_fstat_fstat_pb0_0_proc1 } },
    &setup_fstat_fstat_pb0_0_procfinal,
    &setup_fstat_fstat_pb0_0_final,
    { { &test_fstat_fstat_pc_0_1, 0, "fstat" },
      { &test_fstat_fstat_pf0_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p4_0",
    &setup_fstat_fstat_p4_0_common,
    { { &setup_fstat_fstat_pb0_0_proc1 }, { &setup_fstat_fstat_pb0_0_proc1 } },
    &setup_fstat_fstat_pb0_0_procfinal,
    &setup_fstat_fstat_pb0_0_procfinal,
    { { &test_fstat_fstat_pc_0_1, 0, "fstat" },
      { &test_fstat_fstat_pe_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p4_1",
    &setup_fstat_fstat_p4_0_common,
    { { &setup_fstat_fstat_pb0_0_proc1 }, { &setup_fstat_fstat_pb0_0_proc1 } },
    &setup_fstat_fstat_pb0_0_procfinal,
    &setup_fstat_fstat_pb0_0_procfinal,
    { { &test_fstat_fstat_pc_0_1, 0, "fstat" },
      { &test_fstat_fstat_pc_0_1, 0, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p3_0",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_0_proc1 }, { &setup_fstat_fstat_pf8_3_proc0 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pc_0_1, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_0, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p3_1",
    &setup_fstat_fstat_pf8_0_common,
    { { &setup_fstat_fstat_pf8_0_proc1 }, { &setup_fstat_fstat_pf8_5_proc0 } },
    &setup_fstat_fstat_pf8_0_procfinal,
    &setup_fstat_fstat_pf8_0_final,
    { { &test_fstat_fstat_pc_0_1, 0, "fstat" },
      { &test_fstat_fstat_pf8_0_0, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p2_0",
    &setup_fstat_fstat_pb0_0_common,
    { { &setup_fstat_fstat_pb0_0_proc1 }, { &setup_fstat_fstat_pb0_1_proc0 } },
    &setup_fstat_fstat_pb0_0_procfinal,
    &setup_fstat_fstat_pb0_0_final,
    { { &test_fstat_fstat_pc_0_1, 0, "fstat" },
      { &test_fstat_fstat_pd0_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_fstat_p0_0",
    &setup_fstat_fstat_p4_0_common,
    { { &setup_fstat_fstat_pb0_0_proc1 }, { &setup_fstat_fstat_pb0_0_proc1 } },
    &setup_fstat_fstat_pb0_0_procfinal,
    &setup_fstat_fstat_pb0_0_procfinal,
    { { &test_fstat_fstat_pc_0_1, 0, "fstat" },
      { &test_fstat_fstat_pc_0_1, 1, "fstat" } },
    &cleanup },
  { "fs-fstat_link_pf_0",
    &setup_fstat_link_pf_0_common,
    { { &setup_fstat_link_pf_0_proc0 }, { &setup_fstat_link_pf_0_proc1 } },
    &setup_fstat_link_pf_0_procfinal,
    &setup_fstat_link_pf_0_final,
    { { &test_fstat_link_pf_0_0, 0, "fstat" },
      { &test_fstat_link_pf_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_pf_1",
    &setup_fstat_link_pf_0_common,
    { { &setup_fstat_link_pf_1_proc0 }, { &setup_fstat_link_pf_0_proc1 } },
    &setup_fstat_link_pf_0_procfinal,
    &setup_fstat_link_pf_0_final,
    { { &test_fstat_link_pf_0_0, 0, "fstat" },
      { &test_fstat_link_pf_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_pf_2",
    &setup_fstat_link_pf_2_common,
    { { &setup_fstat_link_pf_0_proc0 }, { &setup_fstat_link_pf_0_proc1 } },
    &setup_fstat_link_pf_0_procfinal,
    &setup_fstat_link_pf_0_final,
    { { &test_fstat_link_pf_0_0, 0, "fstat" },
      { &test_fstat_link_pf_2_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_pf_3",
    &setup_fstat_link_pf_2_common,
    { { &setup_fstat_link_pf_1_proc0 }, { &setup_fstat_link_pf_0_proc1 } },
    &setup_fstat_link_pf_0_procfinal,
    &setup_fstat_link_pf_0_final,
    { { &test_fstat_link_pf_0_0, 0, "fstat" },
      { &test_fstat_link_pf_2_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_pe0_0",
    &setup_fstat_link_pe0_0_common,
    { { &setup_fstat_link_pf_0_proc0 }, { &setup_fstat_link_pf_0_proc1 } },
    &setup_fstat_link_pf_0_procfinal,
    &setup_fstat_link_pf_0_final,
    { { &test_fstat_link_pf_0_0, 0, "fstat" },
      { &test_fstat_link_pe0_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_pe0_1",
    &setup_fstat_link_pe0_0_common,
    { { &setup_fstat_link_pf_1_proc0 }, { &setup_fstat_link_pf_0_proc1 } },
    &setup_fstat_link_pf_0_procfinal,
    &setup_fstat_link_pf_0_final,
    { { &test_fstat_link_pf_0_0, 0, "fstat" },
      { &test_fstat_link_pe0_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_pc_0",
    &setup_fstat_link_pc_0_common,
    { { &setup_fstat_link_pf_0_proc0 }, { &setup_fstat_link_pf_0_proc1 } },
    &setup_fstat_link_pf_0_procfinal,
    &setup_fstat_link_pf_0_final,
    { { &test_fstat_link_pf_0_0, 0, "fstat" },
      { &test_fstat_link_pc_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_pc_1",
    &setup_fstat_link_pc_0_common,
    { { &setup_fstat_link_pf_1_proc0 }, { &setup_fstat_link_pf_0_proc1 } },
    &setup_fstat_link_pf_0_procfinal,
    &setup_fstat_link_pf_0_final,
    { { &test_fstat_link_pf_0_0, 0, "fstat" },
      { &test_fstat_link_pc_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_pb_0",
    &setup_fstat_link_pb_0_common,
    { { &setup_fstat_link_pb_0_proc0 }, { &setup_fstat_link_pb_0_proc1 } },
    &setup_fstat_link_pb_0_procfinal,
    &setup_fstat_link_pb_0_final,
    { { &test_fstat_link_pb_0_0, 0, "fstat" },
      { &test_fstat_link_pf_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_pb_1",
    &setup_fstat_link_pb_1_common,
    { { &setup_fstat_link_pb_0_proc0 }, { &setup_fstat_link_pb_0_proc1 } },
    &setup_fstat_link_pb_0_procfinal,
    &setup_fstat_link_pb_0_final,
    { { &test_fstat_link_pb_0_0, 0, "fstat" },
      { &test_fstat_link_pf_2_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_pa8_0",
    &setup_fstat_link_pa8_0_common,
    { { &setup_fstat_link_pa8_0_proc0 }, { &setup_fstat_link_pb_0_proc1 } },
    &setup_fstat_link_pb_0_procfinal,
    &setup_fstat_link_pa8_0_final,
    { { &test_fstat_link_pa8_0_0, 0, "fstat" },
      { &test_fstat_link_pe0_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_p8_0",
    &setup_fstat_link_p8_0_common,
    { { &setup_fstat_link_pb_0_proc0 }, { &setup_fstat_link_pb_0_proc1 } },
    &setup_fstat_link_pb_0_procfinal,
    &setup_fstat_link_pb_0_final,
    { { &test_fstat_link_pb_0_0, 0, "fstat" },
      { &test_fstat_link_pc_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_p6_0",
    &setup_fstat_link_pb_0_common,
    { { &setup_fstat_link_pb_0_proc1 }, { &setup_fstat_link_pb_0_proc1 } },
    &setup_fstat_link_pb_0_procfinal,
    &setup_fstat_link_pb_0_final,
    { { &test_fstat_link_p6_0_0, 0, "fstat" },
      { &test_fstat_link_pf_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_p6_1",
    &setup_fstat_link_pb_1_common,
    { { &setup_fstat_link_pb_0_proc1 }, { &setup_fstat_link_pb_0_proc1 } },
    &setup_fstat_link_pb_0_procfinal,
    &setup_fstat_link_pb_0_final,
    { { &test_fstat_link_p6_0_0, 0, "fstat" },
      { &test_fstat_link_pf_2_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_p4_0",
    &setup_fstat_link_pb_1_common,
    { { &setup_fstat_link_pb_0_proc1 }, { &setup_fstat_link_pb_0_proc1 } },
    &setup_fstat_link_pb_0_procfinal,
    &setup_fstat_link_pb_0_final,
    { { &test_fstat_link_p6_0_0, 0, "fstat" },
      { &test_fstat_link_pe0_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_link_p0_0",
    &setup_fstat_link_p0_0_common,
    { { &setup_fstat_link_pb_0_proc1 }, { &setup_fstat_link_pb_0_proc1 } },
    &setup_fstat_link_pb_0_procfinal,
    &setup_fstat_link_pb_0_procfinal,
    { { &test_fstat_link_p6_0_0, 0, "fstat" },
      { &test_fstat_link_pc_0_1, 0, "link" } },
    &cleanup },
  { "fs-fstat_lseek_pf8_0",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_0_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf8_1",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_1_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf8_2",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_2_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf8_3",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf8_4",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_4_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf8_5",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf6_0",
    &setup_fstat_lseek_pf6_0_common,
    { { &setup_fstat_lseek_pf6_0_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf6_1",
    &setup_fstat_lseek_pf6_0_common,
    { { &setup_fstat_lseek_pf6_1_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf4_0",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf4_0_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf4_1",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf4_1_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf4_2",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf4_2_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf4_3",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf4_3_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf3_0",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf4_2_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf3_1",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf4_3_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf2_0",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf4_2_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf2_1",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf4_3_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf18_0",
    &setup_fstat_lseek_pf18_0_common,
    { { &setup_fstat_lseek_pf4_0_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf18_1",
    &setup_fstat_lseek_pf18_0_common,
    { { &setup_fstat_lseek_pf4_1_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf10_0",
    &setup_fstat_lseek_pf18_0_common,
    { { &setup_fstat_lseek_pf4_0_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf10_1",
    &setup_fstat_lseek_pf18_0_common,
    { { &setup_fstat_lseek_pf4_1_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf10_2",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf4_2_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf10_3",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf4_3_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf0_0",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf4_2_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pf0_1",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf4_3_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pe_0",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pe_1",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd8_0",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pf8_3_proc0 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd8_1",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pf8_5_proc0 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd8_2",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pf8_3_proc0 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd8_3",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pf8_5_proc0 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd6_0",
    &setup_fstat_lseek_pf6_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pd6_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd6_1",
    &setup_fstat_lseek_pf6_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pd6_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd4_0",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pd4_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd4_1",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pd4_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd4_2",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pd4_2_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd4_3",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pd4_2_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd3_0",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pd4_2_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd3_1",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pd4_2_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd2_0",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pd4_2_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd2_1",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pd4_2_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd18_0",
    &setup_fstat_lseek_pf18_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pd4_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd18_1",
    &setup_fstat_lseek_pf18_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pd4_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd10_0",
    &setup_fstat_lseek_pf18_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pd4_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd10_1",
    &setup_fstat_lseek_pf18_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pd4_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd10_2",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pd4_2_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd10_3",
    &setup_fstat_lseek_pf4_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pd4_2_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd0_0",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pd4_2_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pd0_1",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pd4_2_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pc_0",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_3_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pc_1",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_5_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pf8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb8_0",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pb8_0_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb8_1",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pb8_1_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb6_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb6_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb6_1",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb6_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb4_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb4_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb4_1",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb3_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb3_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb3_1",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb2_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb3_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb2_1",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb18_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb4_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb18_1",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb18_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb10_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb4_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb10_1",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb0_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb3_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pb0_1",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_pa_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p98_0",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pd4_2_proc1 }, { &setup_fstat_lseek_pf8_3_proc0 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p98_1",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pd4_2_proc1 }, { &setup_fstat_lseek_pf8_5_proc0 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p96_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb6_1_proc0 }, { &setup_fstat_lseek_p96_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p96_1",
    &setup_fstat_lseek_p96_1_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p96_1_0, 0, "fstat" },
      { &test_fstat_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p94_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_p94_0_proc0 }, { &setup_fstat_lseek_p94_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p94_1",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p93_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p92_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p918_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_p94_0_proc1 }, { &setup_fstat_lseek_p94_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p910_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_p94_0_proc1 }, { &setup_fstat_lseek_p94_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p910_1",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb6_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p90_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p8_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb4_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_pb8_0_0, 0, "fstat" },
      { &test_fstat_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p7_0",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_p7_0_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p7_1",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_p7_1_proc0 }, { &setup_fstat_lseek_pf8_0_proc1 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p6c_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_p6c_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p68_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_p68_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p68_1",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_p68_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p66_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_p68_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p64_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_p68_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p63_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_p68_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p62_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_p68_0_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p62_1",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_p68_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p60_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_p68_1_proc0 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p4_0",
    &setup_fstat_lseek_p4_0_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_procfinal,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p4_1",
    &setup_fstat_lseek_p4_0_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_procfinal,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pc_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p3_0",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_0_proc1 }, { &setup_fstat_lseek_pf8_3_proc0 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p3_1",
    &setup_fstat_lseek_pf8_0_common,
    { { &setup_fstat_lseek_pf8_0_proc1 }, { &setup_fstat_lseek_pf8_5_proc0 } },
    &setup_fstat_lseek_pf8_0_procfinal,
    &setup_fstat_lseek_pf8_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p2c_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_p96_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p28_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_p94_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p28_1",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p26_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p24_0",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p23_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_p94_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p22_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_p94_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p22_1",
    &setup_fstat_lseek_pb6_0_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p20_0",
    &setup_fstat_lseek_pb4_1_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_pb4_1_proc0 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_final,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pf8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_lseek_p0_0",
    &setup_fstat_lseek_p4_0_common,
    { { &setup_fstat_lseek_pb6_0_proc1 }, { &setup_fstat_lseek_pb6_0_proc1 } },
    &setup_fstat_lseek_pb6_0_procfinal,
    &setup_fstat_lseek_pb6_0_procfinal,
    { { &test_fstat_lseek_p7_0_0, 0, "fstat" },
      { &test_fstat_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-fstat_memread_pf8_0",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pf8_0_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf8_1",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pf8_1_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf8_2",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pf8_2_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf8_3",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pf8_3_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf4_0",
    &setup_fstat_memread_pf4_0_common,
    { { &setup_fstat_memread_pf4_0_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf4_1",
    &setup_fstat_memread_pf4_0_common,
    { { &setup_fstat_memread_pf4_1_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf4_2",
    &setup_fstat_memread_pf4_0_common,
    { { &setup_fstat_memread_pf4_2_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf4_3",
    &setup_fstat_memread_pf4_0_common,
    { { &setup_fstat_memread_pf4_3_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf0_0",
    &setup_fstat_memread_pf0_0_common,
    { { &setup_fstat_memread_pf4_0_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf0_1",
    &setup_fstat_memread_pf0_0_common,
    { { &setup_fstat_memread_pf4_1_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf0_2",
    &setup_fstat_memread_pf0_0_common,
    { { &setup_fstat_memread_pf4_2_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pf0_3",
    &setup_fstat_memread_pf0_0_common,
    { { &setup_fstat_memread_pf4_3_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pe_0",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pe_0_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pe_1",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pe_1_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd8_0",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pe_0_proc0 }, { &setup_fstat_memread_pd8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd8_1",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pe_1_proc0 }, { &setup_fstat_memread_pd8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd8_2",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pe_0_proc0 }, { &setup_fstat_memread_pd8_2_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd8_3",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pe_1_proc0 }, { &setup_fstat_memread_pd8_2_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd4_0",
    &setup_fstat_memread_pd4_0_common,
    { { &setup_fstat_memread_pe_0_proc0 }, { &setup_fstat_memread_pd4_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd4_1",
    &setup_fstat_memread_pd4_1_common,
    { { &setup_fstat_memread_pe_0_proc0 }, { &setup_fstat_memread_pd4_1_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd4_2",
    &setup_fstat_memread_pd4_1_common,
    { { &setup_fstat_memread_pe_1_proc0 }, { &setup_fstat_memread_pd4_2_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd4_3",
    &setup_fstat_memread_pd4_0_common,
    { { &setup_fstat_memread_pe_1_proc0 }, { &setup_fstat_memread_pd4_3_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd0_0",
    &setup_fstat_memread_pf0_0_common,
    { { &setup_fstat_memread_pe_0_proc0 }, { &setup_fstat_memread_pd0_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd0_1",
    &setup_fstat_memread_pf0_0_common,
    { { &setup_fstat_memread_pe_1_proc0 }, { &setup_fstat_memread_pd0_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd0_2",
    &setup_fstat_memread_pf0_0_common,
    { { &setup_fstat_memread_pe_0_proc0 }, { &setup_fstat_memread_pd0_2_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pd0_3",
    &setup_fstat_memread_pf0_0_common,
    { { &setup_fstat_memread_pe_1_proc0 }, { &setup_fstat_memread_pd0_2_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pc_0",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pe_0_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pc_1",
    &setup_fstat_memread_pf8_0_common,
    { { &setup_fstat_memread_pe_1_proc0 }, { &setup_fstat_memread_pf8_0_proc1 } },
    &setup_fstat_memread_pf8_0_procfinal,
    &setup_fstat_memread_pf8_0_final,
    { { &test_fstat_memread_pf8_0_0, 0, "fstat" },
      { &test_fstat_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pb8_0",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pb8_0_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pb8_1",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pb8_1_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pb4_0",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pb4_0_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pb4_1",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pb4_1_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pb4_2",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pb4_2_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pb4_3",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pb4_3_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pb0_0",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_pb4_0_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb0_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pb0_1",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_pb4_1_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb0_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pb0_2",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_pb4_2_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb0_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pb0_3",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_pb4_3_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb0_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_pa_0",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pa_0_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p98_0",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pa_0_proc0 }, { &setup_fstat_memread_p98_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p98_1",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pa_0_proc0 }, { &setup_fstat_memread_p98_1_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p94_0",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_p94_0_proc0 }, { &setup_fstat_memread_p94_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p94_1",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_p94_1_proc0 }, { &setup_fstat_memread_p94_1_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p94_2",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_p94_2_proc0 }, { &setup_fstat_memread_p94_2_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p94_3",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_p94_3_proc0 }, { &setup_fstat_memread_p94_2_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p90_0",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_p90_0_proc0 }, { &setup_fstat_memread_p90_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb0_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p90_1",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_p90_0_proc0 }, { &setup_fstat_memread_p90_1_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb0_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p90_2",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_pa_0_proc0 }, { &setup_fstat_memread_p90_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb0_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p90_3",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_pa_0_proc0 }, { &setup_fstat_memread_p90_1_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb0_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p8_0",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pa_0_proc0 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_pb8_0_0, 0, "fstat" },
      { &test_fstat_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p7_0",
    &setup_fstat_memread_p7_0_common,
    { { &setup_fstat_memread_p98_0_proc1 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_procfinal,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p7_1",
    &setup_fstat_memread_p7_0_common,
    { { &setup_fstat_memread_p98_1_proc1 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_procfinal,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p68_0",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_p90_0_proc1 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p68_1",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_p90_1_proc1 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p60_0",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_p90_0_proc1 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p60_1",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_p90_1_proc1 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p4_0",
    &setup_fstat_memread_p7_0_common,
    { { &setup_fstat_memread_pb8_0_proc1 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_procfinal,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p3_0",
    &setup_fstat_memread_p7_0_common,
    { { &setup_fstat_memread_pb8_0_proc1 }, { &setup_fstat_memread_p98_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_procfinal,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p3_1",
    &setup_fstat_memread_p7_0_common,
    { { &setup_fstat_memread_pb8_0_proc1 }, { &setup_fstat_memread_p98_1_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_procfinal,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p28_0",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pb8_0_proc1 }, { &setup_fstat_memread_p94_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p28_1",
    &setup_fstat_memread_pb8_0_common,
    { { &setup_fstat_memread_pb8_0_proc1 }, { &setup_fstat_memread_p28_1_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p20_0",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_pb8_0_proc1 }, { &setup_fstat_memread_p90_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p20_1",
    &setup_fstat_memread_pb0_0_common,
    { { &setup_fstat_memread_pb8_0_proc1 }, { &setup_fstat_memread_p90_1_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_final,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memread_p0_0",
    &setup_fstat_memread_p7_0_common,
    { { &setup_fstat_memread_pb8_0_proc1 }, { &setup_fstat_memread_pb8_0_proc1 } },
    &setup_fstat_memread_pb8_0_procfinal,
    &setup_fstat_memread_pb8_0_procfinal,
    { { &test_fstat_memread_p7_0_0, 0, "fstat" },
      { &test_fstat_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-fstat_memwrite_pfc_0",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pfc_0_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pfc_1",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pfc_1_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pfa_0",
    &setup_fstat_memwrite_pfa_0_common,
    { { &setup_fstat_memwrite_pfa_0_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pfa_1",
    &setup_fstat_memwrite_pfa_0_common,
    { { &setup_fstat_memwrite_pfa_1_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pf8_0",
    &setup_fstat_memwrite_pf8_0_common,
    { { &setup_fstat_memwrite_pf8_0_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pf8_1",
    &setup_fstat_memwrite_pf8_0_common,
    { { &setup_fstat_memwrite_pf8_1_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pf0_0",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pf0_0_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pf0_1",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pf0_1_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pf0_2",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pf0_2_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pf0_3",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pf0_3_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pe_0",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pe_0_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pe_1",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pe_1_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pdc_0",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pe_0_proc0 }, { &setup_fstat_memwrite_pdc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pdc_1",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pe_1_proc0 }, { &setup_fstat_memwrite_pdc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pda_0",
    &setup_fstat_memwrite_pda_0_common,
    { { &setup_fstat_memwrite_pe_0_proc0 }, { &setup_fstat_memwrite_pda_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pda_1",
    &setup_fstat_memwrite_pda_0_common,
    { { &setup_fstat_memwrite_pe_1_proc0 }, { &setup_fstat_memwrite_pda_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pd8_0",
    &setup_fstat_memwrite_pf8_0_common,
    { { &setup_fstat_memwrite_pe_0_proc0 }, { &setup_fstat_memwrite_pda_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pd8_1",
    &setup_fstat_memwrite_pf8_0_common,
    { { &setup_fstat_memwrite_pe_1_proc0 }, { &setup_fstat_memwrite_pda_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pd0_0",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pe_0_proc0 }, { &setup_fstat_memwrite_pd0_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pd0_1",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pe_1_proc0 }, { &setup_fstat_memwrite_pd0_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pd0_2",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pe_0_proc0 }, { &setup_fstat_memwrite_pd0_2_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pd0_3",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pe_1_proc0 }, { &setup_fstat_memwrite_pd0_2_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pc_0",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pe_0_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pc_1",
    &setup_fstat_memwrite_pfc_0_common,
    { { &setup_fstat_memwrite_pe_1_proc0 }, { &setup_fstat_memwrite_pfc_0_proc1 } },
    &setup_fstat_memwrite_pfc_0_procfinal,
    &setup_fstat_memwrite_pfc_0_final,
    { { &test_fstat_memwrite_pfc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pbc_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pbc_0_proc0 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pba_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pba_0_proc0 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pba_1",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pba_1_proc0 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pb8_0",
    &setup_fstat_memwrite_pb8_0_common,
    { { &setup_fstat_memwrite_pb8_0_proc0 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pb8_1",
    &setup_fstat_memwrite_pb8_0_common,
    { { &setup_fstat_memwrite_pb8_1_proc0 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pb0_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pb0_0_proc0 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pb0_1",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pb0_1_proc0 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_pa_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pa_0_proc0 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p9c_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pa_0_proc0 }, { &setup_fstat_memwrite_p9c_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p9a_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_p9a_0_proc0 }, { &setup_fstat_memwrite_p9a_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p9a_1",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pa_0_proc0 }, { &setup_fstat_memwrite_p9a_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p98_0",
    &setup_fstat_memwrite_pb8_0_common,
    { { &setup_fstat_memwrite_p9a_0_proc0 }, { &setup_fstat_memwrite_p9a_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p98_1",
    &setup_fstat_memwrite_pb8_0_common,
    { { &setup_fstat_memwrite_pa_0_proc0 }, { &setup_fstat_memwrite_p9a_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p90_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pa_0_proc0 }, { &setup_fstat_memwrite_p90_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p90_1",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pa_0_proc0 }, { &setup_fstat_memwrite_p90_1_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p8_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pa_0_proc0 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_pbc_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p78_0",
    &setup_fstat_memwrite_p78_0_common,
    { { &setup_fstat_memwrite_p9c_0_proc1 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_procfinal,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p74_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_p74_0_proc0 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p70_0",
    &setup_fstat_memwrite_pb8_0_common,
    { { &setup_fstat_memwrite_p9a_0_proc1 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p6_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_p90_0_proc1 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p6_1",
    &setup_fstat_memwrite_p78_0_common,
    { { &setup_fstat_memwrite_p90_1_proc1 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_procfinal,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p4_0",
    &setup_fstat_memwrite_p78_0_common,
    { { &setup_fstat_memwrite_pbc_0_proc1 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_procfinal,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p38_0",
    &setup_fstat_memwrite_p78_0_common,
    { { &setup_fstat_memwrite_pbc_0_proc1 }, { &setup_fstat_memwrite_p9c_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_procfinal,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p34_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pbc_0_proc1 }, { &setup_fstat_memwrite_p9a_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p30_0",
    &setup_fstat_memwrite_pb8_0_common,
    { { &setup_fstat_memwrite_pbc_0_proc1 }, { &setup_fstat_memwrite_p9a_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p2_0",
    &setup_fstat_memwrite_pbc_0_common,
    { { &setup_fstat_memwrite_pbc_0_proc1 }, { &setup_fstat_memwrite_p90_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_final,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p2_1",
    &setup_fstat_memwrite_p78_0_common,
    { { &setup_fstat_memwrite_pbc_0_proc1 }, { &setup_fstat_memwrite_p90_1_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_procfinal,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_memwrite_p0_0",
    &setup_fstat_memwrite_p78_0_common,
    { { &setup_fstat_memwrite_pbc_0_proc1 }, { &setup_fstat_memwrite_pbc_0_proc1 } },
    &setup_fstat_memwrite_pbc_0_procfinal,
    &setup_fstat_memwrite_pbc_0_procfinal,
    { { &test_fstat_memwrite_p78_0_0, 0, "fstat" },
      { &test_fstat_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-fstat_mmap_pf8_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf8_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf8_2",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf8_3",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf6_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf6_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf6_2",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf6_3",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_3_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf6_4",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf6_5",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf4_0",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf4_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf4_1",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf4_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf0_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pf0_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_2",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_3",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_4",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_5",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_6",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pec_6_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_7",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_8",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pec_8_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_9",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pec_10",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pec_6_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe6_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe6_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe6_2",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_3_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe6_3",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe6_4",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf6_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe6_5",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe5_0",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf4_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe5_1",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf4_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe5_2",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pec_8_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe5_3",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pec_8_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe5_4",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf4_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe5_5",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pec_6_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe5_6",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf4_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe5_7",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pec_6_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe0_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pe0_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pd8_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pd8_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pd6_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pd6_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pd6_2",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_2_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pd6_3",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_2_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pd4_0",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pd4_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pd4_1",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pd4_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pd0_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pd0_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pcc_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pcc_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pcc_2",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pcc_3",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc6_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc6_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc6_2",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_2_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc6_3",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_2_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc5_0",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pd4_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc5_1",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pd4_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc5_2",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pd4_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc5_3",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pd4_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc5_4",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pc5_4_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc5_5",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pc5_4_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc5_6",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pc5_4_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc5_7",
    &setup_fstat_mmap_pf4_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pc5_4_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc0_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pc0_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_2_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pf8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pb8_0",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pb8_1",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pb6_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pb6_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pb6_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pb6_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pb4_0",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pb4_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb4_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pb4_1",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pb0_0",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pac_0",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pac_1",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pac_2",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pcc_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pac_3",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pa6_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pb6_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pa6_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pb6_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pa5_0",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pb4_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb4_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pa5_1",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pb4_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb4_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pa5_2",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pa5_2_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb4_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pa5_3",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pa5_2_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb4_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pa5_4",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pa5_5",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_pa0_0",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p98_0",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p96_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pc5_4_proc1 }, { &setup_fstat_mmap_pf8_0_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p96_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pc5_4_proc1 }, { &setup_fstat_mmap_pf8_2_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p94_0",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_p94_0_proc0 }, { &setup_fstat_mmap_p94_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb4_0_0, 0, "fstat" },
      { &test_fstat_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p90_0",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p8c_0",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p8c_1",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p86_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pc5_4_proc1 }, { &setup_fstat_mmap_pf8_0_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p86_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pc5_4_proc1 }, { &setup_fstat_mmap_pf8_2_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p85_0",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_p94_0_proc1 }, { &setup_fstat_mmap_p94_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb4_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p85_1",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_p94_0_proc1 }, { &setup_fstat_mmap_p94_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb4_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p85_2",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc0 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb4_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p85_3",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc0 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb4_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p80_0",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_pb8_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_pb8_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p70_0",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p70_1",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_p70_1_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p6c_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_p6c_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p6c_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_p6c_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p68_0",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_p68_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p60_0",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p60_1",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p58_0",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p58_1",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pcc_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p58_2",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_p70_1_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p58_3",
    &setup_fstat_mmap_pb8_0_common,
    { { &setup_fstat_mmap_p70_1_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p4c_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_p6c_0_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p4c_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_p6c_1_proc0 }, { &setup_fstat_mmap_pf8_0_proc1 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p4a_0",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_p68_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p4a_1",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_p68_0_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p4a_2",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_p70_1_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p4a_3",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_p70_1_proc0 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p40_0",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p40_1",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p30_0",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p2c_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc1 }, { &setup_fstat_mmap_pf8_0_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p2c_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc1 }, { &setup_fstat_mmap_pf8_2_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p28_0",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_p94_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p20_0",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p18_0",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p18_1",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p0c_0",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc1 }, { &setup_fstat_mmap_pf8_0_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p0c_1",
    &setup_fstat_mmap_pf8_0_common,
    { { &setup_fstat_mmap_pf8_0_proc1 }, { &setup_fstat_mmap_pf8_2_proc0 } },
    &setup_fstat_mmap_pf8_0_procfinal,
    &setup_fstat_mmap_pf8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p0a_0",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_p94_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p0a_1",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_p94_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p0a_2",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc0 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p0a_3",
    &setup_fstat_mmap_pb4_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc0 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_final,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mmap_p00_0",
    &setup_fstat_mmap_p70_0_common,
    { { &setup_fstat_mmap_pb8_0_proc1 }, { &setup_fstat_mmap_pb8_0_proc1 } },
    &setup_fstat_mmap_pb8_0_procfinal,
    &setup_fstat_mmap_pb8_0_procfinal,
    { { &test_fstat_mmap_p70_0_0, 0, "fstat" },
      { &test_fstat_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-fstat_mprotect_pf_0",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pf_0_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pf_1",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pf_1_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pf_2",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pf_2_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pf_3",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pf_3_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pf_4",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pf_4_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pf_5",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pf_5_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pf_6",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pf_6_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pf_7",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pf_7_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pe_0",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_0_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pe_1",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_1_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pd_0",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_0_proc0 }, { &setup_fstat_mprotect_pd_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pd_1",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_0_proc0 }, { &setup_fstat_mprotect_pd_1_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pd_2",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_1_proc0 }, { &setup_fstat_mprotect_pd_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pd_3",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_1_proc0 }, { &setup_fstat_mprotect_pd_1_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pd_4",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_0_proc0 }, { &setup_fstat_mprotect_pd_4_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pd_5",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_1_proc0 }, { &setup_fstat_mprotect_pd_4_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pd_6",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_0_proc0 }, { &setup_fstat_mprotect_pd_6_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pd_7",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_1_proc0 }, { &setup_fstat_mprotect_pd_6_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pc_0",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_0_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pc_1",
    &setup_fstat_mprotect_pf_0_common,
    { { &setup_fstat_mprotect_pe_1_proc0 }, { &setup_fstat_mprotect_pf_0_proc1 } },
    &setup_fstat_mprotect_pf_0_procfinal,
    &setup_fstat_mprotect_pf_0_final,
    { { &test_fstat_mprotect_pf_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pb_0",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pb_0_proc0 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_pb_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pb_1",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pb_1_proc0 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_pb_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pb_2",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pb_2_proc0 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_pb_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pb_3",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pb_3_proc0 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_pb_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_pa_0",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pa_0_proc0 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_pb_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p9_0",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pa_0_proc0 }, { &setup_fstat_mprotect_p9_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_pb_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p9_1",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pa_0_proc0 }, { &setup_fstat_mprotect_p9_1_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_pb_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p9_2",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pa_0_proc0 }, { &setup_fstat_mprotect_p9_2_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_pb_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p9_3",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pa_0_proc0 }, { &setup_fstat_mprotect_p9_3_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_pb_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p8_0",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pa_0_proc0 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_pb_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p6_0",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_p9_0_proc1 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_p6_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p6_1",
    &setup_fstat_mprotect_p6_1_common,
    { { &setup_fstat_mprotect_p9_1_proc1 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_procfinal,
    { { &test_fstat_mprotect_p6_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p6_2",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_p9_2_proc1 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_p6_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p6_3",
    &setup_fstat_mprotect_p6_1_common,
    { { &setup_fstat_mprotect_p9_3_proc1 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_procfinal,
    { { &test_fstat_mprotect_p6_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p4_0",
    &setup_fstat_mprotect_p6_1_common,
    { { &setup_fstat_mprotect_pb_0_proc1 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_procfinal,
    { { &test_fstat_mprotect_p6_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p2_0",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pb_0_proc1 }, { &setup_fstat_mprotect_p9_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_p6_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p2_1",
    &setup_fstat_mprotect_p6_1_common,
    { { &setup_fstat_mprotect_pb_0_proc1 }, { &setup_fstat_mprotect_p9_1_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_procfinal,
    { { &test_fstat_mprotect_p6_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p2_2",
    &setup_fstat_mprotect_pb_0_common,
    { { &setup_fstat_mprotect_pb_0_proc1 }, { &setup_fstat_mprotect_p9_2_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_final,
    { { &test_fstat_mprotect_p6_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p2_3",
    &setup_fstat_mprotect_p6_1_common,
    { { &setup_fstat_mprotect_pb_0_proc1 }, { &setup_fstat_mprotect_p9_3_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_procfinal,
    { { &test_fstat_mprotect_p6_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_mprotect_p0_0",
    &setup_fstat_mprotect_p6_1_common,
    { { &setup_fstat_mprotect_pb_0_proc1 }, { &setup_fstat_mprotect_pb_0_proc1 } },
    &setup_fstat_mprotect_pb_0_procfinal,
    &setup_fstat_mprotect_pb_0_procfinal,
    { { &test_fstat_mprotect_p6_0_0, 0, "fstat" },
      { &test_fstat_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-fstat_munmap_pe_0",
    &setup_fstat_munmap_pe_0_common,
    { { &setup_fstat_munmap_pe_0_proc0 }, { &setup_fstat_munmap_pe_0_proc1 } },
    &setup_fstat_munmap_pe_0_procfinal,
    &setup_fstat_munmap_pe_0_final,
    { { &test_fstat_munmap_pe_0_0, 0, "fstat" },
      { &test_fstat_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-fstat_munmap_pe_1",
    &setup_fstat_munmap_pe_0_common,
    { { &setup_fstat_munmap_pe_1_proc0 }, { &setup_fstat_munmap_pe_0_proc1 } },
    &setup_fstat_munmap_pe_0_procfinal,
    &setup_fstat_munmap_pe_0_final,
    { { &test_fstat_munmap_pe_0_0, 0, "fstat" },
      { &test_fstat_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-fstat_munmap_pc_0",
    &setup_fstat_munmap_pe_0_common,
    { { &setup_fstat_munmap_pe_0_proc0 }, { &setup_fstat_munmap_pe_0_proc1 } },
    &setup_fstat_munmap_pe_0_procfinal,
    &setup_fstat_munmap_pe_0_final,
    { { &test_fstat_munmap_pe_0_0, 0, "fstat" },
      { &test_fstat_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-fstat_munmap_pc_1",
    &setup_fstat_munmap_pe_0_common,
    { { &setup_fstat_munmap_pe_1_proc0 }, { &setup_fstat_munmap_pe_0_proc1 } },
    &setup_fstat_munmap_pe_0_procfinal,
    &setup_fstat_munmap_pe_0_final,
    { { &test_fstat_munmap_pe_0_0, 0, "fstat" },
      { &test_fstat_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-fstat_munmap_pa_0",
    &setup_fstat_munmap_pa_0_common,
    { { &setup_fstat_munmap_pa_0_proc0 }, { &setup_fstat_munmap_pa_0_proc1 } },
    &setup_fstat_munmap_pa_0_procfinal,
    &setup_fstat_munmap_pa_0_final,
    { { &test_fstat_munmap_pa_0_0, 0, "fstat" },
      { &test_fstat_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-fstat_munmap_p8_0",
    &setup_fstat_munmap_pa_0_common,
    { { &setup_fstat_munmap_pa_0_proc0 }, { &setup_fstat_munmap_pa_0_proc1 } },
    &setup_fstat_munmap_pa_0_procfinal,
    &setup_fstat_munmap_pa_0_final,
    { { &test_fstat_munmap_pa_0_0, 0, "fstat" },
      { &test_fstat_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-fstat_munmap_p4_0",
    &setup_fstat_munmap_p4_0_common,
    { { &setup_fstat_munmap_pa_0_proc1 }, { &setup_fstat_munmap_pa_0_proc1 } },
    &setup_fstat_munmap_pa_0_procfinal,
    &setup_fstat_munmap_pa_0_procfinal,
    { { &test_fstat_munmap_p4_0_0, 0, "fstat" },
      { &test_fstat_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-fstat_munmap_p0_0",
    &setup_fstat_munmap_p4_0_common,
    { { &setup_fstat_munmap_pa_0_proc1 }, { &setup_fstat_munmap_pa_0_proc1 } },
    &setup_fstat_munmap_pa_0_procfinal,
    &setup_fstat_munmap_pa_0_procfinal,
    { { &test_fstat_munmap_p4_0_0, 0, "fstat" },
      { &test_fstat_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-fstat_open_pf8_0",
    &setup_fstat_open_pf8_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pf8_1",
    &setup_fstat_open_pf8_0_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pf70_0",
    &setup_fstat_open_pf70_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pf70_1",
    &setup_fstat_open_pf70_1_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pf50_0",
    &setup_fstat_open_pf50_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pf50_1",
    &setup_fstat_open_pf50_1_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pf3_0",
    &setup_fstat_open_pf3_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pf3_1",
    &setup_fstat_open_pf3_0_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pf1_0",
    &setup_fstat_open_pf1_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pf1_1",
    &setup_fstat_open_pf1_0_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pee_0",
    &setup_fstat_open_pee_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pee_1",
    &setup_fstat_open_pee_0_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pea_0",
    &setup_fstat_open_pea_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pea_1",
    &setup_fstat_open_pea_0_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pe6_0",
    &setup_fstat_open_pe6_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pe6_1",
    &setup_fstat_open_pe6_0_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pe2_0",
    &setup_fstat_open_pea_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pe2_1",
    &setup_fstat_open_pea_0_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pde_0",
    &setup_fstat_open_pf70_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pde_1",
    &setup_fstat_open_pf70_1_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pda_0",
    &setup_fstat_open_pf50_1_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pda_1",
    &setup_fstat_open_pf50_1_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pd6_0",
    &setup_fstat_open_pf3_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pd6_1",
    &setup_fstat_open_pf3_0_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pd2_0",
    &setup_fstat_open_pf1_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pd2_1",
    &setup_fstat_open_pf1_0_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pc_0",
    &setup_fstat_open_pc_0_common,
    { { &setup_fstat_open_pf8_0_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pc_1",
    &setup_fstat_open_pc_0_common,
    { { &setup_fstat_open_pf8_1_proc0 }, { &setup_fstat_open_pf8_0_proc1 } },
    &setup_fstat_open_pf8_0_procfinal,
    &setup_fstat_open_pf8_0_final,
    { { &test_fstat_open_pf8_0_0, 0, "fstat" },
      { &test_fstat_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pb8_0",
    &setup_fstat_open_pb8_0_common,
    { { &setup_fstat_open_pb8_0_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pb8_0_0, 0, "fstat" },
      { &test_fstat_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pb7e_0",
    &setup_fstat_open_pb7e_0_common,
    { { &setup_fstat_open_pb7e_0_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb7e_0_final,
    { { &test_fstat_open_pb7e_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pb7e_1",
    &setup_fstat_open_pb8_0_common,
    { { &setup_fstat_open_pb7e_1_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pb8_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pb5e_0",
    &setup_fstat_open_pb5e_0_common,
    { { &setup_fstat_open_pb5e_0_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb7e_0_final,
    { { &test_fstat_open_pb5e_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pb5e_1",
    &setup_fstat_open_pb8_0_common,
    { { &setup_fstat_open_pb5e_1_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pb8_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pb3_0",
    &setup_fstat_open_pb3_0_common,
    { { &setup_fstat_open_pb5e_1_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pb5e_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pb1_0",
    &setup_fstat_open_pb3_0_common,
    { { &setup_fstat_open_pb1_0_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pb5e_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pae_0",
    &setup_fstat_open_pae_0_common,
    { { &setup_fstat_open_pae_0_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pae_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_paa_0",
    &setup_fstat_open_pae_0_common,
    { { &setup_fstat_open_pb5e_1_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pae_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_pa6_0",
    &setup_fstat_open_pae_0_common,
    { { &setup_fstat_open_pae_0_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pae_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_pa2_0",
    &setup_fstat_open_pae_0_common,
    { { &setup_fstat_open_pb5e_1_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pae_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_p9fc_0",
    &setup_fstat_open_pb7e_0_common,
    { { &setup_fstat_open_pb7e_0_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb7e_0_final,
    { { &test_fstat_open_pb7e_0_0, 0, "fstat" },
      { &test_fstat_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p9fc_1",
    &setup_fstat_open_pb8_0_common,
    { { &setup_fstat_open_pb7e_1_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pb8_0_0, 0, "fstat" },
      { &test_fstat_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p9bc_0",
    &setup_fstat_open_pb5e_0_common,
    { { &setup_fstat_open_pb5e_0_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb7e_0_final,
    { { &test_fstat_open_pb5e_0_0, 0, "fstat" },
      { &test_fstat_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_p9bc_1",
    &setup_fstat_open_pb8_0_common,
    { { &setup_fstat_open_pb5e_1_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pb8_0_0, 0, "fstat" },
      { &test_fstat_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_p96_0",
    &setup_fstat_open_pb3_0_common,
    { { &setup_fstat_open_pb5e_1_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pb5e_0_0, 0, "fstat" },
      { &test_fstat_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p92_0",
    &setup_fstat_open_pb3_0_common,
    { { &setup_fstat_open_pb1_0_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pb5e_0_0, 0, "fstat" },
      { &test_fstat_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_p8_0",
    &setup_fstat_open_p8_0_common,
    { { &setup_fstat_open_pb8_0_proc0 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_pb8_0_0, 0, "fstat" },
      { &test_fstat_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p7_0",
    &setup_fstat_open_pb8_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p6d0_0",
    &setup_fstat_open_pb3_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p6a_0",
    &setup_fstat_open_p6a_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_p65_0",
    &setup_fstat_open_pb3_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p62_0",
    &setup_fstat_open_pb3_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_p5a_0",
    &setup_fstat_open_p5a_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_procfinal,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p54_0",
    &setup_fstat_open_p5a_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_procfinal,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_p4a_0",
    &setup_fstat_open_p5a_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_procfinal,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p44_0",
    &setup_fstat_open_p5a_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_procfinal,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_p3a_0",
    &setup_fstat_open_pb8_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p34_0",
    &setup_fstat_open_p6a_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_p2a_0",
    &setup_fstat_open_pb3_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_open_p24_0",
    &setup_fstat_open_pb3_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_final,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-fstat_open_p0_0",
    &setup_fstat_open_p5a_0_common,
    { { &setup_fstat_open_pb8_0_proc1 }, { &setup_fstat_open_pb8_0_proc1 } },
    &setup_fstat_open_pb8_0_procfinal,
    &setup_fstat_open_pb8_0_procfinal,
    { { &test_fstat_open_p7_0_0, 0, "fstat" },
      { &test_fstat_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-fstat_pipe_pf8_0",
    &setup_fstat_pipe_pf8_0_common,
    { { &setup_fstat_pipe_pf8_0_proc0 }, { &setup_fstat_pipe_pf8_0_proc1 } },
    &setup_fstat_pipe_pf8_0_procfinal,
    &setup_fstat_pipe_pf8_0_final,
    { { &test_fstat_pipe_pf8_0_0, 0, "fstat" },
      { &test_fstat_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-fstat_pipe_pf8_1",
    &setup_fstat_pipe_pf8_0_common,
    { { &setup_fstat_pipe_pf8_1_proc0 }, { &setup_fstat_pipe_pf8_0_proc1 } },
    &setup_fstat_pipe_pf8_0_procfinal,
    &setup_fstat_pipe_pf8_0_final,
    { { &test_fstat_pipe_pf8_0_0, 0, "fstat" },
      { &test_fstat_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-fstat_pipe_pd8_0",
    &setup_fstat_pipe_pd8_0_common,
    { { &setup_fstat_pipe_pf8_0_proc0 }, { &setup_fstat_pipe_pf8_0_proc1 } },
    &setup_fstat_pipe_pf8_0_procfinal,
    &setup_fstat_pipe_pf8_0_final,
    { { &test_fstat_pipe_pf8_0_0, 0, "fstat" },
      { &test_fstat_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-fstat_pipe_pd8_1",
    &setup_fstat_pipe_pd8_0_common,
    { { &setup_fstat_pipe_pf8_1_proc0 }, { &setup_fstat_pipe_pf8_0_proc1 } },
    &setup_fstat_pipe_pf8_0_procfinal,
    &setup_fstat_pipe_pf8_0_final,
    { { &test_fstat_pipe_pf8_0_0, 0, "fstat" },
      { &test_fstat_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-fstat_pipe_pb8_0",
    &setup_fstat_pipe_pb8_0_common,
    { { &setup_fstat_pipe_pb8_0_proc0 }, { &setup_fstat_pipe_pb8_0_proc1 } },
    &setup_fstat_pipe_pb8_0_procfinal,
    &setup_fstat_pipe_pb8_0_final,
    { { &test_fstat_pipe_pb8_0_0, 0, "fstat" },
      { &test_fstat_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-fstat_pipe_p98_0",
    &setup_fstat_pipe_pb8_0_common,
    { { &setup_fstat_pipe_pb8_0_proc0 }, { &setup_fstat_pipe_pb8_0_proc1 } },
    &setup_fstat_pipe_pb8_0_procfinal,
    &setup_fstat_pipe_pb8_0_final,
    { { &test_fstat_pipe_pb8_0_0, 0, "fstat" },
      { &test_fstat_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-fstat_pipe_p58_0",
    &setup_fstat_pipe_p58_0_common,
    { { &setup_fstat_pipe_pb8_0_proc1 }, { &setup_fstat_pipe_pb8_0_proc1 } },
    &setup_fstat_pipe_pb8_0_procfinal,
    &setup_fstat_pipe_pb8_0_procfinal,
    { { &test_fstat_pipe_p58_0_0, 0, "fstat" },
      { &test_fstat_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-fstat_pipe_p30_0",
    &setup_fstat_pipe_p58_0_common,
    { { &setup_fstat_pipe_pb8_0_proc1 }, { &setup_fstat_pipe_pb8_0_proc1 } },
    &setup_fstat_pipe_pb8_0_procfinal,
    &setup_fstat_pipe_pb8_0_procfinal,
    { { &test_fstat_pipe_p58_0_0, 0, "fstat" },
      { &test_fstat_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-fstat_pread_pf8_0",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_0_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf8_1",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_1_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf8_2",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_2_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf8_3",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_3_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf8_4",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_4_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf4_0",
    &setup_fstat_pread_pf4_0_common,
    { { &setup_fstat_pread_pf4_0_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf4_1",
    &setup_fstat_pread_pf4_0_common,
    { { &setup_fstat_pread_pf4_1_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf4_2",
    &setup_fstat_pread_pf4_0_common,
    { { &setup_fstat_pread_pf4_2_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf4_3",
    &setup_fstat_pread_pf4_0_common,
    { { &setup_fstat_pread_pf4_3_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf0_0",
    &setup_fstat_pread_pf0_0_common,
    { { &setup_fstat_pread_pf0_0_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf0_1",
    &setup_fstat_pread_pf0_0_common,
    { { &setup_fstat_pread_pf0_1_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf0_2",
    &setup_fstat_pread_pf0_2_common,
    { { &setup_fstat_pread_pf4_2_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pf0_3",
    &setup_fstat_pread_pf0_2_common,
    { { &setup_fstat_pread_pf4_3_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pe_0",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_3_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pe_1",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_4_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd8_0",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_3_proc0 }, { &setup_fstat_pread_pf8_3_proc0 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd8_1",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_4_proc0 }, { &setup_fstat_pread_pf8_3_proc0 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd8_2",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_3_proc0 }, { &setup_fstat_pread_pf8_4_proc0 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd8_3",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_4_proc0 }, { &setup_fstat_pread_pf8_4_proc0 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd4_0",
    &setup_fstat_pread_pf4_0_common,
    { { &setup_fstat_pread_pf8_3_proc0 }, { &setup_fstat_pread_pd4_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd4_1",
    &setup_fstat_pread_pf4_0_common,
    { { &setup_fstat_pread_pf8_4_proc0 }, { &setup_fstat_pread_pd4_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd4_2",
    &setup_fstat_pread_pf4_0_common,
    { { &setup_fstat_pread_pf8_3_proc0 }, { &setup_fstat_pread_pd4_2_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd4_3",
    &setup_fstat_pread_pf4_0_common,
    { { &setup_fstat_pread_pf8_4_proc0 }, { &setup_fstat_pread_pd4_2_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd0_0",
    &setup_fstat_pread_pf0_0_common,
    { { &setup_fstat_pread_pf8_3_proc0 }, { &setup_fstat_pread_pd0_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd0_1",
    &setup_fstat_pread_pf0_0_common,
    { { &setup_fstat_pread_pf8_4_proc0 }, { &setup_fstat_pread_pd0_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd0_2",
    &setup_fstat_pread_pf0_2_common,
    { { &setup_fstat_pread_pf8_3_proc0 }, { &setup_fstat_pread_pd4_2_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pd0_3",
    &setup_fstat_pread_pd0_3_common,
    { { &setup_fstat_pread_pf8_4_proc0 }, { &setup_fstat_pread_pd4_2_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pc_0",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_3_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pc_1",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_4_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pf8_0_0, 0, "fstat" },
      { &test_fstat_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb8_0",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pb8_0_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb8_1",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pb8_1_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb4_0",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_pb4_0_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb4_1",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_pb4_1_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb4_2",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_pb4_2_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb4_3",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_pb4_3_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb2_0",
    &setup_fstat_pread_pb2_0_common,
    { { &setup_fstat_pread_pb2_0_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb2_0_final,
    { { &test_fstat_pread_pb2_0_0, 0, "fstat" },
      { &test_fstat_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb2_1",
    &setup_fstat_pread_pb2_1_common,
    { { &setup_fstat_pread_pb2_1_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb2_0_0, 0, "fstat" },
      { &test_fstat_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb2_2",
    &setup_fstat_pread_pb2_1_common,
    { { &setup_fstat_pread_pb4_1_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb2_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb2_3",
    &setup_fstat_pread_pb2_1_common,
    { { &setup_fstat_pread_pb4_2_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb2_0_0, 0, "fstat" },
      { &test_fstat_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pb2_4",
    &setup_fstat_pread_pb2_1_common,
    { { &setup_fstat_pread_pb4_3_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb2_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_pa_0",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_pb4_3_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p98_0",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pd4_2_proc1 }, { &setup_fstat_pread_pf8_3_proc0 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p98_1",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pd4_2_proc1 }, { &setup_fstat_pread_pf8_4_proc0 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p94_0",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_pb4_1_proc0 }, { &setup_fstat_pread_pb4_1_proc0 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p94_1",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_pb4_3_proc0 }, { &setup_fstat_pread_pb4_3_proc0 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p92_0",
    &setup_fstat_pread_pb2_0_common,
    { { &setup_fstat_pread_p92_0_proc0 }, { &setup_fstat_pread_p92_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb2_0_final,
    { { &test_fstat_pread_pb2_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p92_1",
    &setup_fstat_pread_pb2_1_common,
    { { &setup_fstat_pread_p92_0_proc1 }, { &setup_fstat_pread_p92_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb2_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p92_2",
    &setup_fstat_pread_pb2_1_common,
    { { &setup_fstat_pread_pb4_3_proc0 }, { &setup_fstat_pread_pb4_3_proc0 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb2_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p8_0",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_pb4_3_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_pb8_0_0, 0, "fstat" },
      { &test_fstat_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p7_0",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_p7_0_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p7_1",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_p7_1_proc0 }, { &setup_fstat_pread_pf8_0_proc1 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p68_0",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_p68_0_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p68_1",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_p68_1_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p60_0",
    &setup_fstat_pread_pb2_1_common,
    { { &setup_fstat_pread_p60_0_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p60_1",
    &setup_fstat_pread_pb2_1_common,
    { { &setup_fstat_pread_p68_1_proc0 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p4_0",
    &setup_fstat_pread_p4_0_common,
    { { &setup_fstat_pread_pb4_0_proc1 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_procfinal,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p4_1",
    &setup_fstat_pread_p4_0_common,
    { { &setup_fstat_pread_pb4_0_proc1 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_procfinal,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p3_0",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_0_proc1 }, { &setup_fstat_pread_pf8_3_proc0 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p3_1",
    &setup_fstat_pread_pf8_0_common,
    { { &setup_fstat_pread_pf8_0_proc1 }, { &setup_fstat_pread_pf8_4_proc0 } },
    &setup_fstat_pread_pf8_0_procfinal,
    &setup_fstat_pread_pf8_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p28_0",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_pb4_0_proc1 }, { &setup_fstat_pread_pb4_1_proc0 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p28_1",
    &setup_fstat_pread_pb4_0_common,
    { { &setup_fstat_pread_pb4_0_proc1 }, { &setup_fstat_pread_pb4_3_proc0 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p20_0",
    &setup_fstat_pread_pb2_1_common,
    { { &setup_fstat_pread_pb4_0_proc1 }, { &setup_fstat_pread_p92_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p20_1",
    &setup_fstat_pread_pb2_1_common,
    { { &setup_fstat_pread_pb4_0_proc1 }, { &setup_fstat_pread_pb4_3_proc0 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_final,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pread_p0_0",
    &setup_fstat_pread_p4_0_common,
    { { &setup_fstat_pread_pb4_0_proc1 }, { &setup_fstat_pread_pb4_0_proc1 } },
    &setup_fstat_pread_pb4_0_procfinal,
    &setup_fstat_pread_pb4_0_procfinal,
    { { &test_fstat_pread_p7_0_0, 0, "fstat" },
      { &test_fstat_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-fstat_pwrite_pf8_0",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_0_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf8_1",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_1_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf8_2",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_2_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf8_3",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_3_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf8_4",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_4_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf8_5",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_5_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf4_0",
    &setup_fstat_pwrite_pf4_0_common,
    { { &setup_fstat_pwrite_pf4_0_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf4_1",
    &setup_fstat_pwrite_pf4_1_common,
    { { &setup_fstat_pwrite_pf4_1_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf4_2",
    &setup_fstat_pwrite_pf4_1_common,
    { { &setup_fstat_pwrite_pf4_2_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf4_3",
    &setup_fstat_pwrite_pf4_1_common,
    { { &setup_fstat_pwrite_pf4_3_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf0_0",
    &setup_fstat_pwrite_pf0_0_common,
    { { &setup_fstat_pwrite_pf0_0_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf0_1",
    &setup_fstat_pwrite_pf0_1_common,
    { { &setup_fstat_pwrite_pf4_1_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf0_2",
    &setup_fstat_pwrite_pf0_1_common,
    { { &setup_fstat_pwrite_pf0_2_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pf0_3",
    &setup_fstat_pwrite_pf0_3_common,
    { { &setup_fstat_pwrite_pf4_3_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pe_0",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_3_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pe_1",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_5_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd8_0",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_3_proc0 }, { &setup_fstat_pwrite_pf8_3_proc0 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd8_1",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_5_proc0 }, { &setup_fstat_pwrite_pf8_3_proc0 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd8_2",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_3_proc0 }, { &setup_fstat_pwrite_pf8_5_proc0 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd8_3",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_5_proc0 }, { &setup_fstat_pwrite_pf8_5_proc0 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd4_0",
    &setup_fstat_pwrite_pf4_0_common,
    { { &setup_fstat_pwrite_pf8_3_proc0 }, { &setup_fstat_pwrite_pd4_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd4_1",
    &setup_fstat_pwrite_pf4_1_common,
    { { &setup_fstat_pwrite_pf8_3_proc0 }, { &setup_fstat_pwrite_pd4_1_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd4_2",
    &setup_fstat_pwrite_pf4_1_common,
    { { &setup_fstat_pwrite_pf8_5_proc0 }, { &setup_fstat_pwrite_pd4_2_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd4_3",
    &setup_fstat_pwrite_pf4_0_common,
    { { &setup_fstat_pwrite_pf8_5_proc0 }, { &setup_fstat_pwrite_pd4_1_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd0_0",
    &setup_fstat_pwrite_pf0_0_common,
    { { &setup_fstat_pwrite_pf8_3_proc0 }, { &setup_fstat_pwrite_pd0_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd0_1",
    &setup_fstat_pwrite_pf0_1_common,
    { { &setup_fstat_pwrite_pf8_3_proc0 }, { &setup_fstat_pwrite_pd4_1_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd0_2",
    &setup_fstat_pwrite_pf0_1_common,
    { { &setup_fstat_pwrite_pf8_5_proc0 }, { &setup_fstat_pwrite_pd4_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pd0_3",
    &setup_fstat_pwrite_pf0_1_common,
    { { &setup_fstat_pwrite_pf8_5_proc0 }, { &setup_fstat_pwrite_pd4_1_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pc_0",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_3_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pc_1",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_5_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pf8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pb8_0",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pb8_0_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pb8_1",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pb8_1_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pb6_0",
    &setup_fstat_pwrite_pb6_0_common,
    { { &setup_fstat_pwrite_pb6_0_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb6_0_final,
    { { &test_fstat_pwrite_pb6_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pb6_1",
    &setup_fstat_pwrite_pb6_1_common,
    { { &setup_fstat_pwrite_pb6_1_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb6_0_final,
    { { &test_fstat_pwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pb6_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pb30_0",
    &setup_fstat_pwrite_pb30_0_common,
    { { &setup_fstat_pwrite_pb30_0_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb6_0_final,
    { { &test_fstat_pwrite_pb30_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pb30_1",
    &setup_fstat_pwrite_pb30_1_common,
    { { &setup_fstat_pwrite_pb30_1_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_pb30_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pb30_2",
    &setup_fstat_pwrite_pb30_1_common,
    { { &setup_fstat_pwrite_pb30_2_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_pb30_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pb30_3",
    &setup_fstat_pwrite_pb30_1_common,
    { { &setup_fstat_pwrite_pb30_3_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_pb30_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pb30_4",
    &setup_fstat_pwrite_pb30_1_common,
    { { &setup_fstat_pwrite_pb30_4_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_pb30_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_pa_0",
    &setup_fstat_pwrite_pa_0_common,
    { { &setup_fstat_pwrite_pb30_4_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p98_0",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pd4_1_proc1 }, { &setup_fstat_pwrite_pf8_3_proc0 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p98_1",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pd4_1_proc1 }, { &setup_fstat_pwrite_pf8_5_proc0 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p96_0",
    &setup_fstat_pwrite_pb6_0_common,
    { { &setup_fstat_pwrite_p96_0_proc0 }, { &setup_fstat_pwrite_p96_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb6_0_final,
    { { &test_fstat_pwrite_pb6_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p96_1",
    &setup_fstat_pwrite_pb6_1_common,
    { { &setup_fstat_pwrite_p96_1_proc0 }, { &setup_fstat_pwrite_p96_1_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb6_0_final,
    { { &test_fstat_pwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_p96_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p930_0",
    &setup_fstat_pwrite_pb30_0_common,
    { { &setup_fstat_pwrite_p930_0_proc0 }, { &setup_fstat_pwrite_p930_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb6_0_final,
    { { &test_fstat_pwrite_pb30_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p930_1",
    &setup_fstat_pwrite_pb30_1_common,
    { { &setup_fstat_pwrite_pb30_2_proc0 }, { &setup_fstat_pwrite_pb30_2_proc0 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_pb30_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p930_2",
    &setup_fstat_pwrite_pb30_1_common,
    { { &setup_fstat_pwrite_pb30_4_proc0 }, { &setup_fstat_pwrite_pb30_4_proc0 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_pb30_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p8_0",
    &setup_fstat_pwrite_pa_0_common,
    { { &setup_fstat_pwrite_pb30_4_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_pb8_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p7_0",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_p7_0_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p7_1",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_p7_1_proc0 }, { &setup_fstat_pwrite_pf8_0_proc1 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p68_0",
    &setup_fstat_pwrite_pa_0_common,
    { { &setup_fstat_pwrite_p68_0_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p68_1",
    &setup_fstat_pwrite_pa_0_common,
    { { &setup_fstat_pwrite_p68_1_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p60_0",
    &setup_fstat_pwrite_pb30_1_common,
    { { &setup_fstat_pwrite_p60_0_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p60_1",
    &setup_fstat_pwrite_pb30_1_common,
    { { &setup_fstat_pwrite_p68_1_proc0 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p4_0",
    &setup_fstat_pwrite_p4_0_common,
    { { &setup_fstat_pwrite_pb6_0_proc1 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb6_0_procfinal,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p4_1",
    &setup_fstat_pwrite_p4_0_common,
    { { &setup_fstat_pwrite_pb6_0_proc1 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb6_0_procfinal,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p3_0",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_0_proc1 }, { &setup_fstat_pwrite_pf8_3_proc0 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p3_1",
    &setup_fstat_pwrite_pf8_0_common,
    { { &setup_fstat_pwrite_pf8_0_proc1 }, { &setup_fstat_pwrite_pf8_5_proc0 } },
    &setup_fstat_pwrite_pf8_0_procfinal,
    &setup_fstat_pwrite_pf8_0_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p28_0",
    &setup_fstat_pwrite_pa_0_common,
    { { &setup_fstat_pwrite_pb6_0_proc1 }, { &setup_fstat_pwrite_p930_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p28_1",
    &setup_fstat_pwrite_pa_0_common,
    { { &setup_fstat_pwrite_pb6_0_proc1 }, { &setup_fstat_pwrite_pb30_4_proc0 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p20_0",
    &setup_fstat_pwrite_pb30_1_common,
    { { &setup_fstat_pwrite_pb6_0_proc1 }, { &setup_fstat_pwrite_p20_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p20_1",
    &setup_fstat_pwrite_pb30_1_common,
    { { &setup_fstat_pwrite_pb6_0_proc1 }, { &setup_fstat_pwrite_pb30_4_proc0 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb30_1_final,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_pwrite_p0_0",
    &setup_fstat_pwrite_p4_0_common,
    { { &setup_fstat_pwrite_pb6_0_proc1 }, { &setup_fstat_pwrite_pb6_0_proc1 } },
    &setup_fstat_pwrite_pb6_0_procfinal,
    &setup_fstat_pwrite_pb6_0_procfinal,
    { { &test_fstat_pwrite_p7_0_0, 0, "fstat" },
      { &test_fstat_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-fstat_read_pfc_0",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pfc_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pfc_1",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pfc_1_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pfc_2",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pfc_2_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_2_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pfb_0",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_pfb_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pfb_1",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_pfb_1_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pfb_2",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_pfb_2_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfb_2_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pfa_0",
    &setup_fstat_read_pfa_0_common,
    { { &setup_fstat_read_pfa_0_proc0 }, { &setup_fstat_read_pfa_0_proc1 } },
    &setup_fstat_read_pfa_0_procfinal,
    &setup_fstat_read_pfa_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pfa_1",
    &setup_fstat_read_pfa_1_common,
    { { &setup_fstat_read_pfb_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pfa_2",
    &setup_fstat_read_pfa_0_common,
    { { &setup_fstat_read_pfa_2_proc0 }, { &setup_fstat_read_pfa_0_proc1 } },
    &setup_fstat_read_pfa_0_procfinal,
    &setup_fstat_read_pfa_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pfa_3",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_pfa_3_proc0 }, { &setup_fstat_read_pfa_3_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pf8_0",
    &setup_fstat_read_pf8_0_common,
    { { &setup_fstat_read_pfb_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pf8_1",
    &setup_fstat_read_pf8_0_common,
    { { &setup_fstat_read_pfb_1_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pf8_2",
    &setup_fstat_read_pf8_0_common,
    { { &setup_fstat_read_pfb_2_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pf4_0",
    &setup_fstat_read_pf4_0_common,
    { { &setup_fstat_read_pf4_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pf4_1",
    &setup_fstat_read_pf4_0_common,
    { { &setup_fstat_read_pf4_1_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pf0_0",
    &setup_fstat_read_pf0_0_common,
    { { &setup_fstat_read_pf4_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pf0_1",
    &setup_fstat_read_pf0_1_common,
    { { &setup_fstat_read_pf4_1_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pe_0",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pfb_2_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pe_1",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pfc_2_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pdc_0",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pfb_2_proc0 }, { &setup_fstat_read_pfc_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pdc_1",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pfc_2_proc0 }, { &setup_fstat_read_pfc_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pdb_0",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_pfb_2_proc0 }, { &setup_fstat_read_pfb_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pdb_1",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_pfc_2_proc0 }, { &setup_fstat_read_pfb_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pda_0",
    &setup_fstat_read_pda_0_common,
    { { &setup_fstat_read_pda_0_proc0 }, { &setup_fstat_read_pda_0_proc1 } },
    &setup_fstat_read_pda_0_procfinal,
    &setup_fstat_read_pda_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pda_1",
    &setup_fstat_read_pda_1_common,
    { { &setup_fstat_read_pda_1_proc0 }, { &setup_fstat_read_pda_1_proc1 } },
    &setup_fstat_read_pfa_0_procfinal,
    &setup_fstat_read_pfa_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pda_2",
    &setup_fstat_read_pfa_1_common,
    { { &setup_fstat_read_pfa_3_proc0 }, { &setup_fstat_read_pfa_3_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pd8_0",
    &setup_fstat_read_pf8_0_common,
    { { &setup_fstat_read_pfb_2_proc0 }, { &setup_fstat_read_pfb_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pd8_1",
    &setup_fstat_read_pf8_0_common,
    { { &setup_fstat_read_pfc_2_proc0 }, { &setup_fstat_read_pfb_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pd4_0",
    &setup_fstat_read_pd4_0_common,
    { { &setup_fstat_read_pfb_2_proc0 }, { &setup_fstat_read_pd4_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pd4_1",
    &setup_fstat_read_pd4_0_common,
    { { &setup_fstat_read_pfc_2_proc0 }, { &setup_fstat_read_pd4_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pd0_0",
    &setup_fstat_read_pf0_0_common,
    { { &setup_fstat_read_pfb_2_proc0 }, { &setup_fstat_read_pd0_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pd0_1",
    &setup_fstat_read_pf0_0_common,
    { { &setup_fstat_read_pfc_2_proc0 }, { &setup_fstat_read_pd0_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pc_0",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pfb_2_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pc_1",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pfc_2_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pfc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_pbc_0",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pbc_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pbc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pbb_0",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_pbb_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pbb_0_0, 0, "fstat" },
      { &test_fstat_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pba_0",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_pba_0_proc0 }, { &setup_fstat_read_pfa_3_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pbb_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pb8_0",
    &setup_fstat_read_pf8_0_common,
    { { &setup_fstat_read_pbb_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pbb_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pb4_0",
    &setup_fstat_read_pb4_0_common,
    { { &setup_fstat_read_pb4_0_proc0 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_pbc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pb4_1",
    &setup_fstat_read_pb4_0_common,
    { { &setup_fstat_read_pb4_1_proc0 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_pbc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pb2_0",
    &setup_fstat_read_pb2_0_common,
    { { &setup_fstat_read_pb2_0_proc0 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb2_0_final,
    { { &test_fstat_read_pb2_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pb2_1",
    &setup_fstat_read_pb2_1_common,
    { { &setup_fstat_read_pb4_0_proc0 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_pb2_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pb2_2",
    &setup_fstat_read_pb2_1_common,
    { { &setup_fstat_read_pb4_1_proc0 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_pb2_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_pa_0",
    &setup_fstat_read_pb4_0_common,
    { { &setup_fstat_read_pb4_1_proc0 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_pbc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_p9c_0",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pd0_0_proc1 }, { &setup_fstat_read_pfc_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pbc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p9b_0",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_p9b_0_proc0 }, { &setup_fstat_read_pfb_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pbb_0_0, 0, "fstat" },
      { &test_fstat_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p9a_0",
    &setup_fstat_read_pfa_1_common,
    { { &setup_fstat_read_p9a_0_proc0 }, { &setup_fstat_read_pfa_3_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_p9a_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p98_0",
    &setup_fstat_read_pf8_0_common,
    { { &setup_fstat_read_p9b_0_proc0 }, { &setup_fstat_read_pfb_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_pbb_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p94_0",
    &setup_fstat_read_pb4_0_common,
    { { &setup_fstat_read_p94_0_proc0 }, { &setup_fstat_read_p94_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_pbc_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p92_0",
    &setup_fstat_read_pb2_0_common,
    { { &setup_fstat_read_pb4_1_proc0 }, { &setup_fstat_read_p92_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb2_0_final,
    { { &test_fstat_read_pb2_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p92_1",
    &setup_fstat_read_pb2_1_common,
    { { &setup_fstat_read_pb4_1_proc0 }, { &setup_fstat_read_pb4_1_proc0 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_pb2_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p8_0",
    &setup_fstat_read_pb4_0_common,
    { { &setup_fstat_read_pb4_1_proc0 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_pbc_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p78_0",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_p78_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_p76_0",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_p76_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_p74_0",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_p74_0_proc0 }, { &setup_fstat_read_pfa_3_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_p70_0",
    &setup_fstat_read_pf8_0_common,
    { { &setup_fstat_read_p76_0_proc0 }, { &setup_fstat_read_pfc_0_proc1 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_p68_0",
    &setup_fstat_read_pb4_0_common,
    { { &setup_fstat_read_p68_0_proc0 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_p60_0",
    &setup_fstat_read_pb2_1_common,
    { { &setup_fstat_read_p68_0_proc0 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_p4_0",
    &setup_fstat_read_p4_0_common,
    { { &setup_fstat_read_pb4_0_proc1 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_procfinal,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_p4_1",
    &setup_fstat_read_p4_0_common,
    { { &setup_fstat_read_pb4_0_proc1 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_procfinal,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_2_1, 0, "read" } },
    &cleanup },
  { "fs-fstat_read_p38_0",
    &setup_fstat_read_pfc_0_common,
    { { &setup_fstat_read_pfc_0_proc1 }, { &setup_fstat_read_pfc_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p36_0",
    &setup_fstat_read_pfb_0_common,
    { { &setup_fstat_read_pfc_0_proc1 }, { &setup_fstat_read_pfb_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p34_0",
    &setup_fstat_read_pfa_1_common,
    { { &setup_fstat_read_pfa_3_proc1 }, { &setup_fstat_read_pfa_3_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p30_0",
    &setup_fstat_read_pf8_0_common,
    { { &setup_fstat_read_pfc_0_proc1 }, { &setup_fstat_read_pfb_2_proc0 } },
    &setup_fstat_read_pfc_0_procfinal,
    &setup_fstat_read_pfc_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p28_0",
    &setup_fstat_read_pb4_0_common,
    { { &setup_fstat_read_pb4_0_proc1 }, { &setup_fstat_read_p94_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p20_0",
    &setup_fstat_read_pb2_1_common,
    { { &setup_fstat_read_pb4_0_proc1 }, { &setup_fstat_read_pb4_1_proc0 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_final,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_read_p0_0",
    &setup_fstat_read_p4_0_common,
    { { &setup_fstat_read_pb4_0_proc1 }, { &setup_fstat_read_pb4_0_proc1 } },
    &setup_fstat_read_pb4_0_procfinal,
    &setup_fstat_read_pb4_0_procfinal,
    { { &test_fstat_read_p78_0_0, 0, "fstat" },
      { &test_fstat_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-fstat_rename_pf_0",
    &setup_fstat_rename_pf_0_common,
    { { &setup_fstat_rename_pf_0_proc0 }, { &setup_fstat_rename_pf_0_proc1 } },
    &setup_fstat_rename_pf_0_procfinal,
    &setup_fstat_rename_pf_0_final,
    { { &test_fstat_rename_pf_0_0, 0, "fstat" },
      { &test_fstat_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pf_1",
    &setup_fstat_rename_pf_0_common,
    { { &setup_fstat_rename_pf_1_proc0 }, { &setup_fstat_rename_pf_0_proc1 } },
    &setup_fstat_rename_pf_0_procfinal,
    &setup_fstat_rename_pf_0_final,
    { { &test_fstat_rename_pf_0_0, 0, "fstat" },
      { &test_fstat_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pe8_0",
    &setup_fstat_rename_pe8_0_common,
    { { &setup_fstat_rename_pf_0_proc0 }, { &setup_fstat_rename_pf_0_proc1 } },
    &setup_fstat_rename_pf_0_procfinal,
    &setup_fstat_rename_pf_0_final,
    { { &test_fstat_rename_pf_0_0, 0, "fstat" },
      { &test_fstat_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pe8_1",
    &setup_fstat_rename_pe8_0_common,
    { { &setup_fstat_rename_pf_1_proc0 }, { &setup_fstat_rename_pf_0_proc1 } },
    &setup_fstat_rename_pf_0_procfinal,
    &setup_fstat_rename_pf_0_final,
    { { &test_fstat_rename_pf_0_0, 0, "fstat" },
      { &test_fstat_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pe0_0",
    &setup_fstat_rename_pf_0_common,
    { { &setup_fstat_rename_pf_0_proc0 }, { &setup_fstat_rename_pf_0_proc1 } },
    &setup_fstat_rename_pf_0_procfinal,
    &setup_fstat_rename_pf_0_final,
    { { &test_fstat_rename_pf_0_0, 0, "fstat" },
      { &test_fstat_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pe0_1",
    &setup_fstat_rename_pf_0_common,
    { { &setup_fstat_rename_pf_1_proc0 }, { &setup_fstat_rename_pf_0_proc1 } },
    &setup_fstat_rename_pf_0_procfinal,
    &setup_fstat_rename_pf_0_final,
    { { &test_fstat_rename_pf_0_0, 0, "fstat" },
      { &test_fstat_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pc_0",
    &setup_fstat_rename_pc_0_common,
    { { &setup_fstat_rename_pf_0_proc0 }, { &setup_fstat_rename_pf_0_proc1 } },
    &setup_fstat_rename_pf_0_procfinal,
    &setup_fstat_rename_pf_0_final,
    { { &test_fstat_rename_pf_0_0, 0, "fstat" },
      { &test_fstat_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pc_1",
    &setup_fstat_rename_pc_0_common,
    { { &setup_fstat_rename_pf_1_proc0 }, { &setup_fstat_rename_pf_0_proc1 } },
    &setup_fstat_rename_pf_0_procfinal,
    &setup_fstat_rename_pf_0_final,
    { { &test_fstat_rename_pf_0_0, 0, "fstat" },
      { &test_fstat_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pb_0",
    &setup_fstat_rename_pb_0_common,
    { { &setup_fstat_rename_pb_0_proc0 }, { &setup_fstat_rename_pb_0_proc1 } },
    &setup_fstat_rename_pb_0_procfinal,
    &setup_fstat_rename_pb_0_final,
    { { &test_fstat_rename_pb_0_0, 0, "fstat" },
      { &test_fstat_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pac_0",
    &setup_fstat_rename_pac_0_common,
    { { &setup_fstat_rename_pac_0_proc0 }, { &setup_fstat_rename_pb_0_proc1 } },
    &setup_fstat_rename_pb_0_procfinal,
    &setup_fstat_rename_pac_0_final,
    { { &test_fstat_rename_pac_0_0, 0, "fstat" },
      { &test_fstat_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pac_1",
    &setup_fstat_rename_pac_1_common,
    { { &setup_fstat_rename_pac_1_proc0 }, { &setup_fstat_rename_pb_0_proc1 } },
    &setup_fstat_rename_pb_0_procfinal,
    &setup_fstat_rename_pac_1_final,
    { { &test_fstat_rename_pac_0_0, 0, "fstat" },
      { &test_fstat_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_pa0_0",
    &setup_fstat_rename_pb_0_common,
    { { &setup_fstat_rename_pb_0_proc0 }, { &setup_fstat_rename_pb_0_proc1 } },
    &setup_fstat_rename_pb_0_procfinal,
    &setup_fstat_rename_pb_0_final,
    { { &test_fstat_rename_pb_0_0, 0, "fstat" },
      { &test_fstat_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_p8_0",
    &setup_fstat_rename_p8_0_common,
    { { &setup_fstat_rename_pb_0_proc0 }, { &setup_fstat_rename_pb_0_proc1 } },
    &setup_fstat_rename_pb_0_procfinal,
    &setup_fstat_rename_pb_0_final,
    { { &test_fstat_rename_pb_0_0, 0, "fstat" },
      { &test_fstat_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_p6_0",
    &setup_fstat_rename_pb_0_common,
    { { &setup_fstat_rename_pb_0_proc1 }, { &setup_fstat_rename_pb_0_proc1 } },
    &setup_fstat_rename_pb_0_procfinal,
    &setup_fstat_rename_pb_0_final,
    { { &test_fstat_rename_p6_0_0, 0, "fstat" },
      { &test_fstat_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_p50_0",
    &setup_fstat_rename_p50_0_common,
    { { &setup_fstat_rename_pb_0_proc1 }, { &setup_fstat_rename_pb_0_proc1 } },
    &setup_fstat_rename_pb_0_procfinal,
    &setup_fstat_rename_pb_0_final,
    { { &test_fstat_rename_p6_0_0, 0, "fstat" },
      { &test_fstat_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_p4_0",
    &setup_fstat_rename_pb_0_common,
    { { &setup_fstat_rename_pb_0_proc1 }, { &setup_fstat_rename_pb_0_proc1 } },
    &setup_fstat_rename_pb_0_procfinal,
    &setup_fstat_rename_pb_0_final,
    { { &test_fstat_rename_p6_0_0, 0, "fstat" },
      { &test_fstat_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_rename_p0_0",
    &setup_fstat_rename_p0_0_common,
    { { &setup_fstat_rename_pb_0_proc1 }, { &setup_fstat_rename_pb_0_proc1 } },
    &setup_fstat_rename_pb_0_procfinal,
    &setup_fstat_rename_pb_0_procfinal,
    { { &test_fstat_rename_p6_0_0, 0, "fstat" },
      { &test_fstat_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-fstat_stat_pe_0",
    &setup_fstat_stat_pe_0_common,
    { { &setup_fstat_stat_pe_0_proc0 }, { &setup_fstat_stat_pe_0_proc1 } },
    &setup_fstat_stat_pe_0_procfinal,
    &setup_fstat_stat_pe_0_final,
    { { &test_fstat_stat_pe_0_0, 0, "fstat" },
      { &test_fstat_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-fstat_stat_pe_1",
    &setup_fstat_stat_pe_0_common,
    { { &setup_fstat_stat_pe_1_proc0 }, { &setup_fstat_stat_pe_0_proc1 } },
    &setup_fstat_stat_pe_0_procfinal,
    &setup_fstat_stat_pe_0_final,
    { { &test_fstat_stat_pe_0_0, 0, "fstat" },
      { &test_fstat_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-fstat_stat_pc_0",
    &setup_fstat_stat_pc_0_common,
    { { &setup_fstat_stat_pe_0_proc0 }, { &setup_fstat_stat_pe_0_proc1 } },
    &setup_fstat_stat_pe_0_procfinal,
    &setup_fstat_stat_pe_0_final,
    { { &test_fstat_stat_pe_0_0, 0, "fstat" },
      { &test_fstat_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-fstat_stat_pc_1",
    &setup_fstat_stat_pc_0_common,
    { { &setup_fstat_stat_pe_1_proc0 }, { &setup_fstat_stat_pe_0_proc1 } },
    &setup_fstat_stat_pe_0_procfinal,
    &setup_fstat_stat_pe_0_final,
    { { &test_fstat_stat_pe_0_0, 0, "fstat" },
      { &test_fstat_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-fstat_stat_pa_0",
    &setup_fstat_stat_pa_0_common,
    { { &setup_fstat_stat_pa_0_proc0 }, { &setup_fstat_stat_pa_0_proc1 } },
    &setup_fstat_stat_pa_0_procfinal,
    &setup_fstat_stat_pa_0_final,
    { { &test_fstat_stat_pa_0_0, 0, "fstat" },
      { &test_fstat_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-fstat_stat_p8_0",
    &setup_fstat_stat_p8_0_common,
    { { &setup_fstat_stat_pa_0_proc0 }, { &setup_fstat_stat_pa_0_proc1 } },
    &setup_fstat_stat_pa_0_procfinal,
    &setup_fstat_stat_pa_0_final,
    { { &test_fstat_stat_pa_0_0, 0, "fstat" },
      { &test_fstat_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-fstat_stat_p4_0",
    &setup_fstat_stat_pa_0_common,
    { { &setup_fstat_stat_pa_0_proc1 }, { &setup_fstat_stat_pa_0_proc1 } },
    &setup_fstat_stat_pa_0_procfinal,
    &setup_fstat_stat_pa_0_final,
    { { &test_fstat_stat_p4_0_0, 0, "fstat" },
      { &test_fstat_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-fstat_stat_p0_0",
    &setup_fstat_stat_p0_0_common,
    { { &setup_fstat_stat_pa_0_proc1 }, { &setup_fstat_stat_pa_0_proc1 } },
    &setup_fstat_stat_pa_0_procfinal,
    &setup_fstat_stat_pa_0_procfinal,
    { { &test_fstat_stat_p4_0_0, 0, "fstat" },
      { &test_fstat_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-fstat_unlink_pe_0",
    &setup_fstat_unlink_pe_0_common,
    { { &setup_fstat_unlink_pe_0_proc0 }, { &setup_fstat_unlink_pe_0_proc1 } },
    &setup_fstat_unlink_pe_0_procfinal,
    &setup_fstat_unlink_pe_0_final,
    { { &test_fstat_unlink_pe_0_0, 0, "fstat" },
      { &test_fstat_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-fstat_unlink_pe_1",
    &setup_fstat_unlink_pe_0_common,
    { { &setup_fstat_unlink_pe_1_proc0 }, { &setup_fstat_unlink_pe_0_proc1 } },
    &setup_fstat_unlink_pe_0_procfinal,
    &setup_fstat_unlink_pe_0_final,
    { { &test_fstat_unlink_pe_0_0, 0, "fstat" },
      { &test_fstat_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-fstat_unlink_pc_0",
    &setup_fstat_unlink_pc_0_common,
    { { &setup_fstat_unlink_pe_0_proc0 }, { &setup_fstat_unlink_pe_0_proc1 } },
    &setup_fstat_unlink_pe_0_procfinal,
    &setup_fstat_unlink_pe_0_final,
    { { &test_fstat_unlink_pe_0_0, 0, "fstat" },
      { &test_fstat_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-fstat_unlink_pc_1",
    &setup_fstat_unlink_pc_0_common,
    { { &setup_fstat_unlink_pe_1_proc0 }, { &setup_fstat_unlink_pe_0_proc1 } },
    &setup_fstat_unlink_pe_0_procfinal,
    &setup_fstat_unlink_pe_0_final,
    { { &test_fstat_unlink_pe_0_0, 0, "fstat" },
      { &test_fstat_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-fstat_unlink_pb0_0",
    &setup_fstat_unlink_pb0_0_common,
    { { &setup_fstat_unlink_pb0_0_proc0 }, { &setup_fstat_unlink_pb0_0_proc1 } },
    &setup_fstat_unlink_pb0_0_procfinal,
    &setup_fstat_unlink_pb0_0_final,
    { { &test_fstat_unlink_pb0_0_0, 0, "fstat" },
      { &test_fstat_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-fstat_unlink_p8_0",
    &setup_fstat_unlink_p8_0_common,
    { { &setup_fstat_unlink_p8_0_proc0 }, { &setup_fstat_unlink_pb0_0_proc1 } },
    &setup_fstat_unlink_pb0_0_procfinal,
    &setup_fstat_unlink_p8_0_final,
    { { &test_fstat_unlink_p8_0_0, 0, "fstat" },
      { &test_fstat_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-fstat_unlink_p4_0",
    &setup_fstat_unlink_p4_0_common,
    { { &setup_fstat_unlink_pb0_0_proc1 }, { &setup_fstat_unlink_pb0_0_proc1 } },
    &setup_fstat_unlink_pb0_0_procfinal,
    &setup_fstat_unlink_p8_0_final,
    { { &test_fstat_unlink_p4_0_0, 0, "fstat" },
      { &test_fstat_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-fstat_unlink_p0_0",
    &setup_fstat_unlink_p0_0_common,
    { { &setup_fstat_unlink_pb0_0_proc1 }, { &setup_fstat_unlink_pb0_0_proc1 } },
    &setup_fstat_unlink_pb0_0_procfinal,
    &setup_fstat_unlink_pb0_0_procfinal,
    { { &test_fstat_unlink_p4_0_0, 0, "fstat" },
      { &test_fstat_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-fstat_write_pfe_0",
    &setup_fstat_write_pfe_0_common,
    { { &setup_fstat_write_pfe_0_proc0 }, { &setup_fstat_write_pfe_0_proc1 } },
    &setup_fstat_write_pfe_0_procfinal,
    &setup_fstat_write_pfe_0_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pfe_1",
    &setup_fstat_write_pfe_1_common,
    { { &setup_fstat_write_pfe_1_proc0 }, { &setup_fstat_write_pfe_1_proc1 } },
    &setup_fstat_write_pfe_1_procfinal,
    &setup_fstat_write_pfe_1_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pfe_2",
    &setup_fstat_write_pfe_2_common,
    { { &setup_fstat_write_pfe_2_proc0 }, { &setup_fstat_write_pfe_2_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pfe_3",
    &setup_fstat_write_pfe_2_common,
    { { &setup_fstat_write_pfe_3_proc0 }, { &setup_fstat_write_pfe_2_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_3_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pfc_0",
    &setup_fstat_write_pfc_0_common,
    { { &setup_fstat_write_pfc_0_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pfc_1",
    &setup_fstat_write_pfc_0_common,
    { { &setup_fstat_write_pfc_1_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pfc_2",
    &setup_fstat_write_pfc_0_common,
    { { &setup_fstat_write_pfc_2_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pf8_0",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pf8_0_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pf8_1",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pf8_1_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pf8_2",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pf8_2_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_2_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pf4_0",
    &setup_fstat_write_pf4_0_common,
    { { &setup_fstat_write_pf4_0_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pf4_1",
    &setup_fstat_write_pf4_1_common,
    { { &setup_fstat_write_pf4_1_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pf0_0",
    &setup_fstat_write_pf0_0_common,
    { { &setup_fstat_write_pf4_0_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pf0_1",
    &setup_fstat_write_pf0_1_common,
    { { &setup_fstat_write_pf4_1_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pe_0",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pf8_2_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pe_1",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pfc_2_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pde_0",
    &setup_fstat_write_pde_0_common,
    { { &setup_fstat_write_pde_0_proc0 }, { &setup_fstat_write_pde_0_proc1 } },
    &setup_fstat_write_pfe_0_procfinal,
    &setup_fstat_write_pfe_0_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pde_1",
    &setup_fstat_write_pde_0_common,
    { { &setup_fstat_write_pde_1_proc0 }, { &setup_fstat_write_pde_0_proc1 } },
    &setup_fstat_write_pfe_0_procfinal,
    &setup_fstat_write_pfe_0_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pde_2",
    &setup_fstat_write_pde_2_common,
    { { &setup_fstat_write_pfe_3_proc0 }, { &setup_fstat_write_pfe_3_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pdc_0",
    &setup_fstat_write_pfc_0_common,
    { { &setup_fstat_write_pf8_2_proc0 }, { &setup_fstat_write_pfc_2_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pdc_1",
    &setup_fstat_write_pfc_0_common,
    { { &setup_fstat_write_pfc_2_proc0 }, { &setup_fstat_write_pfc_2_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pd8_0",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pf8_2_proc0 }, { &setup_fstat_write_pf8_2_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pd8_1",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pfc_2_proc0 }, { &setup_fstat_write_pf8_2_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pd4_0",
    &setup_fstat_write_pf4_0_common,
    { { &setup_fstat_write_pf8_2_proc0 }, { &setup_fstat_write_pd4_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pd4_1",
    &setup_fstat_write_pf4_0_common,
    { { &setup_fstat_write_pfc_2_proc0 }, { &setup_fstat_write_pd4_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pd0_0",
    &setup_fstat_write_pf0_0_common,
    { { &setup_fstat_write_pf8_2_proc0 }, { &setup_fstat_write_pd4_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pd0_1",
    &setup_fstat_write_pf0_0_common,
    { { &setup_fstat_write_pfc_2_proc0 }, { &setup_fstat_write_pd4_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pc_0",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pf8_2_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pc_1",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pfc_2_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pfe_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_pbe_0",
    &setup_fstat_write_pfe_2_common,
    { { &setup_fstat_write_pbe_0_proc0 }, { &setup_fstat_write_pfe_2_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pbe_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pbc_0",
    &setup_fstat_write_pfc_0_common,
    { { &setup_fstat_write_pbc_0_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pbe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pb8_0",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pb8_0_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pb8_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pb6_0",
    &setup_fstat_write_pb6_0_common,
    { { &setup_fstat_write_pb6_0_proc0 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb6_0_final,
    { { &test_fstat_write_pb6_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pb30_0",
    &setup_fstat_write_pb30_0_common,
    { { &setup_fstat_write_pb6_0_proc0 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb6_0_final,
    { { &test_fstat_write_pb30_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pb30_1",
    &setup_fstat_write_pb30_1_common,
    { { &setup_fstat_write_pb30_1_proc0 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb30_1_final,
    { { &test_fstat_write_pb30_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pb30_2",
    &setup_fstat_write_pb30_1_common,
    { { &setup_fstat_write_pb30_2_proc0 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb30_1_final,
    { { &test_fstat_write_pb30_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_pa_0",
    &setup_fstat_write_pa_0_common,
    { { &setup_fstat_write_pb30_2_proc0 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb30_1_final,
    { { &test_fstat_write_pb8_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_p9e_0",
    &setup_fstat_write_pde_2_common,
    { { &setup_fstat_write_p9e_0_proc0 }, { &setup_fstat_write_pfe_3_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_p9e_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p9c_0",
    &setup_fstat_write_pfc_0_common,
    { { &setup_fstat_write_p9c_0_proc0 }, { &setup_fstat_write_pfc_2_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pbe_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p98_0",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pd4_0_proc1 }, { &setup_fstat_write_pf8_2_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_pb8_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p96_0",
    &setup_fstat_write_pb6_0_common,
    { { &setup_fstat_write_pb30_2_proc0 }, { &setup_fstat_write_p96_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb6_0_final,
    { { &test_fstat_write_pb6_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p930_0",
    &setup_fstat_write_pb30_0_common,
    { { &setup_fstat_write_pb30_2_proc0 }, { &setup_fstat_write_p96_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb6_0_final,
    { { &test_fstat_write_pb30_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p930_1",
    &setup_fstat_write_pb30_1_common,
    { { &setup_fstat_write_pb30_2_proc0 }, { &setup_fstat_write_pb30_2_proc0 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb30_1_final,
    { { &test_fstat_write_pb30_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p8_0",
    &setup_fstat_write_pa_0_common,
    { { &setup_fstat_write_pb30_2_proc0 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb30_1_final,
    { { &test_fstat_write_pb8_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p7c_0",
    &setup_fstat_write_pfe_2_common,
    { { &setup_fstat_write_p7c_0_proc0 }, { &setup_fstat_write_pfe_2_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_p78_0",
    &setup_fstat_write_pfc_0_common,
    { { &setup_fstat_write_p78_0_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_p70_0",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_p70_0_proc0 }, { &setup_fstat_write_pfc_0_proc1 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_p68_0",
    &setup_fstat_write_pa_0_common,
    { { &setup_fstat_write_p68_0_proc0 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb30_1_final,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_p60_0",
    &setup_fstat_write_pb30_1_common,
    { { &setup_fstat_write_p68_0_proc0 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb30_1_final,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_p4_0",
    &setup_fstat_write_p4_0_common,
    { { &setup_fstat_write_pb6_0_proc1 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb6_0_procfinal,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_p4_1",
    &setup_fstat_write_p4_0_common,
    { { &setup_fstat_write_pb6_0_proc1 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb6_0_procfinal,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_2_1, 0, "write" } },
    &cleanup },
  { "fs-fstat_write_p3c_0",
    &setup_fstat_write_pde_2_common,
    { { &setup_fstat_write_pfe_2_proc1 }, { &setup_fstat_write_pfe_3_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p38_0",
    &setup_fstat_write_pfc_0_common,
    { { &setup_fstat_write_pfc_0_proc1 }, { &setup_fstat_write_pfc_2_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p30_0",
    &setup_fstat_write_pf8_0_common,
    { { &setup_fstat_write_pfc_0_proc1 }, { &setup_fstat_write_pf8_2_proc0 } },
    &setup_fstat_write_pfe_2_procfinal,
    &setup_fstat_write_pfe_2_final,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p28_0",
    &setup_fstat_write_pa_0_common,
    { { &setup_fstat_write_pb6_0_proc1 }, { &setup_fstat_write_pb30_2_proc0 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb30_1_final,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p20_0",
    &setup_fstat_write_pb30_1_common,
    { { &setup_fstat_write_pb6_0_proc1 }, { &setup_fstat_write_pb30_2_proc0 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb30_1_final,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-fstat_write_p0_0",
    &setup_fstat_write_p4_0_common,
    { { &setup_fstat_write_pb6_0_proc1 }, { &setup_fstat_write_pb6_0_proc1 } },
    &setup_fstat_write_pb6_0_procfinal,
    &setup_fstat_write_pb6_0_procfinal,
    { { &test_fstat_write_p7c_0_0, 0, "fstat" },
      { &test_fstat_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-link_link_pf_0",
    &setup_link_link_pf_0_common,
    { { &setup_link_link_pf_0_proc0 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_0_0, 0, "link" },
      { &test_link_link_pf_0_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pf_1",
    &setup_link_link_pf_1_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_0_0, 0, "link" },
      { &test_link_link_pf_1_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pf_2",
    &setup_link_link_pf_1_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_2_0, 0, "link" },
      { &test_link_link_pf_2_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pf_3",
    &setup_link_link_pf_1_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_0_0, 0, "link" },
      { &test_link_link_pf_3_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pf_4",
    &setup_link_link_pf_4_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_0_0, 0, "link" },
      { &test_link_link_pf_4_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pf_5",
    &setup_link_link_pf_4_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_2_0, 0, "link" },
      { &test_link_link_pf_4_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pf_6",
    &setup_link_link_pf_4_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_2_0, 0, "link" },
      { &test_link_link_pf_0_0, 0, "link" } },
    &cleanup },
  { "fs-link_link_pf_7",
    &setup_link_link_pf_7_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_2_0, 0, "link" },
      { &test_link_link_pf_2_0, 0, "link" } },
    &cleanup },
  { "fs-link_link_pe0_0",
    &setup_link_link_pf_1_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_0_0, 0, "link" },
      { &test_link_link_pe0_0_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pe0_1",
    &setup_link_link_pf_4_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_0_0, 0, "link" },
      { &test_link_link_pe0_1_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pe0_2",
    &setup_link_link_pf_4_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_2_0, 0, "link" },
      { &test_link_link_pe0_2_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pe0_3",
    &setup_link_link_pf_7_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_2_0, 0, "link" },
      { &test_link_link_pe0_3_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pc_0",
    &setup_link_link_pf_4_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_0_0, 0, "link" },
      { &test_link_link_pc_0_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pc_1",
    &setup_link_link_pf_7_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pf_2_0, 0, "link" },
      { &test_link_link_pc_1_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pbc_0",
    &setup_link_link_pbc_0_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pe0_3_1, 0, "link" },
      { &test_link_link_pf_0_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pbc_1",
    &setup_link_link_pbc_1_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pe0_3_1, 0, "link" },
      { &test_link_link_pf_1_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pbc_2",
    &setup_link_link_pbc_1_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pe0_3_1, 0, "link" },
      { &test_link_link_pf_3_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pbc_3",
    &setup_link_link_pf_7_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pe0_3_1, 0, "link" },
      { &test_link_link_pf_2_0, 0, "link" } },
    &cleanup },
  { "fs-link_link_pa8_0",
    &setup_link_link_pa8_0_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pa8_0_final,
    { { &test_link_link_pe0_3_1, 0, "link" },
      { &test_link_link_pe0_0_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pa8_1",
    &setup_link_link_pbc_1_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pe0_3_1, 0, "link" },
      { &test_link_link_pe0_0_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_pa8_2",
    &setup_link_link_pa8_2_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pe0_3_1, 0, "link" },
      { &test_link_link_pe0_1_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_p8_0",
    &setup_link_link_pf_7_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_pe0_3_1, 0, "link" },
      { &test_link_link_pc_0_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_p6_0",
    &setup_link_link_p6_0_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_p6_0_0, 0, "link" },
      { &test_link_link_p6_0_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_p6_1",
    &setup_link_link_p6_1_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_p6_1_0, 0, "link" },
      { &test_link_link_p6_1_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_p40_0",
    &setup_link_link_p40_0_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_p6_0_0, 0, "link" },
      { &test_link_link_p40_0_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_p40_1",
    &setup_link_link_p6_0_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_final,
    { { &test_link_link_p6_0_0, 0, "link" },
      { &test_link_link_pe0_0_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_p0_0",
    &setup_link_link_p0_0_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_procfinal,
    { { &test_link_link_p6_1_0, 0, "link" },
      { &test_link_link_pc_1_1, 0, "link" } },
    &cleanup },
  { "fs-link_link_p0_1",
    &setup_link_link_p0_0_common,
    { { &setup_link_link_pf_0_proc1 }, { &setup_link_link_pf_0_proc1 } },
    &setup_link_link_pf_0_procfinal,
    &setup_link_link_pf_0_procfinal,
    { { &test_link_link_p6_1_0, 0, "link" },
      { &test_link_link_p6_1_0, 0, "link" } },
    &cleanup },
  { "fs-link_lseek_pf8_0",
    &setup_link_lseek_pf8_0_common,
    { { &setup_link_lseek_pf8_0_proc0 }, { &setup_link_lseek_pf8_0_proc1 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf8_1",
    &setup_link_lseek_pf8_0_common,
    { { &setup_link_lseek_pf8_1_proc0 }, { &setup_link_lseek_pf8_0_proc1 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf8_2",
    &setup_link_lseek_pf8_2_common,
    { { &setup_link_lseek_pf8_0_proc0 }, { &setup_link_lseek_pf8_0_proc1 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf8_3",
    &setup_link_lseek_pf8_2_common,
    { { &setup_link_lseek_pf8_1_proc0 }, { &setup_link_lseek_pf8_0_proc1 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf6_0",
    &setup_link_lseek_pf6_0_common,
    { { &setup_link_lseek_pf6_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf6_1",
    &setup_link_lseek_pf6_1_common,
    { { &setup_link_lseek_pf6_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf4_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf4_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf3_0",
    &setup_link_lseek_pf3_0_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf3_1",
    &setup_link_lseek_pf6_1_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf2_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf2_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf18_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf18_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf18_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf18_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf10_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf10_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf0_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pf0_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pe_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pe_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd8_0",
    &setup_link_lseek_pf8_0_common,
    { { &setup_link_lseek_pf8_0_proc1 }, { &setup_link_lseek_pf8_0_proc0 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd8_1",
    &setup_link_lseek_pf8_0_common,
    { { &setup_link_lseek_pf8_0_proc1 }, { &setup_link_lseek_pf8_1_proc0 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd8_2",
    &setup_link_lseek_pf8_2_common,
    { { &setup_link_lseek_pf8_0_proc1 }, { &setup_link_lseek_pf8_0_proc0 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd8_3",
    &setup_link_lseek_pf8_2_common,
    { { &setup_link_lseek_pf8_0_proc1 }, { &setup_link_lseek_pf8_1_proc0 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd6_0",
    &setup_link_lseek_pf6_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pd6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd6_1",
    &setup_link_lseek_pf6_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pd6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd4_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd4_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd3_0",
    &setup_link_lseek_pf3_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd3_1",
    &setup_link_lseek_pf6_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd2_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd2_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd18_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pd18_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd18_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pd18_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd10_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd10_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd0_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pd0_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pc_0",
    &setup_link_lseek_pf4_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_0_0, 0, "link" },
      { &test_link_lseek_pe_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pc_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pf8_2_0, 0, "link" },
      { &test_link_lseek_pe_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb8_0",
    &setup_link_lseek_pb8_0_common,
    { { &setup_link_lseek_pf8_0_proc0 }, { &setup_link_lseek_pf8_0_proc1 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb8_1",
    &setup_link_lseek_pb8_0_common,
    { { &setup_link_lseek_pf8_1_proc0 }, { &setup_link_lseek_pf8_0_proc1 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb6_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pb6_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb4_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pb6_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb4_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pb4_1_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb4_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb30_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pb4_1_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb30_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb20_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pb20_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb20_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb20_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pd18_0_proc1 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb20_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb18_0",
    &setup_link_lseek_pb18_0_common,
    { { &setup_link_lseek_pb6_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pb18_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb18_1",
    &setup_link_lseek_pb18_1_common,
    { { &setup_link_lseek_pb6_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb10_0",
    &setup_link_lseek_pb10_0_common,
    { { &setup_link_lseek_pb6_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pb18_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb10_1",
    &setup_link_lseek_pb10_1_common,
    { { &setup_link_lseek_pb10_1_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb10_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb10_2",
    &setup_link_lseek_pb10_2_common,
    { { &setup_link_lseek_pf18_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pb18_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb10_3",
    &setup_link_lseek_pb10_3_common,
    { { &setup_link_lseek_pf18_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pb00_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pb6_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_pa0_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p98_0",
    &setup_link_lseek_pb8_0_common,
    { { &setup_link_lseek_pf8_0_proc1 }, { &setup_link_lseek_pf8_0_proc0 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p98_1",
    &setup_link_lseek_pb8_0_common,
    { { &setup_link_lseek_pf8_0_proc1 }, { &setup_link_lseek_pf8_1_proc0 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p96_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb6_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pf6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p94_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb6_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pf4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p94_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb4_1_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb4_1_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p930_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb4_1_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb30_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p920_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb20_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb20_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p920_1",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb4_1_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_p920_1_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p918_0",
    &setup_link_lseek_pb18_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb6_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pb18_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p918_1",
    &setup_link_lseek_pb18_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb6_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p910_0",
    &setup_link_lseek_pb10_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb6_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pb18_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p910_1",
    &setup_link_lseek_pb10_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb10_1_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb10_1_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p910_2",
    &setup_link_lseek_pb10_2_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf18_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pb18_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pb10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p910_3",
    &setup_link_lseek_pb18_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pd6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_p910_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p900_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pb6_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p80_0",
    &setup_link_lseek_pf4_1_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_pb8_0_0, 0, "link" },
      { &test_link_lseek_pe_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p7_0",
    &setup_link_lseek_p7_0_common,
    { { &setup_link_lseek_pf8_0_proc0 }, { &setup_link_lseek_pf8_0_proc1 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p7_1",
    &setup_link_lseek_p7_0_common,
    { { &setup_link_lseek_pf8_1_proc0 }, { &setup_link_lseek_pf8_0_proc1 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p6c_0",
    &setup_link_lseek_p6c_0_common,
    { { &setup_link_lseek_pf6_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p68_0",
    &setup_link_lseek_p68_0_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p66_0",
    &setup_link_lseek_p66_0_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p64_0",
    &setup_link_lseek_p68_0_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p63_0",
    &setup_link_lseek_p68_0_common,
    { { &setup_link_lseek_pf18_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p62_0",
    &setup_link_lseek_p68_0_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p60_0",
    &setup_link_lseek_p68_0_common,
    { { &setup_link_lseek_pf4_0_proc0 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p4_0",
    &setup_link_lseek_p4_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_procfinal,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p3_0",
    &setup_link_lseek_p7_0_common,
    { { &setup_link_lseek_pf8_0_proc1 }, { &setup_link_lseek_pf8_0_proc0 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p3_1",
    &setup_link_lseek_p7_0_common,
    { { &setup_link_lseek_pf8_0_proc1 }, { &setup_link_lseek_pf8_1_proc0 } },
    &setup_link_lseek_pf8_0_procfinal,
    &setup_link_lseek_pf8_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p2c_0",
    &setup_link_lseek_p6c_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pd6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p28_0",
    &setup_link_lseek_p68_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p26_0",
    &setup_link_lseek_p66_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p24_0",
    &setup_link_lseek_p68_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p23_0",
    &setup_link_lseek_p68_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pd18_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p22_0",
    &setup_link_lseek_p68_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p20_0",
    &setup_link_lseek_p68_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf4_0_proc0 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_final,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pf8_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_lseek_p0_0",
    &setup_link_lseek_p4_0_common,
    { { &setup_link_lseek_pf6_0_proc1 }, { &setup_link_lseek_pf6_0_proc1 } },
    &setup_link_lseek_pf6_0_procfinal,
    &setup_link_lseek_pf6_0_procfinal,
    { { &test_link_lseek_p7_0_0, 0, "link" },
      { &test_link_lseek_pe_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-link_memread_pf8_0",
    &setup_link_memread_pf8_0_common,
    { { &setup_link_memread_pf8_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf8_1",
    &setup_link_memread_pf8_0_common,
    { { &setup_link_memread_pf8_1_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf8_2",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf8_3",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_1_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf4_0",
    &setup_link_memread_pf8_0_common,
    { { &setup_link_memread_pf4_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf4_1",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf4_1_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf4_2",
    &setup_link_memread_pf8_0_common,
    { { &setup_link_memread_pf4_2_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf4_3",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf4_3_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf0_0",
    &setup_link_memread_pf0_0_common,
    { { &setup_link_memread_pf0_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf0_1",
    &setup_link_memread_pf0_0_common,
    { { &setup_link_memread_pf0_1_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf0_2",
    &setup_link_memread_pf0_2_common,
    { { &setup_link_memread_pf0_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pf0_3",
    &setup_link_memread_pf0_2_common,
    { { &setup_link_memread_pf0_1_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pe_0",
    &setup_link_memread_pf8_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pe_1",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pd8_0",
    &setup_link_memread_pf8_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd8_1",
    &setup_link_memread_pf8_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_1_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd8_2",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd8_3",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_1_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd4_0",
    &setup_link_memread_pf8_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf0_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd4_1",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pd4_1_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd4_2",
    &setup_link_memread_pf8_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pd4_2_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd4_3",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf0_1_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd0_0",
    &setup_link_memread_pf0_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf0_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd0_1",
    &setup_link_memread_pf0_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf0_1_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd0_2",
    &setup_link_memread_pf0_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf0_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pd0_3",
    &setup_link_memread_pf0_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf0_1_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pc_0",
    &setup_link_memread_pf8_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_0_0, 0, "link" },
      { &test_link_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pc_1",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pf8_2_0, 0, "link" },
      { &test_link_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_pb8_0",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pb8_1",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_1_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pb4_0",
    &setup_link_memread_pb4_0_common,
    { { &setup_link_memread_pb4_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pb4_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pb4_1",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf4_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pb4_2",
    &setup_link_memread_pb4_0_common,
    { { &setup_link_memread_pb4_2_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pb4_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pb4_3",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf4_3_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pb0_0",
    &setup_link_memread_pb0_0_common,
    { { &setup_link_memread_pb0_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pb4_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pb0_1",
    &setup_link_memread_pb0_0_common,
    { { &setup_link_memread_pb0_1_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pb4_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pb0_2",
    &setup_link_memread_pb0_2_common,
    { { &setup_link_memread_pb0_2_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pb0_3",
    &setup_link_memread_pb0_2_common,
    { { &setup_link_memread_pb0_3_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_pa0_0",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_p98_0",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p98_1",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_1_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p94_0",
    &setup_link_memread_p94_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pb4_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pb4_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p94_1",
    &setup_link_memread_pb0_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_p94_1_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p94_2",
    &setup_link_memread_pb0_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_p94_2_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pb4_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p94_3",
    &setup_link_memread_pb0_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_p94_3_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p90_0",
    &setup_link_memread_pb0_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pb0_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pb4_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p90_1",
    &setup_link_memread_pb0_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pb0_1_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pb4_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p90_2",
    &setup_link_memread_pb0_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pb0_2_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p90_3",
    &setup_link_memread_pb0_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pb0_3_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p80_0",
    &setup_link_memread_pf8_2_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_pb8_0_0, 0, "link" },
      { &test_link_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p7_0",
    &setup_link_memread_p7_0_common,
    { { &setup_link_memread_pf8_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_procfinal,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_p7_1",
    &setup_link_memread_p7_0_common,
    { { &setup_link_memread_pf8_1_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_procfinal,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_p68_0",
    &setup_link_memread_p68_0_common,
    { { &setup_link_memread_pf4_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_p68_1",
    &setup_link_memread_p68_0_common,
    { { &setup_link_memread_pf4_3_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_p60_0",
    &setup_link_memread_p60_0_common,
    { { &setup_link_memread_pf0_0_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_p60_1",
    &setup_link_memread_p60_0_common,
    { { &setup_link_memread_pf0_1_proc0 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_p4_0",
    &setup_link_memread_p7_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_procfinal,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-link_memread_p3_0",
    &setup_link_memread_p7_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_procfinal,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p3_1",
    &setup_link_memread_p7_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_1_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_procfinal,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p28_0",
    &setup_link_memread_p68_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf0_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p28_1",
    &setup_link_memread_p68_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf0_1_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p20_0",
    &setup_link_memread_p60_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf0_0_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p20_1",
    &setup_link_memread_p60_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf0_1_proc0 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_final,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memread_p0_0",
    &setup_link_memread_p7_0_common,
    { { &setup_link_memread_pf8_0_proc1 }, { &setup_link_memread_pf8_0_proc1 } },
    &setup_link_memread_pf8_0_procfinal,
    &setup_link_memread_pf8_0_procfinal,
    { { &test_link_memread_p7_0_0, 0, "link" },
      { &test_link_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-link_memwrite_pfc_0",
    &setup_link_memwrite_pfc_0_common,
    { { &setup_link_memwrite_pfc_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pfc_1",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pfa_0",
    &setup_link_memwrite_pfc_0_common,
    { { &setup_link_memwrite_pfa_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pfa_1",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfa_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pf8_0",
    &setup_link_memwrite_pf8_0_common,
    { { &setup_link_memwrite_pf8_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pf8_1",
    &setup_link_memwrite_pf8_1_common,
    { { &setup_link_memwrite_pf8_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pf0_0",
    &setup_link_memwrite_pfc_0_common,
    { { &setup_link_memwrite_pf0_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pf0_1",
    &setup_link_memwrite_pfc_0_common,
    { { &setup_link_memwrite_pf0_1_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pf0_2",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pf0_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pf0_3",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pf0_1_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pe_0",
    &setup_link_memwrite_pfc_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pe_1",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pdc_0",
    &setup_link_memwrite_pfc_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pdc_1",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pda_0",
    &setup_link_memwrite_pfc_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf8_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pda_1",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf8_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pd8_0",
    &setup_link_memwrite_pf8_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf8_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pd8_1",
    &setup_link_memwrite_pf8_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf8_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pd0_0",
    &setup_link_memwrite_pfc_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf0_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pd0_1",
    &setup_link_memwrite_pfc_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf0_1_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pd0_2",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf0_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pd0_3",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf0_1_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pc_0",
    &setup_link_memwrite_pfc_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pc_1",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pfc_1_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pbc_0",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pba_0",
    &setup_link_memwrite_pba_0_common,
    { { &setup_link_memwrite_pba_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pba_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pba_1",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfa_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pb8_0",
    &setup_link_memwrite_pb8_0_common,
    { { &setup_link_memwrite_pb8_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pba_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pb8_1",
    &setup_link_memwrite_pb8_1_common,
    { { &setup_link_memwrite_pb8_1_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pb0_0",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pb0_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pb0_1",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pf0_1_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_pa0_0",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p9c_0",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p9a_0",
    &setup_link_memwrite_p9a_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pba_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pba_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p9a_1",
    &setup_link_memwrite_pb8_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_p9a_1_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p98_0",
    &setup_link_memwrite_pb8_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pb8_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pba_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p98_1",
    &setup_link_memwrite_pb8_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pb8_1_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p90_0",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pb0_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p90_1",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf0_1_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p80_0",
    &setup_link_memwrite_pfc_1_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_pbc_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p78_0",
    &setup_link_memwrite_p78_0_common,
    { { &setup_link_memwrite_pfc_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_procfinal,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p74_0",
    &setup_link_memwrite_p74_0_common,
    { { &setup_link_memwrite_pfa_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p70_0",
    &setup_link_memwrite_p70_0_common,
    { { &setup_link_memwrite_pf8_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p6_0",
    &setup_link_memwrite_p74_0_common,
    { { &setup_link_memwrite_pf0_0_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p6_1",
    &setup_link_memwrite_p78_0_common,
    { { &setup_link_memwrite_pf0_1_proc0 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_procfinal,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p4_0",
    &setup_link_memwrite_p78_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_procfinal,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p38_0",
    &setup_link_memwrite_p78_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_procfinal,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p34_0",
    &setup_link_memwrite_p74_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf8_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p30_0",
    &setup_link_memwrite_p70_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf8_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p2_0",
    &setup_link_memwrite_p74_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf0_0_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_final,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p2_1",
    &setup_link_memwrite_p78_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pf0_1_proc0 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_procfinal,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_memwrite_p0_0",
    &setup_link_memwrite_p78_0_common,
    { { &setup_link_memwrite_pfc_0_proc1 }, { &setup_link_memwrite_pfc_0_proc1 } },
    &setup_link_memwrite_pfc_0_procfinal,
    &setup_link_memwrite_pfc_0_procfinal,
    { { &test_link_memwrite_p78_0_0, 0, "link" },
      { &test_link_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-link_mmap_pf8_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pf8_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pf6_0",
    &setup_link_mmap_pf6_0_common,
    { { &setup_link_mmap_pf6_0_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pf6_1",
    &setup_link_mmap_pf6_0_common,
    { { &setup_link_mmap_pf6_1_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pf6_2",
    &setup_link_mmap_pf6_2_common,
    { { &setup_link_mmap_pf6_0_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pf6_3",
    &setup_link_mmap_pf6_2_common,
    { { &setup_link_mmap_pf6_1_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pf4_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pf4_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pf0_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pf0_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pec_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pec_1",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pec_2",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pec_3",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pe6_0",
    &setup_link_mmap_pf6_0_common,
    { { &setup_link_mmap_pf6_0_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pe6_1",
    &setup_link_mmap_pf6_0_common,
    { { &setup_link_mmap_pf6_1_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pe6_2",
    &setup_link_mmap_pf6_2_common,
    { { &setup_link_mmap_pf6_0_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pe6_3",
    &setup_link_mmap_pf6_2_common,
    { { &setup_link_mmap_pf6_1_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pe5_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pe5_1",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pe5_2",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pe5_3",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pe0_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pe0_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pd8_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pd8_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pd6_0",
    &setup_link_mmap_pf6_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_0_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pd6_1",
    &setup_link_mmap_pf6_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_1_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pd6_2",
    &setup_link_mmap_pf6_2_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_0_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pd6_3",
    &setup_link_mmap_pf6_2_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_1_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pd4_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pf4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pd4_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pf4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pd0_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pd0_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pcc_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pcc_1",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pcc_2",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pcc_3",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pc6_0",
    &setup_link_mmap_pf6_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_0_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pc6_1",
    &setup_link_mmap_pf6_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_1_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pc6_2",
    &setup_link_mmap_pf6_2_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_0_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pc6_3",
    &setup_link_mmap_pf6_2_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_1_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pc5_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pc5_1",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pc5_2",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pc5_3",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pc0_0",
    &setup_link_mmap_pf8_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_0_0, 0, "link" },
      { &test_link_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pc0_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pf8_1_0, 0, "link" },
      { &test_link_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pb8_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pb6_0",
    &setup_link_mmap_pb6_0_common,
    { { &setup_link_mmap_pf6_0_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pb6_1",
    &setup_link_mmap_pb6_0_common,
    { { &setup_link_mmap_pf6_1_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pb4_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pb4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pb0_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pac_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pac_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pa6_0",
    &setup_link_mmap_pb6_0_common,
    { { &setup_link_mmap_pf6_0_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pa6_1",
    &setup_link_mmap_pb6_0_common,
    { { &setup_link_mmap_pf6_1_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pa50_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pb4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pa50_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pb4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pa50_2",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pa50_2_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pa50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pa50_3",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pa50_2_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pa50_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_pa0_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p98_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p96_0",
    &setup_link_mmap_pb6_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_0_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p96_1",
    &setup_link_mmap_pb6_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_1_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p94_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pb4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pf4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p90_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p8c_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p8c_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p86_0",
    &setup_link_mmap_pb6_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_0_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p86_1",
    &setup_link_mmap_pb6_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_1_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p850_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pb4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p850_1",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pb4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p850_2",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pa50_2_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pa50_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p850_3",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pa50_2_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pa50_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p80_0",
    &setup_link_mmap_pf8_1_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_pb8_0_0, 0, "link" },
      { &test_link_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p70_0",
    &setup_link_mmap_p70_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_procfinal,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p6c_0",
    &setup_link_mmap_p6c_0_common,
    { { &setup_link_mmap_pf6_0_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p6c_1",
    &setup_link_mmap_p6c_0_common,
    { { &setup_link_mmap_pf6_1_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p68_0",
    &setup_link_mmap_p68_0_common,
    { { &setup_link_mmap_pf4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p60_0",
    &setup_link_mmap_p70_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_procfinal,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p58_0",
    &setup_link_mmap_p70_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_procfinal,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p58_1",
    &setup_link_mmap_p70_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_procfinal,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p4c_0",
    &setup_link_mmap_p6c_0_common,
    { { &setup_link_mmap_pf6_0_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p4c_1",
    &setup_link_mmap_p6c_0_common,
    { { &setup_link_mmap_pf6_1_proc0 }, { &setup_link_mmap_pf6_0_proc1 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p4a_0",
    &setup_link_mmap_p68_0_common,
    { { &setup_link_mmap_pf4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p4a_1",
    &setup_link_mmap_p68_0_common,
    { { &setup_link_mmap_pf4_0_proc0 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p40_0",
    &setup_link_mmap_p70_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_procfinal,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p30_0",
    &setup_link_mmap_p70_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_procfinal,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p2c_0",
    &setup_link_mmap_p6c_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_0_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p2c_1",
    &setup_link_mmap_p6c_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_1_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p28_0",
    &setup_link_mmap_p68_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pf4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p20_0",
    &setup_link_mmap_p70_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_procfinal,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p18_0",
    &setup_link_mmap_p70_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_procfinal,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p18_1",
    &setup_link_mmap_p70_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_procfinal,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p0c_0",
    &setup_link_mmap_p6c_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_0_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p0c_1",
    &setup_link_mmap_p6c_0_common,
    { { &setup_link_mmap_pf6_0_proc1 }, { &setup_link_mmap_pf6_1_proc0 } },
    &setup_link_mmap_pf6_0_procfinal,
    &setup_link_mmap_pf6_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p0a_0",
    &setup_link_mmap_p68_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p0a_1",
    &setup_link_mmap_p68_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf4_0_proc0 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_final,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mmap_p00_0",
    &setup_link_mmap_p70_0_common,
    { { &setup_link_mmap_pf8_0_proc1 }, { &setup_link_mmap_pf8_0_proc1 } },
    &setup_link_mmap_pf8_0_procfinal,
    &setup_link_mmap_pf8_0_procfinal,
    { { &test_link_mmap_p70_0_0, 0, "link" },
      { &test_link_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-link_mprotect_pf_0",
    &setup_link_mprotect_pf_0_common,
    { { &setup_link_mprotect_pf_0_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pf_1",
    &setup_link_mprotect_pf_0_common,
    { { &setup_link_mprotect_pf_1_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pf_2",
    &setup_link_mprotect_pf_0_common,
    { { &setup_link_mprotect_pf_2_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pf_3",
    &setup_link_mprotect_pf_0_common,
    { { &setup_link_mprotect_pf_3_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pf_4",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_4_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pf_5",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_2_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_4_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pf_6",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_1_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_4_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pf_7",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_3_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_4_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pe_0",
    &setup_link_mprotect_pf_0_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_0_0, 0, "link" },
      { &test_link_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pe_1",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_4_0, 0, "link" },
      { &test_link_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pd_0",
    &setup_link_mprotect_pf_0_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pd_1",
    &setup_link_mprotect_pf_0_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_1_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pd_2",
    &setup_link_mprotect_pf_0_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_2_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pd_3",
    &setup_link_mprotect_pf_0_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_3_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pd_4",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_4_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pd_5",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_2_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_4_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pd_6",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_1_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_4_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pd_7",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_3_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_4_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pc_0",
    &setup_link_mprotect_pf_0_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_0_0, 0, "link" },
      { &test_link_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pc_1",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pf_4_0, 0, "link" },
      { &test_link_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pb0_0",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pb0_0_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pb0_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pb0_1",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pb0_1_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pb0_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pb0_2",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_1_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pb0_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pb0_3",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_3_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pb0_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_pa0_0",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pb0_0_0, 0, "link" },
      { &test_link_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p90_0",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pb0_0_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pb0_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p90_1",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pb0_1_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pb0_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p90_2",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_1_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pb0_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p90_3",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_3_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pb0_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p80_0",
    &setup_link_mprotect_pf_4_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_pb0_0_0, 0, "link" },
      { &test_link_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p6_0",
    &setup_link_mprotect_p6_0_common,
    { { &setup_link_mprotect_pf_0_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_p6_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p6_1",
    &setup_link_mprotect_p6_0_common,
    { { &setup_link_mprotect_pf_2_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_p6_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p6_2",
    &setup_link_mprotect_p6_2_common,
    { { &setup_link_mprotect_pf_1_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_procfinal,
    { { &test_link_mprotect_p6_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p6_3",
    &setup_link_mprotect_p6_2_common,
    { { &setup_link_mprotect_pf_3_proc0 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_procfinal,
    { { &test_link_mprotect_p6_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p4_0",
    &setup_link_mprotect_p6_2_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_procfinal,
    { { &test_link_mprotect_p6_0_0, 0, "link" },
      { &test_link_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p2_0",
    &setup_link_mprotect_p6_0_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_p6_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p2_1",
    &setup_link_mprotect_p6_2_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_1_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_procfinal,
    { { &test_link_mprotect_p6_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p2_2",
    &setup_link_mprotect_p6_0_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_2_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_final,
    { { &test_link_mprotect_p6_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p2_3",
    &setup_link_mprotect_p6_2_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_3_proc0 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_procfinal,
    { { &test_link_mprotect_p6_0_0, 0, "link" },
      { &test_link_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_mprotect_p0_0",
    &setup_link_mprotect_p6_2_common,
    { { &setup_link_mprotect_pf_0_proc1 }, { &setup_link_mprotect_pf_0_proc1 } },
    &setup_link_mprotect_pf_0_procfinal,
    &setup_link_mprotect_pf_0_procfinal,
    { { &test_link_mprotect_p6_0_0, 0, "link" },
      { &test_link_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-link_munmap_pe_0",
    &setup_link_munmap_pe_0_common,
    { { &setup_link_munmap_pe_0_proc0 }, { &setup_link_munmap_pe_0_proc1 } },
    &setup_link_munmap_pe_0_procfinal,
    &setup_link_munmap_pe_0_final,
    { { &test_link_munmap_pe_0_0, 0, "link" },
      { &test_link_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-link_munmap_pe_1",
    &setup_link_munmap_pe_1_common,
    { { &setup_link_munmap_pe_0_proc1 }, { &setup_link_munmap_pe_0_proc1 } },
    &setup_link_munmap_pe_0_procfinal,
    &setup_link_munmap_pe_0_final,
    { { &test_link_munmap_pe_1_0, 0, "link" },
      { &test_link_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-link_munmap_pc_0",
    &setup_link_munmap_pe_0_common,
    { { &setup_link_munmap_pe_0_proc1 }, { &setup_link_munmap_pe_0_proc1 } },
    &setup_link_munmap_pe_0_procfinal,
    &setup_link_munmap_pe_0_final,
    { { &test_link_munmap_pe_0_0, 0, "link" },
      { &test_link_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-link_munmap_pc_1",
    &setup_link_munmap_pe_1_common,
    { { &setup_link_munmap_pe_0_proc1 }, { &setup_link_munmap_pe_0_proc1 } },
    &setup_link_munmap_pe_0_procfinal,
    &setup_link_munmap_pe_0_final,
    { { &test_link_munmap_pe_1_0, 0, "link" },
      { &test_link_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-link_munmap_pa_0",
    &setup_link_munmap_pe_1_common,
    { { &setup_link_munmap_pe_0_proc1 }, { &setup_link_munmap_pe_0_proc1 } },
    &setup_link_munmap_pe_0_procfinal,
    &setup_link_munmap_pe_0_final,
    { { &test_link_munmap_pa_0_0, 0, "link" },
      { &test_link_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-link_munmap_p8_0",
    &setup_link_munmap_pe_1_common,
    { { &setup_link_munmap_pe_0_proc1 }, { &setup_link_munmap_pe_0_proc1 } },
    &setup_link_munmap_pe_0_procfinal,
    &setup_link_munmap_pe_0_final,
    { { &test_link_munmap_pa_0_0, 0, "link" },
      { &test_link_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-link_munmap_p4_0",
    &setup_link_munmap_p4_0_common,
    { { &setup_link_munmap_pe_0_proc1 }, { &setup_link_munmap_pe_0_proc1 } },
    &setup_link_munmap_pe_0_procfinal,
    &setup_link_munmap_pe_0_procfinal,
    { { &test_link_munmap_p4_0_0, 0, "link" },
      { &test_link_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-link_munmap_p0_0",
    &setup_link_munmap_p4_0_common,
    { { &setup_link_munmap_pe_0_proc1 }, { &setup_link_munmap_pe_0_proc1 } },
    &setup_link_munmap_pe_0_procfinal,
    &setup_link_munmap_pe_0_procfinal,
    { { &test_link_munmap_p4_0_0, 0, "link" },
      { &test_link_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-link_open_pf8_0",
    &setup_link_open_pf8_0_common,
    { { &setup_link_open_pf8_0_proc0 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf8_1",
    &setup_link_open_pf8_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf8_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf8_2",
    &setup_link_open_pf8_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf8_2_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf8_3",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf8_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf70_0",
    &setup_link_open_pf70_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf70_1",
    &setup_link_open_pf70_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf70_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf70_2",
    &setup_link_open_pf8_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf70_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf70_3",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf70_3_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf50_0",
    &setup_link_open_pf8_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pf50_1",
    &setup_link_open_pf8_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf70_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pf50_2",
    &setup_link_open_pf70_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf70_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pf50_3",
    &setup_link_open_pf50_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf70_3_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pf3_0",
    &setup_link_open_pf3_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf3_1",
    &setup_link_open_pf3_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf3_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf3_2",
    &setup_link_open_pf3_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf3_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf3_3",
    &setup_link_open_pf3_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf3_3_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pf1_0",
    &setup_link_open_pf3_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pf1_1",
    &setup_link_open_pf3_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf3_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pf1_2",
    &setup_link_open_pf3_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf3_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pf1_3",
    &setup_link_open_pf3_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf3_3_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pee_0",
    &setup_link_open_pee_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pee_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pee_1",
    &setup_link_open_pf8_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pee_2",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf70_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pea_0",
    &setup_link_open_pee_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pee_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pea_1",
    &setup_link_open_pea_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pea_2",
    &setup_link_open_pea_2_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf70_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pe6_0",
    &setup_link_open_pe6_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pee_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pe6_1",
    &setup_link_open_pea_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pe6_2",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf3_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pe2_0",
    &setup_link_open_pee_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pee_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pe2_1",
    &setup_link_open_pea_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pe2_2",
    &setup_link_open_pea_2_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pf3_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pde_0",
    &setup_link_open_pf70_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pde_1",
    &setup_link_open_pea_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pde_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pde_2",
    &setup_link_open_pf70_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pde_2_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pde_3",
    &setup_link_open_pf50_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pde_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pda_0",
    &setup_link_open_pf8_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pda_1",
    &setup_link_open_pf70_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pde_2_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pda_2",
    &setup_link_open_pea_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pde_2_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pda_3",
    &setup_link_open_pea_2_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pde_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pd6_0",
    &setup_link_open_pf3_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pd6_1",
    &setup_link_open_pf3_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pd6_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pd6_2",
    &setup_link_open_pf3_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pd6_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pd6_3",
    &setup_link_open_pf3_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pd6_3_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pd2_0",
    &setup_link_open_pf3_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pd2_1",
    &setup_link_open_pf3_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pd6_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pd2_2",
    &setup_link_open_pf3_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pd6_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pd2_3",
    &setup_link_open_pf3_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pd6_3_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pc_0",
    &setup_link_open_pf8_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_0_0, 0, "link" },
      { &test_link_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pc_1",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pf8_2_0, 0, "link" },
      { &test_link_open_pc_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pbc_0",
    &setup_link_open_pbc_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pbc_1",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf8_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pb78_0",
    &setup_link_open_pb78_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pb78_1",
    &setup_link_open_pb78_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf70_3_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pb58_0",
    &setup_link_open_pb78_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pb58_1",
    &setup_link_open_pb78_1_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf70_3_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pb38_0",
    &setup_link_open_pb38_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pee_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pb38_1",
    &setup_link_open_pbc_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pb38_2",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf3_3_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pb18_0",
    &setup_link_open_pb38_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pee_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pb18_1",
    &setup_link_open_pbc_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pb18_2",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf3_3_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pae_0",
    &setup_link_open_pae_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_paa_0",
    &setup_link_open_pae_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_pa6_0",
    &setup_link_open_pae_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_pa2_0",
    &setup_link_open_pae_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p9f0_0",
    &setup_link_open_pb78_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p9f0_1",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pde_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p9b0_0",
    &setup_link_open_pb78_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p9b0_1",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pde_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p970_0",
    &setup_link_open_pb38_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pee_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p970_1",
    &setup_link_open_pbc_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p970_2",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pd6_3_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p930_0",
    &setup_link_open_pb38_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pee_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p930_1",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pd6_3_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p80_0",
    &setup_link_open_pf8_3_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_pbc_0_0, 0, "link" },
      { &test_link_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p7_0",
    &setup_link_open_p7_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pf8_2_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p6e_0",
    &setup_link_open_p6e_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pf70_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p6a_0",
    &setup_link_open_p7_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pf70_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p66_0",
    &setup_link_open_p66_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pf3_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p62_0",
    &setup_link_open_p66_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pf3_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p5a_0",
    &setup_link_open_p5a_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_procfinal,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pf70_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p52_0",
    &setup_link_open_p5a_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_procfinal,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pf70_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p4a_0",
    &setup_link_open_p5a_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_procfinal,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pf3_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p42_0",
    &setup_link_open_p5a_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_procfinal,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pf3_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p3c_0",
    &setup_link_open_p6e_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pde_2_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p34_0",
    &setup_link_open_p34_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pde_2_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p2c_0",
    &setup_link_open_p66_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pd6_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p24_0",
    &setup_link_open_p66_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_final,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pd6_1_1, 1, "open" } },
    &cleanup },
  { "fs-link_open_p0_0",
    &setup_link_open_p5a_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_procfinal,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_pc_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_open_p0_1",
    &setup_link_open_p5a_0_common,
    { { &setup_link_open_pf8_0_proc1 }, { &setup_link_open_pf8_0_proc1 } },
    &setup_link_open_pf8_0_procfinal,
    &setup_link_open_pf8_0_procfinal,
    { { &test_link_open_p7_0_0, 0, "link" },
      { &test_link_open_p0_1_1, 0, "open" } },
    &cleanup },
  { "fs-link_pipe_pf8_0",
    &setup_link_pipe_pf8_0_common,
    { { &setup_link_pipe_pf8_0_proc0 }, { &setup_link_pipe_pf8_0_proc1 } },
    &setup_link_pipe_pf8_0_procfinal,
    &setup_link_pipe_pf8_0_final,
    { { &test_link_pipe_pf8_0_0, 0, "link" },
      { &test_link_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-link_pipe_pf8_1",
    &setup_link_pipe_pf8_1_common,
    { { &setup_link_pipe_pf8_0_proc1 }, { &setup_link_pipe_pf8_0_proc1 } },
    &setup_link_pipe_pf8_0_procfinal,
    &setup_link_pipe_pf8_0_final,
    { { &test_link_pipe_pf8_1_0, 0, "link" },
      { &test_link_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-link_pipe_pd8_0",
    &setup_link_pipe_pf8_0_common,
    { { &setup_link_pipe_pf8_0_proc1 }, { &setup_link_pipe_pf8_0_proc1 } },
    &setup_link_pipe_pf8_0_procfinal,
    &setup_link_pipe_pf8_0_final,
    { { &test_link_pipe_pf8_0_0, 0, "link" },
      { &test_link_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-link_pipe_pd8_1",
    &setup_link_pipe_pf8_1_common,
    { { &setup_link_pipe_pf8_0_proc1 }, { &setup_link_pipe_pf8_0_proc1 } },
    &setup_link_pipe_pf8_0_procfinal,
    &setup_link_pipe_pf8_0_final,
    { { &test_link_pipe_pf8_1_0, 0, "link" },
      { &test_link_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-link_pipe_pb8_0",
    &setup_link_pipe_pb8_0_common,
    { { &setup_link_pipe_pf8_0_proc1 }, { &setup_link_pipe_pf8_0_proc1 } },
    &setup_link_pipe_pf8_0_procfinal,
    &setup_link_pipe_pf8_0_final,
    { { &test_link_pipe_pb8_0_0, 0, "link" },
      { &test_link_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-link_pipe_p98_0",
    &setup_link_pipe_pb8_0_common,
    { { &setup_link_pipe_pf8_0_proc1 }, { &setup_link_pipe_pf8_0_proc1 } },
    &setup_link_pipe_pf8_0_procfinal,
    &setup_link_pipe_pf8_0_final,
    { { &test_link_pipe_pb8_0_0, 0, "link" },
      { &test_link_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-link_pipe_p70_0",
    &setup_link_pipe_p70_0_common,
    { { &setup_link_pipe_pf8_0_proc1 }, { &setup_link_pipe_pf8_0_proc1 } },
    &setup_link_pipe_pf8_0_procfinal,
    &setup_link_pipe_pf8_0_procfinal,
    { { &test_link_pipe_p70_0_0, 0, "link" },
      { &test_link_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-link_pipe_p30_0",
    &setup_link_pipe_p70_0_common,
    { { &setup_link_pipe_pf8_0_proc1 }, { &setup_link_pipe_pf8_0_proc1 } },
    &setup_link_pipe_pf8_0_procfinal,
    &setup_link_pipe_pf8_0_procfinal,
    { { &test_link_pipe_p70_0_0, 0, "link" },
      { &test_link_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-link_pread_pf8_0",
    &setup_link_pread_pf8_0_common,
    { { &setup_link_pread_pf8_0_proc0 }, { &setup_link_pread_pf8_0_proc1 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf8_1",
    &setup_link_pread_pf8_0_common,
    { { &setup_link_pread_pf8_1_proc0 }, { &setup_link_pread_pf8_0_proc1 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf8_2",
    &setup_link_pread_pf8_2_common,
    { { &setup_link_pread_pf8_0_proc0 }, { &setup_link_pread_pf8_0_proc1 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf8_3",
    &setup_link_pread_pf8_2_common,
    { { &setup_link_pread_pf8_1_proc0 }, { &setup_link_pread_pf8_0_proc1 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf4_0",
    &setup_link_pread_pf4_0_common,
    { { &setup_link_pread_pf4_0_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf4_1",
    &setup_link_pread_pf4_0_common,
    { { &setup_link_pread_pf4_1_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf4_2",
    &setup_link_pread_pf4_2_common,
    { { &setup_link_pread_pf4_0_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf4_3",
    &setup_link_pread_pf4_2_common,
    { { &setup_link_pread_pf4_1_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf0_0",
    &setup_link_pread_pf0_0_common,
    { { &setup_link_pread_pf4_0_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf0_1",
    &setup_link_pread_pf0_1_common,
    { { &setup_link_pread_pf4_0_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf0_2",
    &setup_link_pread_pf0_0_common,
    { { &setup_link_pread_pf4_1_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pf0_3",
    &setup_link_pread_pf0_1_common,
    { { &setup_link_pread_pf4_1_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pe_0",
    &setup_link_pread_pf4_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pe_1",
    &setup_link_pread_pf4_2_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pd8_0",
    &setup_link_pread_pf8_0_common,
    { { &setup_link_pread_pf8_0_proc1 }, { &setup_link_pread_pf8_0_proc0 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd8_1",
    &setup_link_pread_pf8_0_common,
    { { &setup_link_pread_pf8_0_proc1 }, { &setup_link_pread_pf8_1_proc0 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd8_2",
    &setup_link_pread_pf8_2_common,
    { { &setup_link_pread_pf8_0_proc1 }, { &setup_link_pread_pf8_0_proc0 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd8_3",
    &setup_link_pread_pf8_2_common,
    { { &setup_link_pread_pf8_0_proc1 }, { &setup_link_pread_pf8_1_proc0 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd4_0",
    &setup_link_pread_pf4_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd4_1",
    &setup_link_pread_pf4_2_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd4_2",
    &setup_link_pread_pf4_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_1_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd4_3",
    &setup_link_pread_pf4_2_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_1_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd0_0",
    &setup_link_pread_pf0_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd0_1",
    &setup_link_pread_pf0_1_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd0_2",
    &setup_link_pread_pf0_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_1_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pd0_3",
    &setup_link_pread_pf0_1_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_1_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pc_0",
    &setup_link_pread_pf4_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_0_0, 0, "link" },
      { &test_link_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pc_1",
    &setup_link_pread_pf4_2_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pf8_2_0, 0, "link" },
      { &test_link_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_pb8_0",
    &setup_link_pread_pb8_0_common,
    { { &setup_link_pread_pf8_0_proc0 }, { &setup_link_pread_pf8_0_proc1 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pb8_1",
    &setup_link_pread_pb8_0_common,
    { { &setup_link_pread_pf8_1_proc0 }, { &setup_link_pread_pf8_0_proc1 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pb4_0",
    &setup_link_pread_pb4_0_common,
    { { &setup_link_pread_pf4_0_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pb4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pb4_1",
    &setup_link_pread_pb4_1_common,
    { { &setup_link_pread_pb4_1_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pb4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pb4_1_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pb4_2",
    &setup_link_pread_pf4_2_common,
    { { &setup_link_pread_pf4_0_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pb4_3",
    &setup_link_pread_pb4_3_common,
    { { &setup_link_pread_pb4_1_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pb4_1_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pb0_0",
    &setup_link_pread_pb0_0_common,
    { { &setup_link_pread_pb0_0_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pb4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pb0_1",
    &setup_link_pread_pb0_1_common,
    { { &setup_link_pread_pf4_0_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pb4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pb0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pb0_2",
    &setup_link_pread_pf0_1_common,
    { { &setup_link_pread_pb0_2_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pb0_3",
    &setup_link_pread_pb0_3_common,
    { { &setup_link_pread_pb0_3_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pb0_3_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_pa0_0",
    &setup_link_pread_pf4_2_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_p98_0",
    &setup_link_pread_pb8_0_common,
    { { &setup_link_pread_pf8_0_proc1 }, { &setup_link_pread_pf8_0_proc0 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p98_1",
    &setup_link_pread_pb8_0_common,
    { { &setup_link_pread_pf8_0_proc1 }, { &setup_link_pread_pf8_1_proc0 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p94_0",
    &setup_link_pread_pb4_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pb4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p94_1",
    &setup_link_pread_pf4_2_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p94_2",
    &setup_link_pread_pb4_1_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pb4_1_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pb4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pb4_1_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p94_3",
    &setup_link_pread_pb4_3_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pb4_1_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pb4_1_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p90_0",
    &setup_link_pread_pb0_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_p90_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pb4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p90_1",
    &setup_link_pread_pb0_1_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pb4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pb0_1_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p90_2",
    &setup_link_pread_pf0_1_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_p90_2_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p90_3",
    &setup_link_pread_pb0_3_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pb0_3_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pb0_3_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p80_0",
    &setup_link_pread_pf4_2_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_pb8_0_0, 0, "link" },
      { &test_link_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p7_0",
    &setup_link_pread_p7_0_common,
    { { &setup_link_pread_pf8_0_proc0 }, { &setup_link_pread_pf8_0_proc1 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_p7_1",
    &setup_link_pread_p7_0_common,
    { { &setup_link_pread_pf8_1_proc0 }, { &setup_link_pread_pf8_0_proc1 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_p68_0",
    &setup_link_pread_p68_0_common,
    { { &setup_link_pread_pf4_0_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_p68_1",
    &setup_link_pread_p68_0_common,
    { { &setup_link_pread_pf4_1_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_p60_0",
    &setup_link_pread_p60_0_common,
    { { &setup_link_pread_pf4_0_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_p60_1",
    &setup_link_pread_p60_0_common,
    { { &setup_link_pread_pf4_1_proc0 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_p4_0",
    &setup_link_pread_p4_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_procfinal,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-link_pread_p3_0",
    &setup_link_pread_p7_0_common,
    { { &setup_link_pread_pf8_0_proc1 }, { &setup_link_pread_pf8_0_proc0 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p3_1",
    &setup_link_pread_p7_0_common,
    { { &setup_link_pread_pf8_0_proc1 }, { &setup_link_pread_pf8_1_proc0 } },
    &setup_link_pread_pf8_0_procfinal,
    &setup_link_pread_pf8_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p28_0",
    &setup_link_pread_p68_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p28_1",
    &setup_link_pread_p68_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_1_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p20_0",
    &setup_link_pread_p60_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p20_1",
    &setup_link_pread_p60_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_1_proc0 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_final,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pread_p0_0",
    &setup_link_pread_p4_0_common,
    { { &setup_link_pread_pf4_0_proc1 }, { &setup_link_pread_pf4_0_proc1 } },
    &setup_link_pread_pf4_0_procfinal,
    &setup_link_pread_pf4_0_procfinal,
    { { &test_link_pread_p7_0_0, 0, "link" },
      { &test_link_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-link_pwrite_pf8_0",
    &setup_link_pwrite_pf8_0_common,
    { { &setup_link_pwrite_pf8_0_proc0 }, { &setup_link_pwrite_pf8_0_proc1 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf8_1",
    &setup_link_pwrite_pf8_0_common,
    { { &setup_link_pwrite_pf8_1_proc0 }, { &setup_link_pwrite_pf8_0_proc1 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf8_2",
    &setup_link_pwrite_pf8_2_common,
    { { &setup_link_pwrite_pf8_0_proc0 }, { &setup_link_pwrite_pf8_0_proc1 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf8_3",
    &setup_link_pwrite_pf8_2_common,
    { { &setup_link_pwrite_pf8_1_proc0 }, { &setup_link_pwrite_pf8_0_proc1 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf4_0",
    &setup_link_pwrite_pf4_0_common,
    { { &setup_link_pwrite_pf4_0_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf4_1",
    &setup_link_pwrite_pf4_1_common,
    { { &setup_link_pwrite_pf4_1_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf4_2",
    &setup_link_pwrite_pf4_0_common,
    { { &setup_link_pwrite_pf4_2_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf4_3",
    &setup_link_pwrite_pf4_1_common,
    { { &setup_link_pwrite_pf4_2_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf0_0",
    &setup_link_pwrite_pf0_0_common,
    { { &setup_link_pwrite_pf0_0_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf0_1",
    &setup_link_pwrite_pf0_0_common,
    { { &setup_link_pwrite_pf4_2_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf0_2",
    &setup_link_pwrite_pf0_2_common,
    { { &setup_link_pwrite_pf4_0_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pf0_3",
    &setup_link_pwrite_pf0_2_common,
    { { &setup_link_pwrite_pf4_2_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pe_0",
    &setup_link_pwrite_pf4_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pe_1",
    &setup_link_pwrite_pf4_1_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd8_0",
    &setup_link_pwrite_pf8_0_common,
    { { &setup_link_pwrite_pf8_0_proc1 }, { &setup_link_pwrite_pf8_0_proc0 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd8_1",
    &setup_link_pwrite_pf8_0_common,
    { { &setup_link_pwrite_pf8_0_proc1 }, { &setup_link_pwrite_pf8_1_proc0 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd8_2",
    &setup_link_pwrite_pf8_2_common,
    { { &setup_link_pwrite_pf8_0_proc1 }, { &setup_link_pwrite_pf8_0_proc0 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd8_3",
    &setup_link_pwrite_pf8_2_common,
    { { &setup_link_pwrite_pf8_0_proc1 }, { &setup_link_pwrite_pf8_1_proc0 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd4_0",
    &setup_link_pwrite_pf4_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pd4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd4_1",
    &setup_link_pwrite_pf4_1_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_1_proc0 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd4_2",
    &setup_link_pwrite_pf4_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_2_proc0 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd4_3",
    &setup_link_pwrite_pf4_1_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_2_proc0 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd0_0",
    &setup_link_pwrite_pf0_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pd0_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd0_1",
    &setup_link_pwrite_pf0_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_2_proc0 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd0_2",
    &setup_link_pwrite_pf0_2_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pd4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pd0_3",
    &setup_link_pwrite_pf0_2_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_2_proc0 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pc_0",
    &setup_link_pwrite_pf4_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_0_0, 0, "link" },
      { &test_link_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pc_1",
    &setup_link_pwrite_pf4_1_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pf8_2_0, 0, "link" },
      { &test_link_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pb8_0",
    &setup_link_pwrite_pb8_0_common,
    { { &setup_link_pwrite_pf8_0_proc0 }, { &setup_link_pwrite_pf8_0_proc1 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pb8_1",
    &setup_link_pwrite_pb8_0_common,
    { { &setup_link_pwrite_pf8_1_proc0 }, { &setup_link_pwrite_pf8_0_proc1 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pb4_0",
    &setup_link_pwrite_pb4_0_common,
    { { &setup_link_pwrite_pf4_1_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pb4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pb4_1",
    &setup_link_pwrite_pb4_1_common,
    { { &setup_link_pwrite_pb4_1_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pb4_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pb0_0",
    &setup_link_pwrite_pf0_2_common,
    { { &setup_link_pwrite_pf4_0_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pb0_1",
    &setup_link_pwrite_pb4_1_common,
    { { &setup_link_pwrite_pb0_1_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pb4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_pa0_0",
    &setup_link_pwrite_pf4_1_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p98_0",
    &setup_link_pwrite_pb8_0_common,
    { { &setup_link_pwrite_pf8_0_proc1 }, { &setup_link_pwrite_pf8_0_proc0 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p98_1",
    &setup_link_pwrite_pb8_0_common,
    { { &setup_link_pwrite_pf8_0_proc1 }, { &setup_link_pwrite_pf8_1_proc0 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p94_0",
    &setup_link_pwrite_pb4_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_1_proc0 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pb4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p94_1",
    &setup_link_pwrite_pb4_1_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pb4_1_proc0 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pb4_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p90_0",
    &setup_link_pwrite_pf0_2_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pd4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p90_1",
    &setup_link_pwrite_pb4_1_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pb0_1_proc0 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pb4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p80_0",
    &setup_link_pwrite_pf4_1_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_pb8_0_0, 0, "link" },
      { &test_link_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p7_0",
    &setup_link_pwrite_p7_0_common,
    { { &setup_link_pwrite_pf8_0_proc0 }, { &setup_link_pwrite_pf8_0_proc1 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p7_1",
    &setup_link_pwrite_p7_0_common,
    { { &setup_link_pwrite_pf8_1_proc0 }, { &setup_link_pwrite_pf8_0_proc1 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p68_0",
    &setup_link_pwrite_p68_0_common,
    { { &setup_link_pwrite_pf4_0_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p68_1",
    &setup_link_pwrite_p68_0_common,
    { { &setup_link_pwrite_pf4_2_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p60_0",
    &setup_link_pwrite_p60_0_common,
    { { &setup_link_pwrite_pf0_0_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p60_1",
    &setup_link_pwrite_p60_0_common,
    { { &setup_link_pwrite_pf4_2_proc0 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p4_0",
    &setup_link_pwrite_p4_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_procfinal,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p3_0",
    &setup_link_pwrite_p7_0_common,
    { { &setup_link_pwrite_pf8_0_proc1 }, { &setup_link_pwrite_pf8_0_proc0 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p3_1",
    &setup_link_pwrite_p7_0_common,
    { { &setup_link_pwrite_pf8_0_proc1 }, { &setup_link_pwrite_pf8_1_proc0 } },
    &setup_link_pwrite_pf8_0_procfinal,
    &setup_link_pwrite_pf8_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p28_0",
    &setup_link_pwrite_p68_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pd4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p28_1",
    &setup_link_pwrite_p68_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_2_proc0 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p20_0",
    &setup_link_pwrite_p60_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pd0_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p20_1",
    &setup_link_pwrite_p60_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_2_proc0 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_final,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_pwrite_p0_0",
    &setup_link_pwrite_p4_0_common,
    { { &setup_link_pwrite_pf4_0_proc1 }, { &setup_link_pwrite_pf4_0_proc1 } },
    &setup_link_pwrite_pf4_0_procfinal,
    &setup_link_pwrite_pf4_0_procfinal,
    { { &test_link_pwrite_p7_0_0, 0, "link" },
      { &test_link_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-link_read_pfc_0",
    &setup_link_read_pfc_0_common,
    { { &setup_link_read_pfc_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pfc_1",
    &setup_link_read_pfc_1_common,
    { { &setup_link_read_pfc_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pfb_0",
    &setup_link_read_pfb_0_common,
    { { &setup_link_read_pfb_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pfb_1",
    &setup_link_read_pfb_1_common,
    { { &setup_link_read_pfb_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pfa_0",
    &setup_link_read_pfa_0_common,
    { { &setup_link_read_pfa_0_proc0 }, { &setup_link_read_pfa_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pfa_1",
    &setup_link_read_pfa_1_common,
    { { &setup_link_read_pfa_0_proc0 }, { &setup_link_read_pfa_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pf8_0",
    &setup_link_read_pf8_0_common,
    { { &setup_link_read_pfb_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pf8_1",
    &setup_link_read_pf8_1_common,
    { { &setup_link_read_pfb_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pf4_0",
    &setup_link_read_pf4_0_common,
    { { &setup_link_read_pf4_0_proc0 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pf4_1",
    &setup_link_read_pf4_1_common,
    { { &setup_link_read_pf4_0_proc0 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pf0_0",
    &setup_link_read_pf0_0_common,
    { { &setup_link_read_pf0_0_proc0 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pf0_1",
    &setup_link_read_pf0_1_common,
    { { &setup_link_read_pf0_0_proc0 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pe_0",
    &setup_link_read_pf4_0_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pe_1",
    &setup_link_read_pf4_1_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pdc_0",
    &setup_link_read_pfc_0_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfc_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pdc_1",
    &setup_link_read_pfc_1_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfc_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pdb_0",
    &setup_link_read_pfb_0_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfb_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pdb_1",
    &setup_link_read_pfb_1_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfb_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pda_0",
    &setup_link_read_pfb_0_common,
    { { &setup_link_read_pfa_0_proc1 }, { &setup_link_read_pfa_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pda_1",
    &setup_link_read_pfb_1_common,
    { { &setup_link_read_pfa_0_proc1 }, { &setup_link_read_pfa_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pd8_0",
    &setup_link_read_pf8_0_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfb_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pd8_1",
    &setup_link_read_pf8_1_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfb_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pd4_0",
    &setup_link_read_pf4_0_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc0 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pd4_1",
    &setup_link_read_pf4_1_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc0 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pd0_0",
    &setup_link_read_pf0_0_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf0_0_proc0 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pd0_1",
    &setup_link_read_pf0_1_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf0_0_proc0 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pc_0",
    &setup_link_read_pf4_0_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pc_1",
    &setup_link_read_pf4_1_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pfc_1_0, 0, "link" },
      { &test_link_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_pbc_0",
    &setup_link_read_pbc_0_common,
    { { &setup_link_read_pfc_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pbb0_0",
    &setup_link_read_pbb0_0_common,
    { { &setup_link_read_pfb_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pba0_0",
    &setup_link_read_pba0_0_common,
    { { &setup_link_read_pfa_0_proc0 }, { &setup_link_read_pfa_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pb8_0",
    &setup_link_read_pb8_0_common,
    { { &setup_link_read_pfb_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pb4_0",
    &setup_link_read_pb4_0_common,
    { { &setup_link_read_pb4_0_proc0 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pb4_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pb4_1",
    &setup_link_read_pf4_1_common,
    { { &setup_link_read_pf4_0_proc0 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pb0_0",
    &setup_link_read_pb0_0_common,
    { { &setup_link_read_pb0_0_proc0 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pb4_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pb0_1",
    &setup_link_read_pb0_1_common,
    { { &setup_link_read_pb0_1_proc0 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_pa0_0",
    &setup_link_read_pf4_1_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_p9c_0",
    &setup_link_read_pbc_0_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfc_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p9b0_0",
    &setup_link_read_pbb0_0_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfb_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p9a0_0",
    &setup_link_read_pba0_0_common,
    { { &setup_link_read_pfa_0_proc1 }, { &setup_link_read_pfa_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p98_0",
    &setup_link_read_pb8_0_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfb_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p94_0",
    &setup_link_read_pb4_0_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pb4_0_proc0 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pb4_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p94_1",
    &setup_link_read_pf4_1_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc0 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p90_0",
    &setup_link_read_pb0_0_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pb0_0_proc0 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pb4_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p90_1",
    &setup_link_read_pb0_1_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pb0_1_proc0 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p80_0",
    &setup_link_read_pf4_1_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_pbc_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p78_0",
    &setup_link_read_p78_0_common,
    { { &setup_link_read_pfc_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_p76_0",
    &setup_link_read_p76_0_common,
    { { &setup_link_read_pfb_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_p74_0",
    &setup_link_read_p76_0_common,
    { { &setup_link_read_pfa_0_proc0 }, { &setup_link_read_pfa_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_p70_0",
    &setup_link_read_p70_0_common,
    { { &setup_link_read_pfb_0_proc0 }, { &setup_link_read_pfc_0_proc1 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_p68_0",
    &setup_link_read_p68_0_common,
    { { &setup_link_read_pf4_0_proc0 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_p60_0",
    &setup_link_read_p60_0_common,
    { { &setup_link_read_pf0_0_proc0 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_p4_0",
    &setup_link_read_p4_0_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_procfinal,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-link_read_p38_0",
    &setup_link_read_p78_0_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfc_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p36_0",
    &setup_link_read_p76_0_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfb_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p34_0",
    &setup_link_read_p34_0_common,
    { { &setup_link_read_pfa_0_proc1 }, { &setup_link_read_pfa_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p30_0",
    &setup_link_read_p70_0_common,
    { { &setup_link_read_pfc_0_proc1 }, { &setup_link_read_pfb_0_proc0 } },
    &setup_link_read_pfc_0_procfinal,
    &setup_link_read_pfc_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p28_0",
    &setup_link_read_p68_0_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc0 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p20_0",
    &setup_link_read_p60_0_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf0_0_proc0 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_final,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_read_p0_0",
    &setup_link_read_p4_0_common,
    { { &setup_link_read_pf4_0_proc1 }, { &setup_link_read_pf4_0_proc1 } },
    &setup_link_read_pf4_0_procfinal,
    &setup_link_read_pf4_0_procfinal,
    { { &test_link_read_p78_0_0, 0, "link" },
      { &test_link_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-link_rename_pf_0",
    &setup_link_rename_pf_0_common,
    { { &setup_link_rename_pf_0_proc0 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_0_0, 0, "link" },
      { &test_link_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pf_1",
    &setup_link_rename_pf_1_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_0_0, 0, "link" },
      { &test_link_rename_pf_1_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pf_2",
    &setup_link_rename_pf_1_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_2_0, 0, "link" },
      { &test_link_rename_pf_2_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pf_3",
    &setup_link_rename_pf_3_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_2_0, 0, "link" },
      { &test_link_rename_pf_1_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pee_0",
    &setup_link_rename_pee_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_0_0, 0, "link" },
      { &test_link_rename_pee_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pee_1",
    &setup_link_rename_pf_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_2_0, 0, "link" },
      { &test_link_rename_pee_1_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pee_2",
    &setup_link_rename_pf_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_0_0, 0, "link" },
      { &test_link_rename_pee_2_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pee_3",
    &setup_link_rename_pf_1_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_2_0, 0, "link" },
      { &test_link_rename_pee_3_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pe6_0",
    &setup_link_rename_pf_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_0_0, 0, "link" },
      { &test_link_rename_pee_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pe6_1",
    &setup_link_rename_pf_1_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_2_0, 0, "link" },
      { &test_link_rename_pee_1_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pc_0",
    &setup_link_rename_pf_1_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_0_0, 0, "link" },
      { &test_link_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pc_1",
    &setup_link_rename_pf_3_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pf_2_0, 0, "link" },
      { &test_link_rename_pc_1_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pb8_0",
    &setup_link_rename_pb8_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pb8_0_0, 0, "link" },
      { &test_link_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pb8_1",
    &setup_link_rename_pf_3_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pb8_0_0, 0, "link" },
      { &test_link_rename_pf_1_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_paf0_0",
    &setup_link_rename_paf0_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_paf0_0_final,
    { { &test_link_rename_pb8_0_0, 0, "link" },
      { &test_link_rename_pee_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_paf0_1",
    &setup_link_rename_paf0_1_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pb8_0_0, 0, "link" },
      { &test_link_rename_pee_2_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_pa6_0",
    &setup_link_rename_pb8_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pb8_0_0, 0, "link" },
      { &test_link_rename_pee_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_p8_0",
    &setup_link_rename_pf_3_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_pb8_0_0, 0, "link" },
      { &test_link_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_p6_0",
    &setup_link_rename_p6_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_p6_0_0, 0, "link" },
      { &test_link_rename_pf_2_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_p50_0",
    &setup_link_rename_p50_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_p50_0_0, 0, "link" },
      { &test_link_rename_p50_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_p50_1",
    &setup_link_rename_p50_1_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_p50_0_0, 0, "link" },
      { &test_link_rename_pee_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_p40_0",
    &setup_link_rename_p40_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_p50_0_0, 0, "link" },
      { &test_link_rename_p50_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_p40_1",
    &setup_link_rename_p50_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_final,
    { { &test_link_rename_p50_0_0, 0, "link" },
      { &test_link_rename_pee_0_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_p0_0",
    &setup_link_rename_p0_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_procfinal,
    { { &test_link_rename_p6_0_0, 0, "link" },
      { &test_link_rename_pc_1_1, 0, "rename" } },
    &cleanup },
  { "fs-link_rename_p0_1",
    &setup_link_rename_p0_0_common,
    { { &setup_link_rename_pf_0_proc1 }, { &setup_link_rename_pf_0_proc1 } },
    &setup_link_rename_pf_0_procfinal,
    &setup_link_rename_pf_0_procfinal,
    { { &test_link_rename_p6_0_0, 0, "link" },
      { &test_link_rename_p0_1_1, 0, "rename" } },
    &cleanup },
  { "fs-link_stat_pe_0",
    &setup_link_stat_pe_0_common,
    { { &setup_link_stat_pe_0_proc0 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pe_0_final,
    { { &test_link_stat_pe_0_0, 0, "link" },
      { &test_link_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-link_stat_pe_1",
    &setup_link_stat_pe_1_common,
    { { &setup_link_stat_pe_0_proc1 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pe_0_final,
    { { &test_link_stat_pe_0_0, 0, "link" },
      { &test_link_stat_pe_1_1, 0, "stat" } },
    &cleanup },
  { "fs-link_stat_pe_2",
    &setup_link_stat_pe_1_common,
    { { &setup_link_stat_pe_0_proc1 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pe_0_final,
    { { &test_link_stat_pe_2_0, 0, "link" },
      { &test_link_stat_pe_2_1, 0, "stat" } },
    &cleanup },
  { "fs-link_stat_pe_3",
    &setup_link_stat_pe_3_common,
    { { &setup_link_stat_pe_0_proc1 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pe_0_final,
    { { &test_link_stat_pe_2_0, 0, "link" },
      { &test_link_stat_pe_1_1, 0, "stat" } },
    &cleanup },
  { "fs-link_stat_pc_0",
    &setup_link_stat_pe_1_common,
    { { &setup_link_stat_pe_0_proc1 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pe_0_final,
    { { &test_link_stat_pe_0_0, 0, "link" },
      { &test_link_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-link_stat_pc_1",
    &setup_link_stat_pe_3_common,
    { { &setup_link_stat_pe_0_proc1 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pe_0_final,
    { { &test_link_stat_pe_2_0, 0, "link" },
      { &test_link_stat_pc_1_1, 0, "stat" } },
    &cleanup },
  { "fs-link_stat_pb8_0",
    &setup_link_stat_pb8_0_common,
    { { &setup_link_stat_pe_0_proc1 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pb8_0_final,
    { { &test_link_stat_pb8_0_0, 0, "link" },
      { &test_link_stat_pb8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-link_stat_p8_0",
    &setup_link_stat_pe_3_common,
    { { &setup_link_stat_pe_0_proc1 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pe_0_final,
    { { &test_link_stat_pb8_0_0, 0, "link" },
      { &test_link_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-link_stat_p4_0",
    &setup_link_stat_p4_0_common,
    { { &setup_link_stat_pe_0_proc1 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pe_0_final,
    { { &test_link_stat_p4_0_0, 0, "link" },
      { &test_link_stat_pe_2_1, 0, "stat" } },
    &cleanup },
  { "fs-link_stat_p0_0",
    &setup_link_stat_p0_0_common,
    { { &setup_link_stat_pe_0_proc1 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pe_0_procfinal,
    { { &test_link_stat_p4_0_0, 0, "link" },
      { &test_link_stat_pc_1_1, 0, "stat" } },
    &cleanup },
  { "fs-link_stat_p0_1",
    &setup_link_stat_p0_0_common,
    { { &setup_link_stat_pe_0_proc1 }, { &setup_link_stat_pe_0_proc1 } },
    &setup_link_stat_pe_0_procfinal,
    &setup_link_stat_pe_0_procfinal,
    { { &test_link_stat_p4_0_0, 0, "link" },
      { &test_link_stat_p0_1_1, 0, "stat" } },
    &cleanup },
  { "fs-link_unlink_pf8_0",
    &setup_link_unlink_pf8_0_common,
    { { &setup_link_unlink_pf8_0_proc0 }, { &setup_link_unlink_pf8_0_proc1 } },
    &setup_link_unlink_pf8_0_procfinal,
    &setup_link_unlink_pf8_0_final,
    { { &test_link_unlink_pf8_0_0, 0, "link" },
      { &test_link_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-link_unlink_pf8_1",
    &setup_link_unlink_pf8_1_common,
    { { &setup_link_unlink_pf8_0_proc1 }, { &setup_link_unlink_pf8_0_proc1 } },
    &setup_link_unlink_pf8_0_procfinal,
    &setup_link_unlink_pf8_0_final,
    { { &test_link_unlink_pf8_1_0, 0, "link" },
      { &test_link_unlink_pf8_1_1, 0, "unlink" } },
    &cleanup },
  { "fs-link_unlink_pc_0",
    &setup_link_unlink_pf8_1_common,
    { { &setup_link_unlink_pf8_0_proc1 }, { &setup_link_unlink_pf8_0_proc1 } },
    &setup_link_unlink_pf8_0_procfinal,
    &setup_link_unlink_pf8_0_final,
    { { &test_link_unlink_pf8_0_0, 0, "link" },
      { &test_link_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-link_unlink_pc_1",
    &setup_link_unlink_pc_1_common,
    { { &setup_link_unlink_pf8_0_proc1 }, { &setup_link_unlink_pf8_0_proc1 } },
    &setup_link_unlink_pf8_0_procfinal,
    &setup_link_unlink_pf8_0_final,
    { { &test_link_unlink_pf8_1_0, 0, "link" },
      { &test_link_unlink_pc_1_1, 0, "unlink" } },
    &cleanup },
  { "fs-link_unlink_pb8_0",
    &setup_link_unlink_pb8_0_common,
    { { &setup_link_unlink_pf8_0_proc1 }, { &setup_link_unlink_pf8_0_proc1 } },
    &setup_link_unlink_pf8_0_procfinal,
    &setup_link_unlink_pf8_0_final,
    { { &test_link_unlink_pb8_0_0, 0, "link" },
      { &test_link_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-link_unlink_p8_0",
    &setup_link_unlink_pc_1_common,
    { { &setup_link_unlink_pf8_0_proc1 }, { &setup_link_unlink_pf8_0_proc1 } },
    &setup_link_unlink_pf8_0_procfinal,
    &setup_link_unlink_pf8_0_final,
    { { &test_link_unlink_pb8_0_0, 0, "link" },
      { &test_link_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-link_unlink_p4_0",
    &setup_link_unlink_p4_0_common,
    { { &setup_link_unlink_pf8_0_proc1 }, { &setup_link_unlink_pf8_0_proc1 } },
    &setup_link_unlink_pf8_0_procfinal,
    &setup_link_unlink_pf8_0_final,
    { { &test_link_unlink_p4_0_0, 0, "link" },
      { &test_link_unlink_pf8_1_1, 0, "unlink" } },
    &cleanup },
  { "fs-link_unlink_p0_0",
    &setup_link_unlink_p0_0_common,
    { { &setup_link_unlink_pf8_0_proc1 }, { &setup_link_unlink_pf8_0_proc1 } },
    &setup_link_unlink_pf8_0_procfinal,
    &setup_link_unlink_pf8_0_procfinal,
    { { &test_link_unlink_p4_0_0, 0, "link" },
      { &test_link_unlink_pc_1_1, 0, "unlink" } },
    &cleanup },
  { "fs-link_unlink_p0_1",
    &setup_link_unlink_p0_0_common,
    { { &setup_link_unlink_pf8_0_proc1 }, { &setup_link_unlink_pf8_0_proc1 } },
    &setup_link_unlink_pf8_0_procfinal,
    &setup_link_unlink_pf8_0_procfinal,
    { { &test_link_unlink_p4_0_0, 0, "link" },
      { &test_link_unlink_p0_1_1, 0, "unlink" } },
    &cleanup },
  { "fs-link_write_pfe_0",
    &setup_link_write_pfe_0_common,
    { { &setup_link_write_pfe_0_proc0 }, { &setup_link_write_pfe_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pfe_1",
    &setup_link_write_pfe_1_common,
    { { &setup_link_write_pfe_0_proc0 }, { &setup_link_write_pfe_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pfc_0",
    &setup_link_write_pfc_0_common,
    { { &setup_link_write_pfc_0_proc0 }, { &setup_link_write_pfc_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pfc_1",
    &setup_link_write_pfc_1_common,
    { { &setup_link_write_pfc_0_proc0 }, { &setup_link_write_pfc_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pf8_0",
    &setup_link_write_pf8_0_common,
    { { &setup_link_write_pf8_0_proc0 }, { &setup_link_write_pfc_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pf8_1",
    &setup_link_write_pf8_1_common,
    { { &setup_link_write_pf8_0_proc0 }, { &setup_link_write_pfc_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pf4_0",
    &setup_link_write_pf4_0_common,
    { { &setup_link_write_pf4_0_proc0 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pf4_1",
    &setup_link_write_pf4_1_common,
    { { &setup_link_write_pf4_0_proc0 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pf0_0",
    &setup_link_write_pf0_0_common,
    { { &setup_link_write_pf4_0_proc0 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pf0_1",
    &setup_link_write_pf0_1_common,
    { { &setup_link_write_pf4_0_proc0 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pe_0",
    &setup_link_write_pf4_0_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pe_1",
    &setup_link_write_pf4_1_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pde_0",
    &setup_link_write_pfe_0_common,
    { { &setup_link_write_pfe_0_proc1 }, { &setup_link_write_pfe_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pde_1",
    &setup_link_write_pfe_1_common,
    { { &setup_link_write_pfe_0_proc1 }, { &setup_link_write_pfe_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pdc_0",
    &setup_link_write_pfc_0_common,
    { { &setup_link_write_pfc_0_proc1 }, { &setup_link_write_pfc_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pdc_1",
    &setup_link_write_pfc_1_common,
    { { &setup_link_write_pfc_0_proc1 }, { &setup_link_write_pfc_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pd8_0",
    &setup_link_write_pf8_0_common,
    { { &setup_link_write_pfc_0_proc1 }, { &setup_link_write_pf8_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pd8_1",
    &setup_link_write_pf8_1_common,
    { { &setup_link_write_pfc_0_proc1 }, { &setup_link_write_pf8_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pd4_0",
    &setup_link_write_pf4_0_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc0 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pd4_1",
    &setup_link_write_pf4_1_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc0 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pd0_0",
    &setup_link_write_pf0_0_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc0 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pd0_1",
    &setup_link_write_pf0_1_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc0 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pc_0",
    &setup_link_write_pf4_0_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pc_1",
    &setup_link_write_pf4_1_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pfe_1_0, 0, "link" },
      { &test_link_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_pbe_0",
    &setup_link_write_pbe_0_common,
    { { &setup_link_write_pfe_0_proc0 }, { &setup_link_write_pfe_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pbc_0",
    &setup_link_write_pbc_0_common,
    { { &setup_link_write_pfc_0_proc0 }, { &setup_link_write_pfc_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pb8_0",
    &setup_link_write_pbc_0_common,
    { { &setup_link_write_pf8_0_proc0 }, { &setup_link_write_pfc_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pb4_0",
    &setup_link_write_pb4_0_common,
    { { &setup_link_write_pb4_0_proc0 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pb0_0",
    &setup_link_write_pb0_0_common,
    { { &setup_link_write_pb4_0_proc0 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_pa0_0",
    &setup_link_write_pf4_1_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_p9e_0",
    &setup_link_write_pbe_0_common,
    { { &setup_link_write_pfe_0_proc1 }, { &setup_link_write_pfe_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p9c_0",
    &setup_link_write_pbc_0_common,
    { { &setup_link_write_pfc_0_proc1 }, { &setup_link_write_pfc_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p98_0",
    &setup_link_write_pbc_0_common,
    { { &setup_link_write_pfc_0_proc1 }, { &setup_link_write_pf8_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p94_0",
    &setup_link_write_pb4_0_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pb4_0_proc0 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p90_0",
    &setup_link_write_pb0_0_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pb4_0_proc0 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p80_0",
    &setup_link_write_pf4_1_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_pbe_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p7c_0",
    &setup_link_write_p7c_0_common,
    { { &setup_link_write_pfe_0_proc0 }, { &setup_link_write_pfe_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_p78_0",
    &setup_link_write_p78_0_common,
    { { &setup_link_write_pfc_0_proc0 }, { &setup_link_write_pfc_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_p70_0",
    &setup_link_write_p70_0_common,
    { { &setup_link_write_pf8_0_proc0 }, { &setup_link_write_pfc_0_proc1 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_p68_0",
    &setup_link_write_p68_0_common,
    { { &setup_link_write_pf4_0_proc0 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_p60_0",
    &setup_link_write_p60_0_common,
    { { &setup_link_write_pf4_0_proc0 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_p4_0",
    &setup_link_write_p4_0_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_procfinal,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-link_write_p3c_0",
    &setup_link_write_p7c_0_common,
    { { &setup_link_write_pfe_0_proc1 }, { &setup_link_write_pfe_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p38_0",
    &setup_link_write_p78_0_common,
    { { &setup_link_write_pfc_0_proc1 }, { &setup_link_write_pfc_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p30_0",
    &setup_link_write_p70_0_common,
    { { &setup_link_write_pfc_0_proc1 }, { &setup_link_write_pf8_0_proc0 } },
    &setup_link_write_pfe_0_procfinal,
    &setup_link_write_pfe_0_final,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p28_0",
    &setup_link_write_p68_0_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc0 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p20_0",
    &setup_link_write_p60_0_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc0 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_final,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-link_write_p0_0",
    &setup_link_write_p4_0_common,
    { { &setup_link_write_pf4_0_proc1 }, { &setup_link_write_pf4_0_proc1 } },
    &setup_link_write_pf4_0_procfinal,
    &setup_link_write_pf4_0_procfinal,
    { { &test_link_write_p7c_0_0, 0, "link" },
      { &test_link_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_lseek_pf8_0",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_0_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf8_1",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_1_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf8_2",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf8_3",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf8_4",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_4_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf8_5",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf6_0",
    &setup_lseek_lseek_pf6_0_common,
    { { &setup_lseek_lseek_pf6_0_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf6_1",
    &setup_lseek_lseek_pf6_0_common,
    { { &setup_lseek_lseek_pf6_1_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf4_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf4_0_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf4_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf4_1_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf4_2",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf4_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf4_3",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf4_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf3_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf4_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf3_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf4_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf2_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf4_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf2_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf4_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf18_0",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pf4_0_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf18_1",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pf4_1_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf10_0",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pf4_0_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf10_1",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pf4_1_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf10_2",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf4_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf10_3",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf4_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf0_0",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf4_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pf0_1",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf4_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pe_0",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pe_1",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd8_0",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd8_1",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd8_2",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd8_3",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd6_0",
    &setup_lseek_lseek_pf6_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pd6_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd6_1",
    &setup_lseek_lseek_pf6_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pd6_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd4_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pd4_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd4_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pd4_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd4_2",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pd4_2_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd4_3",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pd4_2_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd3_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pd4_2_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd3_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pd4_2_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd2_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pd4_2_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd2_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pd4_2_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd18_0",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pd4_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd18_1",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pd4_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd10_0",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pd4_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd10_1",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pd4_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd10_2",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pd4_2_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd10_3",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pd4_2_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd0_0",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pd4_2_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pd0_1",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pd4_2_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pc_0",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pc_1",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_5_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbe_0",
    &setup_lseek_lseek_pf6_0_common,
    { { &setup_lseek_lseek_pbe_0_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbe_1",
    &setup_lseek_lseek_pf6_0_common,
    { { &setup_lseek_lseek_pbe_1_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbd8_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbd8_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbd0_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbd0_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbd0_2",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbd0_3",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbcc_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbcc_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc8_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc8_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc8_2",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbc8_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc8_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc8_3",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc8_3_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc6_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc6_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc6_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc4_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc4_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc4_2",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc4_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc4_3",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc4_4",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc4_4_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc0_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pbc0_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb8_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb6_0",
    &setup_lseek_lseek_pf6_0_common,
    { { &setup_lseek_lseek_pb6_0_proc0 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb6_1",
    &setup_lseek_lseek_pf6_0_common,
    { { &setup_lseek_lseek_pb6_0_proc0 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb58_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_1_proc0 }, { &setup_lseek_lseek_pb58_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb58_1",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb50_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb50_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb4c_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb48_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb48_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbc8_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb46_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb44_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb44_1",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc4_4_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb40_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_1_proc0 }, { &setup_lseek_lseek_pb58_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb40_1",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pb0_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd6_0_1, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pae_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pae_0_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pae_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pae_1_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pae_2",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pae_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pae_3",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pae_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pad8_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pad8_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pad8_2",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pad8_3",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pad0_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pad0_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pad0_2",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pad0_3",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pace_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac90_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac90_1",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac6_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac6_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pac6_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac6_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac6_3",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pac6_3_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac4_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac4_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac4_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pac4_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pac4_2_0, 0, "lseek" },
      { &test_lseek_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac4_3",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac4_4",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc4_4_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac4_5",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac0_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pac0_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa8_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa8_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa6_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pd4_0_proc1 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa6_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pd4_0_proc1 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa6_2",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pd4_2_proc1 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa6_3",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pd4_2_proc1 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa58_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa58_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa50_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa50_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa4c_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa48_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa46_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa46_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pac6_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa44_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa44_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa40_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa40_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa0_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_pa0_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd4_0_1, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9f_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pae_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9f_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pae_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9ec_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9ec_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9ea_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e6_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_p9e6_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9e6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e6_1",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_p9e6_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9e6_1_0, 0, "lseek" },
      { &test_lseek_lseek_p9e6_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e6_2",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9e6_1_0, 0, "lseek" },
      { &test_lseek_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e6_3",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e6_4",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e5_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e5_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_p9e5_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc8_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e3_0",
    &setup_lseek_lseek_p9e3_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9e3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e3_1",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_p9e3_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9e3_1_0, 0, "lseek" },
      { &test_lseek_lseek_p9e3_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e3_2",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_p9e3_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9e3_1_0, 0, "lseek" },
      { &test_lseek_lseek_p9e3_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e28_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9e28_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e28_1",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc4_4_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e0_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9e0_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9c_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9b_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pd4_2_proc1 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9b_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pd4_2_proc1 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9ac_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a8_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a6_0",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pb58_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9a6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a6_1",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9e6_1_0, 0, "lseek" },
      { &test_lseek_lseek_p9e6_1_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a6_2",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9e6_1_0, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a6_3",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a4_0",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_p9a4_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9a4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a4_1",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbc8_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a4_2",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a3_0",
    &setup_lseek_lseek_p9e3_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9a3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a3_1",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_p9e3_2_proc0 }, { &setup_lseek_lseek_p9e3_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9e3_1_0, 0, "lseek" },
      { &test_lseek_lseek_p9e3_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a2_0",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9a2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a2_1",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc4_4_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9a0_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p98_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd3_0_1, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p97_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pae_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p97_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pae_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p96c_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p96c_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p96c_1_0, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p96c_2",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbc8_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc8_3_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p96c_3",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p96c_4",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc8_3_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9690_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9690_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p967_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p967_1",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_p9e6_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc8_3_1, 0, "lseek" },
      { &test_lseek_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p964c_0",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p963_0",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9e3_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p963_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc8_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc8_3_1, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p963_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p96c_1_0, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p963_3",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc8_3_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p963_4",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pac6_3_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9624_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p9624_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9624_0_0, 0, "lseek" },
      { &test_lseek_lseek_p9624_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9624_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9624_1_0, 0, "lseek" },
      { &test_lseek_lseek_pd10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p9624_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p960_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p960_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p94_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p93_0",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pd4_2_proc1 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p93_1",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pd4_2_proc1 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p92c_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p92c_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbc8_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc8_3_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p928_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p926_0",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_p9a4_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_p926_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p926_1",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc8_3_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p926_2",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p926_2_0, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p926_3",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p924_0",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_p924_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_p924_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p924_1",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_p924_0_proc1 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p924_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p924_2",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p923_0",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9e3_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p923_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbc8_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc8_3_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p922_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p920_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p90_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f8_0",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pae_0_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f8_1",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pae_1_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f6_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f6_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc6_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f4_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f4_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p8f4_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8f4_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f4_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f4_3",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p9a4_0_proc1 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pac4_2_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f3_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p8f3_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9e6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f3_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_p8f3_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pac6_3_1, 0, "lseek" },
      { &test_lseek_lseek_p8f3_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f3_2",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_p8f3_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9a3_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8f3_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f3_3",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_p9e3_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9e3_2_1, 0, "lseek" },
      { &test_lseek_lseek_p9e3_1_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f2_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pac4_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8f2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f2_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p96c_1_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f2_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p8f2_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc8_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f2_3",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc8_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc8_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f2_4",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc8_3_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f18_0",
    &setup_lseek_lseek_p8f18_0_common,
    { { &setup_lseek_lseek_p8f18_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9e3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f18_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f18_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f10_0",
    &setup_lseek_lseek_p8f10_0_common,
    { { &setup_lseek_lseek_p8f10_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8f10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f10_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f10_2",
    &setup_lseek_lseek_p8f10_2_common,
    { { &setup_lseek_lseek_p8f10_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8f10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f10_3",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pac4_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8f10_3_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f10_4",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f10_5",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pb58_0_proc1 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8f10_5_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f0_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8f0_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc6_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8e_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d8_0",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pd4_0_proc1 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d8_1",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pd4_0_proc1 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d6_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d4_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d4_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p9a4_0_proc1 }, { &setup_lseek_lseek_p9a4_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pac4_2_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d3_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pb58_0_proc1 }, { &setup_lseek_lseek_pb58_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9a6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d3_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_p9a4_0_proc1 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pac6_3_1, 0, "lseek" },
      { &test_lseek_lseek_p8d3_1_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d3_2",
    &setup_lseek_lseek_p9e3_0_common,
    { { &setup_lseek_lseek_p8d3_2_proc0 }, { &setup_lseek_lseek_p8d3_2_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9a3_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8d3_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d2_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p9a4_0_proc1 }, { &setup_lseek_lseek_p9a4_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9a4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d2_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pb58_0_proc1 }, { &setup_lseek_lseek_p9a4_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8d2_1_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d2_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p924_0_proc1 }, { &setup_lseek_lseek_pbc8_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d2_3",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc8_3_proc0 }, { &setup_lseek_lseek_pbc8_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pbc8_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d18_0",
    &setup_lseek_lseek_p8f18_0_common,
    { { &setup_lseek_lseek_p8d18_0_proc0 }, { &setup_lseek_lseek_p8d18_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9a3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d18_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d10_0",
    &setup_lseek_lseek_p8f10_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_p8d10_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9a2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d10_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d10_2",
    &setup_lseek_lseek_p8f10_2_common,
    { { &setup_lseek_lseek_pb58_0_proc1 }, { &setup_lseek_lseek_p8d10_2_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8d10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d10_3",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p9a4_0_proc1 }, { &setup_lseek_lseek_p9a4_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_p8d10_3_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8d0_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8c_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd18_0_1, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b8_0",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pae_0_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b8_1",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pae_1_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b8_2",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pae_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b8_3",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pae_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b6_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b6_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b6_2",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b6_3",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b6_4",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc4_4_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b6_5",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc4_4_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b4_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b4_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b4_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b4_3",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b38_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc8_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9e6_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b38_1",
    &setup_lseek_lseek_p8b38_1_common,
    { { &setup_lseek_lseek_p8b38_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p8b38_1_0, 0, "lseek" },
      { &test_lseek_lseek_p8b38_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b38_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b38_3",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc4_4_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b24_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p9624_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9624_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9624_0_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b24_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_p9624_1_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b24_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b18_0",
    &setup_lseek_lseek_p8f10_0_common,
    { { &setup_lseek_lseek_p8f10_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9e3_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b18_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b18_2",
    &setup_lseek_lseek_p8b18_2_common,
    { { &setup_lseek_lseek_p8b18_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b18_3",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b18_4",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b18_5",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b10_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b10_1",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_p8b10_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p8b10_1_0, 0, "lseek" },
      { &test_lseek_lseek_p8b10_1_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b0_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8b0_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8a_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8a_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p898_0",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pd4_0_proc1 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p898_1",
    &setup_lseek_lseek_pf18_0_common,
    { { &setup_lseek_lseek_pd4_0_proc1 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p898_2",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pd4_2_proc1 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p898_3",
    &setup_lseek_lseek_pf4_0_common,
    { { &setup_lseek_lseek_pd4_2_proc1 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p896_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p896_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p896_2",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc4_4_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p894_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p894_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p893_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p9a4_0_proc1 }, { &setup_lseek_lseek_p9a4_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_p926_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p893_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_p9a4_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_p926_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p893_2",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_p9a4_0_proc1 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc4_4_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p893_3",
    &setup_lseek_lseek_pbc4_2_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pbc4_4_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p893_4",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9a2_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p892_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p924_0_proc1 }, { &setup_lseek_lseek_p924_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_p924_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p892_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_p9a4_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_p9a4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p892_2",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8918_0",
    &setup_lseek_lseek_p8f10_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_p8d10_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9e3_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8918_1",
    &setup_lseek_lseek_p8918_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_p8918_1_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_p8918_1_0, 0, "lseek" },
      { &test_lseek_lseek_p8918_1_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8918_2",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8918_3",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8910_0",
    &setup_lseek_lseek_p8910_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_p8d10_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8910_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8910_2",
    &setup_lseek_lseek_p8910_2_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_p8918_1_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_p8f18_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_p9a2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p8910_3",
    &setup_lseek_lseek_p9e3_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_p9a2_0_1, 0, "lseek" },
      { &test_lseek_lseek_p9a2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p890_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p890_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p88_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_0_1, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p88_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pd10_2_1, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p87_0",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pae_2_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p87_1",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pae_3_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p86c_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p86c_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p868_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p868_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p866_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p866_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p864_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p864_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p863_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p863_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbc6_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p862_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p862_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p860_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p860_1",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p84_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p83_0",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pd4_2_proc1 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p83_1",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pd4_2_proc1 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p82c_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_1_proc0 }, { &setup_lseek_lseek_pb58_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p82c_1",
    &setup_lseek_lseek_pb58_1_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p828_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p828_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p826_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p824_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p823_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p822_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_2_proc0 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p822_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p820_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p80_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd0_3_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pf8_0_0, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p7_0",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_p7_0_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p7_1",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_p7_1_proc0 }, { &setup_lseek_lseek_pf8_0_proc1 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p6c_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_p6c_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf6_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p68_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_p68_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p68_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_p68_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf4_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p66_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_p68_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf3_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p64_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_p68_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf2_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p63_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p68_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf18_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p62_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p68_0_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf10_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p62_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_p68_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf10_2_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p60_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_p68_1_proc0 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p4_0",
    &setup_lseek_lseek_p4_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_procfinal,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pe_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p4_1",
    &setup_lseek_lseek_p4_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_procfinal,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 0, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p3_0",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_0_proc1 }, { &setup_lseek_lseek_pf8_3_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p3_1",
    &setup_lseek_lseek_pf8_0_common,
    { { &setup_lseek_lseek_pf8_0_proc1 }, { &setup_lseek_lseek_pf8_5_proc0 } },
    &setup_lseek_lseek_pf8_0_procfinal,
    &setup_lseek_lseek_pf8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p2c_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pb58_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd6_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p28_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p28_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd4_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p26_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd3_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p24_0",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd2_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p23_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd18_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p22_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd0_2_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p22_1",
    &setup_lseek_lseek_pbd8_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pd10_2_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p20_0",
    &setup_lseek_lseek_pbc6_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd0_3_proc0 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_final,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pf8_0_0, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_lseek_p0_0",
    &setup_lseek_lseek_p4_0_common,
    { { &setup_lseek_lseek_pbd8_0_proc1 }, { &setup_lseek_lseek_pbd8_0_proc1 } },
    &setup_lseek_lseek_pbd8_0_procfinal,
    &setup_lseek_lseek_pbd8_0_procfinal,
    { { &test_lseek_lseek_pc_0_1, 0, "lseek" },
      { &test_lseek_lseek_pc_0_1, 1, "lseek" } },
    &cleanup },
  { "fs-lseek_memread_pf8_0",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pf8_0_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf8_1",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pf8_1_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf8_2",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pf8_2_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf8_3",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pf8_3_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf4_0",
    &setup_lseek_memread_pf4_0_common,
    { { &setup_lseek_memread_pf4_0_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf4_1",
    &setup_lseek_memread_pf4_0_common,
    { { &setup_lseek_memread_pf4_1_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf4_2",
    &setup_lseek_memread_pf4_0_common,
    { { &setup_lseek_memread_pf4_2_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf4_3",
    &setup_lseek_memread_pf4_0_common,
    { { &setup_lseek_memread_pf4_3_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf0_0",
    &setup_lseek_memread_pf0_0_common,
    { { &setup_lseek_memread_pf4_0_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf0_1",
    &setup_lseek_memread_pf0_0_common,
    { { &setup_lseek_memread_pf4_1_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf0_2",
    &setup_lseek_memread_pf0_0_common,
    { { &setup_lseek_memread_pf4_2_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pf0_3",
    &setup_lseek_memread_pf0_0_common,
    { { &setup_lseek_memread_pf4_3_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pe_0",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pe_0_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pe_1",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pe_1_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd8_0",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pe_0_proc0 }, { &setup_lseek_memread_pd8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd8_1",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pe_1_proc0 }, { &setup_lseek_memread_pd8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd8_2",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pe_0_proc0 }, { &setup_lseek_memread_pd8_2_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd8_3",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pe_1_proc0 }, { &setup_lseek_memread_pd8_2_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd4_0",
    &setup_lseek_memread_pf4_0_common,
    { { &setup_lseek_memread_pe_0_proc0 }, { &setup_lseek_memread_pd4_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd4_1",
    &setup_lseek_memread_pf4_0_common,
    { { &setup_lseek_memread_pe_1_proc0 }, { &setup_lseek_memread_pd4_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd4_2",
    &setup_lseek_memread_pf4_0_common,
    { { &setup_lseek_memread_pe_0_proc0 }, { &setup_lseek_memread_pd4_2_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd4_3",
    &setup_lseek_memread_pf4_0_common,
    { { &setup_lseek_memread_pe_1_proc0 }, { &setup_lseek_memread_pd4_2_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd0_0",
    &setup_lseek_memread_pf0_0_common,
    { { &setup_lseek_memread_pe_0_proc0 }, { &setup_lseek_memread_pd4_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd0_1",
    &setup_lseek_memread_pf0_0_common,
    { { &setup_lseek_memread_pe_1_proc0 }, { &setup_lseek_memread_pd4_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd0_2",
    &setup_lseek_memread_pf0_0_common,
    { { &setup_lseek_memread_pe_0_proc0 }, { &setup_lseek_memread_pd4_2_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pd0_3",
    &setup_lseek_memread_pf0_0_common,
    { { &setup_lseek_memread_pe_1_proc0 }, { &setup_lseek_memread_pd4_2_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pc_0",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pe_0_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pc_1",
    &setup_lseek_memread_pf8_0_common,
    { { &setup_lseek_memread_pe_1_proc0 }, { &setup_lseek_memread_pf8_0_proc1 } },
    &setup_lseek_memread_pf8_0_procfinal,
    &setup_lseek_memread_pf8_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pbe_0",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pbe_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pbe_1",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pbe_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pbd_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pbd_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pbd_2",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pbd_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pbc_0",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pbc_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pbc_2",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pbc_3",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb8_0",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pb8_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb6_0",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pb8_0_proc0 }, { &setup_lseek_memread_pb6_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb6_1",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pb8_0_proc0 }, { &setup_lseek_memread_pb6_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb5_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb5_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb5_2",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb5_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb4_0",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb4_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb4_2",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb4_3",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pb0_0",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pb8_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pbe_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pae_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pae_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pae_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pae_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pad_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pad_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pad_2",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pad_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pad_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pad_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pad_4",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pad_5",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pac_0",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pac_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pac_2",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pac_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pac_3",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pad_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pac_4",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pac_5",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa8_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa6_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb6_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa6_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb6_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa5_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa5_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa5_2",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pa5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa5_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pa5_3_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa5_4",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa5_5",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa4_0",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa4_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa4_2",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pa4_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa4_3",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pa4_3_proc0 }, { &setup_lseek_memread_pa4_3_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pa4_3_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa4_4",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa4_5",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_pa0_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pae_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9f_0",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pae_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9f_1",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pae_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9e8_0",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_p9e8_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9e8_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9e8_2",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9e0_0",
    &setup_lseek_memread_p9e0_0_common,
    { { &setup_lseek_memread_p9e0_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9e0_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9e0_2",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9c_0",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9b_0",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb6_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9b_1",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb6_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9a8_0",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_p9a8_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9a8_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9a8_2",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9a0_0",
    &setup_lseek_memread_p9e0_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_p9a0_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9a0_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p9a0_2",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p98_0",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p9f_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p97_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pae_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p97_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pae_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p968_0",
    &setup_lseek_memread_p968_0_common,
    { { &setup_lseek_memread_p968_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p968_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p968_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p968_1_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p968_2",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p968_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p968_2_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p968_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pad_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p968_2_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p968_4",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p968_5",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pad_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p968_6",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p960_0",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pac_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p960_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_p968_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p968_1_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p960_2",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_p968_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p968_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p960_3",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pad_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p968_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p960_4",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p960_5",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pad_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p960_6",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p94_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p93_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb6_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p93_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb6_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p928_0",
    &setup_lseek_memread_p968_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_p928_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p928_1",
    &setup_lseek_memread_p9e0_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_p928_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p928_1_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p928_2",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p968_2_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p928_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p928_4",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p928_4_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p928_5",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p920_0",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pa4_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p920_1",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pa4_3_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p920_1_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p920_2",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p968_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p920_3",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_p920_3_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p968_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p920_4",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p920_5",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_p920_5_proc0 }, { &setup_lseek_memread_pa4_3_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p920_5_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p920_6",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p90_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p97_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f8_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8f8_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f8_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8f8_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f4_0",
    &setup_lseek_memread_p8f4_0_common,
    { { &setup_lseek_memread_p8f4_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f4_1",
    &setup_lseek_memread_p8f4_0_common,
    { { &setup_lseek_memread_p8f4_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f4_2",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8f4_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f4_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8f4_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f4_4",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8f4_4_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f0_0",
    &setup_lseek_memread_p8f0_0_common,
    { { &setup_lseek_memread_p8f0_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f0_1",
    &setup_lseek_memread_p8f0_0_common,
    { { &setup_lseek_memread_p8f0_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f0_2",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_p8f0_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f0_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f0_3",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f0_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8f0_4",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f0_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8e_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8e_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d8_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8e_0_proc0 }, { &setup_lseek_memread_pb6_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d8_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8e_0_proc0 }, { &setup_lseek_memread_pb6_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d4_0",
    &setup_lseek_memread_p8f4_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_p8d4_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d4_1",
    &setup_lseek_memread_p8f4_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_p8d4_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d4_2",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_p9a8_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d4_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8d4_3_proc0 }, { &setup_lseek_memread_p9a8_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d4_4",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8d4_3_proc0 }, { &setup_lseek_memread_p8d4_4_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d0_0",
    &setup_lseek_memread_p8f0_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_p8d0_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d0_1",
    &setup_lseek_memread_p8f0_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_p8d0_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d0_2",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f0_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d0_3",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f0_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8d0_4",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f0_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8c_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8e_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b8_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pae_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b8_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pae_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_0",
    &setup_lseek_memread_p8b4_0_common,
    { { &setup_lseek_memread_p8b4_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_1",
    &setup_lseek_memread_p8b4_0_common,
    { { &setup_lseek_memread_p8b4_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_2",
    &setup_lseek_memread_p8b4_2_common,
    { { &setup_lseek_memread_p8b4_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b4_2_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8b4_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_4",
    &setup_lseek_memread_p8b4_4_common,
    { { &setup_lseek_memread_p8b4_4_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b4_4_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_5",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_p968_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_5_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_6",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pad_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_5_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_7",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p8b4_7_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_8",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_9",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b4_10",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_0",
    &setup_lseek_memread_p8f4_0_common,
    { { &setup_lseek_memread_p8b0_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_1",
    &setup_lseek_memread_p8f4_0_common,
    { { &setup_lseek_memread_p8b0_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_2",
    &setup_lseek_memread_p8b0_2_common,
    { { &setup_lseek_memread_p8b0_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b4_4_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_3",
    &setup_lseek_memread_p8b0_2_common,
    { { &setup_lseek_memread_p8b0_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b4_4_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_4",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_5_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_5",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pac_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_6",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b0_6_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_7",
    &setup_lseek_memread_pbe_0_common,
    { { &setup_lseek_memread_pad_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_4_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_8",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_5_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_9",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_p8b0_9_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_5_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8b0_10",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_5_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p8a_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p898_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb6_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p898_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb6_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_0",
    &setup_lseek_memread_p8b4_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_p894_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_1",
    &setup_lseek_memread_p8b4_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_p894_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_2",
    &setup_lseek_memread_p8b4_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_p894_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b4_2_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_p928_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_4",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_p920_3_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_5_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_5",
    &setup_lseek_memread_p8f4_0_common,
    { { &setup_lseek_memread_p894_5_proc0 }, { &setup_lseek_memread_p894_5_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p894_5_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_6",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p894_6_proc0 }, { &setup_lseek_memread_p894_6_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p894_6_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_7",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_p894_7_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_8",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_9",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p894_10",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p890_0",
    &setup_lseek_memread_p8f4_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_p890_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p890_1",
    &setup_lseek_memread_p8f4_0_common,
    { { &setup_lseek_memread_pa5_3_proc0 }, { &setup_lseek_memread_p890_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p890_2",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_5_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p890_3",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_5_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p890_4",
    &setup_lseek_memread_p8b0_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_p8d0_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p8b4_4_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p890_5",
    &setup_lseek_memread_pad_2_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pa4_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_2_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p890_6",
    &setup_lseek_memread_p8f0_0_common,
    { { &setup_lseek_memread_p920_5_proc0 }, { &setup_lseek_memread_p8d0_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_p8f4_0_final,
    { { &test_lseek_memread_p890_6_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p890_7",
    &setup_lseek_memread_p9e0_0_common,
    { { &setup_lseek_memread_pa4_3_proc0 }, { &setup_lseek_memread_p9a0_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p890_7_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p890_8",
    &setup_lseek_memread_p9e0_0_common,
    { { &setup_lseek_memread_p890_8_proc0 }, { &setup_lseek_memread_p890_8_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p890_8_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p890_9",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b4_5_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p88_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p87_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pae_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p87_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pae_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p868_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p868_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p868_2",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p868_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p860_0",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_0_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p860_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_2_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p860_2",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p860_3",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbd_3_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p84_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p83_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb6_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p83_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb6_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p828_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p828_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p828_2",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p828_3",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p820_0",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p820_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_0_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p820_2",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p820_3",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p80_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_1_proc0 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_pf8_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p7_0",
    &setup_lseek_memread_p7_0_common,
    { { &setup_lseek_memread_pb6_0_proc1 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_procfinal,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p7_1",
    &setup_lseek_memread_p7_0_common,
    { { &setup_lseek_memread_pb6_1_proc1 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_procfinal,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p68_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_0_proc1 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p68_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pb5_2_proc1 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p60_0",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_0_proc1 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p60_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pb5_2_proc1 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p4_0",
    &setup_lseek_memread_p7_0_common,
    { { &setup_lseek_memread_pbe_0_proc1 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_procfinal,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p3_0",
    &setup_lseek_memread_p7_0_common,
    { { &setup_lseek_memread_pbe_0_proc1 }, { &setup_lseek_memread_pb6_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_procfinal,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p3_1",
    &setup_lseek_memread_p7_0_common,
    { { &setup_lseek_memread_pbe_0_proc1 }, { &setup_lseek_memread_pb6_1_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_procfinal,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p28_0",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbe_0_proc1 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p28_1",
    &setup_lseek_memread_pbd_0_common,
    { { &setup_lseek_memread_pbe_0_proc1 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p20_0",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbe_0_proc1 }, { &setup_lseek_memread_pb5_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p20_1",
    &setup_lseek_memread_pbc_0_common,
    { { &setup_lseek_memread_pbe_0_proc1 }, { &setup_lseek_memread_pb5_2_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_final,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pf8_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memread_p0_0",
    &setup_lseek_memread_p7_0_common,
    { { &setup_lseek_memread_pbe_0_proc1 }, { &setup_lseek_memread_pbe_0_proc1 } },
    &setup_lseek_memread_pbe_0_procfinal,
    &setup_lseek_memread_pbe_0_procfinal,
    { { &test_lseek_memread_p7_0_0, 0, "lseek" },
      { &test_lseek_memread_pe_0_1, 1, "memread" } },
    &cleanup },
  { "fs-lseek_memwrite_pfc_0",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pfc_0_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pfc_1",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pfc_1_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pfa_0",
    &setup_lseek_memwrite_pfa_0_common,
    { { &setup_lseek_memwrite_pfa_0_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pfa_1",
    &setup_lseek_memwrite_pfa_0_common,
    { { &setup_lseek_memwrite_pfa_1_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pf8_0",
    &setup_lseek_memwrite_pf8_0_common,
    { { &setup_lseek_memwrite_pf8_0_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pf8_1",
    &setup_lseek_memwrite_pf8_0_common,
    { { &setup_lseek_memwrite_pf8_1_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pf0_0",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pf0_0_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pf0_1",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pf0_1_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pf0_2",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pf0_2_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pf0_3",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pf0_3_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pe_0",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pe_0_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pe_1",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pe_1_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pdc_0",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pe_0_proc0 }, { &setup_lseek_memwrite_pdc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pdc_1",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pe_1_proc0 }, { &setup_lseek_memwrite_pdc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pda_0",
    &setup_lseek_memwrite_pda_0_common,
    { { &setup_lseek_memwrite_pe_0_proc0 }, { &setup_lseek_memwrite_pda_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pda_1",
    &setup_lseek_memwrite_pda_0_common,
    { { &setup_lseek_memwrite_pe_1_proc0 }, { &setup_lseek_memwrite_pda_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pd8_0",
    &setup_lseek_memwrite_pf8_0_common,
    { { &setup_lseek_memwrite_pe_0_proc0 }, { &setup_lseek_memwrite_pda_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pd8_1",
    &setup_lseek_memwrite_pf8_0_common,
    { { &setup_lseek_memwrite_pe_1_proc0 }, { &setup_lseek_memwrite_pda_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pd0_0",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pe_0_proc0 }, { &setup_lseek_memwrite_pd0_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pd0_1",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pe_1_proc0 }, { &setup_lseek_memwrite_pd0_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pd0_2",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pe_0_proc0 }, { &setup_lseek_memwrite_pd0_2_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pd0_3",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pe_1_proc0 }, { &setup_lseek_memwrite_pd0_2_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pc_0",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pe_0_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pc_1",
    &setup_lseek_memwrite_pfc_0_common,
    { { &setup_lseek_memwrite_pe_1_proc0 }, { &setup_lseek_memwrite_pfc_0_proc1 } },
    &setup_lseek_memwrite_pfc_0_procfinal,
    &setup_lseek_memwrite_pfc_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pbf_0",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pbf_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pbe8_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbe8_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pbe8_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbe8_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pbe0_0",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pbe0_1",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pbc_0",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pbc_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pbc_1",
    &setup_lseek_memwrite_pbc_1_common,
    { { &setup_lseek_memwrite_pbc_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pbc_2",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pbc_2_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pb8_0",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pb8_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pb7_0",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pb8_0_proc0 }, { &setup_lseek_memwrite_pb7_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pb68_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_0_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pb68_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pb60_0",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_0_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pb60_1",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pb4_0",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pb8_0_proc0 }, { &setup_lseek_memwrite_pb4_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pb4_1",
    &setup_lseek_memwrite_pbc_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pb4_2",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pb8_0_proc0 }, { &setup_lseek_memwrite_pb4_2_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pb0_0",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pb8_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pbf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_paf_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_paf_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pae8_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbe8_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pae8_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pae8_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pae8_2",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pae8_2_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pae8_3",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pae0_0",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pae0_1",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pae0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pae0_2",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pac_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbc_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pac_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pac_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa8_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa7_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb7_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa68_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_0_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa68_1",
    &setup_lseek_memwrite_pbc_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pa68_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa68_2",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa60_0",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_0_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa60_1",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pa60_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa60_2",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa4_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa4_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_2_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_pa0_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_paf_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9f8_0",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_paf_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9f4_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p9f4_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9f4_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9f0_0",
    &setup_lseek_memwrite_p9f0_0_common,
    { { &setup_lseek_memwrite_p9f0_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9f0_1",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9e_0",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_p9e_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9e_1",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pbc_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9e_2",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pac_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9c_0",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9b8_0",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb7_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9b4_0",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_p9b4_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9b4_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9b0_0",
    &setup_lseek_memwrite_p9f0_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_p9b0_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9b0_1",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9a_0",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_p9a_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9a_1",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p9a_2",
    &setup_lseek_memwrite_pbf_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_2_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p98_0",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p9f8_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p978_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_paf_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p974_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p974_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p974_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p974_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p974_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p974_2",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p970_0",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pae0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p970_1",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_p974_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p974_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p970_2",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p96_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbc_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p96_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pac_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p94_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p938_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb7_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p934_0",
    &setup_lseek_memwrite_pbc_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pa68_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p934_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p934_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p974_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p934_2",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p930_0",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pa60_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p930_1",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_p934_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p974_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p930_2",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p92_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p92_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_2_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p90_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p978_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8fc_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8fc_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8fa_0",
    &setup_lseek_memwrite_p8fa_0_common,
    { { &setup_lseek_memwrite_p8fa_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8fa_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8fa_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8fa_2",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8fa_2_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8f8_0",
    &setup_lseek_memwrite_p8f8_0_common,
    { { &setup_lseek_memwrite_p8f8_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8f8_1",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8f8_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8f0_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8f0_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8f0_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8f0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8f0_2",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8f0_2_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8e_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8e_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8dc_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8e_0_proc0 }, { &setup_lseek_memwrite_pb7_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8da_0",
    &setup_lseek_memwrite_p8da_0_common,
    { { &setup_lseek_memwrite_p8da_0_proc0 }, { &setup_lseek_memwrite_p8da_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8da_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_0_proc0 }, { &setup_lseek_memwrite_p9b4_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8da_2",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8da_2_proc0 }, { &setup_lseek_memwrite_p9b4_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8d8_0",
    &setup_lseek_memwrite_p8f8_0_common,
    { { &setup_lseek_memwrite_p8da_0_proc0 }, { &setup_lseek_memwrite_p8d8_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8d8_1",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_p8da_0_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8f8_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8d8_2",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8f8_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8d0_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8e_0_proc0 }, { &setup_lseek_memwrite_p8d0_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8d0_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8d0_1_proc0 }, { &setup_lseek_memwrite_p8d0_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8d0_2",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8e_0_proc0 }, { &setup_lseek_memwrite_pb4_2_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8c_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8e_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8fc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8bc_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_paf_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8ba_0",
    &setup_lseek_memwrite_p8fa_0_common,
    { { &setup_lseek_memwrite_p8ba_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8ba_1",
    &setup_lseek_memwrite_p8ba_1_common,
    { { &setup_lseek_memwrite_p8ba_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8ba_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8ba_2",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8ba_2_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8ba_3",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pae8_2_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8ba_3_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8ba_4",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p974_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8ba_5",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8b8_0",
    &setup_lseek_memwrite_p8da_0_common,
    { { &setup_lseek_memwrite_p8b8_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8b8_1",
    &setup_lseek_memwrite_p8b8_1_common,
    { { &setup_lseek_memwrite_p8b8_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8ba_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8b8_2",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8ba_3_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8b8_3",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pae0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8b8_3_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8b8_4",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8ba_3_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8b0_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbc_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8b0_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pac_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p8a_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p89c_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb7_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p89a_0",
    &setup_lseek_memwrite_p89a_0_common,
    { { &setup_lseek_memwrite_p8da_0_proc0 }, { &setup_lseek_memwrite_p89a_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p89a_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_0_proc0 }, { &setup_lseek_memwrite_p89a_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p89a_2",
    &setup_lseek_memwrite_p89a_2_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_p89a_2_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8ba_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p89a_3",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_p89a_3_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8ba_3_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p89a_4",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p934_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p89a_5",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p898_0",
    &setup_lseek_memwrite_p8da_0_common,
    { { &setup_lseek_memwrite_p8da_0_proc0 }, { &setup_lseek_memwrite_p898_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p898_1",
    &setup_lseek_memwrite_p8b8_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_p8d8_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_p8fa_0_final,
    { { &test_lseek_memwrite_p8ba_1_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p898_2",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_0_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8ba_3_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p898_3",
    &setup_lseek_memwrite_pae0_1_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pa60_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8b8_3_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p898_4",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8ba_3_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p890_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p890_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_2_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p88_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p8bc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p878_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_paf_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p874_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbe8_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p874_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_p8fa_2_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p870_0",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_0_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p870_1",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbe0_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p86_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbc_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p86_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pac_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p84_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p838_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb7_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p834_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_0_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p834_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p830_0",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_0_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p830_1",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p82_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p82_1",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pb4_2_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p80_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb68_1_proc0 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_pfc_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p78_0",
    &setup_lseek_memwrite_p78_0_common,
    { { &setup_lseek_memwrite_pb7_0_proc1 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_procfinal,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p74_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pa68_1_proc1 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p70_0",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pb68_0_proc1 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p6_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pb4_1_proc1 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p6_1",
    &setup_lseek_memwrite_p78_0_common,
    { { &setup_lseek_memwrite_pb4_2_proc1 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_procfinal,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p4_0",
    &setup_lseek_memwrite_p78_0_common,
    { { &setup_lseek_memwrite_pbf_0_proc1 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_procfinal,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p38_0",
    &setup_lseek_memwrite_p78_0_common,
    { { &setup_lseek_memwrite_pbf_0_proc1 }, { &setup_lseek_memwrite_pb7_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_procfinal,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p34_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbf_0_proc1 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfa_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p30_0",
    &setup_lseek_memwrite_pbe0_0_common,
    { { &setup_lseek_memwrite_pbf_0_proc1 }, { &setup_lseek_memwrite_pb68_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pfc_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p2_0",
    &setup_lseek_memwrite_pbe8_0_common,
    { { &setup_lseek_memwrite_pbf_0_proc1 }, { &setup_lseek_memwrite_pb4_1_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_final,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p2_1",
    &setup_lseek_memwrite_p78_0_common,
    { { &setup_lseek_memwrite_pbf_0_proc1 }, { &setup_lseek_memwrite_pb4_2_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_procfinal,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_memwrite_p0_0",
    &setup_lseek_memwrite_p78_0_common,
    { { &setup_lseek_memwrite_pbf_0_proc1 }, { &setup_lseek_memwrite_pbf_0_proc1 } },
    &setup_lseek_memwrite_pbf_0_procfinal,
    &setup_lseek_memwrite_pbf_0_procfinal,
    { { &test_lseek_memwrite_p78_0_0, 0, "lseek" },
      { &test_lseek_memwrite_pf0_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-lseek_mmap_pf8_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf8_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf8_2",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf8_3",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf6_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf6_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf6_2",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf6_3",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf6_4",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf6_5",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf4_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf4_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf4_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf4_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf0_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pf0_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_2",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_3",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_4",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_5",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_6",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pec_6_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_7",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_8",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pec_8_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_9",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pec_10",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pec_6_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe6_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe6_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe6_2",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe6_3",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe6_4",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf6_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe6_5",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe5_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf4_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe5_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf4_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe5_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pec_8_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe5_3",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pec_8_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe5_4",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf4_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe5_5",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pec_6_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe5_6",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf4_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe5_7",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pec_6_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe0_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pe0_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pd8_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pd8_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pd6_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pd6_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pd6_2",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pd6_3",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pd4_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pd4_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pd4_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pd4_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pd0_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pd0_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pcc_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pcc_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pcc_2",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pcc_3",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc6_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc6_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc6_2",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc6_3",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc5_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pd4_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc5_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pd4_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc5_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pd4_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc5_3",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pd4_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc5_4",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pc5_4_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc5_5",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pc5_4_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc5_6",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pc5_4_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc5_7",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pc5_4_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc0_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pc0_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbe_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbe_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbe_2",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pbe_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbd8_0",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pbe_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbd8_1",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pbd8_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbd0_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbd0_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbc_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbb0_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbb0_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbb0_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbb0_3",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pbe_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbb0_4",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pbb0_5",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pbe_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb98_0",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pbe_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb98_1",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pbd8_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb94_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb94_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb94_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb94_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb94_4",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb94_5",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb94_6",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb8_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb6_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb58_0",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pb58_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb58_1",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pb58_0_proc0 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb50_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb4_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb30_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb30_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb18_0",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pb58_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb18_1",
    &setup_lseek_mmap_pbe_2_common,
    { { &setup_lseek_mmap_pb58_0_proc0 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb14_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb14_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb14_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb14_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pb0_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pbe_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pae_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pae_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pae_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pae_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pae_4",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pad8_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pad8_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pad8_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pad8_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pad8_3",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pad8_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pad0_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pad0_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pad0_2",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pac_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pac_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pab0_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pab0_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pab0_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pab0_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pab0_4",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pab0_5",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pab0_6",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pab0_7",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pab0_8",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pab0_9",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa98_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa98_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pad8_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa98_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa98_3",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pad8_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa94_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa94_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa94_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa94_3",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa8_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa8_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa6_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa58_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa58_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa58_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa58_3",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa50_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa50_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa4_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa4_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa30_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa30_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa18_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa18_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa18_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa18_3",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa14_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa14_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa14_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa14_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa0_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_pa0_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pae_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9f0_0",
    &setup_lseek_mmap_p9f0_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9f0_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9f0_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9ec_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9ec_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pad8_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9e8_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9e8_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9e0_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9d8_0",
    &setup_lseek_mmap_p9f0_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9d8_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9d8_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9d8_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9d8_4",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9d8_5",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9cc_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9cc_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pad8_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9ca_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9ca_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9ca_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9ca_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9c0_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9b0_0",
    &setup_lseek_mmap_p9f0_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9ac_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9ac_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9a8_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p9a0_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p998_0",
    &setup_lseek_mmap_p9f0_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p998_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p98c_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p98c_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p98a_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p98a_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p980_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p9f0_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p970_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p970_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p970_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p96c_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p96c_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pad8_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p968_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p968_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p960_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p958_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p958_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p958_2",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p958_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p958_4",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p958_5",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p94c_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p94c_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pad8_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p94a_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p94a_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p94a_2",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p94a_3",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p940_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p930_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p92c_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p92c_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p928_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p920_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p918_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p918_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p90c_0",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p90c_1",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p90a_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p90a_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p900_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p970_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8f8_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8f8_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8f8_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8f8_2",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8f6_0",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8f6_1",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pad8_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8f4_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8f4_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8f4_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8f0_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ec_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8f8_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ec_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ec_2",
    &setup_lseek_mmap_p8ec_2_common,
    { { &setup_lseek_mmap_p8ec_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ec_3",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ec_4",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ec_5",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e6_0",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e6_1",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pad8_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e5_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e5_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8e5_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_p8e5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e5_2",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8e5_2_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e5_3",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8e5_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_p8e5_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e5_4",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e5_5",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8e5_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_p8e5_5_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e5_6",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e5_7",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8e5_7_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_p8e5_7_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8e0_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8d8_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8f4_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8d6_0",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8d6_1",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8d4_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8d0_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8cc_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8f4_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8cc_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8f4_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8c6_0",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8c6_1",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8c5_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8c5_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8e5_3_proc0 }, { &setup_lseek_mmap_p8e5_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_p8e5_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8c5_2",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8c5_3",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p8e5_7_proc0 }, { &setup_lseek_mmap_p8e5_7_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_p8e5_7_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8c0_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8f8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b8_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b8_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b8_2",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b8_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b8_4",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b6_0",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b6_1",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pad8_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b6_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b6_3",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pad8_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b4_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b4_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b0_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8b0_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ac_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ac_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ac_2",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ac_3",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ac_4",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ac_5",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ac_6",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ac_7",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ac_8",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8ac_9",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a6_0",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pae_2_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a6_1",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pad8_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a6_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a6_3",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pad8_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a5_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a5_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a5_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a5_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a5_4",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a5_5",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a0_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p8a0_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p898_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p896_0",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p896_1",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p896_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p896_3",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p894_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p894_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p890_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p890_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p88c_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p88c_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p886_0",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p886_1",
    &setup_lseek_mmap_p8f8_2_common,
    { { &setup_lseek_mmap_pd4_0_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p886_2",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p886_3",
    &setup_lseek_mmap_pf4_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p885_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p885_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p885_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p885_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p880_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p880_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p8b8_3_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p870_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p870_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p86c_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p86c_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pad8_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p868_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p868_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p860_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p858_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p858_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p858_2",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p858_3",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p84c_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pae_4_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p84c_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pad8_3_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p84a_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p84a_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbd0_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p84a_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p84a_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p84a_4",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p84a_5",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p840_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p830_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p82c_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p82c_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p828_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p820_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p818_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p818_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p80c_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p80c_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pc5_4_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p80a_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p80a_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_3_proc0 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p80a_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p80a_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p800_0",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_pb94_4_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_pf8_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p70_0",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p70_1",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p70_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p6c_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_p6c_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p6c_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_p6c_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p68_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_p68_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p60_0",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p60_1",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p58_0",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p58_1",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p58_2",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p70_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p58_3",
    &setup_lseek_mmap_pae_0_common,
    { { &setup_lseek_mmap_p70_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p4c_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_p6c_0_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p4c_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_p6c_1_proc0 }, { &setup_lseek_mmap_pf8_0_proc1 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p4a_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_p68_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p4a_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_p68_0_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p4a_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_p70_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p4a_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_p70_1_proc0 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p40_0",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p40_1",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p30_0",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p2c_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p2c_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pf6_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p28_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p20_0",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pd0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p18_0",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p18_1",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pcc_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p0c_0",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc1 }, { &setup_lseek_mmap_pf8_0_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p0c_1",
    &setup_lseek_mmap_pf8_0_common,
    { { &setup_lseek_mmap_pf8_0_proc1 }, { &setup_lseek_mmap_pf8_2_proc0 } },
    &setup_lseek_mmap_pf8_0_procfinal,
    &setup_lseek_mmap_pf8_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pe6_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p0a_0",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p0a_1",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pb94_3_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p0a_2",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p0a_3",
    &setup_lseek_mmap_pbe_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pb94_4_proc0 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_final,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mmap_p00_0",
    &setup_lseek_mmap_p70_0_common,
    { { &setup_lseek_mmap_pbe_0_proc1 }, { &setup_lseek_mmap_pbe_0_proc1 } },
    &setup_lseek_mmap_pbe_0_procfinal,
    &setup_lseek_mmap_pbe_0_procfinal,
    { { &test_lseek_mmap_p70_0_0, 0, "lseek" },
      { &test_lseek_mmap_pc0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-lseek_mprotect_pf_0",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pf_0_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pf_1",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pf_1_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pf_2",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pf_2_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pf_3",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pf_3_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pf_4",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pf_4_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pf_5",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pf_5_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pf_6",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pf_6_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pf_7",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pf_7_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pe_0",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_0_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pe_1",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_1_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pd_0",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_0_proc0 }, { &setup_lseek_mprotect_pd_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pd_1",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_0_proc0 }, { &setup_lseek_mprotect_pd_1_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pd_2",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_1_proc0 }, { &setup_lseek_mprotect_pd_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pd_3",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_1_proc0 }, { &setup_lseek_mprotect_pd_1_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pd_4",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_0_proc0 }, { &setup_lseek_mprotect_pd_4_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pd_5",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_1_proc0 }, { &setup_lseek_mprotect_pd_4_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pd_6",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_0_proc0 }, { &setup_lseek_mprotect_pd_6_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pd_7",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_1_proc0 }, { &setup_lseek_mprotect_pd_6_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pc_0",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_0_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pc_1",
    &setup_lseek_mprotect_pf_0_common,
    { { &setup_lseek_mprotect_pe_1_proc0 }, { &setup_lseek_mprotect_pf_0_proc1 } },
    &setup_lseek_mprotect_pf_0_procfinal,
    &setup_lseek_mprotect_pf_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pbc_0",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pbc_0_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pbc_1",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pbc_1_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pbc_2",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pbc_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pbc_3",
    &setup_lseek_mprotect_pbc_3_common,
    { { &setup_lseek_mprotect_pbc_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pbc_4",
    &setup_lseek_mprotect_pbc_3_common,
    { { &setup_lseek_mprotect_pbc_4_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pbc_5",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pbc_5_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pb8_0",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb8_0_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pb4_0",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb8_0_proc0 }, { &setup_lseek_mprotect_pb4_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pb4_1",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb8_0_proc0 }, { &setup_lseek_mprotect_pb4_1_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pb4_2",
    &setup_lseek_mprotect_pbc_3_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_2_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pb4_3",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb8_0_proc0 }, { &setup_lseek_mprotect_pb4_3_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pb4_4",
    &setup_lseek_mprotect_pbc_3_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_4_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pb4_5",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb8_0_proc0 }, { &setup_lseek_mprotect_pb4_5_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pb0_0",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb8_0_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pbc_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pac_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pbc_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pac_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pac_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pbc_4_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pac_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pac_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pac_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pac_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pac_3",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pac_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pac_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pa8_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pac_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pa4_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_2_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pac_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pa4_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_3_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pac_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pa4_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_4_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pac_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pa4_3",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_5_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pac_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_pa0_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pac_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9e_0",
    &setup_lseek_mprotect_p9e_0_common,
    { { &setup_lseek_mprotect_p9e_0_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9e_1",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pbc_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9e_2",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pbc_4_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9e_3",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pac_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9e_4",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pac_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9c_0",
    &setup_lseek_mprotect_p9e_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9a_0",
    &setup_lseek_mprotect_p9e_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_p9a_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9a_1",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_2_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9a_2",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_3_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9a_3",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_p9a_3_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9a_4",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_4_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p9a_5",
    &setup_lseek_mprotect_pbc_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_5_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p98_0",
    &setup_lseek_mprotect_p9e_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p9e_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p96_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pbc_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p96_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p96_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pbc_4_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p96_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p96_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pac_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p96_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p96_3",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pac_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p96_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p94_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p96_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p92_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_2_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p96_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p92_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_3_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p96_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p92_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_4_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p96_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p92_3",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_5_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p96_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p90_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p96_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8f_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8f_0_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8f_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8f_1_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8f_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8f_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8f_3",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8f_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8f_4",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8f_4_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8f_5",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8f_5_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8e_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8e_0_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8d_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8e_0_proc0 }, { &setup_lseek_mprotect_p8d_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8d_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8e_0_proc0 }, { &setup_lseek_mprotect_p8d_1_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8d_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8d_2_proc0 }, { &setup_lseek_mprotect_p8d_2_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8d_3",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8d_2_proc0 }, { &setup_lseek_mprotect_p8d_3_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8d_4",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8e_0_proc0 }, { &setup_lseek_mprotect_pb4_3_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8d_5",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8e_0_proc0 }, { &setup_lseek_mprotect_pb4_5_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8c_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_p8e_0_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8f_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8b_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pbc_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8b_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8b_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pac_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8b_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8b_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pbc_4_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8b_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8b_3",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pac_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8b_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p8a_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8b_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p89_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_2_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8b_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p89_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_3_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8b_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p89_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_4_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8b_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p89_3",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_5_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8b_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p88_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p8b_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p86_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pbc_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p86_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pac_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p86_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pbc_4_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p86_3",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pac_3_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p84_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p82_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_2_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p82_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_3_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p82_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_4_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p82_3",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pb4_5_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p80_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc0 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_pf_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p6_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_2_proc1 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p6_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p6_1",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pb4_4_proc1 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p6_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p6_2",
    &setup_lseek_mprotect_p6_2_common,
    { { &setup_lseek_mprotect_pb4_3_proc1 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_procfinal,
    { { &test_lseek_mprotect_p6_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p6_3",
    &setup_lseek_mprotect_p6_2_common,
    { { &setup_lseek_mprotect_pb4_5_proc1 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_procfinal,
    { { &test_lseek_mprotect_p6_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p4_0",
    &setup_lseek_mprotect_p6_2_common,
    { { &setup_lseek_mprotect_pbc_0_proc1 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_procfinal,
    { { &test_lseek_mprotect_p6_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p2_0",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pbc_0_proc1 }, { &setup_lseek_mprotect_pb4_2_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p6_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p2_1",
    &setup_lseek_mprotect_p6_2_common,
    { { &setup_lseek_mprotect_pbc_0_proc1 }, { &setup_lseek_mprotect_pb4_3_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_procfinal,
    { { &test_lseek_mprotect_p6_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p2_2",
    &setup_lseek_mprotect_pac_0_common,
    { { &setup_lseek_mprotect_pbc_0_proc1 }, { &setup_lseek_mprotect_pb4_4_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_final,
    { { &test_lseek_mprotect_p6_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p2_3",
    &setup_lseek_mprotect_p6_2_common,
    { { &setup_lseek_mprotect_pbc_0_proc1 }, { &setup_lseek_mprotect_pb4_5_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_procfinal,
    { { &test_lseek_mprotect_p6_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pf_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_mprotect_p0_0",
    &setup_lseek_mprotect_p6_2_common,
    { { &setup_lseek_mprotect_pbc_0_proc1 }, { &setup_lseek_mprotect_pbc_0_proc1 } },
    &setup_lseek_mprotect_pbc_0_procfinal,
    &setup_lseek_mprotect_pbc_0_procfinal,
    { { &test_lseek_mprotect_p6_0_0, 0, "lseek" },
      { &test_lseek_mprotect_pe_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-lseek_munmap_pe_0",
    &setup_lseek_munmap_pe_0_common,
    { { &setup_lseek_munmap_pe_0_proc0 }, { &setup_lseek_munmap_pe_0_proc1 } },
    &setup_lseek_munmap_pe_0_procfinal,
    &setup_lseek_munmap_pe_0_final,
    { { &test_lseek_munmap_pe_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_pe_1",
    &setup_lseek_munmap_pe_0_common,
    { { &setup_lseek_munmap_pe_1_proc0 }, { &setup_lseek_munmap_pe_0_proc1 } },
    &setup_lseek_munmap_pe_0_procfinal,
    &setup_lseek_munmap_pe_0_final,
    { { &test_lseek_munmap_pe_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_pc_0",
    &setup_lseek_munmap_pe_0_common,
    { { &setup_lseek_munmap_pe_0_proc0 }, { &setup_lseek_munmap_pe_0_proc1 } },
    &setup_lseek_munmap_pe_0_procfinal,
    &setup_lseek_munmap_pe_0_final,
    { { &test_lseek_munmap_pe_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_pc_1",
    &setup_lseek_munmap_pe_0_common,
    { { &setup_lseek_munmap_pe_1_proc0 }, { &setup_lseek_munmap_pe_0_proc1 } },
    &setup_lseek_munmap_pe_0_procfinal,
    &setup_lseek_munmap_pe_0_final,
    { { &test_lseek_munmap_pe_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_pb8_0",
    &setup_lseek_munmap_pb8_0_common,
    { { &setup_lseek_munmap_pb8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_pb8_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_pb0_0",
    &setup_lseek_munmap_pb8_0_common,
    { { &setup_lseek_munmap_pb8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_pb8_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_pa8_0",
    &setup_lseek_munmap_pa8_0_common,
    { { &setup_lseek_munmap_pa8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_pa8_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_pa0_0",
    &setup_lseek_munmap_pa8_0_common,
    { { &setup_lseek_munmap_pa8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_pa8_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p9c_0",
    &setup_lseek_munmap_p9c_0_common,
    { { &setup_lseek_munmap_pa8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_p9c_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p98_0",
    &setup_lseek_munmap_p9c_0_common,
    { { &setup_lseek_munmap_pa8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_p9c_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p94_0",
    &setup_lseek_munmap_pa8_0_common,
    { { &setup_lseek_munmap_pa8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_p94_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p90_0",
    &setup_lseek_munmap_pa8_0_common,
    { { &setup_lseek_munmap_pa8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_p94_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p8e_0",
    &setup_lseek_munmap_pa8_0_common,
    { { &setup_lseek_munmap_p8e_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_p8e_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p8c_0",
    &setup_lseek_munmap_pa8_0_common,
    { { &setup_lseek_munmap_p8e_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_p8e_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p8a_0",
    &setup_lseek_munmap_pa8_0_common,
    { { &setup_lseek_munmap_pa8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_p8a_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p88_0",
    &setup_lseek_munmap_pa8_0_common,
    { { &setup_lseek_munmap_pa8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_p8a_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p84_0",
    &setup_lseek_munmap_pa8_0_common,
    { { &setup_lseek_munmap_pa8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_pe_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p80_0",
    &setup_lseek_munmap_pa8_0_common,
    { { &setup_lseek_munmap_pa8_0_proc0 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_final,
    { { &test_lseek_munmap_pe_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p4_0",
    &setup_lseek_munmap_p4_0_common,
    { { &setup_lseek_munmap_pb8_0_proc1 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_procfinal,
    { { &test_lseek_munmap_p4_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-lseek_munmap_p0_0",
    &setup_lseek_munmap_p4_0_common,
    { { &setup_lseek_munmap_pb8_0_proc1 }, { &setup_lseek_munmap_pb8_0_proc1 } },
    &setup_lseek_munmap_pb8_0_procfinal,
    &setup_lseek_munmap_pb8_0_procfinal,
    { { &test_lseek_munmap_p4_0_0, 0, "lseek" },
      { &test_lseek_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-lseek_open_pf8_0",
    &setup_lseek_open_pf8_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pf8_1",
    &setup_lseek_open_pf8_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pf70_0",
    &setup_lseek_open_pf70_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pf70_1",
    &setup_lseek_open_pf70_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pf50_0",
    &setup_lseek_open_pf50_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pf50_1",
    &setup_lseek_open_pf50_1_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pf3_0",
    &setup_lseek_open_pf3_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pf3_1",
    &setup_lseek_open_pf3_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pf1_0",
    &setup_lseek_open_pf3_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pf1_1",
    &setup_lseek_open_pf3_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pee_0",
    &setup_lseek_open_pee_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pee_1",
    &setup_lseek_open_pee_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pea_0",
    &setup_lseek_open_pea_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pea_1",
    &setup_lseek_open_pea_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pe6_0",
    &setup_lseek_open_pe6_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pe6_1",
    &setup_lseek_open_pe6_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pe2_0",
    &setup_lseek_open_pe2_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pe2_1",
    &setup_lseek_open_pea_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pde_0",
    &setup_lseek_open_pf70_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pde_1",
    &setup_lseek_open_pde_1_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pda_0",
    &setup_lseek_open_pf50_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pda_1",
    &setup_lseek_open_pf50_1_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pd6_0",
    &setup_lseek_open_pf3_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pd6_1",
    &setup_lseek_open_pf3_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pd2_0",
    &setup_lseek_open_pf3_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pd2_1",
    &setup_lseek_open_pf3_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pc_0",
    &setup_lseek_open_pc_0_common,
    { { &setup_lseek_open_pf8_0_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pc_1",
    &setup_lseek_open_pc_0_common,
    { { &setup_lseek_open_pf8_1_proc0 }, { &setup_lseek_open_pf8_0_proc1 } },
    &setup_lseek_open_pf8_0_procfinal,
    &setup_lseek_open_pf8_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pbe_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbe_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pbdc_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbdc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pbd4_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbd4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pbcc_0",
    &setup_lseek_open_pbcc_0_common,
    { { &setup_lseek_open_pbcc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pbc4_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pbb8_0",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_pbb8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pba8_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_pbb8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pb98_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_pbb8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pb88_0",
    &setup_lseek_open_pb88_0_common,
    { { &setup_lseek_open_pbb8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pb78_0",
    &setup_lseek_open_pb78_0_common,
    { { &setup_lseek_open_pb78_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pb68_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbd4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pb58_0",
    &setup_lseek_open_pbcc_0_common,
    { { &setup_lseek_open_pbcc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pb48_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pb0_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_pbe_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pbe_0_0, 0, "lseek" },
      { &test_lseek_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pae_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_padc_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pb78_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_padc_1",
    &setup_lseek_open_padc_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pad4_0",
    &setup_lseek_open_pb78_0_common,
    { { &setup_lseek_open_pad4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pad4_1",
    &setup_lseek_open_pad4_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pacc_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pacc_1",
    &setup_lseek_open_pad4_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pac4_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pac4_1",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pab8_0",
    &setup_lseek_open_pb88_0_common,
    { { &setup_lseek_open_pab8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pab8_1",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_paa8_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_pbb8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_paa8_1",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_paa8_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_paa8_1_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pa98_0",
    &setup_lseek_open_pb88_0_common,
    { { &setup_lseek_open_pbdc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pa98_1",
    &setup_lseek_open_pa98_1_common,
    { { &setup_lseek_open_pb78_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pa98_1_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pa88_0",
    &setup_lseek_open_pb88_0_common,
    { { &setup_lseek_open_pbb8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pa88_1",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pa78_0",
    &setup_lseek_open_pb78_0_common,
    { { &setup_lseek_open_pb78_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pa78_1",
    &setup_lseek_open_padc_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pa68_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbd4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pa68_1",
    &setup_lseek_open_pad4_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pa58_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pa58_1",
    &setup_lseek_open_pad4_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_pa48_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pa48_1",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_pa0_0",
    &setup_lseek_open_pb88_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pae_0_0, 0, "lseek" },
      { &test_lseek_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p9f_0",
    &setup_lseek_open_pad4_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p9ee_0",
    &setup_lseek_open_padc_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p9ea_0",
    &setup_lseek_open_pad4_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p9e6_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p9e2_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p9dc_0",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p9d4_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p9cc_0",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p9c4_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p9bc_0",
    &setup_lseek_open_padc_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p9b4_0",
    &setup_lseek_open_pad4_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p9ac_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p9a4_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p98_0",
    &setup_lseek_open_p98_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p9f_0_0, 0, "lseek" },
      { &test_lseek_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p97_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p96e_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p96a_0",
    &setup_lseek_open_pad4_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p966_0",
    &setup_lseek_open_p966_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p962_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p95c_0",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p954_0",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p94c_0",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p944_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_p944_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p944_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p944_1",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_paa8_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p944_1_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p93c_0",
    &setup_lseek_open_padc_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p934_0",
    &setup_lseek_open_pad4_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p92c_0",
    &setup_lseek_open_pad4_1_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p924_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p90_0",
    &setup_lseek_open_pb88_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p97_0_0, 0, "lseek" },
      { &test_lseek_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8f8_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbcc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f8_0_0, 0, "lseek" },
      { &test_lseek_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8f70_0",
    &setup_lseek_open_p8f70_0_common,
    { { &setup_lseek_open_pbdc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8f70_0_final,
    { { &test_lseek_open_p8f70_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8f70_1",
    &setup_lseek_open_p8f70_1_common,
    { { &setup_lseek_open_pb78_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f70_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8f50_0",
    &setup_lseek_open_p8f70_0_common,
    { { &setup_lseek_open_pbdc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8f70_0_final,
    { { &test_lseek_open_p8f70_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8f50_1",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8f3_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8f3_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8f1_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8ee_0",
    &setup_lseek_open_p8ee_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f70_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8ea_0",
    &setup_lseek_open_p8ea_0_common,
    { { &setup_lseek_open_p8ea_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8ea_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8e6_0",
    &setup_lseek_open_p8ee_0_common,
    { { &setup_lseek_open_pab8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f70_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8e2_0",
    &setup_lseek_open_p8ea_0_common,
    { { &setup_lseek_open_p8ea_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8ea_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8de_0",
    &setup_lseek_open_p8f70_1_common,
    { { &setup_lseek_open_pbdc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f70_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8da_0",
    &setup_lseek_open_p8f70_0_common,
    { { &setup_lseek_open_pbdc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8f70_0_final,
    { { &test_lseek_open_p8f70_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8da_1",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8d6_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8f3_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8d2_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8c_0",
    &setup_lseek_open_pb88_0_common,
    { { &setup_lseek_open_pbcc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8f8_0_0, 0, "lseek" },
      { &test_lseek_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b8_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b6c_0",
    &setup_lseek_open_p8b6c_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8b6c_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b6c_1",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b6c_2",
    &setup_lseek_open_p8b6c_2_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8b6c_0_final,
    { { &test_lseek_open_p8b6c_2_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b6c_3",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8b6c_3_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b6c_3_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b4c_0",
    &setup_lseek_open_p8b4c_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8f70_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b4c_1",
    &setup_lseek_open_p8f70_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8f70_0_final,
    { { &test_lseek_open_p8b6c_2_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b4c_2",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b4c_3",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbe_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b4c_3_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b3_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8b3_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b3_1",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b1_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8b1_1",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b1_1_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8ae_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_p944_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8ae_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8ae_1",
    &setup_lseek_open_p8ee_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b6c_2_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8aa_0",
    &setup_lseek_open_p8ee_0_common,
    { { &setup_lseek_open_pab8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b6c_2_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8aa_1",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8aa_1_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8a6_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_p944_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8ae_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8a6_1",
    &setup_lseek_open_p8ee_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b6c_2_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8a2_0",
    &setup_lseek_open_pb88_0_common,
    { { &setup_lseek_open_pab8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8a2_1",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_paa8_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8a2_1_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p89d8_0",
    &setup_lseek_open_p8b6c_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8b6c_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p89d8_1",
    &setup_lseek_open_p8b6c_0_common,
    { { &setup_lseek_open_p89d8_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8b6c_0_final,
    { { &test_lseek_open_p89d8_1_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p89d8_2",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p89d8_3",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8b6c_3_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b6c_3_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p8998_0",
    &setup_lseek_open_p8b4c_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8f70_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8998_1",
    &setup_lseek_open_p8f70_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_p8f70_0_final,
    { { &test_lseek_open_p8b6c_2_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8998_2",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8f50_1_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p8998_3",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbe_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b4c_3_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p896_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_p8b3_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p896_1",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p892_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p892_1",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b1_1_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p88_0",
    &setup_lseek_open_pb88_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p8b8_0_0, 0, "lseek" },
      { &test_lseek_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p87_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p86e_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbdc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p86a_0",
    &setup_lseek_open_pb78_0_common,
    { { &setup_lseek_open_pad4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p866_0",
    &setup_lseek_open_pbcc_0_common,
    { { &setup_lseek_open_pbcc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p862_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p85c_0",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_pbb8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p854_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_pbb8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p84c_0",
    &setup_lseek_open_pbb8_0_common,
    { { &setup_lseek_open_pbb8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p844_0",
    &setup_lseek_open_pba8_0_common,
    { { &setup_lseek_open_pbb8_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p83c_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbdc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p834_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbd4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p82c_0",
    &setup_lseek_open_pbcc_0_common,
    { { &setup_lseek_open_pbcc_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p824_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbc4_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p80_0",
    &setup_lseek_open_pb88_0_common,
    { { &setup_lseek_open_pae_0_proc0 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_pf8_0_0, 0, "lseek" },
      { &test_lseek_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p7_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p6d0_0",
    &setup_lseek_open_pb78_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p6a_0",
    &setup_lseek_open_pb78_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p65_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p62_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p5a_0",
    &setup_lseek_open_p5a_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_procfinal,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p54_0",
    &setup_lseek_open_p5a_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_procfinal,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p4a_0",
    &setup_lseek_open_p5a_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_procfinal,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p44_0",
    &setup_lseek_open_p5a_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_procfinal,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p3a_0",
    &setup_lseek_open_pb78_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p34_0",
    &setup_lseek_open_pbd4_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p2a_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_open_p24_0",
    &setup_lseek_open_pbe_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_final,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-lseek_open_p0_0",
    &setup_lseek_open_p5a_0_common,
    { { &setup_lseek_open_pbe_0_proc1 }, { &setup_lseek_open_pbe_0_proc1 } },
    &setup_lseek_open_pbe_0_procfinal,
    &setup_lseek_open_pbe_0_procfinal,
    { { &test_lseek_open_p7_0_0, 0, "lseek" },
      { &test_lseek_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-lseek_pipe_pf8_0",
    &setup_lseek_pipe_pf8_0_common,
    { { &setup_lseek_pipe_pf8_0_proc0 }, { &setup_lseek_pipe_pf8_0_proc1 } },
    &setup_lseek_pipe_pf8_0_procfinal,
    &setup_lseek_pipe_pf8_0_final,
    { { &test_lseek_pipe_pf8_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_pf8_1",
    &setup_lseek_pipe_pf8_0_common,
    { { &setup_lseek_pipe_pf8_1_proc0 }, { &setup_lseek_pipe_pf8_0_proc1 } },
    &setup_lseek_pipe_pf8_0_procfinal,
    &setup_lseek_pipe_pf8_0_final,
    { { &test_lseek_pipe_pf8_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_pd8_0",
    &setup_lseek_pipe_pd8_0_common,
    { { &setup_lseek_pipe_pf8_0_proc0 }, { &setup_lseek_pipe_pf8_0_proc1 } },
    &setup_lseek_pipe_pf8_0_procfinal,
    &setup_lseek_pipe_pf8_0_final,
    { { &test_lseek_pipe_pf8_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_pd8_1",
    &setup_lseek_pipe_pd8_0_common,
    { { &setup_lseek_pipe_pf8_1_proc0 }, { &setup_lseek_pipe_pf8_0_proc1 } },
    &setup_lseek_pipe_pf8_0_procfinal,
    &setup_lseek_pipe_pf8_0_final,
    { { &test_lseek_pipe_pf8_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_pbe_0",
    &setup_lseek_pipe_pbe_0_common,
    { { &setup_lseek_pipe_pbe_0_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_pbe_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_pb6_0",
    &setup_lseek_pipe_pbe_0_common,
    { { &setup_lseek_pipe_pbe_0_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_pbe_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_pae_0",
    &setup_lseek_pipe_pae_0_common,
    { { &setup_lseek_pipe_pae_0_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_pae_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_pae_1",
    &setup_lseek_pipe_pbe_0_common,
    { { &setup_lseek_pipe_pae_1_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_pae_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_pa6_0",
    &setup_lseek_pipe_pa6_0_common,
    { { &setup_lseek_pipe_pa6_0_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_pae_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_pa6_1",
    &setup_lseek_pipe_pae_0_common,
    { { &setup_lseek_pipe_pae_1_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_pae_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p9f0_0",
    &setup_lseek_pipe_pae_0_common,
    { { &setup_lseek_pipe_pae_1_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_p9f0_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p9b0_0",
    &setup_lseek_pipe_pae_0_common,
    { { &setup_lseek_pipe_pae_1_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_p9f0_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p970_0",
    &setup_lseek_pipe_p970_0_common,
    { { &setup_lseek_pipe_p970_0_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_p970_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p970_1",
    &setup_lseek_pipe_p970_1_common,
    { { &setup_lseek_pipe_p970_1_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_p970_1_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p930_0",
    &setup_lseek_pipe_pae_0_common,
    { { &setup_lseek_pipe_pae_1_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_p930_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p8f8_0",
    &setup_lseek_pipe_p8f8_0_common,
    { { &setup_lseek_pipe_p8f8_0_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p8d8_0",
    &setup_lseek_pipe_p8f8_0_common,
    { { &setup_lseek_pipe_pae_0_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p8b8_0",
    &setup_lseek_pipe_p8f8_0_common,
    { { &setup_lseek_pipe_pbe_0_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p8b8_1",
    &setup_lseek_pipe_p970_0_common,
    { { &setup_lseek_pipe_pae_1_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_p8b8_1_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p870_0",
    &setup_lseek_pipe_pbe_0_common,
    { { &setup_lseek_pipe_pbe_0_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_pf8_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p830_0",
    &setup_lseek_pipe_pa6_0_common,
    { { &setup_lseek_pipe_pa6_0_proc0 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_final,
    { { &test_lseek_pipe_pf8_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p58_0",
    &setup_lseek_pipe_p58_0_common,
    { { &setup_lseek_pipe_pbe_0_proc1 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_procfinal,
    { { &test_lseek_pipe_p58_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-lseek_pipe_p30_0",
    &setup_lseek_pipe_p58_0_common,
    { { &setup_lseek_pipe_pbe_0_proc1 }, { &setup_lseek_pipe_pbe_0_proc1 } },
    &setup_lseek_pipe_pbe_0_procfinal,
    &setup_lseek_pipe_pbe_0_procfinal,
    { { &test_lseek_pipe_p58_0_0, 0, "lseek" },
      { &test_lseek_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-lseek_pread_pf8_0",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_0_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf8_1",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_1_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf8_2",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_2_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf8_3",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_3_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf8_4",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_4_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf4_0",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pf4_0_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf4_1",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pf4_1_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf4_2",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pf4_2_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf4_3",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pf4_3_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf0_0",
    &setup_lseek_pread_pf0_0_common,
    { { &setup_lseek_pread_pf0_0_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf0_1",
    &setup_lseek_pread_pf0_0_common,
    { { &setup_lseek_pread_pf0_1_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf0_2",
    &setup_lseek_pread_pf0_2_common,
    { { &setup_lseek_pread_pf4_2_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pf0_3",
    &setup_lseek_pread_pf0_2_common,
    { { &setup_lseek_pread_pf4_3_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pe_0",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_3_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pe_1",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_4_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd8_0",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_3_proc0 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd8_1",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_4_proc0 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd8_2",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_3_proc0 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd8_3",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_4_proc0 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd4_0",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pf8_3_proc0 }, { &setup_lseek_pread_pd4_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd4_1",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pf8_4_proc0 }, { &setup_lseek_pread_pd4_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd4_2",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pf8_3_proc0 }, { &setup_lseek_pread_pd4_2_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd4_3",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pf8_4_proc0 }, { &setup_lseek_pread_pd4_2_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd0_0",
    &setup_lseek_pread_pf0_0_common,
    { { &setup_lseek_pread_pf8_3_proc0 }, { &setup_lseek_pread_pd0_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd0_1",
    &setup_lseek_pread_pf0_0_common,
    { { &setup_lseek_pread_pf8_4_proc0 }, { &setup_lseek_pread_pd0_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd0_2",
    &setup_lseek_pread_pf0_2_common,
    { { &setup_lseek_pread_pf8_3_proc0 }, { &setup_lseek_pread_pd4_2_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pd0_3",
    &setup_lseek_pread_pd0_3_common,
    { { &setup_lseek_pread_pf8_4_proc0 }, { &setup_lseek_pread_pd4_2_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pc_0",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_3_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pc_1",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_4_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pbe_0",
    &setup_lseek_pread_pbe_0_common,
    { { &setup_lseek_pread_pbe_0_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pbe_1",
    &setup_lseek_pread_pbe_0_common,
    { { &setup_lseek_pread_pbe_1_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pbd_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pbd_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pbd_2",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pbd_3",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pbc0_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbc0_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pbc0_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pbc0_2",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pbc0_3",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pb8_0",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pb8_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pb6_0",
    &setup_lseek_pread_pbe_0_common,
    { { &setup_lseek_pread_pb6_0_proc0 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pb6_1",
    &setup_lseek_pread_pbe_0_common,
    { { &setup_lseek_pread_pb6_0_proc0 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pb5_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_2_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pb5_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pb40_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pb40_0_proc0 }, { &setup_lseek_pread_pb40_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pb40_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pb0_0",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pb8_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pbe_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pae_0",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pae_0_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pae_1",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pae_1_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pae_2",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pae_2_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pae_3",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pae_3_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pad_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pad_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pad_2",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pad_3",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pac0_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbc0_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pac0_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pac0_2",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pac0_3",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa8_0",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa8_1",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa6_0",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pd4_0_proc1 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa6_1",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pd4_0_proc1 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa6_2",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pd4_2_proc1 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa6_3",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pd4_2_proc1 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa5_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_2_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa5_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa40_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pb40_0_proc1 }, { &setup_lseek_pread_pb40_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa40_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa0_0",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_pa0_1",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pae_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9f_0",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pae_2_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9f_1",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pae_3_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9e8_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9e8_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9e0_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9e0_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9c_0",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9b_0",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pd4_2_proc1 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9b_1",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pd4_2_proc1 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9a8_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p9a0_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p98_0",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p9f_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p97_0",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pae_2_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p97_1",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pae_3_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p968_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p968_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p960_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p960_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p94_0",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p93_0",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pd4_2_proc1 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p93_1",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pd4_2_proc1 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p928_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p920_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p90_0",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p97_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f8_0",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pae_0_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f8_1",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pae_1_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f4_0",
    &setup_lseek_pread_p8f4_0_common,
    { { &setup_lseek_pread_p8f4_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f4_1",
    &setup_lseek_pread_p8f4_1_common,
    { { &setup_lseek_pread_p8f4_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_p8f4_1_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f4_2",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f4_3",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_p8f4_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_p8f4_3_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f4_4",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f4_5",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_p8f4_5_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_p8f4_5_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f0_0",
    &setup_lseek_pread_p8f0_0_common,
    { { &setup_lseek_pread_p8f0_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f0_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbc0_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f0_1_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f0_2",
    &setup_lseek_pread_p8f0_2_common,
    { { &setup_lseek_pread_p8f0_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_p8f0_2_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f0_3",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f0_1_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f0_4",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pb40_0_proc1 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f0_1_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8f0_5",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f0_1_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8e_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8d8_0",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pd4_0_proc1 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8d8_1",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pd4_0_proc1 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8d4_0",
    &setup_lseek_pread_p8f4_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_p8d4_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8d4_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_2_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8d4_2",
    &setup_lseek_pread_p8f0_2_common,
    { { &setup_lseek_pread_p8d4_2_proc0 }, { &setup_lseek_pread_p8d4_2_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_p8d4_2_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8d4_3",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_p8f4_5_proc0 }, { &setup_lseek_pread_p8f4_5_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_p8f4_5_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8d0_0",
    &setup_lseek_pread_p8f0_0_common,
    { { &setup_lseek_pread_pb40_0_proc1 }, { &setup_lseek_pread_p8d0_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8d0_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pb40_0_proc1 }, { &setup_lseek_pread_pb40_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f0_1_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8d0_2",
    &setup_lseek_pread_p8d0_2_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_p8d0_2_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8d0_2_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8d0_3",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f0_1_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8c_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b8_0",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pae_0_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b8_1",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pae_1_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b8_2",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pae_2_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b8_3",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pae_3_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b4_0",
    &setup_lseek_pread_p8f4_0_common,
    { { &setup_lseek_pread_p8f4_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b4_1",
    &setup_lseek_pread_p8b4_1_common,
    { { &setup_lseek_pread_p8b4_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b4_2",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b4_3",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b4_4",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b4_5",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b0_0",
    &setup_lseek_pread_p8f0_0_common,
    { { &setup_lseek_pread_p8b0_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b0_1",
    &setup_lseek_pread_p8d0_2_common,
    { { &setup_lseek_pread_p8b4_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b0_2",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbc0_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b0_3",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b0_4",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pb40_0_proc1 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8b0_5",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8a_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p8a_1",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p898_0",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pd4_0_proc1 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p898_1",
    &setup_lseek_pread_pf4_0_common,
    { { &setup_lseek_pread_pd4_0_proc1 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p898_2",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pd4_2_proc1 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p898_3",
    &setup_lseek_pread_pae_0_common,
    { { &setup_lseek_pread_pd4_2_proc1 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p894_0",
    &setup_lseek_pread_p8f4_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_p8d4_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p894_1",
    &setup_lseek_pread_p8b4_1_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_p8d0_2_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p894_2",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_2_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p894_3",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p890_0",
    &setup_lseek_pread_p8f0_0_common,
    { { &setup_lseek_pread_p890_0_proc0 }, { &setup_lseek_pread_p890_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p890_1",
    &setup_lseek_pread_p8d0_2_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_p8d0_2_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_p8f4_0_final,
    { { &test_lseek_pread_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p890_2",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pb40_0_proc1 }, { &setup_lseek_pread_pb40_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p890_3",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p88_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p88_1",
    &setup_lseek_pread_pb8_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p87_0",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pae_2_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p87_1",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pae_3_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p868_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p868_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p868_2",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p868_3",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p860_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbc0_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p860_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p860_2",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p860_3",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p84_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p83_0",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pd4_2_proc1 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p83_1",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pd4_2_proc1 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p828_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_2_proc0 }, { &setup_lseek_pread_pbd_2_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p828_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p820_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pb40_0_proc1 }, { &setup_lseek_pread_pb40_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p820_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p80_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_3_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_pf8_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p7_0",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_p7_0_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p7_1",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_p7_1_proc0 }, { &setup_lseek_pread_pf8_0_proc1 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p68_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_p68_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p68_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_p68_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p60_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_p60_0_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p60_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_p68_1_proc0 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p4_0",
    &setup_lseek_pread_p4_0_common,
    { { &setup_lseek_pread_pbd_0_proc1 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_procfinal,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p4_1",
    &setup_lseek_pread_p4_0_common,
    { { &setup_lseek_pread_pbd_0_proc1 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_procfinal,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p3_0",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_0_proc1 }, { &setup_lseek_pread_pf8_3_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p3_1",
    &setup_lseek_pread_pf8_0_common,
    { { &setup_lseek_pread_pf8_0_proc1 }, { &setup_lseek_pread_pf8_4_proc0 } },
    &setup_lseek_pread_pf8_0_procfinal,
    &setup_lseek_pread_pf8_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pf8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p28_0",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_0_proc1 }, { &setup_lseek_pread_pbd_2_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p28_1",
    &setup_lseek_pread_pbd_0_common,
    { { &setup_lseek_pread_pbd_0_proc1 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p20_0",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_0_proc1 }, { &setup_lseek_pread_pb40_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p20_1",
    &setup_lseek_pread_pbc0_0_common,
    { { &setup_lseek_pread_pbd_0_proc1 }, { &setup_lseek_pread_pbd_3_proc0 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_final,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pread_p0_0",
    &setup_lseek_pread_p4_0_common,
    { { &setup_lseek_pread_pbd_0_proc1 }, { &setup_lseek_pread_pbd_0_proc1 } },
    &setup_lseek_pread_pbd_0_procfinal,
    &setup_lseek_pread_pbd_0_procfinal,
    { { &test_lseek_pread_p7_0_0, 0, "lseek" },
      { &test_lseek_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-lseek_pwrite_pf8_0",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_0_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf8_1",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_1_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf8_2",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_2_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf8_3",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_3_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf8_4",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_4_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf8_5",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_5_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf4_0",
    &setup_lseek_pwrite_pf4_0_common,
    { { &setup_lseek_pwrite_pf4_0_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf4_1",
    &setup_lseek_pwrite_pf4_1_common,
    { { &setup_lseek_pwrite_pf4_1_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf4_2",
    &setup_lseek_pwrite_pf4_1_common,
    { { &setup_lseek_pwrite_pf4_2_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf4_3",
    &setup_lseek_pwrite_pf4_1_common,
    { { &setup_lseek_pwrite_pf4_3_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf0_0",
    &setup_lseek_pwrite_pf0_0_common,
    { { &setup_lseek_pwrite_pf0_0_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf0_1",
    &setup_lseek_pwrite_pf0_1_common,
    { { &setup_lseek_pwrite_pf4_1_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf0_2",
    &setup_lseek_pwrite_pf0_1_common,
    { { &setup_lseek_pwrite_pf0_2_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pf0_3",
    &setup_lseek_pwrite_pf0_3_common,
    { { &setup_lseek_pwrite_pf4_3_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pe_0",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_3_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pe_1",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_5_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd8_0",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_3_proc0 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd8_1",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_3_proc0 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd8_2",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_5_proc0 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd8_3",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_5_proc0 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd4_0",
    &setup_lseek_pwrite_pf4_0_common,
    { { &setup_lseek_pwrite_pf8_3_proc0 }, { &setup_lseek_pwrite_pd4_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd4_1",
    &setup_lseek_pwrite_pf4_1_common,
    { { &setup_lseek_pwrite_pf8_3_proc0 }, { &setup_lseek_pwrite_pd4_1_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd4_2",
    &setup_lseek_pwrite_pf4_1_common,
    { { &setup_lseek_pwrite_pf8_5_proc0 }, { &setup_lseek_pwrite_pd4_2_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd4_3",
    &setup_lseek_pwrite_pf4_0_common,
    { { &setup_lseek_pwrite_pf8_5_proc0 }, { &setup_lseek_pwrite_pd4_1_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd0_0",
    &setup_lseek_pwrite_pf0_0_common,
    { { &setup_lseek_pwrite_pf8_3_proc0 }, { &setup_lseek_pwrite_pd0_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd0_1",
    &setup_lseek_pwrite_pf0_1_common,
    { { &setup_lseek_pwrite_pf8_3_proc0 }, { &setup_lseek_pwrite_pd4_1_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd0_2",
    &setup_lseek_pwrite_pf0_1_common,
    { { &setup_lseek_pwrite_pf8_5_proc0 }, { &setup_lseek_pwrite_pd4_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pd0_3",
    &setup_lseek_pwrite_pf0_1_common,
    { { &setup_lseek_pwrite_pf8_5_proc0 }, { &setup_lseek_pwrite_pd4_1_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pc_0",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_3_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pc_1",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_5_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pbe_0",
    &setup_lseek_pwrite_pbe_0_common,
    { { &setup_lseek_pwrite_pbe_0_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pbe_1",
    &setup_lseek_pwrite_pbe_0_common,
    { { &setup_lseek_pwrite_pbe_1_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pbd0_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pbd0_1",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pbd0_2",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pbd0_3",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pbc0_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbc0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pbc0_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pbc0_2",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbc0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pbc0_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb8_0",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pb8_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb6_0",
    &setup_lseek_pwrite_pbe_0_common,
    { { &setup_lseek_pwrite_pd4_0_proc1 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb6_1",
    &setup_lseek_pwrite_pbe_0_common,
    { { &setup_lseek_pwrite_pd4_0_proc1 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb50_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbc0_2_proc0 }, { &setup_lseek_pwrite_pb8_0_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb50_1",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pb50_1_proc0 }, { &setup_lseek_pwrite_pb50_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb50_2",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pb50_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb50_3",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb40_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pb40_0_proc0 }, { &setup_lseek_pwrite_pb40_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb40_1",
    &setup_lseek_pwrite_pb40_1_common,
    { { &setup_lseek_pwrite_pb40_1_proc0 }, { &setup_lseek_pwrite_pb40_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pb40_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb40_2",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pb50_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb40_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pb0_0",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pb8_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pbe_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pae_0",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pae_0_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pae_1",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pae_1_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pae_2",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pae_2_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pae_3",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pae_3_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pad0_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pad0_1",
    &setup_lseek_pwrite_pb40_1_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pad0_2",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbc0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pad0_3",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pad0_4",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pad0_5",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pb40_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pad0_6",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pac0_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbc0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pac0_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pac0_2",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbc0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pac0_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa8_0",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pa8_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa8_1",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa6_0",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pa6_0_proc0 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa6_1",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pa6_0_proc0 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa6_2",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pd4_1_proc1 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa6_3",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pd4_1_proc1 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa50_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbc0_2_proc0 }, { &setup_lseek_pwrite_pb8_0_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa50_1",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pb40_0_proc1 }, { &setup_lseek_pwrite_pa50_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pa50_1_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa50_2",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pb50_1_proc1 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa50_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa50_4",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pb40_0_proc1 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa50_5",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pb50_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa50_6",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa40_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pb40_0_proc0 }, { &setup_lseek_pwrite_pb40_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa40_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pb50_1_proc1 }, { &setup_lseek_pwrite_pa40_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pa40_1_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa40_2",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pa40_2_proc0 }, { &setup_lseek_pwrite_pa40_2_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa40_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pb50_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa40_4",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pb50_1_proc1 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa40_5",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa0_0",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pa8_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_pa0_1",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pae_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9f_0",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pae_2_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9f_1",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pae_3_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9e8_0",
    &setup_lseek_pwrite_p9e8_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_p9e8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9e8_1",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9e8_2",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9e0_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9e0_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9c_0",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9b_0",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pd4_1_proc1 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9b_1",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pd4_1_proc1 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9a8_0",
    &setup_lseek_pwrite_p9e8_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_p9a8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9a8_1",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p9a0_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p98_0",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p9f_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p97_0",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pae_2_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p97_1",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pae_3_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p968_0",
    &setup_lseek_pwrite_pb40_1_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p968_1",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_p968_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p968_1_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p968_2",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p968_3",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pa40_2_proc1 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p968_3_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p968_4",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pa40_2_proc1 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p968_4_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p968_5",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p968_5_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p968_6",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p960_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p960_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p94_0",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p93_0",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pd4_1_proc1 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p93_1",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pd4_1_proc1 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p928_0",
    &setup_lseek_pwrite_pb40_1_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_p928_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p928_1",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_p928_1_proc0 }, { &setup_lseek_pwrite_p928_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p928_1_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p928_2",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p920_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p90_0",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p97_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f8_0",
    &setup_lseek_pwrite_p8f8_0_common,
    { { &setup_lseek_pwrite_pae_0_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f8_1",
    &setup_lseek_pwrite_p8f8_0_common,
    { { &setup_lseek_pwrite_pae_1_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f6_0",
    &setup_lseek_pwrite_p8f6_0_common,
    { { &setup_lseek_pwrite_p8f6_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8f6_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f6_1",
    &setup_lseek_pwrite_p8f6_1_common,
    { { &setup_lseek_pwrite_p8f6_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_p8f6_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f6_2",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_p8f6_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f6_3",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f6_4",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f6_5",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f0_0",
    &setup_lseek_pwrite_p8f0_0_common,
    { { &setup_lseek_pwrite_p8f0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f0_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_p8f0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f0_2",
    &setup_lseek_pwrite_p8f0_2_common,
    { { &setup_lseek_pwrite_p8f0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8f6_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f0_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f0_4",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbc0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8f0_5",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8e_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pa8_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d8_0",
    &setup_lseek_pwrite_p8f8_0_common,
    { { &setup_lseek_pwrite_pa6_0_proc0 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d8_1",
    &setup_lseek_pwrite_p8f8_0_common,
    { { &setup_lseek_pwrite_pa6_0_proc0 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d6_0",
    &setup_lseek_pwrite_p8f0_0_common,
    { { &setup_lseek_pwrite_pbd0_2_proc0 }, { &setup_lseek_pwrite_p8d6_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d6_1",
    &setup_lseek_pwrite_p8f6_1_common,
    { { &setup_lseek_pwrite_p8d6_1_proc0 }, { &setup_lseek_pwrite_p8d6_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_p8d6_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d6_2",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_2_proc0 }, { &setup_lseek_pwrite_pbc0_2_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d6_3",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pb50_1_proc1 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d6_4",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pb50_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d6_5",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d0_0",
    &setup_lseek_pwrite_p8f0_0_common,
    { { &setup_lseek_pwrite_p8d0_0_proc0 }, { &setup_lseek_pwrite_p8d0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d0_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_p8d0_0_proc0 }, { &setup_lseek_pwrite_p8d0_0_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d0_2",
    &setup_lseek_pwrite_p8f6_1_common,
    { { &setup_lseek_pwrite_p8d0_2_proc0 }, { &setup_lseek_pwrite_p8d0_2_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_p9a8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8d0_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8c_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pa8_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8f8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b8_0",
    &setup_lseek_pwrite_p8f8_0_common,
    { { &setup_lseek_pwrite_pae_0_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b8_1",
    &setup_lseek_pwrite_p8f8_0_common,
    { { &setup_lseek_pwrite_pae_1_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b8_2",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pae_2_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b8_3",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pae_3_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b6_0",
    &setup_lseek_pwrite_p8b6_0_common,
    { { &setup_lseek_pwrite_p8f0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b6_1",
    &setup_lseek_pwrite_p8b6_1_common,
    { { &setup_lseek_pwrite_p8b6_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b6_1_0, 0, "lseek" },
      { &test_lseek_pwrite_p9e8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b6_2",
    &setup_lseek_pwrite_p8b6_2_common,
    { { &setup_lseek_pwrite_p8f0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b6_3",
    &setup_lseek_pwrite_p8b6_3_common,
    { { &setup_lseek_pwrite_p8b6_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b6_3_0, 0, "lseek" },
      { &test_lseek_pwrite_p8b6_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b0_0",
    &setup_lseek_pwrite_p8f0_0_common,
    { { &setup_lseek_pwrite_p8b0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b0_1",
    &setup_lseek_pwrite_p8f0_2_common,
    { { &setup_lseek_pwrite_p8f0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b0_2",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b0_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b0_4",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbc0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8b0_5",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8a_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pa8_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p8a_1",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p898_0",
    &setup_lseek_pwrite_p8f8_0_common,
    { { &setup_lseek_pwrite_pa6_0_proc0 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p898_1",
    &setup_lseek_pwrite_p8f8_0_common,
    { { &setup_lseek_pwrite_pa6_0_proc0 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p898_2",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pd4_1_proc1 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p898_3",
    &setup_lseek_pwrite_pae_0_common,
    { { &setup_lseek_pwrite_pd4_1_proc1 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p896_0",
    &setup_lseek_pwrite_p8b6_0_common,
    { { &setup_lseek_pwrite_p8d0_0_proc0 }, { &setup_lseek_pwrite_p8d0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_p928_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p896_1",
    &setup_lseek_pwrite_p896_1_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_p896_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_p9a8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p896_2",
    &setup_lseek_pwrite_p8f6_1_common,
    { { &setup_lseek_pwrite_p8d6_1_proc0 }, { &setup_lseek_pwrite_p8d6_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_p8d6_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p896_3",
    &setup_lseek_pwrite_p896_3_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_p896_3_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b6_2_0, 0, "lseek" },
      { &test_lseek_pwrite_p896_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p890_0",
    &setup_lseek_pwrite_p8f0_0_common,
    { { &setup_lseek_pwrite_pbc0_2_proc0 }, { &setup_lseek_pwrite_p890_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p890_1",
    &setup_lseek_pwrite_p8f0_2_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_p896_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_p8f6_0_final,
    { { &test_lseek_pwrite_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p890_2",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbc0_2_proc0 }, { &setup_lseek_pwrite_pb8_0_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p890_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pb50_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p890_4",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pb50_1_proc1 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p890_5",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b0_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p88_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pa8_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p88_1",
    &setup_lseek_pwrite_pb8_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p8b8_2_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p87_0",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pae_2_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p87_1",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pae_3_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p868_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p868_1",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_p868_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p868_2",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_2_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p868_3",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p868_4",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p860_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbc0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p860_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_p8d0_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p860_2",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p860_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p84_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p83_0",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pd4_1_proc1 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p83_1",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pd4_1_proc1 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p828_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbc0_2_proc0 }, { &setup_lseek_pwrite_pb8_0_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p828_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pa40_2_proc1 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pad0_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p828_2",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pb50_1_proc1 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p828_3",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p820_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pb40_0_proc0 }, { &setup_lseek_pwrite_pb40_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p820_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pb50_1_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p820_2",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pb50_1_proc1 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p820_3",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p80_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_3_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_pf8_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p7_0",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_p7_0_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p7_1",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_p7_1_proc0 }, { &setup_lseek_pwrite_pf8_0_proc1 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p68_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_p68_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p68_1",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_p68_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p60_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_p60_0_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p60_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_p68_1_proc0 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p4_0",
    &setup_lseek_pwrite_p4_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc1 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_procfinal,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p4_1",
    &setup_lseek_pwrite_p4_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc1 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_procfinal,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p3_0",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_0_proc1 }, { &setup_lseek_pwrite_pf8_3_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p3_1",
    &setup_lseek_pwrite_pf8_0_common,
    { { &setup_lseek_pwrite_pf8_0_proc1 }, { &setup_lseek_pwrite_pf8_5_proc0 } },
    &setup_lseek_pwrite_pf8_0_procfinal,
    &setup_lseek_pwrite_pf8_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p28_0",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc1 }, { &setup_lseek_pwrite_pb8_0_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p28_1",
    &setup_lseek_pwrite_pbd0_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc1 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p20_0",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc1 }, { &setup_lseek_pwrite_pb40_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p20_1",
    &setup_lseek_pwrite_pbc0_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc1 }, { &setup_lseek_pwrite_pbd0_3_proc0 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_final,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_pwrite_p0_0",
    &setup_lseek_pwrite_p4_0_common,
    { { &setup_lseek_pwrite_pbd0_0_proc1 }, { &setup_lseek_pwrite_pbd0_0_proc1 } },
    &setup_lseek_pwrite_pbd0_0_procfinal,
    &setup_lseek_pwrite_pbd0_0_procfinal,
    { { &test_lseek_pwrite_p7_0_0, 0, "lseek" },
      { &test_lseek_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-lseek_read_pfc_0",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pfc_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pfc_1",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pfc_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pfc_2",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pfc_2_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pfb_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pfb_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pfb_1",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pfb_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pfb_2",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pfb_2_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pfa_0",
    &setup_lseek_read_pfa_0_common,
    { { &setup_lseek_read_pfa_0_proc0 }, { &setup_lseek_read_pfa_0_proc1 } },
    &setup_lseek_read_pfa_0_procfinal,
    &setup_lseek_read_pfa_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pfa_1",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pfb_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pfa_2",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pfb_2_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pfa_3",
    &setup_lseek_read_pfa_3_common,
    { { &setup_lseek_read_pfa_3_proc0 }, { &setup_lseek_read_pfa_3_proc1 } },
    &setup_lseek_read_pfa_3_procfinal,
    &setup_lseek_read_pfa_3_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pf8_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pfb_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pf8_1",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pfb_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pf8_2",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pfb_2_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pf4_0",
    &setup_lseek_read_pf4_0_common,
    { { &setup_lseek_read_pf4_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pf4_1",
    &setup_lseek_read_pf4_1_common,
    { { &setup_lseek_read_pf4_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pf0_0",
    &setup_lseek_read_pf0_0_common,
    { { &setup_lseek_read_pf0_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pf0_1",
    &setup_lseek_read_pf0_1_common,
    { { &setup_lseek_read_pf0_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pe_0",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pfb_2_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pe_1",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pfc_2_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pdc_0",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pfb_2_proc0 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pdc_1",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pfc_2_proc0 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pdb_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pfb_2_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pdb_1",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pfc_2_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pda_0",
    &setup_lseek_read_pda_0_common,
    { { &setup_lseek_read_pda_0_proc0 }, { &setup_lseek_read_pda_0_proc1 } },
    &setup_lseek_read_pfa_0_procfinal,
    &setup_lseek_read_pfa_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pda_1",
    &setup_lseek_read_pfa_3_common,
    { { &setup_lseek_read_pda_1_proc0 }, { &setup_lseek_read_pda_1_proc1 } },
    &setup_lseek_read_pfa_3_procfinal,
    &setup_lseek_read_pfa_3_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pda_2",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pda_2_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pd8_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pfb_2_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pd8_1",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pfc_2_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pd4_0",
    &setup_lseek_read_pf4_0_common,
    { { &setup_lseek_read_pfb_2_proc0 }, { &setup_lseek_read_pd4_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pd4_1",
    &setup_lseek_read_pf4_0_common,
    { { &setup_lseek_read_pfc_2_proc0 }, { &setup_lseek_read_pd4_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pd0_0",
    &setup_lseek_read_pf0_0_common,
    { { &setup_lseek_read_pfb_2_proc0 }, { &setup_lseek_read_pd0_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pd0_1",
    &setup_lseek_read_pf0_0_common,
    { { &setup_lseek_read_pfc_2_proc0 }, { &setup_lseek_read_pd0_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pc_0",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pfb_2_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pc_1",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pfc_2_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pbf_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pbf_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pbec_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pbec_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pbe8_0",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pbe8_0_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pbe0_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pbec_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pbd_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbd_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pbd_1",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbd_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pbc0_0",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pbc0_1",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pb8_0",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pb8_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pb7_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pb7_0_proc0 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pb6c_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pb68_0",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pb68_0_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pb60_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pb5_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pb5_0_proc0 }, { &setup_lseek_read_pb5_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pb40_0",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pb0_0",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pb8_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pbf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_paf_0",
    &setup_lseek_read_paf_0_common,
    { { &setup_lseek_read_paf_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_paf_1",
    &setup_lseek_read_paf_0_common,
    { { &setup_lseek_read_paf_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_paec_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pbec_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_paec_1",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_paec_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paec_1_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pae8_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pae8_0_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pae8_1",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pae8_1_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paec_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pae0_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pbec_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pae0_1",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pae0_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pad8_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pad8_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pad8_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pad8_1",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pad8_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pad8_2",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pad8_2_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pad8_3",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pad8_4",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pac4_0",
    &setup_lseek_read_pac4_0_common,
    { { &setup_lseek_read_pac4_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pac4_1",
    &setup_lseek_read_pac4_1_common,
    { { &setup_lseek_read_pac4_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pac4_1_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pac4_2",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pac4_2_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pac4_2_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pa8_0",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pa8_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pa8_1",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_pa7_0",
    &setup_lseek_read_paf_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa7_1",
    &setup_lseek_read_paf_0_common,
    { { &setup_lseek_read_pd0_0_proc1 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa6c_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa6c_1",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pa6c_1_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paec_1_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa68_0",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pb68_0_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa68_1",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pa68_1_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paec_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa60_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa60_1",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pd0_0_proc1 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa5_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pb5_0_proc1 }, { &setup_lseek_read_pb5_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa5_1",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pb5_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa5_2",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa40_0",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa0_0",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pa8_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_pa0_1",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_paf_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p9f8_0",
    &setup_lseek_read_paf_0_common,
    { { &setup_lseek_read_paf_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9f6_0",
    &setup_lseek_read_p9f6_0_common,
    { { &setup_lseek_read_paec_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p9f6_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9f4_0",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pae8_1_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p9f6_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9f0_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pae0_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9e8_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pad8_2_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9e8_1",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9e8_2",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9e4_0",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_p9e4_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9e4_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9e4_1",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9e4_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9e4_2",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9e4_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9c_0",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p9b8_0",
    &setup_lseek_read_paf_0_common,
    { { &setup_lseek_read_pd0_0_proc1 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p9b6_0",
    &setup_lseek_read_p9f6_0_common,
    { { &setup_lseek_read_pa6c_1_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p9f6_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p9b4_0",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pa68_1_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p9f6_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p9b0_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pd0_0_proc1 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p9a8_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p9a8_1",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p9a0_0",
    &setup_lseek_read_pac4_1_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_p9a0_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p9a0_1",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p98_0",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p9f8_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p978_0",
    &setup_lseek_read_paf_0_common,
    { { &setup_lseek_read_paf_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p976_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_p976_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p976_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p976_1",
    &setup_lseek_read_p976_1_common,
    { { &setup_lseek_read_p976_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p976_1_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p974_0",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_p974_0_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p976_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p974_1",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pae8_1_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p974_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p970_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pae0_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p96c_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p962_0",
    &setup_lseek_read_pac4_0_common,
    { { &setup_lseek_read_p962_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p962_1",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_p962_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p962_1_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p962_2",
    &setup_lseek_read_p962_2_common,
    { { &setup_lseek_read_p962_2_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p962_2_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p94_0",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p938_0",
    &setup_lseek_read_paf_0_common,
    { { &setup_lseek_read_pd0_0_proc1 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p936_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pd4_0_proc1 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p976_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p936_1",
    &setup_lseek_read_p976_1_common,
    { { &setup_lseek_read_p936_1_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p976_1_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p934_0",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_p934_0_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p976_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p934_1",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pa68_1_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p974_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p930_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pd0_0_proc1 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p928_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pb5_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p928_1",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pb5_0_proc1 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p976_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p928_2",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p920_0",
    &setup_lseek_read_p920_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_p920_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p920_1",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pb5_0_proc1 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p976_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p920_2",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p90_0",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p978_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p8fc_0",
    &setup_lseek_read_p8fc_0_common,
    { { &setup_lseek_read_paf_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8fb_0",
    &setup_lseek_read_p8fb_0_common,
    { { &setup_lseek_read_pbec_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8fb_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8fa_0",
    &setup_lseek_read_p8fb_0_common,
    { { &setup_lseek_read_pbe8_0_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8fb_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8f8_0",
    &setup_lseek_read_p8f8_0_common,
    { { &setup_lseek_read_pbec_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8f4_0",
    &setup_lseek_read_p8f4_0_common,
    { { &setup_lseek_read_p8f4_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8f4_1",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_p8f4_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8f4_2",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_p8f4_2_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8f0_0",
    &setup_lseek_read_p8f0_0_common,
    { { &setup_lseek_read_p8f0_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8f0_1",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8f0_1_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8f0_2",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8f0_1_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8e_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pa8_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8dc_0",
    &setup_lseek_read_p8fc_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p8db_0",
    &setup_lseek_read_p8fb_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8fb_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p8da_0",
    &setup_lseek_read_p8fb_0_common,
    { { &setup_lseek_read_pb68_0_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8fb_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p8d8_0",
    &setup_lseek_read_p8f8_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p8d4_0",
    &setup_lseek_read_p8f4_0_common,
    { { &setup_lseek_read_pbd_1_proc0 }, { &setup_lseek_read_p8d4_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p8d4_1",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbd_1_proc0 }, { &setup_lseek_read_pbd_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p8d0_0",
    &setup_lseek_read_p8f0_0_common,
    { { &setup_lseek_read_p9a0_0_proc1 }, { &setup_lseek_read_p8d0_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p8d0_1",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8f0_1_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p8c_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pa8_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8fc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p8bc_0",
    &setup_lseek_read_p8fc_0_common,
    { { &setup_lseek_read_paf_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8bc_1",
    &setup_lseek_read_paf_0_common,
    { { &setup_lseek_read_paf_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8bb_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pbec_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8bb_1",
    &setup_lseek_read_p8fb_0_common,
    { { &setup_lseek_read_p8bb_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bb_1_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8ba_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pbe8_0_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8ba_1",
    &setup_lseek_read_p8fb_0_common,
    { { &setup_lseek_read_p8ba_1_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bb_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b8_0",
    &setup_lseek_read_p8f8_0_common,
    { { &setup_lseek_read_pbec_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b8_1",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pae0_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b6_0",
    &setup_lseek_read_p8b6_0_common,
    { { &setup_lseek_read_p8b6_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p8b6_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b6_1",
    &setup_lseek_read_p8b6_1_common,
    { { &setup_lseek_read_p8b6_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b6_2",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_p8f4_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b6_3",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pad8_2_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b6_4",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pa8_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b6_5",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b6_6",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b10_0",
    &setup_lseek_read_p8b10_0_common,
    { { &setup_lseek_read_p8b10_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b10_1",
    &setup_lseek_read_p8f0_0_common,
    { { &setup_lseek_read_p8b10_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b10_2",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pac4_2_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b10_3",
    &setup_lseek_read_pac4_0_common,
    { { &setup_lseek_read_p962_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8b10_3_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8b10_4",
    &setup_lseek_read_pac4_0_common,
    { { &setup_lseek_read_pac4_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8b10_4_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8a_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pa8_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p8a_1",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p89c_0",
    &setup_lseek_read_p8fc_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p89c_1",
    &setup_lseek_read_paf_0_common,
    { { &setup_lseek_read_pd0_0_proc1 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p89b_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p89b_1",
    &setup_lseek_read_p8fb_0_common,
    { { &setup_lseek_read_p89b_1_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bb_1_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p89a_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pb68_0_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p89a_1",
    &setup_lseek_read_p8fb_0_common,
    { { &setup_lseek_read_p89a_1_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bb_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p898_0",
    &setup_lseek_read_p8f8_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p898_1",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pd0_0_proc1 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p894_0",
    &setup_lseek_read_p8f4_0_common,
    { { &setup_lseek_read_pb5_0_proc1 }, { &setup_lseek_read_p894_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p894_1",
    &setup_lseek_read_p8b6_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_p894_1_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p894_1_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p894_2",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbd_1_proc0 }, { &setup_lseek_read_pbd_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p894_3",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pb5_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p894_4",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p890_0",
    &setup_lseek_read_p890_0_common,
    { { &setup_lseek_read_p920_0_proc1 }, { &setup_lseek_read_p890_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p890_1",
    &setup_lseek_read_p890_1_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_p890_1_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_p8f4_0_final,
    { { &test_lseek_read_p894_1_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p890_2",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p890_2_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p88_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pa8_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p88_1",
    &setup_lseek_read_pb8_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p8bc_1_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p878_0",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_paf_1_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p876_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pbec_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p874_0",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pbe8_0_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p870_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pbec_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p868_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbd_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p868_1",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pb5_0_proc1 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p860_0",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p860_1",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p84_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p838_0",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pd0_0_proc1 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p836_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p834_0",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pb68_0_proc0 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p830_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pb6c_0_proc0 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p828_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pb5_0_proc1 }, { &setup_lseek_read_pb5_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p820_0",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p80_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbc0_1_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_pfc_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p78_0",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_p78_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p76_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_p76_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p74_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_p74_0_proc0 }, { &setup_lseek_read_pbe8_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p70_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_p76_0_proc0 }, { &setup_lseek_read_pfc_0_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p68_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_p68_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p60_0",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_p60_0_proc0 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p4_0",
    &setup_lseek_read_p4_0_common,
    { { &setup_lseek_read_pbd_0_proc1 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_procfinal,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p4_1",
    &setup_lseek_read_p4_0_common,
    { { &setup_lseek_read_pbd_0_proc1 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_procfinal,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 0, "read" } },
    &cleanup },
  { "fs-lseek_read_p38_0",
    &setup_lseek_read_pfc_0_common,
    { { &setup_lseek_read_pfc_0_proc1 }, { &setup_lseek_read_pfc_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p36_0",
    &setup_lseek_read_pfb_0_common,
    { { &setup_lseek_read_pfc_0_proc1 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p34_0",
    &setup_lseek_read_pfa_1_common,
    { { &setup_lseek_read_pbe8_0_proc1 }, { &setup_lseek_read_pda_2_proc1 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p30_0",
    &setup_lseek_read_pf8_0_common,
    { { &setup_lseek_read_pfc_0_proc1 }, { &setup_lseek_read_pfb_2_proc0 } },
    &setup_lseek_read_pfc_0_procfinal,
    &setup_lseek_read_pfc_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p28_0",
    &setup_lseek_read_pbd_0_common,
    { { &setup_lseek_read_pbd_0_proc1 }, { &setup_lseek_read_pb5_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p20_0",
    &setup_lseek_read_pbc0_0_common,
    { { &setup_lseek_read_pbd_0_proc1 }, { &setup_lseek_read_pbc0_1_proc0 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_final,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_read_p0_0",
    &setup_lseek_read_p4_0_common,
    { { &setup_lseek_read_pbd_0_proc1 }, { &setup_lseek_read_pbd_0_proc1 } },
    &setup_lseek_read_pbd_0_procfinal,
    &setup_lseek_read_pbd_0_procfinal,
    { { &test_lseek_read_p78_0_0, 0, "lseek" },
      { &test_lseek_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-lseek_rename_pf_0",
    &setup_lseek_rename_pf_0_common,
    { { &setup_lseek_rename_pf_0_proc0 }, { &setup_lseek_rename_pf_0_proc1 } },
    &setup_lseek_rename_pf_0_procfinal,
    &setup_lseek_rename_pf_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pf_1",
    &setup_lseek_rename_pf_0_common,
    { { &setup_lseek_rename_pf_1_proc0 }, { &setup_lseek_rename_pf_0_proc1 } },
    &setup_lseek_rename_pf_0_procfinal,
    &setup_lseek_rename_pf_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pe8_0",
    &setup_lseek_rename_pe8_0_common,
    { { &setup_lseek_rename_pf_0_proc0 }, { &setup_lseek_rename_pf_0_proc1 } },
    &setup_lseek_rename_pf_0_procfinal,
    &setup_lseek_rename_pf_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pe8_1",
    &setup_lseek_rename_pe8_0_common,
    { { &setup_lseek_rename_pf_1_proc0 }, { &setup_lseek_rename_pf_0_proc1 } },
    &setup_lseek_rename_pf_0_procfinal,
    &setup_lseek_rename_pf_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pe0_0",
    &setup_lseek_rename_pf_0_common,
    { { &setup_lseek_rename_pf_0_proc0 }, { &setup_lseek_rename_pf_0_proc1 } },
    &setup_lseek_rename_pf_0_procfinal,
    &setup_lseek_rename_pf_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pe0_1",
    &setup_lseek_rename_pf_0_common,
    { { &setup_lseek_rename_pf_1_proc0 }, { &setup_lseek_rename_pf_0_proc1 } },
    &setup_lseek_rename_pf_0_procfinal,
    &setup_lseek_rename_pf_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pc_0",
    &setup_lseek_rename_pc_0_common,
    { { &setup_lseek_rename_pf_0_proc0 }, { &setup_lseek_rename_pf_0_proc1 } },
    &setup_lseek_rename_pf_0_procfinal,
    &setup_lseek_rename_pf_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pc_1",
    &setup_lseek_rename_pc_0_common,
    { { &setup_lseek_rename_pf_1_proc0 }, { &setup_lseek_rename_pf_0_proc1 } },
    &setup_lseek_rename_pf_0_procfinal,
    &setup_lseek_rename_pf_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pbc_0",
    &setup_lseek_rename_pbc_0_common,
    { { &setup_lseek_rename_pbc_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pbc_0_0, 0, "lseek" },
      { &test_lseek_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pba_0",
    &setup_lseek_rename_pba_0_common,
    { { &setup_lseek_rename_pba_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pbc_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pb8_0",
    &setup_lseek_rename_pbc_0_common,
    { { &setup_lseek_rename_pbc_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pbc_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pb0_0",
    &setup_lseek_rename_pb0_0_common,
    { { &setup_lseek_rename_pbc_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pbc_0_0, 0, "lseek" },
      { &test_lseek_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pac_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pac_0_0, 0, "lseek" },
      { &test_lseek_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_paa_0",
    &setup_lseek_rename_pba_0_common,
    { { &setup_lseek_rename_pba_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pac_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_paa_1",
    &setup_lseek_rename_paa_1_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pac_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pa8_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pac_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_pa0_0",
    &setup_lseek_rename_pa0_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pac_0_0, 0, "lseek" },
      { &test_lseek_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p9e_0",
    &setup_lseek_rename_p9e_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p9e_0_0, 0, "lseek" },
      { &test_lseek_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p9d0_0",
    &setup_lseek_rename_paa_1_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p9e_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p9c_0",
    &setup_lseek_rename_p9e_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p9e_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p98_0",
    &setup_lseek_rename_p98_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p9e_0_0, 0, "lseek" },
      { &test_lseek_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p96_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p96_0_0, 0, "lseek" },
      { &test_lseek_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p950_0",
    &setup_lseek_rename_paa_1_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p96_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p94_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p96_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p90_0",
    &setup_lseek_rename_pa0_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p96_0_0, 0, "lseek" },
      { &test_lseek_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8f_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_p8f_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p8f_0_0, 0, "lseek" },
      { &test_lseek_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8e8_0",
    &setup_lseek_rename_p8e8_0_common,
    { { &setup_lseek_rename_pba_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_p8e8_0_final,
    { { &test_lseek_rename_p8f_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8e8_1",
    &setup_lseek_rename_p8e8_1_common,
    { { &setup_lseek_rename_pba_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_p8e8_1_final,
    { { &test_lseek_rename_p8f_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8e8_2",
    &setup_lseek_rename_pba_0_common,
    { { &setup_lseek_rename_pba_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p8f_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8e0_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_p8f_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p8f_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8c_0",
    &setup_lseek_rename_pa0_0_common,
    { { &setup_lseek_rename_p8f_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p8f_0_0, 0, "lseek" },
      { &test_lseek_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8b_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p8b_0_0, 0, "lseek" },
      { &test_lseek_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8a8_0",
    &setup_lseek_rename_p8e8_0_common,
    { { &setup_lseek_rename_p8f_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_p8e8_0_final,
    { { &test_lseek_rename_p8b_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8a8_1",
    &setup_lseek_rename_p8a8_1_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_p8e8_0_final,
    { { &test_lseek_rename_p8a8_1_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8a8_2",
    &setup_lseek_rename_p8e8_1_common,
    { { &setup_lseek_rename_p8a8_2_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_p8e8_1_final,
    { { &test_lseek_rename_p8b_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8a8_3",
    &setup_lseek_rename_p8a8_3_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_p8e8_1_final,
    { { &test_lseek_rename_p8a8_3_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8a8_4",
    &setup_lseek_rename_pba_0_common,
    { { &setup_lseek_rename_p8a8_2_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p8b_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8a8_5",
    &setup_lseek_rename_paa_1_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p8a8_3_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p8a0_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p8b_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p88_0",
    &setup_lseek_rename_pa0_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p8b_0_0, 0, "lseek" },
      { &test_lseek_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p86_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p850_0",
    &setup_lseek_rename_pba_0_common,
    { { &setup_lseek_rename_pba_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p84_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p80_0",
    &setup_lseek_rename_pa0_0_common,
    { { &setup_lseek_rename_pac_0_proc0 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_pf_0_0, 0, "lseek" },
      { &test_lseek_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p6_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_pbc_0_proc1 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p6_0_0, 0, "lseek" },
      { &test_lseek_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p50_0",
    &setup_lseek_rename_pba_0_common,
    { { &setup_lseek_rename_pbc_0_proc1 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p6_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p4_0",
    &setup_lseek_rename_pac_0_common,
    { { &setup_lseek_rename_pbc_0_proc1 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_final,
    { { &test_lseek_rename_p6_0_0, 0, "lseek" },
      { &test_lseek_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_rename_p0_0",
    &setup_lseek_rename_p0_0_common,
    { { &setup_lseek_rename_pbc_0_proc1 }, { &setup_lseek_rename_pbc_0_proc1 } },
    &setup_lseek_rename_pbc_0_procfinal,
    &setup_lseek_rename_pbc_0_procfinal,
    { { &test_lseek_rename_p6_0_0, 0, "lseek" },
      { &test_lseek_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-lseek_stat_pe_0",
    &setup_lseek_stat_pe_0_common,
    { { &setup_lseek_stat_pe_0_proc0 }, { &setup_lseek_stat_pe_0_proc1 } },
    &setup_lseek_stat_pe_0_procfinal,
    &setup_lseek_stat_pe_0_final,
    { { &test_lseek_stat_pe_0_0, 0, "lseek" },
      { &test_lseek_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_pe_1",
    &setup_lseek_stat_pe_0_common,
    { { &setup_lseek_stat_pe_1_proc0 }, { &setup_lseek_stat_pe_0_proc1 } },
    &setup_lseek_stat_pe_0_procfinal,
    &setup_lseek_stat_pe_0_final,
    { { &test_lseek_stat_pe_0_0, 0, "lseek" },
      { &test_lseek_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_pc_0",
    &setup_lseek_stat_pc_0_common,
    { { &setup_lseek_stat_pe_0_proc0 }, { &setup_lseek_stat_pe_0_proc1 } },
    &setup_lseek_stat_pe_0_procfinal,
    &setup_lseek_stat_pe_0_final,
    { { &test_lseek_stat_pe_0_0, 0, "lseek" },
      { &test_lseek_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_pc_1",
    &setup_lseek_stat_pc_0_common,
    { { &setup_lseek_stat_pe_1_proc0 }, { &setup_lseek_stat_pe_0_proc1 } },
    &setup_lseek_stat_pe_0_procfinal,
    &setup_lseek_stat_pe_0_final,
    { { &test_lseek_stat_pe_0_0, 0, "lseek" },
      { &test_lseek_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_pb8_0",
    &setup_lseek_stat_pb8_0_common,
    { { &setup_lseek_stat_pb8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_pb8_0_0, 0, "lseek" },
      { &test_lseek_stat_pb8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_pb0_0",
    &setup_lseek_stat_pb0_0_common,
    { { &setup_lseek_stat_pb8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_pb8_0_0, 0, "lseek" },
      { &test_lseek_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_pa8_0",
    &setup_lseek_stat_pa8_0_common,
    { { &setup_lseek_stat_pa8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_pa8_0_0, 0, "lseek" },
      { &test_lseek_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_pa0_0",
    &setup_lseek_stat_pa0_0_common,
    { { &setup_lseek_stat_pa8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_pa8_0_0, 0, "lseek" },
      { &test_lseek_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p9c_0",
    &setup_lseek_stat_p9c_0_common,
    { { &setup_lseek_stat_pa8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_p9c_0_0, 0, "lseek" },
      { &test_lseek_stat_p9c_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p98_0",
    &setup_lseek_stat_p98_0_common,
    { { &setup_lseek_stat_pa8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_p9c_0_0, 0, "lseek" },
      { &test_lseek_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p94_0",
    &setup_lseek_stat_pa8_0_common,
    { { &setup_lseek_stat_pa8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_p94_0_0, 0, "lseek" },
      { &test_lseek_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p90_0",
    &setup_lseek_stat_pa0_0_common,
    { { &setup_lseek_stat_pa8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_p94_0_0, 0, "lseek" },
      { &test_lseek_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p8e_0",
    &setup_lseek_stat_pa8_0_common,
    { { &setup_lseek_stat_p8e_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_p8e_0_0, 0, "lseek" },
      { &test_lseek_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p8c_0",
    &setup_lseek_stat_pa0_0_common,
    { { &setup_lseek_stat_p8e_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_p8e_0_0, 0, "lseek" },
      { &test_lseek_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p8a_0",
    &setup_lseek_stat_pa8_0_common,
    { { &setup_lseek_stat_pa8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_p8a_0_0, 0, "lseek" },
      { &test_lseek_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p88_0",
    &setup_lseek_stat_pa0_0_common,
    { { &setup_lseek_stat_pa8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_p8a_0_0, 0, "lseek" },
      { &test_lseek_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p84_0",
    &setup_lseek_stat_pa8_0_common,
    { { &setup_lseek_stat_pa8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_pe_0_0, 0, "lseek" },
      { &test_lseek_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p80_0",
    &setup_lseek_stat_pa0_0_common,
    { { &setup_lseek_stat_pa8_0_proc0 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_pe_0_0, 0, "lseek" },
      { &test_lseek_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p4_0",
    &setup_lseek_stat_pa8_0_common,
    { { &setup_lseek_stat_pb8_0_proc1 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_final,
    { { &test_lseek_stat_p4_0_0, 0, "lseek" },
      { &test_lseek_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_stat_p0_0",
    &setup_lseek_stat_p0_0_common,
    { { &setup_lseek_stat_pb8_0_proc1 }, { &setup_lseek_stat_pb8_0_proc1 } },
    &setup_lseek_stat_pb8_0_procfinal,
    &setup_lseek_stat_pb8_0_procfinal,
    { { &test_lseek_stat_p4_0_0, 0, "lseek" },
      { &test_lseek_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-lseek_unlink_pe_0",
    &setup_lseek_unlink_pe_0_common,
    { { &setup_lseek_unlink_pe_0_proc0 }, { &setup_lseek_unlink_pe_0_proc1 } },
    &setup_lseek_unlink_pe_0_procfinal,
    &setup_lseek_unlink_pe_0_final,
    { { &test_lseek_unlink_pe_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_pe_1",
    &setup_lseek_unlink_pe_0_common,
    { { &setup_lseek_unlink_pe_1_proc0 }, { &setup_lseek_unlink_pe_0_proc1 } },
    &setup_lseek_unlink_pe_0_procfinal,
    &setup_lseek_unlink_pe_0_final,
    { { &test_lseek_unlink_pe_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_pc_0",
    &setup_lseek_unlink_pc_0_common,
    { { &setup_lseek_unlink_pe_0_proc0 }, { &setup_lseek_unlink_pe_0_proc1 } },
    &setup_lseek_unlink_pe_0_procfinal,
    &setup_lseek_unlink_pe_0_final,
    { { &test_lseek_unlink_pe_0_0, 0, "lseek" },
      { &test_lseek_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_pc_1",
    &setup_lseek_unlink_pc_0_common,
    { { &setup_lseek_unlink_pe_1_proc0 }, { &setup_lseek_unlink_pe_0_proc1 } },
    &setup_lseek_unlink_pe_0_procfinal,
    &setup_lseek_unlink_pe_0_final,
    { { &test_lseek_unlink_pe_0_0, 0, "lseek" },
      { &test_lseek_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_pb8_0",
    &setup_lseek_unlink_pb8_0_common,
    { { &setup_lseek_unlink_pb8_0_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_pb8_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_pb0_0",
    &setup_lseek_unlink_pb0_0_common,
    { { &setup_lseek_unlink_pb0_0_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_pb8_0_0, 0, "lseek" },
      { &test_lseek_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_pa8_0",
    &setup_lseek_unlink_pb8_0_common,
    { { &setup_lseek_unlink_pb8_0_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_pa8_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_pa8_1",
    &setup_lseek_unlink_pa8_1_common,
    { { &setup_lseek_unlink_pa8_1_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_pa8_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_pa0_0",
    &setup_lseek_unlink_pa0_0_common,
    { { &setup_lseek_unlink_pa8_1_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_pa8_0_0, 0, "lseek" },
      { &test_lseek_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p9c_0",
    &setup_lseek_unlink_pa8_1_common,
    { { &setup_lseek_unlink_pa8_1_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_p9c_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p98_0",
    &setup_lseek_unlink_p98_0_common,
    { { &setup_lseek_unlink_pa8_1_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_p9c_0_0, 0, "lseek" },
      { &test_lseek_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p94_0",
    &setup_lseek_unlink_pa8_1_common,
    { { &setup_lseek_unlink_pa8_1_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_p94_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p90_0",
    &setup_lseek_unlink_pa0_0_common,
    { { &setup_lseek_unlink_pa8_1_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_p94_0_0, 0, "lseek" },
      { &test_lseek_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p8e_0",
    &setup_lseek_unlink_p8e_0_common,
    { { &setup_lseek_unlink_pb8_0_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_p8e_0_final,
    { { &test_lseek_unlink_p8e_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p8e_1",
    &setup_lseek_unlink_pb8_0_common,
    { { &setup_lseek_unlink_pb8_0_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_p8e_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p8c_0",
    &setup_lseek_unlink_pa0_0_common,
    { { &setup_lseek_unlink_p8c_0_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_p8e_0_0, 0, "lseek" },
      { &test_lseek_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p8a_0",
    &setup_lseek_unlink_p8e_0_common,
    { { &setup_lseek_unlink_p8c_0_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_p8e_0_final,
    { { &test_lseek_unlink_p8a_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p8a_1",
    &setup_lseek_unlink_p8a_1_common,
    { { &setup_lseek_unlink_pa8_1_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_p8e_0_final,
    { { &test_lseek_unlink_p8a_1_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p8a_2",
    &setup_lseek_unlink_pb8_0_common,
    { { &setup_lseek_unlink_p8a_2_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_p8a_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p8a_3",
    &setup_lseek_unlink_pa8_1_common,
    { { &setup_lseek_unlink_pa8_1_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_p8a_3_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p88_0",
    &setup_lseek_unlink_pa0_0_common,
    { { &setup_lseek_unlink_pa8_1_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_p8a_0_0, 0, "lseek" },
      { &test_lseek_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p84_0",
    &setup_lseek_unlink_pb8_0_common,
    { { &setup_lseek_unlink_pb8_0_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_pe_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p80_0",
    &setup_lseek_unlink_pa0_0_common,
    { { &setup_lseek_unlink_pa8_1_proc0 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_pe_0_0, 0, "lseek" },
      { &test_lseek_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p4_0",
    &setup_lseek_unlink_pb8_0_common,
    { { &setup_lseek_unlink_pb8_0_proc1 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_final,
    { { &test_lseek_unlink_p4_0_0, 0, "lseek" },
      { &test_lseek_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_unlink_p0_0",
    &setup_lseek_unlink_p0_0_common,
    { { &setup_lseek_unlink_pb8_0_proc1 }, { &setup_lseek_unlink_pb8_0_proc1 } },
    &setup_lseek_unlink_pb8_0_procfinal,
    &setup_lseek_unlink_pb8_0_procfinal,
    { { &test_lseek_unlink_p4_0_0, 0, "lseek" },
      { &test_lseek_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-lseek_write_pfe_0",
    &setup_lseek_write_pfe_0_common,
    { { &setup_lseek_write_pfe_0_proc0 }, { &setup_lseek_write_pfe_0_proc1 } },
    &setup_lseek_write_pfe_0_procfinal,
    &setup_lseek_write_pfe_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pfe_1",
    &setup_lseek_write_pfe_0_common,
    { { &setup_lseek_write_pfe_1_proc0 }, { &setup_lseek_write_pfe_0_proc1 } },
    &setup_lseek_write_pfe_0_procfinal,
    &setup_lseek_write_pfe_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pfe_2",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pfe_2_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pfe_3",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pfe_3_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pfc_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pfc_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pfc_1",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pfc_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pfc_2",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pfc_2_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pf8_0",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pf8_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pf8_1",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pf8_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pf8_2",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pf8_2_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pf4_0",
    &setup_lseek_write_pf4_0_common,
    { { &setup_lseek_write_pf4_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pf4_1",
    &setup_lseek_write_pf4_1_common,
    { { &setup_lseek_write_pf4_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pf0_0",
    &setup_lseek_write_pf0_0_common,
    { { &setup_lseek_write_pf4_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pf0_1",
    &setup_lseek_write_pf0_1_common,
    { { &setup_lseek_write_pf4_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pe_0",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pf8_2_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pe_1",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pfc_2_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pde_0",
    &setup_lseek_write_pde_0_common,
    { { &setup_lseek_write_pde_0_proc0 }, { &setup_lseek_write_pde_0_proc1 } },
    &setup_lseek_write_pfe_0_procfinal,
    &setup_lseek_write_pfe_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pde_1",
    &setup_lseek_write_pde_0_common,
    { { &setup_lseek_write_pde_1_proc0 }, { &setup_lseek_write_pde_0_proc1 } },
    &setup_lseek_write_pfe_0_procfinal,
    &setup_lseek_write_pfe_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pde_2",
    &setup_lseek_write_pde_2_common,
    { { &setup_lseek_write_pfe_3_proc0 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pdc_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pf8_2_proc0 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pdc_1",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pfc_2_proc0 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pd8_0",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pf8_2_proc0 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pd8_1",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pfc_2_proc0 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pd4_0",
    &setup_lseek_write_pf4_0_common,
    { { &setup_lseek_write_pf8_2_proc0 }, { &setup_lseek_write_pd4_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pd4_1",
    &setup_lseek_write_pf4_0_common,
    { { &setup_lseek_write_pfc_2_proc0 }, { &setup_lseek_write_pd4_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pd0_0",
    &setup_lseek_write_pf0_0_common,
    { { &setup_lseek_write_pf8_2_proc0 }, { &setup_lseek_write_pd4_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pd0_1",
    &setup_lseek_write_pf0_0_common,
    { { &setup_lseek_write_pfc_2_proc0 }, { &setup_lseek_write_pd4_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pc_0",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pf8_2_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pc_1",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pfc_2_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pbf8_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pbf8_0_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pbf0_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pbf0_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pbe_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pbe_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pbd0_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pbd0_1",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pbc0_0",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pbc0_1",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pb8_0",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pb8_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pb78_0",
    &setup_lseek_write_pde_2_common,
    { { &setup_lseek_write_pb78_0_proc0 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pb70_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pb70_0_proc0 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pb6_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pb6_0_proc0 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pb50_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pb40_0",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pb0_0",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pb8_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pbf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_paf8_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pbf8_0_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_paf8_1",
    &setup_lseek_write_pde_2_common,
    { { &setup_lseek_write_paf8_1_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_paf0_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pbf0_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_paf0_1",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_paf0_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pae_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pae_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pae_1",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pae_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pad8_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pac0_0",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pa8_0",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pa8_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pa8_1",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_pa78_0",
    &setup_lseek_write_pde_2_common,
    { { &setup_lseek_write_pb78_0_proc0 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pa78_1",
    &setup_lseek_write_pde_2_common,
    { { &setup_lseek_write_pa78_1_proc0 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pa70_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pb70_0_proc0 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pa70_1",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pd4_0_proc1 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pa6_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pb70_0_proc0 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pa6_1",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pd4_0_proc1 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pa50_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pa40_0",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pa0_0",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pa8_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_pa0_1",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_paf8_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p9fc_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_paf8_1_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p9f8_0",
    &setup_lseek_write_p9f8_0_common,
    { { &setup_lseek_write_paf0_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p9f0_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pae_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p9ec_0",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_p9ec_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9ec_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p9ec_1",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p9ec_2",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9ec_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p9e4_0",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_p9ec_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9ec_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p9e4_1",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9ec_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p9e4_2",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9ec_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p9c_0",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p9bc_0",
    &setup_lseek_write_pde_2_common,
    { { &setup_lseek_write_pa78_1_proc0 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p9b8_0",
    &setup_lseek_write_p9f8_0_common,
    { { &setup_lseek_write_pd4_0_proc1 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p9b0_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pd4_0_proc1 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p9a8_0",
    &setup_lseek_write_p9a8_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_p9a8_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p9a8_1",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p9a0_0",
    &setup_lseek_write_p9a0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_p9a8_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p9a0_1",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p98_0",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p9fc_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p97c_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_paf8_1_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p978_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_paf0_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p970_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pae_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p96e_0",
    &setup_lseek_write_p9a8_0_common,
    { { &setup_lseek_write_p96e_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p96e_1",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_p96e_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p96e_1_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p96e_2",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_p96e_2_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p96e_2_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p962_0",
    &setup_lseek_write_p9a0_0_common,
    { { &setup_lseek_write_p96e_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p962_1",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_p96e_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p96e_1_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p962_2",
    &setup_lseek_write_p962_2_common,
    { { &setup_lseek_write_p96e_2_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p96e_2_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p94_0",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p93c_0",
    &setup_lseek_write_pde_2_common,
    { { &setup_lseek_write_pa78_1_proc0 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p938_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pd4_0_proc1 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p930_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pd4_0_proc1 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p928_0",
    &setup_lseek_write_p928_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_p928_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p928_1",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_p928_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p928_1_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p928_2",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p920_0",
    &setup_lseek_write_p9a8_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_p928_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p920_1",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_p928_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p928_1_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p920_2",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p90_0",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p97c_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p8fe_0",
    &setup_lseek_write_p8fe_0_common,
    { { &setup_lseek_write_pbf8_0_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8fe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8fc_0",
    &setup_lseek_write_p8fc_0_common,
    { { &setup_lseek_write_pbf0_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8fe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8f8_0",
    &setup_lseek_write_p8fe_0_common,
    { { &setup_lseek_write_pae_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8fe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8f6_0",
    &setup_lseek_write_p8f6_0_common,
    { { &setup_lseek_write_p8f6_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8f6_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8f6_1",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8f6_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8f6_2",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8f6_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8f0_0",
    &setup_lseek_write_p8f0_0_common,
    { { &setup_lseek_write_p8f0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8fe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8f0_1",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8f6_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8f0_2",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8f6_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8e_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pa8_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8fe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8de_0",
    &setup_lseek_write_p8de_0_common,
    { { &setup_lseek_write_pb78_0_proc0 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8fe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p8dc_0",
    &setup_lseek_write_p8fc_0_common,
    { { &setup_lseek_write_pb70_0_proc0 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8fe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p8d8_0",
    &setup_lseek_write_p8fe_0_common,
    { { &setup_lseek_write_pb70_0_proc0 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8fe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p8d6_0",
    &setup_lseek_write_p8f6_0_common,
    { { &setup_lseek_write_p8d6_0_proc0 }, { &setup_lseek_write_p8d6_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8f6_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p8d6_1",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8f6_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p8d0_0",
    &setup_lseek_write_p8f0_0_common,
    { { &setup_lseek_write_p9a8_0_proc1 }, { &setup_lseek_write_p8d0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8fe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p8d0_1",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8f6_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p8c_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pa8_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8fe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p8be_0",
    &setup_lseek_write_p8fe_0_common,
    { { &setup_lseek_write_pbf8_0_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8be_1",
    &setup_lseek_write_p8be_1_common,
    { { &setup_lseek_write_paf8_1_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_1_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8bc_0",
    &setup_lseek_write_p8fe_0_common,
    { { &setup_lseek_write_pbf0_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8bc_1",
    &setup_lseek_write_p9f8_0_common,
    { { &setup_lseek_write_paf0_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_1_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8b8_0",
    &setup_lseek_write_p8fe_0_common,
    { { &setup_lseek_write_pae_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8b8_1",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pae_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_1_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8b70_0",
    &setup_lseek_write_p8f6_0_common,
    { { &setup_lseek_write_p8f6_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8b70_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8b70_1",
    &setup_lseek_write_p8b70_1_common,
    { { &setup_lseek_write_p8b70_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8be_1_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8b0_0",
    &setup_lseek_write_p8f0_0_common,
    { { &setup_lseek_write_p8f0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8b0_1",
    &setup_lseek_write_p8b0_1_common,
    { { &setup_lseek_write_p8b0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8b0_1_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8b0_2",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8b0_2_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8a_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pa8_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p8a_1",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8be_1_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p89e_0",
    &setup_lseek_write_p8de_0_common,
    { { &setup_lseek_write_pb78_0_proc0 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p89e_1",
    &setup_lseek_write_p8be_1_common,
    { { &setup_lseek_write_pa78_1_proc0 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_1_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p89c_0",
    &setup_lseek_write_p8fe_0_common,
    { { &setup_lseek_write_pb70_0_proc0 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p89c_1",
    &setup_lseek_write_p9f8_0_common,
    { { &setup_lseek_write_pd4_0_proc1 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_1_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p898_0",
    &setup_lseek_write_p8fe_0_common,
    { { &setup_lseek_write_pb70_0_proc0 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p898_1",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pd4_0_proc1 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p8be_1_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p896_0",
    &setup_lseek_write_p896_0_common,
    { { &setup_lseek_write_p928_0_proc1 }, { &setup_lseek_write_p896_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p896_1",
    &setup_lseek_write_p896_1_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_p8d0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p896_1_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p890_0",
    &setup_lseek_write_p890_0_common,
    { { &setup_lseek_write_p928_0_proc1 }, { &setup_lseek_write_p896_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p890_1",
    &setup_lseek_write_p890_1_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_p890_1_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_p8f6_0_final,
    { { &test_lseek_write_p8be_1_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p890_2",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8b0_2_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p88_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pa8_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8be_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p88_1",
    &setup_lseek_write_pb8_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p8be_1_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p87c_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_pbf8_0_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p878_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pbf0_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p870_0",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pae_1_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p868_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p868_1",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p860_0",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p860_1",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p84_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p83c_0",
    &setup_lseek_write_pde_2_common,
    { { &setup_lseek_write_pb78_0_proc0 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p838_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pb70_0_proc0 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p830_0",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pd4_0_proc1 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p828_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p820_0",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p80_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_1_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_pfe_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p7c_0",
    &setup_lseek_write_pfe_2_common,
    { { &setup_lseek_write_p7c_0_proc0 }, { &setup_lseek_write_pfe_2_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p78_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_p78_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p70_0",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_p70_0_proc0 }, { &setup_lseek_write_pfc_0_proc1 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p68_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_p68_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p60_0",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_p68_0_proc0 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p4_0",
    &setup_lseek_write_p4_0_common,
    { { &setup_lseek_write_pbd0_0_proc1 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_procfinal,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p4_1",
    &setup_lseek_write_p4_0_common,
    { { &setup_lseek_write_pbd0_0_proc1 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_procfinal,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 0, "write" } },
    &cleanup },
  { "fs-lseek_write_p3c_0",
    &setup_lseek_write_pde_2_common,
    { { &setup_lseek_write_pfe_2_proc1 }, { &setup_lseek_write_pfe_3_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p38_0",
    &setup_lseek_write_pfc_0_common,
    { { &setup_lseek_write_pfc_0_proc1 }, { &setup_lseek_write_pfc_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p30_0",
    &setup_lseek_write_pf8_0_common,
    { { &setup_lseek_write_pfc_0_proc1 }, { &setup_lseek_write_pf8_2_proc0 } },
    &setup_lseek_write_pfe_2_procfinal,
    &setup_lseek_write_pfe_2_final,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p28_0",
    &setup_lseek_write_pbd0_0_common,
    { { &setup_lseek_write_pbd0_0_proc1 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p20_0",
    &setup_lseek_write_pbc0_0_common,
    { { &setup_lseek_write_pbd0_0_proc1 }, { &setup_lseek_write_pbd0_1_proc0 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_final,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-lseek_write_p0_0",
    &setup_lseek_write_p4_0_common,
    { { &setup_lseek_write_pbd0_0_proc1 }, { &setup_lseek_write_pbd0_0_proc1 } },
    &setup_lseek_write_pbd0_0_procfinal,
    &setup_lseek_write_pbd0_0_procfinal,
    { { &test_lseek_write_p7c_0_0, 0, "lseek" },
      { &test_lseek_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-memread_memread_pf8_0",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf8_1",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf8_2",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_2_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf8_3",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf8_4",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_4_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf8_5",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_5_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf4_0",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pf4_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf4_1",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pf4_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf4_2",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pf4_2_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf4_3",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pf4_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf0_0",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pf0_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf0_1",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pf0_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf0_2",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pf0_2_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pf0_3",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pf0_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pe_0",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pe_1",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_5_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd8_0",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_3_proc0 }, { &setup_memread_memread_pf8_3_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd8_1",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_5_proc0 }, { &setup_memread_memread_pf8_3_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd8_2",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_3_proc0 }, { &setup_memread_memread_pf8_5_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd8_3",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_5_proc0 }, { &setup_memread_memread_pf8_5_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd4_0",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pf8_3_proc0 }, { &setup_memread_memread_pd4_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd4_1",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pf8_3_proc0 }, { &setup_memread_memread_pd4_1_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd4_2",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pf8_5_proc0 }, { &setup_memread_memread_pd4_2_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd4_3",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pf8_5_proc0 }, { &setup_memread_memread_pd4_3_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd0_0",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pf8_3_proc0 }, { &setup_memread_memread_pd4_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd0_1",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pf8_5_proc0 }, { &setup_memread_memread_pd4_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd0_2",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pf8_3_proc0 }, { &setup_memread_memread_pd4_3_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pd0_3",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pf8_5_proc0 }, { &setup_memread_memread_pd4_3_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pc_0",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pc_1",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_5_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pbc_0",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pbc_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pbc_1",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pbc_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pbc_2",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pbc_2_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pbc_3",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pbc_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_0",
    &setup_memread_memread_pba_0_common,
    { { &setup_memread_memread_pba_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_1",
    &setup_memread_memread_pba_1_common,
    { { &setup_memread_memread_pba_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_2",
    &setup_memread_memread_pba_1_common,
    { { &setup_memread_memread_pba_2_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_3",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_4",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_4_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_5",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_5_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_6",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_6_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_7",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_7_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_8",
    &setup_memread_memread_pba_8_common,
    { { &setup_memread_memread_pba_8_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_9",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_9_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_10",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_10_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_11",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_11_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_12",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_12_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pba_13",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_13_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pb8_0",
    &setup_memread_memread_pb8_0_common,
    { { &setup_memread_memread_pb8_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pb8_1",
    &setup_memread_memread_pb8_1_common,
    { { &setup_memread_memread_pb8_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pb8_2",
    &setup_memread_memread_pb8_1_common,
    { { &setup_memread_memread_pb8_2_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pb8_3",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pb8_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pb8_4",
    &setup_memread_memread_pb8_4_common,
    { { &setup_memread_memread_pb8_4_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pb8_5",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_pb8_5_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pb8_6",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_pb8_6_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pb8_7",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_pb8_7_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pb0_0",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pb0_1",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_13_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_pac_0",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_pf8_3_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pac_1",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pac_1_proc0 }, { &setup_memread_memread_pf8_5_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pac_2",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_13_proc0 }, { &setup_memread_memread_pf8_3_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pac_3",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pac_3_proc0 }, { &setup_memread_memread_pf8_5_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_0",
    &setup_memread_memread_pba_8_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_paa_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_1",
    &setup_memread_memread_pba_8_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_paa_1_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_2",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_pac_1_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_3",
    &setup_memread_memread_paa_3_common,
    { { &setup_memread_memread_paa_3_proc0 }, { &setup_memread_memread_pac_3_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_4",
    &setup_memread_memread_paa_3_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_pb0_0_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_5",
    &setup_memread_memread_paa_3_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_pac_3_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_6",
    &setup_memread_memread_pb8_1_common,
    { { &setup_memread_memread_paa_6_proc0 }, { &setup_memread_memread_paa_6_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_7",
    &setup_memread_memread_paa_3_common,
    { { &setup_memread_memread_paa_6_proc0 }, { &setup_memread_memread_pb0_0_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_8",
    &setup_memread_memread_paa_3_common,
    { { &setup_memread_memread_pac_3_proc0 }, { &setup_memread_memread_pb0_0_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_9",
    &setup_memread_memread_pb8_1_common,
    { { &setup_memread_memread_paa_9_proc0 }, { &setup_memread_memread_paa_9_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_10",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_paa_6_proc0 }, { &setup_memread_memread_pac_3_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_paa_11",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pba_13_proc0 }, { &setup_memread_memread_pba_13_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pa8_0",
    &setup_memread_memread_pb8_0_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_pa8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pa8_1",
    &setup_memread_memread_pb8_0_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_pa8_1_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pa8_2",
    &setup_memread_memread_pa8_2_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_pa8_2_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pa8_3",
    &setup_memread_memread_pa8_2_common,
    { { &setup_memread_memread_pa8_3_proc0 }, { &setup_memread_memread_pa8_3_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pa8_4",
    &setup_memread_memread_pb8_0_common,
    { { &setup_memread_memread_pa8_3_proc1 }, { &setup_memread_memread_pa8_4_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pa8_5",
    &setup_memread_memread_pb8_0_common,
    { { &setup_memread_memread_pa8_3_proc1 }, { &setup_memread_memread_pa8_5_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pa8_6",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_pa8_3_proc1 }, { &setup_memread_memread_pa8_6_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pa8_7",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_pa8_3_proc1 }, { &setup_memread_memread_pa8_7_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pa0_0",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pb0_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_pa0_1",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pac_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pd4_0_1, 0, "memread" },
      { &test_memread_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9c_0",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_p9c_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9c_1",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_p9c_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9c_2",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_p9c_2_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9c_3",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_p9c_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9a_0",
    &setup_memread_memread_pba_1_common,
    { { &setup_memread_memread_p9a_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9a_1",
    &setup_memread_memread_p9a_1_common,
    { { &setup_memread_memread_p9a_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9a_2",
    &setup_memread_memread_p9a_1_common,
    { { &setup_memread_memread_p9a_2_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9a_3",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_p9a_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9a_4",
    &setup_memread_memread_pa8_2_common,
    { { &setup_memread_memread_p9a_4_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9a_5",
    &setup_memread_memread_p9a_5_common,
    { { &setup_memread_memread_p9a_5_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9a_6",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_p9a_6_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p9a_7",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_p9a_7_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p98_0",
    &setup_memread_memread_p98_0_common,
    { { &setup_memread_memread_p98_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p98_1",
    &setup_memread_memread_p98_0_common,
    { { &setup_memread_memread_p98_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p98_2",
    &setup_memread_memread_p98_0_common,
    { { &setup_memread_memread_p98_2_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p98_3",
    &setup_memread_memread_p98_0_common,
    { { &setup_memread_memread_p98_3_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p98_4",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_p98_4_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p98_5",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_p98_5_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p98_6",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_p98_6_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p98_7",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_p98_7_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p98_8",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_0_proc1 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p98_9",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_3_proc1 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p90_0",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_0_proc1 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p90_1",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_3_proc1 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8c_0",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_0_proc1 }, { &setup_memread_memread_pf8_3_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8c_1",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_3_proc1 }, { &setup_memread_memread_pf8_3_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8c_2",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_0_proc1 }, { &setup_memread_memread_pf8_5_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8c_3",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_3_proc1 }, { &setup_memread_memread_pf8_5_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8a_0",
    &setup_memread_memread_p8a_0_common,
    { { &setup_memread_memread_pd4_0_proc1 }, { &setup_memread_memread_paa_6_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8a_1",
    &setup_memread_memread_p8a_0_common,
    { { &setup_memread_memread_pd4_0_proc1 }, { &setup_memread_memread_paa_9_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8a_2",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_0_proc1 }, { &setup_memread_memread_pb0_0_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8a_3",
    &setup_memread_memread_p8a_3_common,
    { { &setup_memread_memread_pd4_1_proc1 }, { &setup_memread_memread_p8a_3_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8a_4",
    &setup_memread_memread_p8a_3_common,
    { { &setup_memread_memread_pd4_1_proc1 }, { &setup_memread_memread_p8a_4_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8a_5",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_pa8_6_proc1 }, { &setup_memread_memread_pa8_3_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8a_6",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_pa8_7_proc1 }, { &setup_memread_memread_pa8_2_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p8a_7",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_pa8_7_proc1 }, { &setup_memread_memread_pa8_3_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p88_0",
    &setup_memread_memread_p98_0_common,
    { { &setup_memread_memread_pd4_0_proc1 }, { &setup_memread_memread_pa8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p88_1",
    &setup_memread_memread_p98_0_common,
    { { &setup_memread_memread_pd4_0_proc1 }, { &setup_memread_memread_pa8_1_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p88_2",
    &setup_memread_memread_paa_3_common,
    { { &setup_memread_memread_p88_2_proc0 }, { &setup_memread_memread_p88_2_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p88_3",
    &setup_memread_memread_paa_3_common,
    { { &setup_memread_memread_p88_2_proc1 }, { &setup_memread_memread_p88_3_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p88_4",
    &setup_memread_memread_p98_0_common,
    { { &setup_memread_memread_pd4_3_proc1 }, { &setup_memread_memread_pa8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p88_5",
    &setup_memread_memread_paa_3_common,
    { { &setup_memread_memread_p88_3_proc1 }, { &setup_memread_memread_p88_2_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p88_6",
    &setup_memread_memread_p98_0_common,
    { { &setup_memread_memread_pd4_3_proc1 }, { &setup_memread_memread_pa8_1_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pba_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p88_7",
    &setup_memread_memread_pb8_5_common,
    { { &setup_memread_memread_pa8_7_proc1 }, { &setup_memread_memread_pa8_7_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p80_0",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_0_proc1 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p80_1",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pd4_3_proc1 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pf8_0_0, 0, "memread" },
      { &test_memread_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p7_0",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_p7_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p7_1",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_p7_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p68_0",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_p68_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p68_1",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_p68_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pf4_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p60_0",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_p60_0_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p60_1",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_p60_1_proc0 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p4_0",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_0_proc1 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pe_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p4_1",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_0_proc1 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pc_0_1, 0, "memread" } },
    &cleanup },
  { "fs-memread_memread_p3_0",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_0_proc1 }, { &setup_memread_memread_pf8_3_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p3_1",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_0_proc1 }, { &setup_memread_memread_pf8_5_proc0 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p28_0",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pf8_0_proc1 }, { &setup_memread_memread_pd4_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p28_1",
    &setup_memread_memread_pf4_0_common,
    { { &setup_memread_memread_pf8_0_proc1 }, { &setup_memread_memread_pd4_3_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pd4_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p20_0",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pf8_0_proc1 }, { &setup_memread_memread_pd4_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p20_1",
    &setup_memread_memread_pf0_0_common,
    { { &setup_memread_memread_pf8_0_proc1 }, { &setup_memread_memread_pd4_3_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf4_0_final,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pf8_0_0, 1, "memread" } },
    &cleanup },
  { "fs-memread_memread_p0_0",
    &setup_memread_memread_pf8_0_common,
    { { &setup_memread_memread_pf8_0_proc1 }, { &setup_memread_memread_pf8_0_proc1 } },
    &setup_memread_memread_pf8_0_procfinal,
    &setup_memread_memread_pf8_0_procfinal,
    { { &test_memread_memread_pc_0_1, 0, "memread" },
      { &test_memread_memread_pc_0_1, 1, "memread" } },
    &cleanup },
  { "fs-memread_memwrite_pfe_0",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pfe_1",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pfe_2",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pfa_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pfa_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pfa_1",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pfa_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pf8_0",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pf8_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pf8_1",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pf8_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pf0_0",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pf0_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pf0_1",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pf0_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pf0_2",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pf0_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pf0_3",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pf0_3_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pf0_4",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pf0_4_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pe_0",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pf0_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pe_1",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pdc_0",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pf0_2_proc0 }, { &setup_memread_memwrite_pfe_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pdc_1",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_2_proc0 }, { &setup_memread_memwrite_pfe_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pda_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pf0_2_proc0 }, { &setup_memread_memwrite_pda_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pda_1",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pfe_2_proc0 }, { &setup_memread_memwrite_pda_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pd8_0",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pf0_2_proc0 }, { &setup_memread_memwrite_pda_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pd8_1",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pfe_2_proc0 }, { &setup_memread_memwrite_pda_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pd0_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pf0_2_proc0 }, { &setup_memread_memwrite_pd0_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pd0_1",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pfe_2_proc0 }, { &setup_memread_memwrite_pd0_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pd0_2",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pf0_2_proc0 }, { &setup_memread_memwrite_pf0_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pd0_3",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_2_proc0 }, { &setup_memread_memwrite_pf0_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pc_0",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pf0_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pc_1",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbe_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pbe_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbe_1",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pbe_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbd_0",
    &setup_memread_memwrite_pbd_0_common,
    { { &setup_memread_memwrite_pbd_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbd_1",
    &setup_memread_memwrite_pbd_1_common,
    { { &setup_memread_memwrite_pbd_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbd_2",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pbd_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbd_3",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pbd_3_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbd_4",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pbd_4_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbd_5",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pbd_5_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbd_6",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pbd_6_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbc_0",
    &setup_memread_memwrite_pbc_0_common,
    { { &setup_memread_memwrite_pbc_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbc_1",
    &setup_memread_memwrite_pbc_1_common,
    { { &setup_memread_memwrite_pbc_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbc_2",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pbc_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pbc_3",
    &setup_memread_memwrite_pbc_3_common,
    { { &setup_memread_memwrite_pbc_3_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pb8_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb8_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pb8_1",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb8_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pb8_2",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb8_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pb8_3",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb8_3_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pb8_4",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb8_4_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pb0_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb0_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pb0_1",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pbd_6_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pae_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb0_0_proc0 }, { &setup_memread_memwrite_pfe_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pae_1",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pae_1_proc0 }, { &setup_memread_memwrite_pfe_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pad_0",
    &setup_memread_memwrite_pad_0_common,
    { { &setup_memread_memwrite_pb0_0_proc0 }, { &setup_memread_memwrite_pad_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pad_1",
    &setup_memread_memwrite_pbc_3_common,
    { { &setup_memread_memwrite_pb0_0_proc0 }, { &setup_memread_memwrite_pbd_6_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pad_2",
    &setup_memread_memwrite_pbc_1_common,
    { { &setup_memread_memwrite_pad_2_proc0 }, { &setup_memread_memwrite_pad_2_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pad_3",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb0_0_proc0 }, { &setup_memread_memwrite_pae_1_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pad_4",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pad_2_proc0 }, { &setup_memread_memwrite_pae_1_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pad_5",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pbd_6_proc0 }, { &setup_memread_memwrite_pbd_6_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pac_0",
    &setup_memread_memwrite_pbc_0_common,
    { { &setup_memread_memwrite_pb0_0_proc0 }, { &setup_memread_memwrite_pac_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pac_1",
    &setup_memread_memwrite_pac_1_common,
    { { &setup_memread_memwrite_pb0_0_proc0 }, { &setup_memread_memwrite_pac_1_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pac_2",
    &setup_memread_memwrite_pbc_0_common,
    { { &setup_memread_memwrite_pac_2_proc0 }, { &setup_memread_memwrite_pac_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pac_3",
    &setup_memread_memwrite_pbc_3_common,
    { { &setup_memread_memwrite_pac_1_proc1 }, { &setup_memread_memwrite_pac_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pa8_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb0_0_proc0 }, { &setup_memread_memwrite_pb0_0_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pa8_1",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb8_2_proc0 }, { &setup_memread_memwrite_pf0_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pa8_2",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pbd_6_proc0 }, { &setup_memread_memwrite_pb8_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pa8_3",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pae_1_proc0 }, { &setup_memread_memwrite_pf0_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pa0_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pb0_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_pa0_1",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pae_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pbe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9e_0",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_p9e_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9e_1",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_p9e_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9d_0",
    &setup_memread_memwrite_p9d_0_common,
    { { &setup_memread_memwrite_p9d_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9d_1",
    &setup_memread_memwrite_p9d_1_common,
    { { &setup_memread_memwrite_p9d_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9d_2",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_p9d_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9d_3",
    &setup_memread_memwrite_pbc_3_common,
    { { &setup_memread_memwrite_p9d_3_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9c8_0",
    &setup_memread_memwrite_p9c8_0_common,
    { { &setup_memread_memwrite_p9c8_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_p9c8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9c8_1",
    &setup_memread_memwrite_p9c8_0_common,
    { { &setup_memread_memwrite_p9c8_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_p9c8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9c8_2",
    &setup_memread_memwrite_p9c8_2_common,
    { { &setup_memread_memwrite_p9c8_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9c8_3",
    &setup_memread_memwrite_p9c8_2_common,
    { { &setup_memread_memwrite_p9c8_3_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p9c8_4",
    &setup_memread_memwrite_p9c8_2_common,
    { { &setup_memread_memwrite_pda_0_proc1 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p98_0",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_p98_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p98_1",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_p98_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p98_2",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_p98_2_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p98_3",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_p98_3_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p98_4",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pd0_0_proc1 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p90_0",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pd0_0_proc1 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p90_1",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pda_0_proc1 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p8e_0",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pd0_0_proc1 }, { &setup_memread_memwrite_pfe_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p8e_1",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pda_0_proc1 }, { &setup_memread_memwrite_pfe_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p8d_0",
    &setup_memread_memwrite_p8d_0_common,
    { { &setup_memread_memwrite_pd0_0_proc1 }, { &setup_memread_memwrite_pad_2_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p8d_1",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pd0_0_proc1 }, { &setup_memread_memwrite_pae_1_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p8d_2",
    &setup_memread_memwrite_p8d_2_common,
    { { &setup_memread_memwrite_p8d_2_proc0 }, { &setup_memread_memwrite_p8d_2_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pbd_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p8d_3",
    &setup_memread_memwrite_pbc_3_common,
    { { &setup_memread_memwrite_pac_2_proc0 }, { &setup_memread_memwrite_pac_1_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p8c8_0",
    &setup_memread_memwrite_p9c8_0_common,
    { { &setup_memread_memwrite_p8c8_0_proc0 }, { &setup_memread_memwrite_pda_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_p8c8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p8c8_1",
    &setup_memread_memwrite_p8c8_1_common,
    { { &setup_memread_memwrite_p8c8_1_proc0 }, { &setup_memread_memwrite_p8d_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_p8c8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p8c8_2",
    &setup_memread_memwrite_p9c8_2_common,
    { { &setup_memread_memwrite_pd0_0_proc1 }, { &setup_memread_memwrite_pda_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p8c8_3",
    &setup_memread_memwrite_p9c8_2_common,
    { { &setup_memread_memwrite_pda_0_proc1 }, { &setup_memread_memwrite_pda_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p88_0",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pd0_0_proc1 }, { &setup_memread_memwrite_pd0_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p88_1",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pda_0_proc1 }, { &setup_memread_memwrite_pd0_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p88_2",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pd0_0_proc1 }, { &setup_memread_memwrite_pf0_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p88_3",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pda_0_proc1 }, { &setup_memread_memwrite_pf0_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p80_0",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pd0_0_proc1 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p80_1",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pda_0_proc1 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_pfe_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p78_0",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_p78_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p74_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_p74_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pfa_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p70_0",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_p70_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p6_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_p6_0_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p6_1",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_p6_1_proc0 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p4_0",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_0_proc1 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p4_1",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_0_proc1 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p38_0",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_0_proc1 }, { &setup_memread_memwrite_pfe_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p34_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pfe_0_proc1 }, { &setup_memread_memwrite_pda_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pda_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p30_0",
    &setup_memread_memwrite_pf8_0_common,
    { { &setup_memread_memwrite_pfe_0_proc1 }, { &setup_memread_memwrite_pda_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pfe_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p2_0",
    &setup_memread_memwrite_pfa_0_common,
    { { &setup_memread_memwrite_pfe_0_proc1 }, { &setup_memread_memwrite_pd0_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfa_0_final,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p2_1",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_0_proc1 }, { &setup_memread_memwrite_pf0_2_proc0 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_memwrite_p0_0",
    &setup_memread_memwrite_pfe_0_common,
    { { &setup_memread_memwrite_pfe_0_proc1 }, { &setup_memread_memwrite_pfe_0_proc1 } },
    &setup_memread_memwrite_pfe_0_procfinal,
    &setup_memread_memwrite_pfe_0_procfinal,
    { { &test_memread_memwrite_p78_0_0, 0, "memread" },
      { &test_memread_memwrite_pf0_2_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memread_mmap_pfc_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_2",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_4",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_5",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_5_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_6",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_6_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_7",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_7_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_8",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_8_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_9",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_10",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pfc_11",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf6_0",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_0_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf6_1",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_1_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf6_2",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_2_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf6_3",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_3_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf5_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf5_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf5_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf5_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf5_4",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf5_5",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_5_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf5_6",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_6_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf5_7",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_7_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf5_8",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_8_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf5_9",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf44_0",
    &setup_memread_mmap_pf44_0_common,
    { { &setup_memread_mmap_pf44_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf44_1",
    &setup_memread_mmap_pf44_0_common,
    { { &setup_memread_mmap_pf44_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf44_2",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_pf5_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf44_3",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_pf5_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf0_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pf0_1",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pec_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pec_1",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pec_2",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pec_3",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pe6_0",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_0_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pe6_1",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_1_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pe6_2",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_2_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pe6_3",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_3_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pe5_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pe5_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pe5_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pe5_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pf5_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pe0_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pe0_1",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pd8_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pd8_1",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pd6_0",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_0_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pd6_1",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_1_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pd6_2",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_0_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pd6_3",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_1_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pd4_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pd4_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pd0_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pd0_1",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pcc_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pcc_1",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pcc_2",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pcc_3",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pc6_0",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_0_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pc6_1",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_1_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pc6_2",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_0_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pc6_3",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_1_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pc5_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pc5_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pc5_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pc5_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pc0_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pc0_1",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbc_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbc_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbc_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbc_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbc_4",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbc_5",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_5_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbc_6",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_6_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbc_7",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_7_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbc_8",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_8_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbc_9",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbb_0",
    &setup_memread_mmap_pbb_0_common,
    { { &setup_memread_mmap_pbb_0_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbb_1",
    &setup_memread_mmap_pbb_1_common,
    { { &setup_memread_mmap_pbb_1_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbb_2",
    &setup_memread_mmap_pbb_1_common,
    { { &setup_memread_mmap_pbb_2_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pbb_3",
    &setup_memread_mmap_pbb_0_common,
    { { &setup_memread_mmap_pbb_3_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_0",
    &setup_memread_mmap_pba8_0_common,
    { { &setup_memread_mmap_pba8_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pba8_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_1",
    &setup_memread_mmap_pba8_1_common,
    { { &setup_memread_mmap_pba8_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pba8_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_4",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_5",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_5_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_6",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_6_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_7",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_7_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_8",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_8_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_9",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_10",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_10_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_11",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_11_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_11_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_12",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_12_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_11_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_13",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_13_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_11_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_14",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_14_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_11_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_15",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_15_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_11_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_16",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_16_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_11_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_17",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_17_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_11_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_18",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_18_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_18_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_19",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_19_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_11_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_20",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_20_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_20_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_21",
    &setup_memread_mmap_pba8_21_common,
    { { &setup_memread_mmap_pba8_21_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pba8_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_21_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_22",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_22_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_22_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_23",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_23_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_11_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_24",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_24_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_11_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_25",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_11_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_25_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_26",
    &setup_memread_mmap_pba8_0_common,
    { { &setup_memread_mmap_pba8_26_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pba8_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_26_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_27",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_27_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_28",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_28_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_20_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_29",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_29_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_29_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pba8_30",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_30_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_22_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb8_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb8_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb6_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb6_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb6_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb6_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb3_0",
    &setup_memread_mmap_pbb_0_common,
    { { &setup_memread_mmap_pbb_0_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb3_1",
    &setup_memread_mmap_pbb_1_common,
    { { &setup_memread_mmap_pbb_1_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb3_2",
    &setup_memread_mmap_pbb_1_common,
    { { &setup_memread_mmap_pbb_2_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb3_3",
    &setup_memread_mmap_pbb_0_common,
    { { &setup_memread_mmap_pbb_3_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_4",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_5",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_5_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_5_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_6",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_7",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_7_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_7_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_8",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_8_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_8_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_9",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_7_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_10",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_7_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_11",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_11_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_8_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_12",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb28_8_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_12_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_13",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_29_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb28_14",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pba8_30_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pb28_14_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb0_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pb0_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pac_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pac_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pab_0",
    &setup_memread_mmap_pbb_0_common,
    { { &setup_memread_mmap_pab_0_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pab_1",
    &setup_memread_mmap_pbb_1_common,
    { { &setup_memread_mmap_pab_1_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pab_2",
    &setup_memread_mmap_pbb_1_common,
    { { &setup_memread_mmap_pab_2_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pab_3",
    &setup_memread_mmap_pbb_0_common,
    { { &setup_memread_mmap_pab_3_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_paa_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_0_proc0 }, { &setup_memread_mmap_paa_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_paa_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_paa_1_proc0 }, { &setup_memread_mmap_paa_1_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_paa_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_3_proc0 }, { &setup_memread_mmap_paa_2_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_paa_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_3_proc0 }, { &setup_memread_mmap_paa_3_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa8_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa8_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa6_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa6_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa6_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa6_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa3_0",
    &setup_memread_mmap_pbb_0_common,
    { { &setup_memread_mmap_pab_0_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa3_1",
    &setup_memread_mmap_pbb_1_common,
    { { &setup_memread_mmap_pab_1_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa3_2",
    &setup_memread_mmap_pbb_1_common,
    { { &setup_memread_mmap_pab_2_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa3_3",
    &setup_memread_mmap_pbb_0_common,
    { { &setup_memread_mmap_pab_3_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_0_proc0 }, { &setup_memread_mmap_paa_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pa28_1_proc0 }, { &setup_memread_mmap_pa28_1_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pa28_1_proc0 }, { &setup_memread_mmap_pa28_1_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pa28_3_proc0 }, { &setup_memread_mmap_pa28_3_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pa28_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_4",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pa28_4_proc0 }, { &setup_memread_mmap_pa28_4_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pa28_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_5",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pa28_5_proc0 }, { &setup_memread_mmap_pa28_5_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pa28_5_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_6",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pa28_6_proc0 }, { &setup_memread_mmap_pa28_1_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_7",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pa28_6_proc0 }, { &setup_memread_mmap_pa28_1_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_8",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_3_proc0 }, { &setup_memread_mmap_paa_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pa28_8_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_9",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pa28_5_proc0 }, { &setup_memread_mmap_paa_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pa28_9_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_10",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_1_proc0 }, { &setup_memread_mmap_paa_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pa28_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_11",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pa28_11_proc0 }, { &setup_memread_mmap_paa_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pa28_11_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_12",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pbc_3_proc0 }, { &setup_memread_mmap_pa28_12_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pa28_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa28_13",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pa28_5_proc0 }, { &setup_memread_mmap_paa_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pa28_11_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa0_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_pa0_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pb8_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pbc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9f0_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9f0_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9c_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9c_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9c_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9c_2",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9c_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9c_3",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9c_4",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9c_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9c_5",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9c_5_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9c_6",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9c_6_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9c_7",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9c_7_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9c_8",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9c_8_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9c_9",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9c_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9b_0",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p9b_0_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9b_1",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p9b_1_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9b_2",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p9b_2_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9b_3",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p9b_3_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_0",
    &setup_memread_mmap_p9a4_0_common,
    { { &setup_memread_mmap_p9a4_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pba8_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_1",
    &setup_memread_mmap_p9a4_0_common,
    { { &setup_memread_mmap_p9a4_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pba8_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_2",
    &setup_memread_mmap_p9a4_2_common,
    { { &setup_memread_mmap_p9a4_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pba8_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_3",
    &setup_memread_mmap_p9a4_2_common,
    { { &setup_memread_mmap_p9a4_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pba8_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pba8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_4",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_5",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_5_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_6",
    &setup_memread_mmap_p9a4_6_common,
    { { &setup_memread_mmap_p9a4_6_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_7",
    &setup_memread_mmap_pf44_0_common,
    { { &setup_memread_mmap_p9a4_7_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_7_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_8",
    &setup_memread_mmap_p9a4_8_common,
    { { &setup_memread_mmap_p9a4_8_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_9",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_10",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_10_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_11",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_11_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_12",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_12_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_13",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_13_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_14",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_14_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_15",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_15_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_16",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_16_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_17",
    &setup_memread_mmap_pf44_0_common,
    { { &setup_memread_mmap_p9a4_17_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_17_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_18",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_18_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_19",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_19_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_20",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_20_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_21",
    &setup_memread_mmap_pf44_0_common,
    { { &setup_memread_mmap_p9a4_21_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_17_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_22",
    &setup_memread_mmap_pf44_0_common,
    { { &setup_memread_mmap_p9a4_22_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_17_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_23",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_23_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_24",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_24_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_25",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_25_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_26",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_26_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_27",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_28",
    &setup_memread_mmap_pf44_0_common,
    { { &setup_memread_mmap_p9a4_28_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_28_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_29",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_11_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p9a4_30",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_12_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p9a4_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p98_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p98_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p96_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p96_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p96_2",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p96_3",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p93_0",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p9b_0_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p93_1",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p9b_1_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p93_2",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p9b_2_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p93_3",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p9b_3_proc0 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_0",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_1",
    &setup_memread_mmap_p9a4_6_common,
    { { &setup_memread_mmap_p928_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_2",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p928_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_3",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p928_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_4",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_5",
    &setup_memread_mmap_p9a4_8_common,
    { { &setup_memread_mmap_p928_5_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_6",
    &setup_memread_mmap_p9a4_8_common,
    { { &setup_memread_mmap_p928_5_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_7",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_12_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_8",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_12_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_9",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p928_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_10",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_11",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_9_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_12",
    &setup_memread_mmap_p928_12_common,
    { { &setup_memread_mmap_p928_12_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_12_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_13",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_12_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_14",
    &setup_memread_mmap_p928_12_common,
    { { &setup_memread_mmap_p928_12_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_14_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p928_15",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p9a4_12_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_9_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p90_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p90_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p8c_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p8c_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p8b_0",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p8b_0_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p8b_1",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p8b_1_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p8b_2",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p8b_0_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p8b_3",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p8b_1_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p8a_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pa28_12_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p8a_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pa28_12_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p8a_2",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p8a_3",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p88_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p88_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p86_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p86_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p86_2",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p86_3",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p83_0",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p8b_0_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p83_1",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p8b_1_proc0 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p83_2",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p8b_0_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p83_3",
    &setup_memread_mmap_p9b_0_common,
    { { &setup_memread_mmap_p8b_1_proc0 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pa28_12_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pa28_12_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_2",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pa28_12_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_3",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pa28_12_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_4",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_paa_3_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pa28_8_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_5",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_6",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p828_6_proc0 }, { &setup_memread_mmap_p828_6_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_7",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_8",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p828_8_proc0 }, { &setup_memread_mmap_p828_6_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_9",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_10",
    &setup_memread_mmap_p9a4_4_common,
    { { &setup_memread_mmap_p828_6_proc0 }, { &setup_memread_mmap_p828_6_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_p928_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p828_11",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p80_0",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_0_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p80_1",
    &setup_memread_mmap_pf44_2_common,
    { { &setup_memread_mmap_p9f0_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_pfc_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p70_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p70_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_p70_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p70_2",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_p70_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p70_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_p70_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p70_4",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_p70_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p6c_0",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_0_proc1 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p6c_1",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_2_proc1 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p68_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pd4_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p68_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_p68_1_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p68_2",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_p68_2_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p68_3",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_p68_3_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p68_4",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_p68_4_proc0 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p60_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p54_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p54_1",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p4c_0",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_0_proc1 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p4c_1",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pd6_2_proc1 }, { &setup_memread_mmap_pf6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p49_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pd4_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p49_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pd4_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p40_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p30_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pfc_10_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p2c_0",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_0_proc1 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p2c_1",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_0_proc1 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p28_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf44_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p20_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p18_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p18_1",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pec_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p0c_0",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_0_proc1 }, { &setup_memread_mmap_pd6_0_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p0c_1",
    &setup_memread_mmap_pf6_0_common,
    { { &setup_memread_mmap_pf6_0_proc1 }, { &setup_memread_mmap_pd6_2_proc1 } },
    &setup_memread_mmap_pf6_0_procfinal,
    &setup_memread_mmap_pf6_0_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p0a_0",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p0a_1",
    &setup_memread_mmap_pfc_1_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pd4_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_1_final,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pe5_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mmap_p00_0",
    &setup_memread_mmap_pfc_0_common,
    { { &setup_memread_mmap_pfc_0_proc1 }, { &setup_memread_mmap_pfc_0_proc1 } },
    &setup_memread_mmap_pfc_0_procfinal,
    &setup_memread_mmap_pfc_0_procfinal,
    { { &test_memread_mmap_p70_0_0, 0, "memread" },
      { &test_memread_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memread_mprotect_pf_0",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_0_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pf_1",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pf_1_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pf_2",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_2_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pf_3",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_3_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pf_4",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pf_4_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pf_5",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_5_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pf_6",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pf_6_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pf_7",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_7_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pe_0",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_5_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pe_1",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_7_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pd_0",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pf_5_proc0 }, { &setup_memread_mprotect_pd_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pd_1",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pf_7_proc0 }, { &setup_memread_mprotect_pd_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pd_2",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_5_proc0 }, { &setup_memread_mprotect_pf_5_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pd_3",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_7_proc0 }, { &setup_memread_mprotect_pf_5_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pd_4",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pf_5_proc0 }, { &setup_memread_mprotect_pd_4_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pd_5",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_5_proc0 }, { &setup_memread_mprotect_pf_7_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pd_6",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pf_7_proc0 }, { &setup_memread_mprotect_pd_4_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pd_7",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_7_proc0 }, { &setup_memread_mprotect_pf_7_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pc_0",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_5_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pc_1",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_7_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb8_0",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_0_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb8_1",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_1_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb8_2",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_2_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb8_3",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_3_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb8_4",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_4_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb8_5",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_5_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb8_6",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_6_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb8_7",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_7_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb8_8",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_8_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb8_9",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_9_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb0_0",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb0_0_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pb0_1",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb0_1_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pa8_0",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb0_0_proc0 }, { &setup_memread_mprotect_pb0_0_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pa8_1",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_5_proc0 }, { &setup_memread_mprotect_pf_5_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pa8_2",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_5_proc0 }, { &setup_memread_mprotect_pb0_1_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pa8_3",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_5_proc0 }, { &setup_memread_mprotect_pf_7_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pa8_4",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb0_1_proc0 }, { &setup_memread_mprotect_pb8_5_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pa8_5",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb0_1_proc0 }, { &setup_memread_mprotect_pb0_1_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pa8_6",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb0_1_proc0 }, { &setup_memread_mprotect_pf_5_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pa8_7",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_9_proc0 }, { &setup_memread_mprotect_pf_7_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pa0_0",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb0_0_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_pa0_1",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pb8_9_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pb8_0_0, 0, "memread" },
      { &test_memread_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p98_0",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_p98_0_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p98_1",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_p98_1_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p98_2",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_p98_2_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p98_3",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_p98_3_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p98_4",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_p98_4_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p98_5",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_p98_5_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p98_6",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_p98_6_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p98_7",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_p98_7_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p98_8",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_0_proc1 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p98_9",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_4_proc1 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p90_0",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_0_proc1 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p90_1",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_4_proc1 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p88_0",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_0_proc1 }, { &setup_memread_mprotect_pd_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p88_1",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_4_proc1 }, { &setup_memread_mprotect_pd_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p88_2",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_0_proc1 }, { &setup_memread_mprotect_pf_5_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p88_3",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_4_proc1 }, { &setup_memread_mprotect_pf_5_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p88_4",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_0_proc1 }, { &setup_memread_mprotect_pd_4_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p88_5",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_0_proc1 }, { &setup_memread_mprotect_pf_7_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p88_6",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_4_proc1 }, { &setup_memread_mprotect_pd_4_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p88_7",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_4_proc1 }, { &setup_memread_mprotect_pf_7_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p80_0",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_0_proc1 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p80_1",
    &setup_memread_mprotect_p98_0_common,
    { { &setup_memread_mprotect_pd_4_proc1 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_pf_0_0, 0, "memread" },
      { &test_memread_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p6_0",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_p6_0_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p6_1",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_p6_1_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p6_2",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_p6_2_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p6_3",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_p6_3_proc0 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p4_0",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_0_proc1 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p4_1",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_0_proc1 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p2_0",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pf_0_proc1 }, { &setup_memread_mprotect_pd_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p2_1",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_0_proc1 }, { &setup_memread_mprotect_pf_5_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p2_2",
    &setup_memread_mprotect_pf_1_common,
    { { &setup_memread_mprotect_pf_0_proc1 }, { &setup_memread_mprotect_pd_4_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_1_final,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p2_3",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_0_proc1 }, { &setup_memread_mprotect_pf_7_proc0 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pf_5_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_mprotect_p0_0",
    &setup_memread_mprotect_pf_0_common,
    { { &setup_memread_mprotect_pf_0_proc1 }, { &setup_memread_mprotect_pf_0_proc1 } },
    &setup_memread_mprotect_pf_0_procfinal,
    &setup_memread_mprotect_pf_0_procfinal,
    { { &test_memread_mprotect_p6_0_0, 0, "memread" },
      { &test_memread_mprotect_pc_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memread_munmap_pf_0",
    &setup_memread_munmap_pf_0_common,
    { { &setup_memread_munmap_pf_0_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_0_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pf_1",
    &setup_memread_munmap_pf_0_common,
    { { &setup_memread_munmap_pf_1_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_0_procfinal,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pf_2",
    &setup_memread_munmap_pf_0_common,
    { { &setup_memread_munmap_pf_2_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_0_procfinal,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pf_3",
    &setup_memread_munmap_pf_0_common,
    { { &setup_memread_munmap_pf_3_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_0_procfinal,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pf_4",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pf_4_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pf_5",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pf_5_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pf_6",
    &setup_memread_munmap_pf_0_common,
    { { &setup_memread_munmap_pf_6_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_0_procfinal,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pf_7",
    &setup_memread_munmap_pf_0_common,
    { { &setup_memread_munmap_pf_7_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_0_procfinal,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pf_8",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pf_8_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pf_9",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pf_9_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pc_0",
    &setup_memread_munmap_pf_0_common,
    { { &setup_memread_munmap_pf_1_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_0_procfinal,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pc_1",
    &setup_memread_munmap_pf_0_common,
    { { &setup_memread_munmap_pf_3_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_0_procfinal,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pb8_0",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pb8_0_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pb8_1",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pb8_1_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pb8_2",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pb8_2_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pb8_3",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pb8_3_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pb8_4",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pb8_4_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pb8_5",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pb8_5_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pb8_6",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pb8_6_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pb8_7",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pb8_7_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pb8_8",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pb8_8_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pb8_9",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pb8_9_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pa_0",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pa_0_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_pa_1",
    &setup_memread_munmap_pf_4_common,
    { { &setup_memread_munmap_pa_1_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pb8_0_0, 0, "memread" },
      { &test_memread_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p98_0",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_pb8_0_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p98_1",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_pa_0_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p98_2",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_p98_2_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p98_3",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_pa_1_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p98_4",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_p98_4_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p98_5",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_p98_5_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p98_6",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_p98_6_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p98_7",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_p98_7_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p98_8",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_p98_8_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p98_9",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_p98_9_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pf_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p8_0",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_pa_0_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p8_1",
    &setup_memread_munmap_p98_0_common,
    { { &setup_memread_munmap_pa_1_proc0 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_4_final,
    { { &test_memread_munmap_pf_0_0, 0, "memread" },
      { &test_memread_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p4_0",
    &setup_memread_munmap_pf_0_common,
    { { &setup_memread_munmap_pf_0_proc1 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_0_procfinal,
    { { &test_memread_munmap_p4_0_0, 0, "memread" },
      { &test_memread_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memread_munmap_p0_0",
    &setup_memread_munmap_pf_0_common,
    { { &setup_memread_munmap_pf_0_proc1 }, { &setup_memread_munmap_pf_0_proc1 } },
    &setup_memread_munmap_pf_0_procfinal,
    &setup_memread_munmap_pf_0_procfinal,
    { { &test_memread_munmap_p4_0_0, 0, "memread" },
      { &test_memread_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memread_open_pf8_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pf8_1",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pf70_0",
    &setup_memread_open_pf70_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pf70_1",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pf50_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pf50_1",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pf3_0",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pf3_1",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pf1_0",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pf1_1",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pee_0",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pee_1",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pea_0",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pea_1",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pe6_0",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pe6_1",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pe2_0",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pe2_1",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pde_0",
    &setup_memread_open_pf70_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pde_1",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pda_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pda_1",
    &setup_memread_open_pda_1_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pd6_0",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pd6_1",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pd2_0",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pd2_1",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pc_0",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pc_1",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pbc_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pbc_1",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pbb8_0",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_pbb8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pbb8_1",
    &setup_memread_open_pbb8_1_common,
    { { &setup_memread_open_pbb8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pbb8_2",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbb8_2_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pbb8_3",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbb8_3_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pba8_0",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_pbb8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pba8_1",
    &setup_memread_open_pbb8_1_common,
    { { &setup_memread_open_pbb8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pba8_2",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbb8_2_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pba8_3",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbb8_3_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pb98_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pb98_1",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pb88_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pb88_1",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pb70_0",
    &setup_memread_open_pb70_0_common,
    { { &setup_memread_open_pbb8_2_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pb70_1",
    &setup_memread_open_pb70_0_common,
    { { &setup_memread_open_pbb8_3_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pb50_0",
    &setup_memread_open_pb70_0_common,
    { { &setup_memread_open_pbb8_2_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pb50_1",
    &setup_memread_open_pb70_0_common,
    { { &setup_memread_open_pbb8_3_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pb30_0",
    &setup_memread_open_pb70_0_common,
    { { &setup_memread_open_pbb8_2_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pb30_1",
    &setup_memread_open_pb70_0_common,
    { { &setup_memread_open_pbb8_3_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pb10_0",
    &setup_memread_open_pb70_0_common,
    { { &setup_memread_open_pbb8_2_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pb10_1",
    &setup_memread_open_pb70_0_common,
    { { &setup_memread_open_pbb8_3_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_paf0_0",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_pbb8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_paf0_1",
    &setup_memread_open_pbb8_1_common,
    { { &setup_memread_open_pbb8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_paf0_2",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbb8_2_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_paf0_3",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbb8_3_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pad0_0",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_pbb8_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pad0_1",
    &setup_memread_open_pbb8_1_common,
    { { &setup_memread_open_pbb8_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pad0_2",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbb8_2_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pad0_3",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbb8_3_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pab_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pab_1",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pa9_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pa9_1",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_pa0_0",
    &setup_memread_open_pb70_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_pa0_1",
    &setup_memread_open_pb70_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pbc_0_0, 0, "memread" },
      { &test_memread_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p9c_0",
    &setup_memread_open_p9c_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p9c_1",
    &setup_memread_open_p9c_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p9b4_0",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_p9b4_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p9b4_1",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_p9b4_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p9a4_0",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_p9b4_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p9a4_1",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_p9b4_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p998_0",
    &setup_memread_open_p9c_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p998_1",
    &setup_memread_open_p9c_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p988_0",
    &setup_memread_open_p9c_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p988_1",
    &setup_memread_open_p9c_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p968_0",
    &setup_memread_open_p968_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p968_1",
    &setup_memread_open_p968_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p948_0",
    &setup_memread_open_p968_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p948_1",
    &setup_memread_open_p968_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p928_0",
    &setup_memread_open_p968_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p928_1",
    &setup_memread_open_p968_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p908_0",
    &setup_memread_open_p968_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p908_1",
    &setup_memread_open_p968_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p8e8_0",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_p9b4_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p8e8_1",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_p9b4_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p8c8_0",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_p9b4_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p8c8_1",
    &setup_memread_open_pbb8_0_common,
    { { &setup_memread_open_p9b4_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pbb8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p8b_0",
    &setup_memread_open_p9c_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p8b_1",
    &setup_memread_open_p9c_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p89_0",
    &setup_memread_open_p9c_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p89_1",
    &setup_memread_open_p9c_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p80_0",
    &setup_memread_open_p968_0_common,
    { { &setup_memread_open_pbc_0_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p80_1",
    &setup_memread_open_p968_0_common,
    { { &setup_memread_open_pbc_1_proc0 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_pf8_0_0, 0, "memread" },
      { &test_memread_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p7_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p6e_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p6a_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p66_0",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p62_0",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p5c_0",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p54_0",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p4c_0",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p44_0",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pf3_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p3c_0",
    &setup_memread_open_pf8_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p34_0",
    &setup_memread_open_pf70_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p2c_0",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_open_p24_0",
    &setup_memread_open_pf3_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_final,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-memread_open_p0_0",
    &setup_memread_open_pee_0_common,
    { { &setup_memread_open_pf8_0_proc1 }, { &setup_memread_open_pf8_0_proc1 } },
    &setup_memread_open_pf8_0_procfinal,
    &setup_memread_open_pf8_0_procfinal,
    { { &test_memread_open_p7_0_0, 0, "memread" },
      { &test_memread_open_pc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memread_pipe_pf8_0",
    &setup_memread_pipe_pf8_0_common,
    { { &setup_memread_pipe_pf8_0_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pf8_0_final,
    { { &test_memread_pipe_pf8_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_pf8_1",
    &setup_memread_pipe_pf8_0_common,
    { { &setup_memread_pipe_pf8_1_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pf8_0_procfinal,
    { { &test_memread_pipe_pf8_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_pd8_0",
    &setup_memread_pipe_pf8_0_common,
    { { &setup_memread_pipe_pf8_0_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pf8_0_procfinal,
    { { &test_memread_pipe_pf8_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_pd8_1",
    &setup_memread_pipe_pf8_0_common,
    { { &setup_memread_pipe_pf8_1_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pf8_0_procfinal,
    { { &test_memread_pipe_pf8_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_pbc_0",
    &setup_memread_pipe_pbc_0_common,
    { { &setup_memread_pipe_pbc_0_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pbc_0_final,
    { { &test_memread_pipe_pbc_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_pbc_1",
    &setup_memread_pipe_pbc_0_common,
    { { &setup_memread_pipe_pbc_1_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pbc_0_final,
    { { &test_memread_pipe_pbc_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_pac_0",
    &setup_memread_pipe_pbc_0_common,
    { { &setup_memread_pipe_pbc_0_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pbc_0_final,
    { { &test_memread_pipe_pbc_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_pac_1",
    &setup_memread_pipe_pbc_0_common,
    { { &setup_memread_pipe_pbc_1_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pbc_0_final,
    { { &test_memread_pipe_pbc_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_p9c_0",
    &setup_memread_pipe_p9c_0_common,
    { { &setup_memread_pipe_p9c_0_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pbc_0_final,
    { { &test_memread_pipe_pf8_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_p9c_1",
    &setup_memread_pipe_p9c_0_common,
    { { &setup_memread_pipe_p9c_1_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pbc_0_final,
    { { &test_memread_pipe_pf8_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_p8c_0",
    &setup_memread_pipe_p9c_0_common,
    { { &setup_memread_pipe_p9c_0_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pbc_0_final,
    { { &test_memread_pipe_pf8_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_p8c_1",
    &setup_memread_pipe_p9c_0_common,
    { { &setup_memread_pipe_p9c_1_proc0 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pbc_0_final,
    { { &test_memread_pipe_pf8_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_p70_0",
    &setup_memread_pipe_pf8_0_common,
    { { &setup_memread_pipe_pf8_0_proc1 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pf8_0_procfinal,
    { { &test_memread_pipe_p70_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memread_pipe_p30_0",
    &setup_memread_pipe_pf8_0_common,
    { { &setup_memread_pipe_pf8_0_proc1 }, { &setup_memread_pipe_pf8_0_proc1 } },
    &setup_memread_pipe_pf8_0_procfinal,
    &setup_memread_pipe_pf8_0_procfinal,
    { { &test_memread_pipe_p70_0_0, 0, "memread" },
      { &test_memread_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memread_pread_pf8_0",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pf8_0_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf8_1",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pf8_1_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf8_2",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pf8_2_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf8_3",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pf8_3_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf4_0",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pf4_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf4_1",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pf4_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf4_2",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pf4_2_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf4_3",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pf4_3_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf0_0",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pf4_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf0_1",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pf4_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf0_2",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pf4_2_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pf0_3",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pf4_3_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pe_0",
    &setup_memread_pread_pe_0_common,
    { { &setup_memread_pread_pe_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_procfinal,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pe_1",
    &setup_memread_pread_pe_0_common,
    { { &setup_memread_pread_pe_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_procfinal,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd8_0",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pd8_0_proc0 }, { &setup_memread_pread_pd8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd8_1",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pd8_1_proc0 }, { &setup_memread_pread_pd8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd8_2",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pd8_0_proc0 }, { &setup_memread_pread_pd8_2_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd8_3",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pd8_1_proc0 }, { &setup_memread_pread_pd8_2_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd4_0",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pe_0_proc0 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd4_1",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pe_1_proc0 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd4_2",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pe_0_proc0 }, { &setup_memread_pread_pd4_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd4_3",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pe_1_proc0 }, { &setup_memread_pread_pd4_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd0_0",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pe_0_proc0 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd0_1",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pe_1_proc0 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd0_2",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pe_0_proc0 }, { &setup_memread_pread_pd4_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pd0_3",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pe_1_proc0 }, { &setup_memread_pread_pd4_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pc_0",
    &setup_memread_pread_pe_0_common,
    { { &setup_memread_pread_pe_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_procfinal,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pc_1",
    &setup_memread_pread_pe_0_common,
    { { &setup_memread_pread_pe_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_procfinal,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pbc_0",
    &setup_memread_pread_pbc_0_common,
    { { &setup_memread_pread_pbc_0_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pbc_1",
    &setup_memread_pread_pbc_1_common,
    { { &setup_memread_pread_pbc_1_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pbc_2",
    &setup_memread_pread_pbc_1_common,
    { { &setup_memread_pread_pbc_2_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pbc_3",
    &setup_memread_pread_pbc_0_common,
    { { &setup_memread_pread_pbc_3_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_0",
    &setup_memread_pread_pba_0_common,
    { { &setup_memread_pread_pba_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_1",
    &setup_memread_pread_pba_1_common,
    { { &setup_memread_pread_pba_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_2",
    &setup_memread_pread_pba_1_common,
    { { &setup_memread_pread_pba_2_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_3",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pba_3_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_4",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pba_4_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_5",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pba_5_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_6",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pba_6_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_7",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pba_7_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pba_7_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_8",
    &setup_memread_pread_pba_8_common,
    { { &setup_memread_pread_pba_8_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pba_8_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_9",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pba_9_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pba_7_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_10",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pba_10_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pba_10_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pba_11",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pba_11_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pba_10_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pb8_0",
    &setup_memread_pread_pb8_0_common,
    { { &setup_memread_pread_pb8_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pb8_1",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pb8_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pb8_2",
    &setup_memread_pread_pb8_2_common,
    { { &setup_memread_pread_pb8_2_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pb8_2_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pb8_3",
    &setup_memread_pread_pb8_3_common,
    { { &setup_memread_pread_pb8_3_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pb8_4",
    &setup_memread_pread_pb8_2_common,
    { { &setup_memread_pread_pb8_4_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pb8_2_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pb8_5",
    &setup_memread_pread_pb8_3_common,
    { { &setup_memread_pread_pb8_5_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pb0_0",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pb0_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pb0_1",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pb0_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_pac_0",
    &setup_memread_pread_pbc_0_common,
    { { &setup_memread_pread_pac_0_proc0 }, { &setup_memread_pread_pd8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pac_1",
    &setup_memread_pread_pbc_1_common,
    { { &setup_memread_pread_pac_1_proc0 }, { &setup_memread_pread_pd8_2_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pac_2",
    &setup_memread_pread_pbc_1_common,
    { { &setup_memread_pread_pac_2_proc0 }, { &setup_memread_pread_pd8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pac_3",
    &setup_memread_pread_pbc_0_common,
    { { &setup_memread_pread_pac_3_proc0 }, { &setup_memread_pread_pd8_2_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_0",
    &setup_memread_pread_pba_0_common,
    { { &setup_memread_pread_paa_0_proc0 }, { &setup_memread_pread_paa_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_1",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pb0_0_proc0 }, { &setup_memread_pread_paa_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_2",
    &setup_memread_pread_pba_8_common,
    { { &setup_memread_pread_paa_2_proc0 }, { &setup_memread_pread_paa_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pba_8_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_3",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_paa_3_proc0 }, { &setup_memread_pread_paa_3_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_paa_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_4",
    &setup_memread_pread_pba_0_common,
    { { &setup_memread_pread_paa_4_proc0 }, { &setup_memread_pread_paa_4_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_5",
    &setup_memread_pread_pba_8_common,
    { { &setup_memread_pread_paa_5_proc0 }, { &setup_memread_pread_paa_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pba_8_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_6",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_paa_6_proc0 }, { &setup_memread_pread_paa_6_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_paa_6_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_7",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_paa_7_proc0 }, { &setup_memread_pread_paa_7_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_paa_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_8",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_paa_8_proc0 }, { &setup_memread_pread_paa_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pba_10_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_9",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_paa_9_proc0 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_paa_6_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_paa_10",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_paa_10_proc0 }, { &setup_memread_pread_paa_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pba_10_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pa8_0",
    &setup_memread_pread_pb8_0_common,
    { { &setup_memread_pread_paa_0_proc0 }, { &setup_memread_pread_pa8_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pa8_1",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pa8_1_proc0 }, { &setup_memread_pread_paa_3_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pa8_2",
    &setup_memread_pread_pb8_2_common,
    { { &setup_memread_pread_pa8_2_proc0 }, { &setup_memread_pread_pa8_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pb8_2_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pa8_3",
    &setup_memread_pread_pa8_3_common,
    { { &setup_memread_pread_pa8_3_proc0 }, { &setup_memread_pread_paa_4_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pb8_2_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pa8_4",
    &setup_memread_pread_pb8_2_common,
    { { &setup_memread_pread_pa8_4_proc0 }, { &setup_memread_pread_pa8_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pb8_2_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pa8_5",
    &setup_memread_pread_pb8_3_common,
    { { &setup_memread_pread_pa8_5_proc0 }, { &setup_memread_pread_pa8_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pa8_6",
    &setup_memread_pread_pb8_3_common,
    { { &setup_memread_pread_pa8_5_proc0 }, { &setup_memread_pread_pa8_6_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pa0_0",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pb0_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_pa0_1",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pb0_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pbc_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9c_0",
    &setup_memread_pread_p9c_0_common,
    { { &setup_memread_pread_p9c_0_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9c_1",
    &setup_memread_pread_p9c_0_common,
    { { &setup_memread_pread_p9c_1_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9c_2",
    &setup_memread_pread_p9c_0_common,
    { { &setup_memread_pread_p9c_2_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9c_3",
    &setup_memread_pread_p9c_0_common,
    { { &setup_memread_pread_p9c_3_proc0 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9a_0",
    &setup_memread_pread_pba_1_common,
    { { &setup_memread_pread_p9a_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9a_1",
    &setup_memread_pread_pba_1_common,
    { { &setup_memread_pread_p9a_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9a_2",
    &setup_memread_pread_p9a_2_common,
    { { &setup_memread_pread_p9a_2_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p9a_2_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9a_3",
    &setup_memread_pread_p9a_2_common,
    { { &setup_memread_pread_p9a_3_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p9a_2_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9a_4",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p9a_4_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p9a_4_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9a_5",
    &setup_memread_pread_p9a_5_common,
    { { &setup_memread_pread_p9a_5_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p9a_5_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9a_6",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p9a_6_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p9a_4_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p9a_7",
    &setup_memread_pread_p9a_5_common,
    { { &setup_memread_pread_p9a_7_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p9a_5_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p98_0",
    &setup_memread_pread_p98_0_common,
    { { &setup_memread_pread_p98_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p98_1",
    &setup_memread_pread_p98_0_common,
    { { &setup_memread_pread_p98_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p98_2",
    &setup_memread_pread_p9a_2_common,
    { { &setup_memread_pread_p98_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pb8_2_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p98_3",
    &setup_memread_pread_p9a_2_common,
    { { &setup_memread_pread_p98_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pb8_2_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p98_4",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p98_4_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p98_5",
    &setup_memread_pread_pb8_3_common,
    { { &setup_memread_pread_p98_5_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p98_6",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p98_6_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p98_7",
    &setup_memread_pread_pb8_3_common,
    { { &setup_memread_pread_p98_7_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p90_0",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p90_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p90_1",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p90_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8c_0",
    &setup_memread_pread_p9c_0_common,
    { { &setup_memread_pread_p8c_0_proc0 }, { &setup_memread_pread_pd8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8c_1",
    &setup_memread_pread_p9c_0_common,
    { { &setup_memread_pread_p8c_1_proc0 }, { &setup_memread_pread_pd8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8c_2",
    &setup_memread_pread_p9c_0_common,
    { { &setup_memread_pread_p8c_0_proc0 }, { &setup_memread_pread_pd8_2_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8c_3",
    &setup_memread_pread_p9c_0_common,
    { { &setup_memread_pread_p8c_1_proc0 }, { &setup_memread_pread_pd8_2_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8a_0",
    &setup_memread_pread_pba_1_common,
    { { &setup_memread_pread_p8a_0_proc0 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8a_1",
    &setup_memread_pread_pba_1_common,
    { { &setup_memread_pread_p8a_1_proc0 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8a_2",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p90_0_proc0 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p9a_4_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8a_3",
    &setup_memread_pread_p8a_3_common,
    { { &setup_memread_pread_p8a_3_proc0 }, { &setup_memread_pread_pd4_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8a_4",
    &setup_memread_pread_p8a_3_common,
    { { &setup_memread_pread_paa_4_proc0 }, { &setup_memread_pread_pd4_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8a_5",
    &setup_memread_pread_p9a_5_common,
    { { &setup_memread_pread_pa8_3_proc0 }, { &setup_memread_pread_p8a_5_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p9a_5_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8a_6",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p90_1_proc0 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p9a_4_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p8a_7",
    &setup_memread_pread_p9a_5_common,
    { { &setup_memread_pread_pa8_5_proc0 }, { &setup_memread_pread_p8a_5_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p9a_5_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p88_0",
    &setup_memread_pread_p98_0_common,
    { { &setup_memread_pread_p8a_0_proc0 }, { &setup_memread_pread_pa8_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p88_1",
    &setup_memread_pread_p98_0_common,
    { { &setup_memread_pread_p8a_1_proc0 }, { &setup_memread_pread_pa8_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p88_2",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p90_0_proc0 }, { &setup_memread_pread_pa8_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p88_3",
    &setup_memread_pread_p88_3_common,
    { { &setup_memread_pread_p8a_0_proc0 }, { &setup_memread_pread_p88_3_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p88_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p88_4",
    &setup_memread_pread_p88_3_common,
    { { &setup_memread_pread_p8a_1_proc0 }, { &setup_memread_pread_p88_3_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pba_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_p88_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p88_5",
    &setup_memread_pread_pa8_3_common,
    { { &setup_memread_pread_p88_5_proc0 }, { &setup_memread_pread_pa8_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pb8_2_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p88_6",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p90_1_proc0 }, { &setup_memread_pread_pa8_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p88_7",
    &setup_memread_pread_pb8_3_common,
    { { &setup_memread_pread_p88_7_proc0 }, { &setup_memread_pread_pa8_6_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pb8_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p80_0",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p90_0_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p80_1",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_p90_1_proc0 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_pf8_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p7_0",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pd8_0_proc1 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p7_1",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pd8_2_proc1 }, { &setup_memread_pread_pf8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p68_0",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pd4_0_proc1 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p68_1",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pd4_2_proc1 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p60_0",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pd4_0_proc1 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p60_1",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pd4_2_proc1 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p4_0",
    &setup_memread_pread_pe_0_common,
    { { &setup_memread_pread_pf4_0_proc1 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_procfinal,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memread_pread_p3_0",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pf8_0_proc1 }, { &setup_memread_pread_pd8_0_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p3_1",
    &setup_memread_pread_pf8_0_common,
    { { &setup_memread_pread_pf8_0_proc1 }, { &setup_memread_pread_pd8_2_proc1 } },
    &setup_memread_pread_pf8_0_procfinal,
    &setup_memread_pread_pf8_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p28_0",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pf4_0_proc1 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p28_1",
    &setup_memread_pread_pf4_0_common,
    { { &setup_memread_pread_pf4_0_proc1 }, { &setup_memread_pread_pd4_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p20_0",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pf4_0_proc1 }, { &setup_memread_pread_pd4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p20_1",
    &setup_memread_pread_pf0_0_common,
    { { &setup_memread_pread_pf4_0_proc1 }, { &setup_memread_pread_pd4_2_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_final,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pread_p0_0",
    &setup_memread_pread_pe_0_common,
    { { &setup_memread_pread_pf4_0_proc1 }, { &setup_memread_pread_pf4_0_proc1 } },
    &setup_memread_pread_pf4_0_procfinal,
    &setup_memread_pread_pf4_0_procfinal,
    { { &test_memread_pread_p7_0_0, 0, "memread" },
      { &test_memread_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memread_pwrite_pf8_0",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pf8_0_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf8_1",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pf8_1_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf8_2",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pf8_2_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf8_3",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pf8_3_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf4_0",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pf4_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf4_1",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pf4_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf4_2",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pf4_2_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf4_3",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pf4_3_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf0_0",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pf0_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf0_1",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pf4_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf0_2",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pf0_2_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pf0_3",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pf4_3_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pe_0",
    &setup_memread_pwrite_pe_0_common,
    { { &setup_memread_pwrite_pe_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_procfinal,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pe_1",
    &setup_memread_pwrite_pe_0_common,
    { { &setup_memread_pwrite_pe_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_procfinal,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd8_0",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pd8_0_proc0 }, { &setup_memread_pwrite_pd8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd8_1",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pd8_1_proc0 }, { &setup_memread_pwrite_pd8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd8_2",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pd8_0_proc0 }, { &setup_memread_pwrite_pd8_2_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd8_3",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pd8_1_proc0 }, { &setup_memread_pwrite_pd8_2_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd4_0",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pe_0_proc0 }, { &setup_memread_pwrite_pd4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd4_1",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pe_0_proc0 }, { &setup_memread_pwrite_pd4_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd4_2",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pe_1_proc0 }, { &setup_memread_pwrite_pd4_2_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd4_3",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pe_1_proc0 }, { &setup_memread_pwrite_pd4_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd0_0",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pe_0_proc0 }, { &setup_memread_pwrite_pd0_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd0_1",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pe_0_proc0 }, { &setup_memread_pwrite_pd4_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd0_2",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pe_1_proc0 }, { &setup_memread_pwrite_pd4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pd0_3",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pe_1_proc0 }, { &setup_memread_pwrite_pd4_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pc_0",
    &setup_memread_pwrite_pe_0_common,
    { { &setup_memread_pwrite_pe_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_procfinal,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pc_1",
    &setup_memread_pwrite_pe_0_common,
    { { &setup_memread_pwrite_pe_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_procfinal,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbc_0",
    &setup_memread_pwrite_pbc_0_common,
    { { &setup_memread_pwrite_pbc_0_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbc_1",
    &setup_memread_pwrite_pbc_1_common,
    { { &setup_memread_pwrite_pbc_1_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbc_2",
    &setup_memread_pwrite_pbc_1_common,
    { { &setup_memread_pwrite_pbc_2_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbc_3",
    &setup_memread_pwrite_pbc_0_common,
    { { &setup_memread_pwrite_pbc_3_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbb0_0",
    &setup_memread_pwrite_pbb0_0_common,
    { { &setup_memread_pwrite_pbb0_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbb0_1",
    &setup_memread_pwrite_pbb0_1_common,
    { { &setup_memread_pwrite_pbb0_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pbb0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbb0_2",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pbb0_2_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbb0_3",
    &setup_memread_pwrite_pbb0_3_common,
    { { &setup_memread_pwrite_pbb0_3_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pbb0_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbb0_4",
    &setup_memread_pwrite_pbb0_3_common,
    { { &setup_memread_pwrite_pbb0_4_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pbb0_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbb0_5",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pbb0_5_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbb0_6",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pbb0_6_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbb0_7",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pbb0_7_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pbb0_8",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pbb0_8_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pb8_0",
    &setup_memread_pwrite_pb8_0_common,
    { { &setup_memread_pwrite_pb8_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pb8_1",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pb8_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pb8_2",
    &setup_memread_pwrite_pbb0_3_common,
    { { &setup_memread_pwrite_pb8_2_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pb8_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pb8_3",
    &setup_memread_pwrite_pbb0_3_common,
    { { &setup_memread_pwrite_pb8_3_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pb8_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pb8_4",
    &setup_memread_pwrite_pb8_4_common,
    { { &setup_memread_pwrite_pb8_4_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pb8_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pb8_5",
    &setup_memread_pwrite_pb8_5_common,
    { { &setup_memread_pwrite_pb8_5_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pb8_5_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pb0_0",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pb0_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pb0_1",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pb0_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pac_0",
    &setup_memread_pwrite_pbc_0_common,
    { { &setup_memread_pwrite_pac_0_proc0 }, { &setup_memread_pwrite_pd8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pac_1",
    &setup_memread_pwrite_pbc_1_common,
    { { &setup_memread_pwrite_pac_1_proc0 }, { &setup_memread_pwrite_pd8_2_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pac_2",
    &setup_memread_pwrite_pbc_1_common,
    { { &setup_memread_pwrite_pac_2_proc0 }, { &setup_memread_pwrite_pd8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pac_3",
    &setup_memread_pwrite_pbc_0_common,
    { { &setup_memread_pwrite_pac_3_proc0 }, { &setup_memread_pwrite_pd8_2_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pab0_0",
    &setup_memread_pwrite_pbb0_0_common,
    { { &setup_memread_pwrite_pab0_0_proc0 }, { &setup_memread_pwrite_pd4_2_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pab0_1",
    &setup_memread_pwrite_pbb0_1_common,
    { { &setup_memread_pwrite_pab0_1_proc0 }, { &setup_memread_pwrite_pab0_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pbb0_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pab0_2",
    &setup_memread_pwrite_pbb0_0_common,
    { { &setup_memread_pwrite_pab0_0_proc0 }, { &setup_memread_pwrite_pd4_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pab0_3",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pab0_3_proc0 }, { &setup_memread_pwrite_pab0_3_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pab0_4",
    &setup_memread_pwrite_pbb0_3_common,
    { { &setup_memread_pwrite_pab0_4_proc0 }, { &setup_memread_pwrite_pab0_4_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pbb0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pab0_5",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pab0_3_proc0 }, { &setup_memread_pwrite_pab0_5_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pab0_6",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pab0_6_proc0 }, { &setup_memread_pwrite_pab0_6_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pab0_7",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pab0_6_proc0 }, { &setup_memread_pwrite_pd4_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pa8_0",
    &setup_memread_pwrite_pb8_0_common,
    { { &setup_memread_pwrite_pa8_0_proc0 }, { &setup_memread_pwrite_pd4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pa8_1",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pa8_1_proc0 }, { &setup_memread_pwrite_pd4_2_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pa8_2",
    &setup_memread_pwrite_pbb0_3_common,
    { { &setup_memread_pwrite_pa8_2_proc0 }, { &setup_memread_pwrite_pa8_2_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pb8_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pa8_3",
    &setup_memread_pwrite_pbb0_3_common,
    { { &setup_memread_pwrite_pa8_3_proc0 }, { &setup_memread_pwrite_pa8_2_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pb8_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pa8_4",
    &setup_memread_pwrite_pb8_4_common,
    { { &setup_memread_pwrite_pa8_4_proc0 }, { &setup_memread_pwrite_pa8_4_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pb8_4_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pa8_5",
    &setup_memread_pwrite_pb8_5_common,
    { { &setup_memread_pwrite_pa8_5_proc0 }, { &setup_memread_pwrite_pab0_6_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pb8_5_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pa0_0",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pb0_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_pa0_1",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pb0_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pbc_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9c_0",
    &setup_memread_pwrite_p9c_0_common,
    { { &setup_memread_pwrite_p9c_0_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9c_1",
    &setup_memread_pwrite_p9c_0_common,
    { { &setup_memread_pwrite_p9c_1_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9c_2",
    &setup_memread_pwrite_p9c_0_common,
    { { &setup_memread_pwrite_p9c_2_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9c_3",
    &setup_memread_pwrite_p9c_0_common,
    { { &setup_memread_pwrite_p9c_3_proc0 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9a_0",
    &setup_memread_pwrite_p9a_0_common,
    { { &setup_memread_pwrite_p9a_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9a_1",
    &setup_memread_pwrite_p9a_0_common,
    { { &setup_memread_pwrite_p9a_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9a_2",
    &setup_memread_pwrite_p9a_2_common,
    { { &setup_memread_pwrite_p9a_2_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9a_3",
    &setup_memread_pwrite_p9a_3_common,
    { { &setup_memread_pwrite_p9a_3_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9a_4",
    &setup_memread_pwrite_p9a_4_common,
    { { &setup_memread_pwrite_p9a_4_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9a_5",
    &setup_memread_pwrite_p9a_4_common,
    { { &setup_memread_pwrite_p9a_5_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9a_6",
    &setup_memread_pwrite_p9a_4_common,
    { { &setup_memread_pwrite_p9a_6_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9a_7",
    &setup_memread_pwrite_p9a_4_common,
    { { &setup_memread_pwrite_p9a_7_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9a_8",
    &setup_memread_pwrite_p9a_4_common,
    { { &setup_memread_pwrite_p9a_8_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p9a_9",
    &setup_memread_pwrite_p9a_4_common,
    { { &setup_memread_pwrite_p9a_9_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_0",
    &setup_memread_pwrite_p990_0_common,
    { { &setup_memread_pwrite_p990_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_1",
    &setup_memread_pwrite_p990_1_common,
    { { &setup_memread_pwrite_p990_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_2",
    &setup_memread_pwrite_p990_1_common,
    { { &setup_memread_pwrite_p990_2_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_3",
    &setup_memread_pwrite_p990_3_common,
    { { &setup_memread_pwrite_p990_3_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_4",
    &setup_memread_pwrite_p990_3_common,
    { { &setup_memread_pwrite_p990_4_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_5",
    &setup_memread_pwrite_p990_0_common,
    { { &setup_memread_pwrite_p990_5_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_5_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_6",
    &setup_memread_pwrite_p990_6_common,
    { { &setup_memread_pwrite_p990_6_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_5_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_7",
    &setup_memread_pwrite_p990_7_common,
    { { &setup_memread_pwrite_p990_5_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_8",
    &setup_memread_pwrite_p990_8_common,
    { { &setup_memread_pwrite_p990_8_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_9",
    &setup_memread_pwrite_p990_0_common,
    { { &setup_memread_pwrite_p990_9_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_5_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_10",
    &setup_memread_pwrite_p990_6_common,
    { { &setup_memread_pwrite_p990_10_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_5_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p990_11",
    &setup_memread_pwrite_p990_7_common,
    { { &setup_memread_pwrite_p990_9_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p90_0",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_p90_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p90_1",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_p90_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8c_0",
    &setup_memread_pwrite_p9c_0_common,
    { { &setup_memread_pwrite_p8c_0_proc0 }, { &setup_memread_pwrite_pd8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8c_1",
    &setup_memread_pwrite_p9c_0_common,
    { { &setup_memread_pwrite_p8c_1_proc0 }, { &setup_memread_pwrite_pd8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8c_2",
    &setup_memread_pwrite_p9c_0_common,
    { { &setup_memread_pwrite_p8c_0_proc0 }, { &setup_memread_pwrite_pd8_2_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8c_3",
    &setup_memread_pwrite_p9c_0_common,
    { { &setup_memread_pwrite_p8c_1_proc0 }, { &setup_memread_pwrite_pd8_2_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8a_0",
    &setup_memread_pwrite_p8a_0_common,
    { { &setup_memread_pwrite_p8a_0_proc0 }, { &setup_memread_pwrite_p8a_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p8a_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8a_1",
    &setup_memread_pwrite_p8a_1_common,
    { { &setup_memread_pwrite_p8a_1_proc0 }, { &setup_memread_pwrite_p8a_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_5_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8a_2",
    &setup_memread_pwrite_p8a_2_common,
    { { &setup_memread_pwrite_p8a_2_proc0 }, { &setup_memread_pwrite_pab0_5_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_5_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8a_3",
    &setup_memread_pwrite_p8a_2_common,
    { { &setup_memread_pwrite_p8a_3_proc0 }, { &setup_memread_pwrite_p8a_3_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_5_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8a_4",
    &setup_memread_pwrite_p990_0_common,
    { { &setup_memread_pwrite_pab0_3_proc0 }, { &setup_memread_pwrite_pab0_5_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8a_5",
    &setup_memread_pwrite_p9a_3_common,
    { { &setup_memread_pwrite_p8a_5_proc0 }, { &setup_memread_pwrite_p8a_5_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pbb0_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p9a_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8a_6",
    &setup_memread_pwrite_p8a_0_common,
    { { &setup_memread_pwrite_p8a_6_proc0 }, { &setup_memread_pwrite_p8a_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p8a_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p8a_7",
    &setup_memread_pwrite_p8a_0_common,
    { { &setup_memread_pwrite_p8a_6_proc0 }, { &setup_memread_pwrite_p8a_7_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p8a_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p890_0",
    &setup_memread_pwrite_p990_0_common,
    { { &setup_memread_pwrite_pab0_3_proc0 }, { &setup_memread_pwrite_pab0_6_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p890_1",
    &setup_memread_pwrite_p990_6_common,
    { { &setup_memread_pwrite_p890_1_proc0 }, { &setup_memread_pwrite_p8a_5_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_5_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p890_2",
    &setup_memread_pwrite_p990_6_common,
    { { &setup_memread_pwrite_p890_2_proc0 }, { &setup_memread_pwrite_p8a_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_5_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p890_3",
    &setup_memread_pwrite_p990_6_common,
    { { &setup_memread_pwrite_p890_2_proc0 }, { &setup_memread_pwrite_pab0_5_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p990_5_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p890_4",
    &setup_memread_pwrite_p890_4_common,
    { { &setup_memread_pwrite_pab0_3_proc0 }, { &setup_memread_pwrite_p890_4_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_p890_4_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p890_5",
    &setup_memread_pwrite_p990_7_common,
    { { &setup_memread_pwrite_p90_0_proc0 }, { &setup_memread_pwrite_pd4_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p890_6",
    &setup_memread_pwrite_p990_7_common,
    { { &setup_memread_pwrite_p90_1_proc0 }, { &setup_memread_pwrite_p890_6_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p890_7",
    &setup_memread_pwrite_p990_7_common,
    { { &setup_memread_pwrite_p90_1_proc0 }, { &setup_memread_pwrite_pd4_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p80_0",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_p90_0_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p80_1",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_p90_1_proc0 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_pf8_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p7_0",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pd8_0_proc1 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p7_1",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pd8_2_proc1 }, { &setup_memread_pwrite_pf8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p68_0",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pd4_2_proc1 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p68_1",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pd4_1_proc1 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p60_0",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pab0_3_proc1 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p60_1",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pd4_1_proc1 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p4_0",
    &setup_memread_pwrite_pe_0_common,
    { { &setup_memread_pwrite_pf4_0_proc1 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_procfinal,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p3_0",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pf8_0_proc1 }, { &setup_memread_pwrite_pd8_0_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p3_1",
    &setup_memread_pwrite_pf8_0_common,
    { { &setup_memread_pwrite_pf8_0_proc1 }, { &setup_memread_pwrite_pd8_2_proc1 } },
    &setup_memread_pwrite_pf8_0_procfinal,
    &setup_memread_pwrite_pf8_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p28_0",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pf4_0_proc1 }, { &setup_memread_pwrite_pd4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p28_1",
    &setup_memread_pwrite_pf4_0_common,
    { { &setup_memread_pwrite_pf4_0_proc1 }, { &setup_memread_pwrite_pd4_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p20_0",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pf4_0_proc1 }, { &setup_memread_pwrite_pd0_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p20_1",
    &setup_memread_pwrite_pf0_0_common,
    { { &setup_memread_pwrite_pf4_0_proc1 }, { &setup_memread_pwrite_pd4_1_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_final,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pf4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_pwrite_p0_0",
    &setup_memread_pwrite_pe_0_common,
    { { &setup_memread_pwrite_pf4_0_proc1 }, { &setup_memread_pwrite_pf4_0_proc1 } },
    &setup_memread_pwrite_pf4_0_procfinal,
    &setup_memread_pwrite_pf4_0_procfinal,
    { { &test_memread_pwrite_p7_0_0, 0, "memread" },
      { &test_memread_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memread_read_pfc_0",
    &setup_memread_read_pfc_0_common,
    { { &setup_memread_read_pfc_0_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pfc_1",
    &setup_memread_read_pfc_0_common,
    { { &setup_memread_read_pfc_1_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pfb_0",
    &setup_memread_read_pfb_0_common,
    { { &setup_memread_read_pfb_0_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pfb_1",
    &setup_memread_read_pfb_0_common,
    { { &setup_memread_read_pfb_1_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pfa_0",
    &setup_memread_read_pfb_0_common,
    { { &setup_memread_read_pfa_0_proc0 }, { &setup_memread_read_pfa_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pfa_1",
    &setup_memread_read_pfa_1_common,
    { { &setup_memread_read_pfa_1_proc0 }, { &setup_memread_read_pfa_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pf8_0",
    &setup_memread_read_pf8_0_common,
    { { &setup_memread_read_pfb_0_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pf8_1",
    &setup_memread_read_pf8_0_common,
    { { &setup_memread_read_pfb_1_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pf4_0",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pf4_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pf4_1",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pf4_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pf0_0",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_pf0_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pf0_1",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_pf0_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pe_0",
    &setup_memread_read_pe_0_common,
    { { &setup_memread_read_pe_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_procfinal,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pe_1",
    &setup_memread_read_pe_0_common,
    { { &setup_memread_read_pe_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_procfinal,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pdc_0",
    &setup_memread_read_pfc_0_common,
    { { &setup_memread_read_pdc_0_proc0 }, { &setup_memread_read_pdc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pdc_1",
    &setup_memread_read_pfc_0_common,
    { { &setup_memread_read_pdc_1_proc0 }, { &setup_memread_read_pdc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pdb_0",
    &setup_memread_read_pfb_0_common,
    { { &setup_memread_read_pdc_0_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pdb_1",
    &setup_memread_read_pfb_0_common,
    { { &setup_memread_read_pdc_1_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pda_0",
    &setup_memread_read_pfb_0_common,
    { { &setup_memread_read_pda_0_proc0 }, { &setup_memread_read_pda_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pda_1",
    &setup_memread_read_pfa_1_common,
    { { &setup_memread_read_pda_1_proc0 }, { &setup_memread_read_pda_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pd8_0",
    &setup_memread_read_pf8_0_common,
    { { &setup_memread_read_pdc_0_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pd8_1",
    &setup_memread_read_pf8_0_common,
    { { &setup_memread_read_pdc_1_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pd4_0",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pe_0_proc0 }, { &setup_memread_read_pd4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pd4_1",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pe_1_proc0 }, { &setup_memread_read_pd4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pd0_0",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_pe_0_proc0 }, { &setup_memread_read_pd0_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pd0_1",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_pe_1_proc0 }, { &setup_memread_read_pd0_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pc_0",
    &setup_memread_read_pe_0_common,
    { { &setup_memread_read_pe_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_procfinal,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pc_1",
    &setup_memread_read_pe_0_common,
    { { &setup_memread_read_pe_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_procfinal,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pbe_0",
    &setup_memread_read_pbe_0_common,
    { { &setup_memread_read_pbe_0_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pbe_1",
    &setup_memread_read_pbe_0_common,
    { { &setup_memread_read_pbe_1_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pbd8_0",
    &setup_memread_read_pbd8_0_common,
    { { &setup_memread_read_pbd8_0_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pbd8_1",
    &setup_memread_read_pbd8_0_common,
    { { &setup_memread_read_pbd8_1_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pbd0_0",
    &setup_memread_read_pfc_0_common,
    { { &setup_memread_read_pbd0_0_proc0 }, { &setup_memread_read_pfa_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pbd0_1",
    &setup_memread_read_pfc_0_common,
    { { &setup_memread_read_pbd0_1_proc0 }, { &setup_memread_read_pfa_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pbc_0",
    &setup_memread_read_pbc_0_common,
    { { &setup_memread_read_pbd8_0_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pbc_1",
    &setup_memread_read_pbc_0_common,
    { { &setup_memread_read_pbd8_1_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pba_0",
    &setup_memread_read_pba_0_common,
    { { &setup_memread_read_pba_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pba_1",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pba_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pba_2",
    &setup_memread_read_pba_2_common,
    { { &setup_memread_read_pba_2_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pba_3",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pba_3_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pba_4",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pba_4_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pba_5",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pba_5_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pb8_0",
    &setup_memread_read_pb8_0_common,
    { { &setup_memread_read_pb8_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pb8_1",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_pb8_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pb8_2",
    &setup_memread_read_pb8_0_common,
    { { &setup_memread_read_pb8_2_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pb8_3",
    &setup_memread_read_pb8_3_common,
    { { &setup_memread_read_pb8_3_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pb0_0",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pb0_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pb0_1",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pb0_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_pae_0",
    &setup_memread_read_pbe_0_common,
    { { &setup_memread_read_pae_0_proc0 }, { &setup_memread_read_pdc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pae_1",
    &setup_memread_read_pbe_0_common,
    { { &setup_memread_read_pae_1_proc0 }, { &setup_memread_read_pdc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pad8_0",
    &setup_memread_read_pbd8_0_common,
    { { &setup_memread_read_pae_0_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pad8_1",
    &setup_memread_read_pbd8_0_common,
    { { &setup_memread_read_pae_1_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pad0_0",
    &setup_memread_read_pfc_0_common,
    { { &setup_memread_read_pad0_0_proc0 }, { &setup_memread_read_pda_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pad0_1",
    &setup_memread_read_pfc_0_common,
    { { &setup_memread_read_pad0_1_proc0 }, { &setup_memread_read_pda_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pac_0",
    &setup_memread_read_pbc_0_common,
    { { &setup_memread_read_pae_0_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pac_1",
    &setup_memread_read_pbc_0_common,
    { { &setup_memread_read_pae_1_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_paa_0",
    &setup_memread_read_pba_0_common,
    { { &setup_memread_read_paa_0_proc0 }, { &setup_memread_read_paa_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_paa_1",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pb0_0_proc0 }, { &setup_memread_read_paa_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_paa_2",
    &setup_memread_read_pba_2_common,
    { { &setup_memread_read_paa_2_proc0 }, { &setup_memread_read_pd4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_paa_3",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_paa_3_proc0 }, { &setup_memread_read_paa_3_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_paa_4",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_paa_4_proc0 }, { &setup_memread_read_paa_4_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_paa_5",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_paa_4_proc0 }, { &setup_memread_read_paa_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pa8_0",
    &setup_memread_read_pb8_0_common,
    { { &setup_memread_read_paa_0_proc0 }, { &setup_memread_read_pa8_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pa8_1",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_pa8_1_proc0 }, { &setup_memread_read_pd0_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pa8_2",
    &setup_memread_read_pb8_0_common,
    { { &setup_memread_read_pa8_2_proc0 }, { &setup_memread_read_pa8_2_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pa8_3",
    &setup_memread_read_pb8_3_common,
    { { &setup_memread_read_pa8_3_proc0 }, { &setup_memread_read_pa8_2_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pa0_0",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pb0_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_pa0_1",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pb0_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pbe_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p9e_0",
    &setup_memread_read_p9e_0_common,
    { { &setup_memread_read_p9e_0_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9e_1",
    &setup_memread_read_p9e_0_common,
    { { &setup_memread_read_p9e_1_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9d8_0",
    &setup_memread_read_p9d8_0_common,
    { { &setup_memread_read_p9d8_0_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9d8_1",
    &setup_memread_read_p9d8_0_common,
    { { &setup_memread_read_p9d8_1_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9d0_0",
    &setup_memread_read_p9d8_0_common,
    { { &setup_memread_read_p9d0_0_proc0 }, { &setup_memread_read_pfa_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9d0_1",
    &setup_memread_read_p9d8_0_common,
    { { &setup_memread_read_p9d0_1_proc0 }, { &setup_memread_read_pfa_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9c_0",
    &setup_memread_read_p9c_0_common,
    { { &setup_memread_read_p9c_0_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9c_1",
    &setup_memread_read_p9c_0_common,
    { { &setup_memread_read_p9c_1_proc0 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9a_0",
    &setup_memread_read_p9a_0_common,
    { { &setup_memread_read_p9a_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9a_1",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_p9a_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9a_2",
    &setup_memread_read_p9a_2_common,
    { { &setup_memread_read_p9a_2_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p9a_3",
    &setup_memread_read_pb8_3_common,
    { { &setup_memread_read_p9a_3_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p98_0",
    &setup_memread_read_p98_0_common,
    { { &setup_memread_read_p98_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p98_1",
    &setup_memread_read_p98_0_common,
    { { &setup_memread_read_p98_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p98_2",
    &setup_memread_read_pb8_3_common,
    { { &setup_memread_read_p98_2_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p98_3",
    &setup_memread_read_pb8_3_common,
    { { &setup_memread_read_p98_3_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p90_0",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_p90_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p90_1",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_p90_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p8e_0",
    &setup_memread_read_p9e_0_common,
    { { &setup_memread_read_p8e_0_proc0 }, { &setup_memread_read_pdc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8e_1",
    &setup_memread_read_p9e_0_common,
    { { &setup_memread_read_p8e_1_proc0 }, { &setup_memread_read_pdc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8d8_0",
    &setup_memread_read_p9d8_0_common,
    { { &setup_memread_read_p8d8_0_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8d8_1",
    &setup_memread_read_p9d8_0_common,
    { { &setup_memread_read_p8d8_1_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8d0_0",
    &setup_memread_read_p9d8_0_common,
    { { &setup_memread_read_p8d0_0_proc0 }, { &setup_memread_read_pda_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8d0_1",
    &setup_memread_read_p9d8_0_common,
    { { &setup_memread_read_p8d0_1_proc0 }, { &setup_memread_read_pda_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8c_0",
    &setup_memread_read_p9c_0_common,
    { { &setup_memread_read_p8e_0_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8c_1",
    &setup_memread_read_p9c_0_common,
    { { &setup_memread_read_p8e_1_proc0 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8a_0",
    &setup_memread_read_p9a_0_common,
    { { &setup_memread_read_p8a_0_proc0 }, { &setup_memread_read_pd4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8a_1",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_p90_0_proc0 }, { &setup_memread_read_pd4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8a_2",
    &setup_memread_read_p9a_2_common,
    { { &setup_memread_read_p8a_2_proc0 }, { &setup_memread_read_p8a_2_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p8a_3",
    &setup_memread_read_pb8_3_common,
    { { &setup_memread_read_p8a_3_proc0 }, { &setup_memread_read_pa8_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p88_0",
    &setup_memread_read_p98_0_common,
    { { &setup_memread_read_p8a_0_proc0 }, { &setup_memread_read_pa8_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p88_1",
    &setup_memread_read_p98_0_common,
    { { &setup_memread_read_p88_1_proc0 }, { &setup_memread_read_pa8_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pba_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p88_2",
    &setup_memread_read_pb8_3_common,
    { { &setup_memread_read_p88_2_proc0 }, { &setup_memread_read_pa8_2_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p88_3",
    &setup_memread_read_pb8_3_common,
    { { &setup_memread_read_p8a_3_proc0 }, { &setup_memread_read_pa8_2_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p80_0",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_p90_0_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p80_1",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_p90_1_proc0 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_pfc_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p78_0",
    &setup_memread_read_pfc_0_common,
    { { &setup_memread_read_pdc_0_proc1 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p76_0",
    &setup_memread_read_pfb_0_common,
    { { &setup_memread_read_pdb_0_proc1 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p74_0",
    &setup_memread_read_pfa_1_common,
    { { &setup_memread_read_pda_0_proc1 }, { &setup_memread_read_pfa_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p70_0",
    &setup_memread_read_pf8_0_common,
    { { &setup_memread_read_pdb_0_proc1 }, { &setup_memread_read_pfc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p68_0",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pd4_0_proc1 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p60_0",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_pd0_0_proc1 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p4_0",
    &setup_memread_read_pe_0_common,
    { { &setup_memread_read_pf4_0_proc1 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_procfinal,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memread_read_p38_0",
    &setup_memread_read_pfc_0_common,
    { { &setup_memread_read_pfc_0_proc1 }, { &setup_memread_read_pdc_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p36_0",
    &setup_memread_read_pfb_0_common,
    { { &setup_memread_read_pfc_0_proc1 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pfb_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p34_0",
    &setup_memread_read_pfa_1_common,
    { { &setup_memread_read_pfa_0_proc1 }, { &setup_memread_read_pda_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p30_0",
    &setup_memread_read_pf8_0_common,
    { { &setup_memread_read_pfc_0_proc1 }, { &setup_memread_read_pdb_0_proc1 } },
    &setup_memread_read_pfc_0_procfinal,
    &setup_memread_read_pfc_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p28_0",
    &setup_memread_read_pf4_0_common,
    { { &setup_memread_read_pf4_0_proc1 }, { &setup_memread_read_pd4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pfa_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p20_0",
    &setup_memread_read_pf0_0_common,
    { { &setup_memread_read_pf4_0_proc1 }, { &setup_memread_read_pd0_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_final,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_read_p0_0",
    &setup_memread_read_pe_0_common,
    { { &setup_memread_read_pf4_0_proc1 }, { &setup_memread_read_pf4_0_proc1 } },
    &setup_memread_read_pf4_0_procfinal,
    &setup_memread_read_pf4_0_procfinal,
    { { &test_memread_read_p78_0_0, 0, "memread" },
      { &test_memread_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memread_rename_pf_0",
    &setup_memread_rename_pf_0_common,
    { { &setup_memread_rename_pf_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pf_1",
    &setup_memread_rename_pf_0_common,
    { { &setup_memread_rename_pf_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pe8_0",
    &setup_memread_rename_pe8_0_common,
    { { &setup_memread_rename_pf_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pe8_1",
    &setup_memread_rename_pe8_0_common,
    { { &setup_memread_rename_pf_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pe0_0",
    &setup_memread_rename_pf_0_common,
    { { &setup_memread_rename_pf_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pe0_1",
    &setup_memread_rename_pf_0_common,
    { { &setup_memread_rename_pf_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pc_0",
    &setup_memread_rename_pc_0_common,
    { { &setup_memread_rename_pf_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_procfinal,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pc_1",
    &setup_memread_rename_pc_0_common,
    { { &setup_memread_rename_pf_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_procfinal,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pb8_0",
    &setup_memread_rename_pf_0_common,
    { { &setup_memread_rename_pb8_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pb8_1",
    &setup_memread_rename_pf_0_common,
    { { &setup_memread_rename_pb8_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pb4_0",
    &setup_memread_rename_pb4_0_common,
    { { &setup_memread_rename_pb4_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pb4_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pb4_1",
    &setup_memread_rename_pb4_1_common,
    { { &setup_memread_rename_pb4_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pb4_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pb4_2",
    &setup_memread_rename_pb4_0_common,
    { { &setup_memread_rename_pb4_2_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pb4_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pb4_3",
    &setup_memread_rename_pe8_0_common,
    { { &setup_memread_rename_pb4_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pb4_4",
    &setup_memread_rename_pb4_1_common,
    { { &setup_memread_rename_pb4_4_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pb4_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pb4_5",
    &setup_memread_rename_pe8_0_common,
    { { &setup_memread_rename_pb8_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pb0_0",
    &setup_memread_rename_pf_0_common,
    { { &setup_memread_rename_pb8_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pb0_1",
    &setup_memread_rename_pf_0_common,
    { { &setup_memread_rename_pb8_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pa_0",
    &setup_memread_rename_pa_0_common,
    { { &setup_memread_rename_pb8_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_pa_1",
    &setup_memread_rename_pa_0_common,
    { { &setup_memread_rename_pb8_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pb8_0_0, 0, "memread" },
      { &test_memread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p98_0",
    &setup_memread_rename_p98_0_common,
    { { &setup_memread_rename_p98_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p98_1",
    &setup_memread_rename_p98_0_common,
    { { &setup_memread_rename_p98_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p94_0",
    &setup_memread_rename_p94_0_common,
    { { &setup_memread_rename_p94_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pb4_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p94_1",
    &setup_memread_rename_p94_1_common,
    { { &setup_memread_rename_p98_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pb4_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p94_2",
    &setup_memread_rename_p94_0_common,
    { { &setup_memread_rename_p94_2_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pb4_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p94_3",
    &setup_memread_rename_p94_3_common,
    { { &setup_memread_rename_p98_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p94_4",
    &setup_memread_rename_p94_1_common,
    { { &setup_memread_rename_p98_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pb4_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p94_5",
    &setup_memread_rename_p94_3_common,
    { { &setup_memread_rename_p98_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p90_0",
    &setup_memread_rename_p98_0_common,
    { { &setup_memread_rename_p98_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p90_1",
    &setup_memread_rename_p98_0_common,
    { { &setup_memread_rename_p98_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p8_0",
    &setup_memread_rename_p8_0_common,
    { { &setup_memread_rename_p98_0_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p8_1",
    &setup_memread_rename_p8_0_common,
    { { &setup_memread_rename_p98_1_proc0 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_pf_0_0, 0, "memread" },
      { &test_memread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p6_0",
    &setup_memread_rename_pf_0_common,
    { { &setup_memread_rename_pf_0_proc1 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_p6_0_0, 0, "memread" },
      { &test_memread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p50_0",
    &setup_memread_rename_pe8_0_common,
    { { &setup_memread_rename_pf_0_proc1 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_p6_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p4_0",
    &setup_memread_rename_pf_0_common,
    { { &setup_memread_rename_pf_0_proc1 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_final,
    { { &test_memread_rename_p6_0_0, 0, "memread" },
      { &test_memread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_rename_p0_0",
    &setup_memread_rename_pc_0_common,
    { { &setup_memread_rename_pf_0_proc1 }, { &setup_memread_rename_pf_0_proc1 } },
    &setup_memread_rename_pf_0_procfinal,
    &setup_memread_rename_pf_0_procfinal,
    { { &test_memread_rename_p6_0_0, 0, "memread" },
      { &test_memread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memread_stat_pe_0",
    &setup_memread_stat_pe_0_common,
    { { &setup_memread_stat_pe_0_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_pe_0_0, 0, "memread" },
      { &test_memread_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_pe_1",
    &setup_memread_stat_pe_0_common,
    { { &setup_memread_stat_pe_1_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_pe_0_0, 0, "memread" },
      { &test_memread_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_pc_0",
    &setup_memread_stat_pc_0_common,
    { { &setup_memread_stat_pe_0_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_procfinal,
    { { &test_memread_stat_pe_0_0, 0, "memread" },
      { &test_memread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_pc_1",
    &setup_memread_stat_pc_0_common,
    { { &setup_memread_stat_pe_1_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_procfinal,
    { { &test_memread_stat_pe_0_0, 0, "memread" },
      { &test_memread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_pb_0",
    &setup_memread_stat_pe_0_common,
    { { &setup_memread_stat_pb_0_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_pb_0_0, 0, "memread" },
      { &test_memread_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_pb_1",
    &setup_memread_stat_pe_0_common,
    { { &setup_memread_stat_pb_1_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_pb_0_0, 0, "memread" },
      { &test_memread_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_pa_0",
    &setup_memread_stat_pa_0_common,
    { { &setup_memread_stat_pb_0_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_pb_0_0, 0, "memread" },
      { &test_memread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_pa_1",
    &setup_memread_stat_pa_0_common,
    { { &setup_memread_stat_pb_1_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_pb_0_0, 0, "memread" },
      { &test_memread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_p9_0",
    &setup_memread_stat_p9_0_common,
    { { &setup_memread_stat_p9_0_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_pe_0_0, 0, "memread" },
      { &test_memread_stat_p9_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_p9_1",
    &setup_memread_stat_p9_0_common,
    { { &setup_memread_stat_p9_1_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_pe_0_0, 0, "memread" },
      { &test_memread_stat_p9_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_p8_0",
    &setup_memread_stat_p8_0_common,
    { { &setup_memread_stat_p9_0_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_pe_0_0, 0, "memread" },
      { &test_memread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_p8_1",
    &setup_memread_stat_p8_0_common,
    { { &setup_memread_stat_p9_1_proc0 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_pe_0_0, 0, "memread" },
      { &test_memread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_p4_0",
    &setup_memread_stat_pe_0_common,
    { { &setup_memread_stat_pe_0_proc1 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_final,
    { { &test_memread_stat_p4_0_0, 0, "memread" },
      { &test_memread_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_stat_p0_0",
    &setup_memread_stat_pc_0_common,
    { { &setup_memread_stat_pe_0_proc1 }, { &setup_memread_stat_pe_0_proc1 } },
    &setup_memread_stat_pe_0_procfinal,
    &setup_memread_stat_pe_0_procfinal,
    { { &test_memread_stat_p4_0_0, 0, "memread" },
      { &test_memread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memread_unlink_pe_0",
    &setup_memread_unlink_pe_0_common,
    { { &setup_memread_unlink_pe_0_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_pe_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_pe_1",
    &setup_memread_unlink_pe_0_common,
    { { &setup_memread_unlink_pe_1_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_pe_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_pc_0",
    &setup_memread_unlink_pc_0_common,
    { { &setup_memread_unlink_pe_0_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_procfinal,
    { { &test_memread_unlink_pe_0_0, 0, "memread" },
      { &test_memread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_pc_1",
    &setup_memread_unlink_pc_0_common,
    { { &setup_memread_unlink_pe_1_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_procfinal,
    { { &test_memread_unlink_pe_0_0, 0, "memread" },
      { &test_memread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_pb0_0",
    &setup_memread_unlink_pb0_0_common,
    { { &setup_memread_unlink_pb0_0_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pb0_0_final,
    { { &test_memread_unlink_pb0_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_pb0_1",
    &setup_memread_unlink_pe_0_common,
    { { &setup_memread_unlink_pb0_1_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_pb0_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_pb0_2",
    &setup_memread_unlink_pb0_0_common,
    { { &setup_memread_unlink_pb0_2_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pb0_0_final,
    { { &test_memread_unlink_pb0_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_pb0_3",
    &setup_memread_unlink_pe_0_common,
    { { &setup_memread_unlink_pb0_3_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_pb0_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_pa_0",
    &setup_memread_unlink_pa_0_common,
    { { &setup_memread_unlink_pa_0_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_pb0_0_0, 0, "memread" },
      { &test_memread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_pa_1",
    &setup_memread_unlink_pa_0_common,
    { { &setup_memread_unlink_pb0_3_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_pb0_0_0, 0, "memread" },
      { &test_memread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_p90_0",
    &setup_memread_unlink_p90_0_common,
    { { &setup_memread_unlink_pb0_0_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pb0_0_final,
    { { &test_memread_unlink_pe_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_p90_1",
    &setup_memread_unlink_p90_1_common,
    { { &setup_memread_unlink_pa_0_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_pe_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_p90_2",
    &setup_memread_unlink_p90_0_common,
    { { &setup_memread_unlink_p90_2_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pb0_0_final,
    { { &test_memread_unlink_pe_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_p90_3",
    &setup_memread_unlink_p90_1_common,
    { { &setup_memread_unlink_pb0_3_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_pe_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_p8_0",
    &setup_memread_unlink_p8_0_common,
    { { &setup_memread_unlink_pa_0_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_pe_0_0, 0, "memread" },
      { &test_memread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_p8_1",
    &setup_memread_unlink_p8_0_common,
    { { &setup_memread_unlink_pb0_3_proc0 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_pe_0_0, 0, "memread" },
      { &test_memread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_p4_0",
    &setup_memread_unlink_pe_0_common,
    { { &setup_memread_unlink_pe_0_proc1 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_final,
    { { &test_memread_unlink_p4_0_0, 0, "memread" },
      { &test_memread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_unlink_p0_0",
    &setup_memread_unlink_pc_0_common,
    { { &setup_memread_unlink_pe_0_proc1 }, { &setup_memread_unlink_pe_0_proc1 } },
    &setup_memread_unlink_pe_0_procfinal,
    &setup_memread_unlink_pe_0_procfinal,
    { { &test_memread_unlink_p4_0_0, 0, "memread" },
      { &test_memread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memread_write_pfe_0",
    &setup_memread_write_pfe_0_common,
    { { &setup_memread_write_pfe_0_proc0 }, { &setup_memread_write_pfe_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pfe_1",
    &setup_memread_write_pfe_0_common,
    { { &setup_memread_write_pfe_1_proc0 }, { &setup_memread_write_pfe_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pfc_0",
    &setup_memread_write_pfc_0_common,
    { { &setup_memread_write_pfc_0_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pfc_1",
    &setup_memread_write_pfc_0_common,
    { { &setup_memread_write_pfc_1_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pf8_0",
    &setup_memread_write_pf8_0_common,
    { { &setup_memread_write_pf8_0_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pf8_1",
    &setup_memread_write_pf8_0_common,
    { { &setup_memread_write_pf8_1_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pf4_0",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pf4_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pf4_1",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pf4_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pf0_0",
    &setup_memread_write_pf0_0_common,
    { { &setup_memread_write_pf4_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pf0_1",
    &setup_memread_write_pf0_0_common,
    { { &setup_memread_write_pf4_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pe_0",
    &setup_memread_write_pe_0_common,
    { { &setup_memread_write_pe_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_procfinal,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pe_1",
    &setup_memread_write_pe_0_common,
    { { &setup_memread_write_pe_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_procfinal,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pde_0",
    &setup_memread_write_pfe_0_common,
    { { &setup_memread_write_pde_0_proc0 }, { &setup_memread_write_pde_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pde_1",
    &setup_memread_write_pfe_0_common,
    { { &setup_memread_write_pde_1_proc0 }, { &setup_memread_write_pde_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pdc_0",
    &setup_memread_write_pfc_0_common,
    { { &setup_memread_write_pdc_0_proc0 }, { &setup_memread_write_pdc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pdc_1",
    &setup_memread_write_pfc_0_common,
    { { &setup_memread_write_pdc_1_proc0 }, { &setup_memread_write_pdc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pd8_0",
    &setup_memread_write_pf8_0_common,
    { { &setup_memread_write_pdc_0_proc0 }, { &setup_memread_write_pd8_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pd8_1",
    &setup_memread_write_pf8_0_common,
    { { &setup_memread_write_pdc_1_proc0 }, { &setup_memread_write_pd8_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pd4_0",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pe_0_proc0 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pd4_1",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pe_1_proc0 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pd0_0",
    &setup_memread_write_pf0_0_common,
    { { &setup_memread_write_pe_0_proc0 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pd0_1",
    &setup_memread_write_pf0_0_common,
    { { &setup_memread_write_pe_1_proc0 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pc_0",
    &setup_memread_write_pe_0_common,
    { { &setup_memread_write_pe_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_procfinal,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pc_1",
    &setup_memread_write_pe_0_common,
    { { &setup_memread_write_pe_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_procfinal,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pbf_0",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_pbf_0_proc0 }, { &setup_memread_write_pfe_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pbf_1",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_pbf_1_proc0 }, { &setup_memread_write_pfe_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pbe_0",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_pbe_0_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pbe_1",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_pbe_1_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pbc_0",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_pbc_0_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pbc_1",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_pbc_1_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pbb0_0",
    &setup_memread_write_pbb0_0_common,
    { { &setup_memread_write_pbb0_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pbb0_1",
    &setup_memread_write_pbb0_1_common,
    { { &setup_memread_write_pbb0_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pbb0_2",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pbb0_2_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pbb0_3",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pbb0_3_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pb8_0",
    &setup_memread_write_pb8_0_common,
    { { &setup_memread_write_pb8_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pb8_1",
    &setup_memread_write_pb8_0_common,
    { { &setup_memread_write_pbb0_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pb8_2",
    &setup_memread_write_pb8_2_common,
    { { &setup_memread_write_pb8_2_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pb8_3",
    &setup_memread_write_pb8_2_common,
    { { &setup_memread_write_pb8_3_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pb0_0",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pb0_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_pb0_1",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pb0_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_paf_0",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_paf_0_proc0 }, { &setup_memread_write_pde_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_paf_1",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_paf_1_proc0 }, { &setup_memread_write_pde_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pae_0",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_pae_0_proc0 }, { &setup_memread_write_pdc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pae_1",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_pae_1_proc0 }, { &setup_memread_write_pdc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pac_0",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_pae_0_proc0 }, { &setup_memread_write_pd8_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pac_1",
    &setup_memread_write_pbf_0_common,
    { { &setup_memread_write_pae_1_proc0 }, { &setup_memread_write_pd8_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pab0_0",
    &setup_memread_write_pbb0_0_common,
    { { &setup_memread_write_pab0_0_proc0 }, { &setup_memread_write_pab0_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pab0_1",
    &setup_memread_write_pbb0_1_common,
    { { &setup_memread_write_pab0_1_proc0 }, { &setup_memread_write_pab0_1_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pab0_2",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pab0_2_proc0 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pab0_3",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pab0_3_proc0 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pa8_0",
    &setup_memread_write_pb8_0_common,
    { { &setup_memread_write_pab0_0_proc0 }, { &setup_memread_write_pab0_1_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pa8_1",
    &setup_memread_write_pb8_0_common,
    { { &setup_memread_write_pab0_1_proc0 }, { &setup_memread_write_pab0_1_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pa8_2",
    &setup_memread_write_pb8_2_common,
    { { &setup_memread_write_pa8_2_proc0 }, { &setup_memread_write_pa8_2_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pa8_3",
    &setup_memread_write_pb8_2_common,
    { { &setup_memread_write_pa8_3_proc0 }, { &setup_memread_write_pa8_2_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pa0_0",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pb0_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_pa0_1",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pb0_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pbf_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p9f_0",
    &setup_memread_write_p9f_0_common,
    { { &setup_memread_write_pbf_0_proc0 }, { &setup_memread_write_pfe_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p9f_1",
    &setup_memread_write_p9f_0_common,
    { { &setup_memread_write_pbf_1_proc0 }, { &setup_memread_write_pfe_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p9e_0",
    &setup_memread_write_p9e_0_common,
    { { &setup_memread_write_pbe_0_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p9e_1",
    &setup_memread_write_p9e_0_common,
    { { &setup_memread_write_pbe_1_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p9c_0",
    &setup_memread_write_p9e_0_common,
    { { &setup_memread_write_pbc_0_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p9c_1",
    &setup_memread_write_p9e_0_common,
    { { &setup_memread_write_pbc_1_proc0 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p9a_0",
    &setup_memread_write_p9a_0_common,
    { { &setup_memread_write_p9a_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p9a_1",
    &setup_memread_write_p9a_1_common,
    { { &setup_memread_write_p9a_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p9a_2",
    &setup_memread_write_p9a_2_common,
    { { &setup_memread_write_p9a_2_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p9a_3",
    &setup_memread_write_p9a_0_common,
    { { &setup_memread_write_p9a_3_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p990_0",
    &setup_memread_write_p990_0_common,
    { { &setup_memread_write_p990_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p990_1",
    &setup_memread_write_p990_0_common,
    { { &setup_memread_write_pbb0_3_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p990_2",
    &setup_memread_write_p990_2_common,
    { { &setup_memread_write_p990_2_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p990_3",
    &setup_memread_write_p990_3_common,
    { { &setup_memread_write_p990_3_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p90_0",
    &setup_memread_write_pf0_0_common,
    { { &setup_memread_write_pb0_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p90_1",
    &setup_memread_write_pf0_0_common,
    { { &setup_memread_write_pb0_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p8f_0",
    &setup_memread_write_p9f_0_common,
    { { &setup_memread_write_paf_0_proc0 }, { &setup_memread_write_pde_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p8f_1",
    &setup_memread_write_p9f_0_common,
    { { &setup_memread_write_paf_1_proc0 }, { &setup_memread_write_pde_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p8e_0",
    &setup_memread_write_p9e_0_common,
    { { &setup_memread_write_pae_0_proc0 }, { &setup_memread_write_pdc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p8e_1",
    &setup_memread_write_p9e_0_common,
    { { &setup_memread_write_pae_1_proc0 }, { &setup_memread_write_pdc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p8c_0",
    &setup_memread_write_p9e_0_common,
    { { &setup_memread_write_pae_0_proc0 }, { &setup_memread_write_pd8_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p8c_1",
    &setup_memread_write_p9e_0_common,
    { { &setup_memread_write_pae_1_proc0 }, { &setup_memread_write_pd8_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p8a_0",
    &setup_memread_write_p9a_0_common,
    { { &setup_memread_write_p8a_0_proc0 }, { &setup_memread_write_p8a_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p8a_1",
    &setup_memread_write_p9a_1_common,
    { { &setup_memread_write_p8a_1_proc0 }, { &setup_memread_write_pab0_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p8a_2",
    &setup_memread_write_p9a_2_common,
    { { &setup_memread_write_p8a_2_proc0 }, { &setup_memread_write_p8a_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pbb0_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p8a_3",
    &setup_memread_write_p9a_0_common,
    { { &setup_memread_write_p8a_3_proc0 }, { &setup_memread_write_p8a_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p890_0",
    &setup_memread_write_p990_0_common,
    { { &setup_memread_write_pb0_0_proc0 }, { &setup_memread_write_pab0_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p890_1",
    &setup_memread_write_p990_0_common,
    { { &setup_memread_write_pab0_3_proc0 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_p9a_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p890_2",
    &setup_memread_write_p990_3_common,
    { { &setup_memread_write_pb0_0_proc0 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p890_3",
    &setup_memread_write_p990_3_common,
    { { &setup_memread_write_pb0_1_proc0 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p80_0",
    &setup_memread_write_pf0_0_common,
    { { &setup_memread_write_pb0_0_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p80_1",
    &setup_memread_write_pf0_0_common,
    { { &setup_memread_write_pb0_1_proc0 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_pfe_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p7c_0",
    &setup_memread_write_pfe_0_common,
    { { &setup_memread_write_pde_0_proc1 }, { &setup_memread_write_pfe_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p78_0",
    &setup_memread_write_pfc_0_common,
    { { &setup_memread_write_pdc_0_proc1 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p70_0",
    &setup_memread_write_pf8_0_common,
    { { &setup_memread_write_pd8_0_proc1 }, { &setup_memread_write_pfc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p68_0",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pd4_0_proc1 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p60_0",
    &setup_memread_write_pf0_0_common,
    { { &setup_memread_write_pd4_0_proc1 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p4_0",
    &setup_memread_write_pe_0_common,
    { { &setup_memread_write_pf4_0_proc1 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_procfinal,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-memread_write_p3c_0",
    &setup_memread_write_pfe_0_common,
    { { &setup_memread_write_pfe_0_proc1 }, { &setup_memread_write_pde_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p38_0",
    &setup_memread_write_pfc_0_common,
    { { &setup_memread_write_pfc_0_proc1 }, { &setup_memread_write_pdc_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p30_0",
    &setup_memread_write_pf8_0_common,
    { { &setup_memread_write_pfc_0_proc1 }, { &setup_memread_write_pd8_0_proc1 } },
    &setup_memread_write_pfe_0_procfinal,
    &setup_memread_write_pfe_0_final,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p28_0",
    &setup_memread_write_pf4_0_common,
    { { &setup_memread_write_pf4_0_proc1 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p20_0",
    &setup_memread_write_pf0_0_common,
    { { &setup_memread_write_pf4_0_proc1 }, { &setup_memread_write_pd4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_final,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memread_write_p0_0",
    &setup_memread_write_pe_0_common,
    { { &setup_memread_write_pf4_0_proc1 }, { &setup_memread_write_pf4_0_proc1 } },
    &setup_memread_write_pf4_0_procfinal,
    &setup_memread_write_pf4_0_procfinal,
    { { &test_memread_write_p7c_0_0, 0, "memread" },
      { &test_memread_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_memwrite_pfe_0",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pfe_1",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pfd_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pfd_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfd_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pfc_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pfc_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pf8_0",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pf8_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pf8_1",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pf8_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pf0_0",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pee_0",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_1_proc0 }, { &setup_memwrite_memwrite_pfe_1_proc0 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_ped_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pfe_1_proc0 }, { &setup_memwrite_memwrite_ped_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_ped_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pec_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pfe_1_proc0 }, { &setup_memwrite_memwrite_pec_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pe8_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pfe_1_proc0 }, { &setup_memwrite_memwrite_pe8_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pe8_1",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_1_proc0 }, { &setup_memwrite_memwrite_pe8_1_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pe0_0",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pdf_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pdf_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pde8_0",
    &setup_memwrite_memwrite_pde8_0_common,
    { { &setup_memwrite_memwrite_pde8_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pde8_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfd_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pde8_1",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pde8_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfd_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pde8_2",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pde8_2_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfd_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pde8_3",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pde0_0",
    &setup_memwrite_memwrite_pde0_0_common,
    { { &setup_memwrite_memwrite_pde0_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pde8_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pde0_1",
    &setup_memwrite_memwrite_pde0_1_common,
    { { &setup_memwrite_memwrite_pde0_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pdc_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pdc_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pdc_1",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pdc_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pd8_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pd7_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pfe_1_proc0 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pd68_0",
    &setup_memwrite_memwrite_pde8_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pd68_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pde8_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_ped_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pd68_1",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_ped_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_ped_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pd68_2",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pec_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_ped_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pd60_0",
    &setup_memwrite_memwrite_pde0_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pd60_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pde8_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pd60_1",
    &setup_memwrite_memwrite_pde0_1_common,
    { { &setup_memwrite_memwrite_pd60_1_proc0 }, { &setup_memwrite_memwrite_pd60_1_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pd4_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pe8_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pd4_1",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pe8_1_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pd0_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_ped_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pcf_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pdf_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pce8_0",
    &setup_memwrite_memwrite_pce8_0_common,
    { { &setup_memwrite_memwrite_pde8_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pde8_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfd_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pce8_1",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pce8_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfd_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pce0_0",
    &setup_memwrite_memwrite_pce0_0_common,
    { { &setup_memwrite_memwrite_pce0_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pce0_1",
    &setup_memwrite_memwrite_pce0_1_common,
    { { &setup_memwrite_memwrite_pde8_2_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pce0_2",
    &setup_memwrite_memwrite_pce0_1_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pcc_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pdc_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pcc_1",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pcc_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pc8_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pc7_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pfe_1_proc0 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pc68_0",
    &setup_memwrite_memwrite_pce8_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pd68_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pde8_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_ped_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pc68_1",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pc68_1_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_ped_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pc60_0",
    &setup_memwrite_memwrite_pce0_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pc60_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pc60_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pc60_1",
    &setup_memwrite_memwrite_pce0_1_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pec_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pc4_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pe8_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pc4_1",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pe8_1_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pc0_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pec_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pbc_0",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pbc_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pbc_1",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pbc_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pba_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pba_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfd_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pba_1",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pba_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfd_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pb8_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pb8_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pb8_1",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pb8_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pb0_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pb0_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pb0_1",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pb0_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pb0_2",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pb0_2_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pb0_3",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pe8_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pb0_4",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pb0_4_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pb0_5",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pe8_1_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pa_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pe8_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_pa_1",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pe8_1_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p9c_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pe8_0_proc1 }, { &setup_memwrite_memwrite_pfe_1_proc0 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p9c_1",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pe8_1_proc1 }, { &setup_memwrite_memwrite_pfe_1_proc0 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p9a_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_p9a_0_proc0 }, { &setup_memwrite_memwrite_ped_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_ped_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p9a_1",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pe8_1_proc1 }, { &setup_memwrite_memwrite_ped_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_ped_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p98_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pe8_0_proc1 }, { &setup_memwrite_memwrite_pec_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p98_1",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pe8_1_proc1 }, { &setup_memwrite_memwrite_pec_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p90_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pe8_0_proc1 }, { &setup_memwrite_memwrite_pe8_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p90_1",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pe8_1_proc1 }, { &setup_memwrite_memwrite_pe8_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p90_2",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pe8_0_proc1 }, { &setup_memwrite_memwrite_pe8_1_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p90_3",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pe8_1_proc1 }, { &setup_memwrite_memwrite_pe8_1_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p8_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pe8_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p8_1",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pe8_1_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p78_0",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_p78_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p74_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_p74_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfd_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p70_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_p70_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfc_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p6_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_p6_0_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p6_1",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_p6_1_proc0 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p4_0",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pf8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p4_1",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p38_0",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_0_proc1 }, { &setup_memwrite_memwrite_pfe_1_proc0 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p34_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pfe_0_proc1 }, { &setup_memwrite_memwrite_ped_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_ped_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p30_0",
    &setup_memwrite_memwrite_pfc_0_common,
    { { &setup_memwrite_memwrite_pfe_0_proc1 }, { &setup_memwrite_memwrite_pec_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pfe_0_0, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p2_0",
    &setup_memwrite_memwrite_pfd_0_common,
    { { &setup_memwrite_memwrite_pfe_0_proc1 }, { &setup_memwrite_memwrite_pe8_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfd_0_final,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p2_1",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_0_proc1 }, { &setup_memwrite_memwrite_pe8_1_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_memwrite_p0_0",
    &setup_memwrite_memwrite_pfe_0_common,
    { { &setup_memwrite_memwrite_pfe_0_proc1 }, { &setup_memwrite_memwrite_pfe_0_proc1 } },
    &setup_memwrite_memwrite_pfe_0_procfinal,
    &setup_memwrite_memwrite_pfe_0_procfinal,
    { { &test_memwrite_memwrite_pe8_0_1, 0, "memwrite" },
      { &test_memwrite_memwrite_pe8_0_1, 1, "memwrite" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_1",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfe_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_3",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_4",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_5",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfe_5_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_6",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_7",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_8",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfe_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_9",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfe_5_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfe_10",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfb_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pfb_0_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfb_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pfb_1_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfac_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfac_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfac_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfac_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfac_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfac_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfac_3",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfac_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfac_4",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfac_4_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfa8_0",
    &setup_memwrite_mmap_pfa8_0_common,
    { { &setup_memwrite_mmap_pfa8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfa8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pfa8_1",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pfac_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfa8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pf8_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pf6_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pf6_1",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pf3_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pfb_0_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pf3_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pfb_1_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pf28_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfac_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pf28_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfac_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pf0_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pec_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_peb_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_peb_0_proc0 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_peb_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_peb_0_proc0 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pea_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pe8_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pe6_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pe6_1",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pe3_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_peb_0_proc0 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pe3_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_peb_0_proc0 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pe28_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pe28_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pe0_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdf0_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdf0_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdf0_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdf0_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdf0_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdf0_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdf0_3",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdf0_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdf0_4",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdf0_4_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd8_0",
    &setup_memwrite_mmap_pdd8_0_common,
    { { &setup_memwrite_mmap_pdd8_0_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd8_1",
    &setup_memwrite_mmap_pdd8_0_common,
    { { &setup_memwrite_mmap_pdd8_1_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_0",
    &setup_memwrite_mmap_pdd6_0_common,
    { { &setup_memwrite_mmap_pdd6_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pdd6_0_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_3",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_4",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_4_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_5",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_5_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_6",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_4_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_5_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_7",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_7_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_8",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_8_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_9",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_7_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_5_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_10",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_8_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_5_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_11",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_5_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_12",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_12_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_12_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_13",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_13_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfa8_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_14",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_14_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_14_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_15",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_15_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_14_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_16",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_13_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_14_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_17",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_15_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_17_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_18",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_13_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_17_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_19",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_19_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_14_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_20",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_19_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_17_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_21",
    &setup_memwrite_mmap_pdd6_21_common,
    { { &setup_memwrite_mmap_pdd6_21_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pdd6_0_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_21_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_22",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_22_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_23",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_13_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_24",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_24_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_12_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_25",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_25_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_25_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_26",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_26_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_26_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdd6_27",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_27_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_26_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdc_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdb0_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pdb0_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd98_0",
    &setup_memwrite_mmap_pdd8_0_common,
    { { &setup_memwrite_mmap_pdd8_0_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd98_1",
    &setup_memwrite_mmap_pdd8_0_common,
    { { &setup_memwrite_mmap_pdd8_1_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd94_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd94_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd94_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd94_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd94_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd94_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd94_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd94_3",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd94_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd94_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd94_4",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd94_4_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd94_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd94_5",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdd6_13_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd94_5_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd94_6",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd94_6_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd94_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd94_7",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd94_7_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd94_7_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd8_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd6_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd58_0",
    &setup_memwrite_mmap_pdd8_0_common,
    { { &setup_memwrite_mmap_pd58_0_proc0 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd58_1",
    &setup_memwrite_mmap_pdd8_0_common,
    { { &setup_memwrite_mmap_pd58_0_proc0 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd50_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pd50_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd50_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdf0_2_proc0 }, { &setup_memwrite_mmap_pd50_1_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd4_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd30_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd30_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd18_0",
    &setup_memwrite_mmap_pdd8_0_common,
    { { &setup_memwrite_mmap_pd58_0_proc0 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd18_1",
    &setup_memwrite_mmap_pdd8_0_common,
    { { &setup_memwrite_mmap_pd58_0_proc0 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd14_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pd50_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd14_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd14_1_proc0 }, { &setup_memwrite_mmap_pd14_1_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd14_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd14_1_proc0 }, { &setup_memwrite_mmap_pd14_1_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd14_3",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdf0_2_proc0 }, { &setup_memwrite_mmap_pd50_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd14_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd14_4",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd14_4_proc0 }, { &setup_memwrite_mmap_pd50_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd14_4_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd14_5",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdf0_2_proc0 }, { &setup_memwrite_mmap_pd14_5_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd14_5_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd14_6",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pd14_4_proc0 }, { &setup_memwrite_mmap_pd50_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd14_6_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pd0_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pdc_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pdf0_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcf8_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_10_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcf0_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf0_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcf0_1",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcf0_2",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf0_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcf0_3",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf0_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcf0_4",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf0_4_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd8_0",
    &setup_memwrite_mmap_pcd8_0_common,
    { { &setup_memwrite_mmap_pcd8_0_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd8_1",
    &setup_memwrite_mmap_pcd8_0_common,
    { { &setup_memwrite_mmap_pcd8_1_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_0",
    &setup_memwrite_mmap_pcd4_0_common,
    { { &setup_memwrite_mmap_pcd4_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_1",
    &setup_memwrite_mmap_pcd4_0_common,
    { { &setup_memwrite_mmap_pcd4_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_2",
    &setup_memwrite_mmap_pcd4_2_common,
    { { &setup_memwrite_mmap_pcd4_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_3",
    &setup_memwrite_mmap_pcd4_2_common,
    { { &setup_memwrite_mmap_pcd4_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_4",
    &setup_memwrite_mmap_pcd4_4_common,
    { { &setup_memwrite_mmap_pcd4_4_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_5",
    &setup_memwrite_mmap_pcd4_5_common,
    { { &setup_memwrite_mmap_pcd4_5_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_6",
    &setup_memwrite_mmap_pcd4_6_common,
    { { &setup_memwrite_mmap_pcd4_6_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_7",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_7_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_8",
    &setup_memwrite_mmap_pcd4_5_common,
    { { &setup_memwrite_mmap_pcd4_8_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_8_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_9",
    &setup_memwrite_mmap_pcd4_9_common,
    { { &setup_memwrite_mmap_pcd4_9_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_10",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_7_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_11",
    &setup_memwrite_mmap_pcd4_9_common,
    { { &setup_memwrite_mmap_pcd4_9_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_12",
    &setup_memwrite_mmap_pcd4_12_common,
    { { &setup_memwrite_mmap_pcd4_12_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_13",
    &setup_memwrite_mmap_pcd4_12_common,
    { { &setup_memwrite_mmap_pcd4_13_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_14",
    &setup_memwrite_mmap_pcd4_12_common,
    { { &setup_memwrite_mmap_pcd4_14_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_15",
    &setup_memwrite_mmap_pcd4_9_common,
    { { &setup_memwrite_mmap_pcd4_15_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_16",
    &setup_memwrite_mmap_pcd4_12_common,
    { { &setup_memwrite_mmap_pcd4_14_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_17",
    &setup_memwrite_mmap_pcd4_9_common,
    { { &setup_memwrite_mmap_pcd4_15_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_18",
    &setup_memwrite_mmap_pcd4_18_common,
    { { &setup_memwrite_mmap_pcd4_18_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pcd4_4_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_19",
    &setup_memwrite_mmap_pcd4_19_common,
    { { &setup_memwrite_mmap_pcd4_19_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_19_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_20",
    &setup_memwrite_mmap_pcd4_20_common,
    { { &setup_memwrite_mmap_pcd4_20_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pdd6_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_20_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_21",
    &setup_memwrite_mmap_pcd4_19_common,
    { { &setup_memwrite_mmap_pcd4_21_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_19_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_22",
    &setup_memwrite_mmap_pcd4_20_common,
    { { &setup_memwrite_mmap_pcd4_22_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pdd6_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pdd6_14_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_23",
    &setup_memwrite_mmap_pcd4_23_common,
    { { &setup_memwrite_mmap_pcd4_23_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_23_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_24",
    &setup_memwrite_mmap_pcd4_19_common,
    { { &setup_memwrite_mmap_pcd4_21_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_8_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_25",
    &setup_memwrite_mmap_pcd4_23_common,
    { { &setup_memwrite_mmap_pcd4_25_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_23_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_26",
    &setup_memwrite_mmap_pcd4_19_common,
    { { &setup_memwrite_mmap_pcd4_26_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_8_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_27",
    &setup_memwrite_mmap_pcd4_27_common,
    { { &setup_memwrite_mmap_pcd4_27_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pdd6_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_23_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_28",
    &setup_memwrite_mmap_pcd4_28_common,
    { { &setup_memwrite_mmap_pcd4_28_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_29",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_29_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_30",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_30_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_31",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_31_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_32",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_32_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_33",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_30_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_34",
    &setup_memwrite_mmap_pcd4_34_common,
    { { &setup_memwrite_mmap_pcd4_34_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_35",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_32_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_36",
    &setup_memwrite_mmap_pcd4_34_common,
    { { &setup_memwrite_mmap_pcd4_36_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_37",
    &setup_memwrite_mmap_pcd4_27_common,
    { { &setup_memwrite_mmap_pcd4_37_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pdd6_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_37_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_38",
    &setup_memwrite_mmap_pcd4_6_common,
    { { &setup_memwrite_mmap_pcd4_38_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_37_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_39",
    &setup_memwrite_mmap_pcd4_27_common,
    { { &setup_memwrite_mmap_pcd4_39_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pdd6_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_37_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_40",
    &setup_memwrite_mmap_pcd4_6_common,
    { { &setup_memwrite_mmap_pcd4_40_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_37_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_41",
    &setup_memwrite_mmap_pcd4_6_common,
    { { &setup_memwrite_mmap_pcd4_38_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_41_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_42",
    &setup_memwrite_mmap_pcd4_6_common,
    { { &setup_memwrite_mmap_pcd4_40_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_41_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_43",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_43_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_44",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_44_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_45",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_43_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_46",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_44_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_47",
    &setup_memwrite_mmap_pcd4_6_common,
    { { &setup_memwrite_mmap_pcd4_47_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_47_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcd4_48",
    &setup_memwrite_mmap_pcd4_0_common,
    { { &setup_memwrite_mmap_pcd4_48_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcc_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcb0_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pcb0_1",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc98_0",
    &setup_memwrite_mmap_pcd8_0_common,
    { { &setup_memwrite_mmap_pcd8_0_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc98_1",
    &setup_memwrite_mmap_pcd8_0_common,
    { { &setup_memwrite_mmap_pcd8_1_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc94_0",
    &setup_memwrite_mmap_pcd4_28_common,
    { { &setup_memwrite_mmap_pc94_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc94_1",
    &setup_memwrite_mmap_pcd4_28_common,
    { { &setup_memwrite_mmap_pc94_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc94_2",
    &setup_memwrite_mmap_pcd4_6_common,
    { { &setup_memwrite_mmap_pcd4_6_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pc94_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc94_3",
    &setup_memwrite_mmap_pcd4_0_common,
    { { &setup_memwrite_mmap_pc94_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc94_4",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_7_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc94_5",
    &setup_memwrite_mmap_pcd4_7_common,
    { { &setup_memwrite_mmap_pcd4_7_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc8_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc6_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc58_0",
    &setup_memwrite_mmap_pcd8_0_common,
    { { &setup_memwrite_mmap_pc58_0_proc0 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc58_1",
    &setup_memwrite_mmap_pcd8_0_common,
    { { &setup_memwrite_mmap_pc58_0_proc0 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc50_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pd14_5_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc50_1",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc4_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc30_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc30_1",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc18_0",
    &setup_memwrite_mmap_pcd8_0_common,
    { { &setup_memwrite_mmap_pc58_0_proc0 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc18_1",
    &setup_memwrite_mmap_pcd8_0_common,
    { { &setup_memwrite_mmap_pc58_0_proc0 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc14_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pd14_5_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc14_1",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pd14_5_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc14_2",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pd50_1_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pd14_3_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc14_3",
    &setup_memwrite_mmap_pc14_3_common,
    { { &setup_memwrite_mmap_pd14_1_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc14_4",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc14_5",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pc0_0",
    &setup_memwrite_mmap_pfa8_1_common,
    { { &setup_memwrite_mmap_pcf8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_3",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_4",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_5",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_5_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_6",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_6_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_7",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_7_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_8",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_8_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_9",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_9_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_10",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_10_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_11",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_11_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_12",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_13",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_7_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_14",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_5_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_15",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_6_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_16",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_8_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_17",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_9_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_18",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_10_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_19",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_11_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_4_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_20",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb8_21",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb6_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pb6_0_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb6_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pb6_1_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb6_2",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pb6_2_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb6_3",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pb6_3_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_3",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_4",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_4_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_5",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_5_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_6",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_6_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_7",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_7_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_8",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_8_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_9",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_10",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_10_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb4_11",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_11_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pcd4_3_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb0_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pb0_1",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pac_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pac_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pac_2",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pac_3",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pa6_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pb6_0_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pa6_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pb6_1_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pa6_2",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pb6_2_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pa6_3",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pb6_3_proc0 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pa5_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pa5_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_0_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pa5_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pa5_3",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb4_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pa0_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_pa0_1",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p98_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p98_1",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p96_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_p96_0_proc0 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p96_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_p96_1_proc0 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p96_2",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_p96_0_proc0 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p96_3",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_p96_1_proc0 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p94_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p94_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p90_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p90_1",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p8c_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p8c_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p8c_2",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p8c_3",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p86_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_p96_0_proc0 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p86_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_p96_1_proc0 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p86_2",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_p96_0_proc0 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p86_3",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_p96_1_proc0 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p85_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p85_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p85_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p85_3",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p80_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pb8_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p80_1",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pb8_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p78_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p70_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p70_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_p70_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p70_2",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_p70_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p70_3",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_p70_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p70_4",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_p70_4_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfe_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p6c_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_peb_0_proc1 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p6c_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_peb_1_proc1 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p6a_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pea_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p68_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pea_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p68_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_p68_1_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p68_2",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_p68_2_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p68_3",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_p68_3_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p68_4",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_p68_4_proc0 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfac_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p60_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p5a_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p54_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p54_1",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p4c_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_peb_0_proc1 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p4c_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_peb_1_proc1 }, { &setup_memwrite_mmap_pfb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p4a8_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pea_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p49_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pea_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p49_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pea_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p40_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p30_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p2c_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pfb_0_proc1 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p2c_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pfb_0_proc1 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pfb_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p28_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pea_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p20_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf8_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p18_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p18_1",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf6_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p0c_0",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pfb_0_proc1 }, { &setup_memwrite_mmap_peb_0_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p0c_1",
    &setup_memwrite_mmap_pfb_0_common,
    { { &setup_memwrite_mmap_pfb_0_proc1 }, { &setup_memwrite_mmap_peb_1_proc1 } },
    &setup_memwrite_mmap_pfb_0_procfinal,
    &setup_memwrite_mmap_pfb_0_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf3_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p0a_0",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p0a_1",
    &setup_memwrite_mmap_pfe_2_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pea_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_2_final,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf28_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mmap_p00_0",
    &setup_memwrite_mmap_pfe_0_common,
    { { &setup_memwrite_mmap_pfe_0_proc1 }, { &setup_memwrite_mmap_pfe_0_proc1 } },
    &setup_memwrite_mmap_pfe_0_procfinal,
    &setup_memwrite_mmap_pfe_0_procfinal,
    { { &test_memwrite_mmap_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-memwrite_mprotect_pfc_0",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pfc_1",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_1_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pfc_2",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pfc_2_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pfc_3",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_1_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pfc_4",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pfc_2_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pfc_5",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pfc_5_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pfc_6",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pfc_7",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pfc_5_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pfc_8",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_8_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_8_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pf0_0",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_8_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pf0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pe8_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pfc_8_proc0 }, { &setup_memwrite_mprotect_pe8_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pe8_1",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_8_proc0 }, { &setup_memwrite_mprotect_pe8_1_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pe8_2",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pfc_8_proc0 }, { &setup_memwrite_mprotect_pe8_2_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pe8_3",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_8_proc0 }, { &setup_memwrite_mprotect_pfc_8_proc0 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pe0_0",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_8_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pde_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pde_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pde_1",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pde_1_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pde_2",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pde_1_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pde_3",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pde_3_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pde_4",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pde_4_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pde_5",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pde_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pde_6",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pde_6_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_8_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pd8_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pd8_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pf0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pd4_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pd8_0_proc0 }, { &setup_memwrite_mprotect_pd4_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pd4_1",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pde_6_proc0 }, { &setup_memwrite_mprotect_pde_6_proc0 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pd4_2",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pde_6_proc0 }, { &setup_memwrite_mprotect_pe8_1_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pd4_3",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pd8_0_proc0 }, { &setup_memwrite_mprotect_pfc_8_proc0 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pd0_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pd8_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pde_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pce_0",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pce_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pce_1",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pce_1_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pce_2",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pce_1_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pce_3",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pce_3_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pce_4",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pce_3_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pce_5",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pce_5_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pce_6",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pce_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pce_7",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pce_5_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pce_8",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pe8_2_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_8_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pc8_0",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pe8_2_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pf0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pc4_0",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pe8_2_proc1 }, { &setup_memwrite_mprotect_pe8_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pc4_1",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pe8_2_proc1 }, { &setup_memwrite_mprotect_pe8_1_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pc4_2",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pe8_2_proc1 }, { &setup_memwrite_mprotect_pe8_2_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pc4_3",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pe8_2_proc1 }, { &setup_memwrite_mprotect_pfc_8_proc0 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pc0_0",
    &setup_memwrite_mprotect_pce_0_common,
    { { &setup_memwrite_mprotect_pe8_2_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_1",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_2",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pb0_2_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_3",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_3_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_4",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_3_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_5",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_5_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_6",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_6_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_7",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_5_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_8",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_6_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_9",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_9_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_10",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_10_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_11",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_9_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_12",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pb0_10_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_13",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pb0_2_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_14",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pb0_14_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_15",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pb0_14_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_3_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_16",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pe8_0_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pb0_17",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pe8_1_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pa_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pe8_0_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pf0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_pa_1",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pe8_1_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pf0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p9_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pe8_0_proc1 }, { &setup_memwrite_mprotect_pe8_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p9_1",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pe8_0_proc1 }, { &setup_memwrite_mprotect_pe8_1_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p9_2",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pe8_1_proc1 }, { &setup_memwrite_mprotect_pe8_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p9_3",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pe8_1_proc1 }, { &setup_memwrite_mprotect_pe8_1_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p9_4",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pe8_0_proc1 }, { &setup_memwrite_mprotect_pe8_2_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p9_5",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pe8_1_proc1 }, { &setup_memwrite_mprotect_pe8_2_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p9_6",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pe8_0_proc1 }, { &setup_memwrite_mprotect_pfc_8_proc0 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p9_7",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pe8_1_proc1 }, { &setup_memwrite_mprotect_pfc_8_proc0 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p8_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pe8_0_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p8_1",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pe8_1_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p6_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_p6_0_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p6_1",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_p6_1_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p6_2",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_p6_2_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p6_3",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_p6_3_proc0 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pfc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p4_0",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_0_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pf0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p4_1",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_0_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p2_0",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pfc_0_proc1 }, { &setup_memwrite_mprotect_pe8_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p2_1",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_0_proc1 }, { &setup_memwrite_mprotect_pe8_1_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p2_2",
    &setup_memwrite_mprotect_pfc_2_common,
    { { &setup_memwrite_mprotect_pfc_0_proc1 }, { &setup_memwrite_mprotect_pe8_2_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_2_final,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p2_3",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_0_proc1 }, { &setup_memwrite_mprotect_pfc_8_proc0 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_mprotect_p0_0",
    &setup_memwrite_mprotect_pfc_0_common,
    { { &setup_memwrite_mprotect_pfc_0_proc1 }, { &setup_memwrite_mprotect_pfc_0_proc1 } },
    &setup_memwrite_mprotect_pfc_0_procfinal,
    &setup_memwrite_mprotect_pfc_0_procfinal,
    { { &test_memwrite_mprotect_pb0_0_0, 0, "memwrite" },
      { &test_memwrite_mprotect_pe0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-memwrite_munmap_pf8_0",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pf8_0_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_final,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pf8_1",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pf8_1_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_procfinal,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pf8_2",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pf8_2_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_procfinal,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pf8_3",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pf8_3_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pf8_4",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pf8_4_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pe_0",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pf8_1_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_procfinal,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pdc_0",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pdc_0_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pdc_1",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pdc_1_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pdc_2",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pdc_2_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pdc_3",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pdc_3_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pdc_4",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pdc_4_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pd0_0",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pd0_0_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pcc_0",
    &setup_memwrite_munmap_pcc_0_common,
    { { &setup_memwrite_munmap_pcc_0_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pcc_1",
    &setup_memwrite_munmap_pcc_0_common,
    { { &setup_memwrite_munmap_pcc_1_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pcc_2",
    &setup_memwrite_munmap_pcc_0_common,
    { { &setup_memwrite_munmap_pcc_2_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pcc_3",
    &setup_memwrite_munmap_pcc_0_common,
    { { &setup_memwrite_munmap_pcc_3_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pcc_4",
    &setup_memwrite_munmap_pcc_0_common,
    { { &setup_memwrite_munmap_pcc_4_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pc0_0",
    &setup_memwrite_munmap_pcc_0_common,
    { { &setup_memwrite_munmap_pcc_1_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pb_0",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pb_0_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pb_1",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pb_1_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pb_2",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pb_2_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_procfinal,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pb_3",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pb_3_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_procfinal,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pb_4",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pb_4_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pb_5",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pb_5_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pb_6",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pb_6_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pb_7",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pb_7_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pb_8",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pb_8_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_procfinal,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pb_9",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pb_9_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pf8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pa_0",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pb_1_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_pa_1",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pb_3_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_procfinal,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_p8_0",
    &setup_memwrite_munmap_pf8_3_common,
    { { &setup_memwrite_munmap_pb_1_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_3_final,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_p8_1",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pb_3_proc0 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_procfinal,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_p4_0",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pf8_0_proc1 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_procfinal,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-memwrite_munmap_p0_0",
    &setup_memwrite_munmap_pf8_0_common,
    { { &setup_memwrite_munmap_pf8_0_proc1 }, { &setup_memwrite_munmap_pf8_0_proc1 } },
    &setup_memwrite_munmap_pf8_0_procfinal,
    &setup_memwrite_munmap_pf8_0_procfinal,
    { { &test_memwrite_munmap_pb_0_0, 0, "memwrite" },
      { &test_memwrite_munmap_pe_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-memwrite_open_pfc_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pfb8_0",
    &setup_memwrite_open_pfb8_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pfa8_0",
    &setup_memwrite_open_pfa8_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pf98_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pf88_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pf70_0",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pf50_0",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pf30_0",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pf10_0",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pef0_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_ped0_0",
    &setup_memwrite_open_pfa8_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_peb_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pe9_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pe0_0",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pfc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pde_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pddc_0",
    &setup_memwrite_open_pddc_0_common,
    { { &setup_memwrite_open_pddc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pddc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pddc_1",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pddc_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pdd4_0",
    &setup_memwrite_open_pddc_0_common,
    { { &setup_memwrite_open_pddc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pddc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pdd4_1",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pddc_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pdcc_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pdc4_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pdb8_0",
    &setup_memwrite_open_pdb8_0_common,
    { { &setup_memwrite_open_pddc_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pda8_0",
    &setup_memwrite_open_pdb8_0_common,
    { { &setup_memwrite_open_pddc_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pd98_0",
    &setup_memwrite_open_pdb8_0_common,
    { { &setup_memwrite_open_pddc_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pd88_0",
    &setup_memwrite_open_pdb8_0_common,
    { { &setup_memwrite_open_pddc_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pd78_0",
    &setup_memwrite_open_pddc_0_common,
    { { &setup_memwrite_open_pddc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pddc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pd78_1",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pddc_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pd68_0",
    &setup_memwrite_open_pddc_0_common,
    { { &setup_memwrite_open_pddc_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pddc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pd68_1",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pddc_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pd58_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pd48_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pd0_0",
    &setup_memwrite_open_pdb8_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pde_0_0, 0, "memwrite" },
      { &test_memwrite_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pce_0",
    &setup_memwrite_open_pce_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pcda_0",
    &setup_memwrite_open_pddc_0_common,
    { { &setup_memwrite_open_pcda_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pddc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pcd2_0",
    &setup_memwrite_open_pddc_0_common,
    { { &setup_memwrite_open_pcda_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pddc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pccc_0",
    &setup_memwrite_open_pce_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pcc4_0",
    &setup_memwrite_open_pce_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pcb4_0",
    &setup_memwrite_open_pcb4_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pca4_0",
    &setup_memwrite_open_pcb4_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pc94_0",
    &setup_memwrite_open_pcb4_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pc84_0",
    &setup_memwrite_open_pcb4_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pc74_0",
    &setup_memwrite_open_pddc_0_common,
    { { &setup_memwrite_open_pcda_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pddc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pc64_0",
    &setup_memwrite_open_pddc_0_common,
    { { &setup_memwrite_open_pcda_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pddc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pc58_0",
    &setup_memwrite_open_pce_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pc48_0",
    &setup_memwrite_open_pce_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pc0_0",
    &setup_memwrite_open_pcb4_0_common,
    { { &setup_memwrite_open_pde_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pb8_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pb8_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pb8_1",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pb70_0",
    &setup_memwrite_open_pfb8_0_common,
    { { &setup_memwrite_open_pb70_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pb70_1",
    &setup_memwrite_open_pfa8_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pb50_0",
    &setup_memwrite_open_pfb8_0_common,
    { { &setup_memwrite_open_pb70_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pb50_1",
    &setup_memwrite_open_pfb8_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pb3_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pb3_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pb3_1",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pb1_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pb3_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pb1_1",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pae_0",
    &setup_memwrite_open_pae_0_common,
    { { &setup_memwrite_open_pae_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pae_1",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_paa_0",
    &setup_memwrite_open_pae_0_common,
    { { &setup_memwrite_open_pae_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_paa_1",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pa6_0",
    &setup_memwrite_open_pae_0_common,
    { { &setup_memwrite_open_pae_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pa6_1",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_pa2_0",
    &setup_memwrite_open_pae_0_common,
    { { &setup_memwrite_open_pae_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_pa2_1",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p9e_0",
    &setup_memwrite_open_pfa8_0_common,
    { { &setup_memwrite_open_p9e_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p9e_1",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p9a_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_p9e_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p9a_1",
    &setup_memwrite_open_pfb8_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p96_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pb3_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p96_1",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p92_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pb3_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p92_1",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p8_0",
    &setup_memwrite_open_pdb8_0_common,
    { { &setup_memwrite_open_pb8_0_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p8_1",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pb8_1_proc0 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p7_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p6e_0",
    &setup_memwrite_open_pfb8_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p6a_0",
    &setup_memwrite_open_pfa8_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p66_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p62_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p5c_0",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p54_0",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p4c_0",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p44_0",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p3c_0",
    &setup_memwrite_open_pfb8_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p34_0",
    &setup_memwrite_open_pfc_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p2c_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_open_p24_0",
    &setup_memwrite_open_pf98_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_final,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-memwrite_open_p0_0",
    &setup_memwrite_open_pf70_0_common,
    { { &setup_memwrite_open_pfc_0_proc1 }, { &setup_memwrite_open_pfc_0_proc1 } },
    &setup_memwrite_open_pfc_0_procfinal,
    &setup_memwrite_open_pfc_0_procfinal,
    { { &test_memwrite_open_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-memwrite_pipe_pfc_0",
    &setup_memwrite_pipe_pfc_0_common,
    { { &setup_memwrite_pipe_pfc_0_proc0 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pfc_0_final,
    { { &test_memwrite_pipe_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_pec_0",
    &setup_memwrite_pipe_pfc_0_common,
    { { &setup_memwrite_pipe_pfc_0_proc0 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pfc_0_procfinal,
    { { &test_memwrite_pipe_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_pde_0",
    &setup_memwrite_pipe_pde_0_common,
    { { &setup_memwrite_pipe_pde_0_proc0 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pde_0_final,
    { { &test_memwrite_pipe_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_pd6_0",
    &setup_memwrite_pipe_pde_0_common,
    { { &setup_memwrite_pipe_pde_0_proc0 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pde_0_final,
    { { &test_memwrite_pipe_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_pce_0",
    &setup_memwrite_pipe_pce_0_common,
    { { &setup_memwrite_pipe_pde_0_proc0 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pde_0_final,
    { { &test_memwrite_pipe_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_pc6_0",
    &setup_memwrite_pipe_pce_0_common,
    { { &setup_memwrite_pipe_pde_0_proc0 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pde_0_final,
    { { &test_memwrite_pipe_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_pb8_0",
    &setup_memwrite_pipe_pb8_0_common,
    { { &setup_memwrite_pipe_pb8_0_proc0 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pde_0_final,
    { { &test_memwrite_pipe_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_pb8_1",
    &setup_memwrite_pipe_pfc_0_common,
    { { &setup_memwrite_pipe_pb8_1_proc0 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pfc_0_procfinal,
    { { &test_memwrite_pipe_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_p98_0",
    &setup_memwrite_pipe_pb8_0_common,
    { { &setup_memwrite_pipe_pb8_0_proc0 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pde_0_final,
    { { &test_memwrite_pipe_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_p98_1",
    &setup_memwrite_pipe_pfc_0_common,
    { { &setup_memwrite_pipe_pb8_1_proc0 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pfc_0_procfinal,
    { { &test_memwrite_pipe_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_p70_0",
    &setup_memwrite_pipe_pfc_0_common,
    { { &setup_memwrite_pipe_pfc_0_proc1 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pfc_0_procfinal,
    { { &test_memwrite_pipe_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-memwrite_pipe_p30_0",
    &setup_memwrite_pipe_pfc_0_common,
    { { &setup_memwrite_pipe_pfc_0_proc1 }, { &setup_memwrite_pipe_pfc_0_proc1 } },
    &setup_memwrite_pipe_pfc_0_procfinal,
    &setup_memwrite_pipe_pfc_0_procfinal,
    { { &test_memwrite_pipe_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-memwrite_pread_pfc_0",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pfc_0_proc0 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pfc_1",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pfc_1_proc0 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pfa_0",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pfa_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pfa_1",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pfa_1_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pf8_0",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pfa_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pf8_1",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pfa_1_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pf0_0",
    &setup_memwrite_pread_pf0_0_common,
    { { &setup_memwrite_pread_pf0_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_procfinal,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pec_0",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pec_0_proc0 }, { &setup_memwrite_pread_pec_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pec_1",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pec_0_proc0 }, { &setup_memwrite_pread_pec_1_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pea_0",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pf0_0_proc0 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pea_1",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pf0_0_proc0 }, { &setup_memwrite_pread_pea_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pe8_0",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pf0_0_proc0 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pe8_1",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pf0_0_proc0 }, { &setup_memwrite_pread_pea_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pe0_0",
    &setup_memwrite_pread_pf0_0_common,
    { { &setup_memwrite_pread_pf0_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_procfinal,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pde_0",
    &setup_memwrite_pread_pde_0_common,
    { { &setup_memwrite_pread_pde_0_proc0 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pde_1",
    &setup_memwrite_pread_pde_0_common,
    { { &setup_memwrite_pread_pde_1_proc0 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdd_0",
    &setup_memwrite_pread_pdd_0_common,
    { { &setup_memwrite_pread_pdd_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdd_1",
    &setup_memwrite_pread_pdd_1_common,
    { { &setup_memwrite_pread_pdd_1_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pdd_1_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdd_2",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pdd_2_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdd_3",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pdd_3_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pdd_3_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdd_4",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pdd_4_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pdd_4_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdd_5",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pdd_5_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pdd_5_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdc0_0",
    &setup_memwrite_pread_pdc0_0_common,
    { { &setup_memwrite_pread_pdc0_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdc0_1",
    &setup_memwrite_pread_pdc0_1_common,
    { { &setup_memwrite_pread_pdc0_1_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdc0_2",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pdc0_2_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdc0_3",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pdc0_3_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pdc0_4",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pdc0_4_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd8_0",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pd8_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd6_0",
    &setup_memwrite_pread_pde_0_common,
    { { &setup_memwrite_pread_pd6_0_proc0 }, { &setup_memwrite_pread_pec_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd6_1",
    &setup_memwrite_pread_pde_0_common,
    { { &setup_memwrite_pread_pd6_0_proc0 }, { &setup_memwrite_pread_pec_1_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd5_0",
    &setup_memwrite_pread_pdd_0_common,
    { { &setup_memwrite_pread_pd5_0_proc0 }, { &setup_memwrite_pread_pd5_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd5_1",
    &setup_memwrite_pread_pd5_1_common,
    { { &setup_memwrite_pread_pd5_1_proc0 }, { &setup_memwrite_pread_pea_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd5_2",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pd5_2_proc0 }, { &setup_memwrite_pread_pd5_2_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd5_3",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pd5_3_proc0 }, { &setup_memwrite_pread_pd5_3_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pdd_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd5_4",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pd5_4_proc0 }, { &setup_memwrite_pread_pd5_4_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pdd_4_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd5_5",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pd5_5_proc0 }, { &setup_memwrite_pread_pd5_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pdd_5_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd40_0",
    &setup_memwrite_pread_pdc0_0_common,
    { { &setup_memwrite_pread_pd5_0_proc0 }, { &setup_memwrite_pread_pd5_2_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd40_1",
    &setup_memwrite_pread_pdd_1_common,
    { { &setup_memwrite_pread_pd40_1_proc0 }, { &setup_memwrite_pread_pd40_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pd40_1_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd40_2",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pd5_3_proc0 }, { &setup_memwrite_pread_pd5_2_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd40_3",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pd40_3_proc0 }, { &setup_memwrite_pread_pd40_3_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pd0_0",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pd8_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pce_0",
    &setup_memwrite_pread_pce_0_common,
    { { &setup_memwrite_pread_pce_0_proc0 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pce_1",
    &setup_memwrite_pread_pce_0_common,
    { { &setup_memwrite_pread_pce_1_proc0 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pcd_0",
    &setup_memwrite_pread_pd5_1_common,
    { { &setup_memwrite_pread_pcd_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pcd_1",
    &setup_memwrite_pread_pcd_1_common,
    { { &setup_memwrite_pread_pcd_1_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcd_1_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pcd_2",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pcd_2_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcd_2_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pcd_3",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pcd_3_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcd_3_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pcc8_0",
    &setup_memwrite_pread_pcc8_0_common,
    { { &setup_memwrite_pread_pcc8_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcc8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pcc8_1",
    &setup_memwrite_pread_pcc8_0_common,
    { { &setup_memwrite_pread_pcc8_1_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcc8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pcc8_2",
    &setup_memwrite_pread_pcc8_2_common,
    { { &setup_memwrite_pread_pcc8_2_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcc8_2_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pcc8_3",
    &setup_memwrite_pread_pcc8_3_common,
    { { &setup_memwrite_pread_pcc8_3_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcc8_3_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pcc8_4",
    &setup_memwrite_pread_pcc8_4_common,
    { { &setup_memwrite_pread_pcc8_4_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc8_0",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pc8_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc6_0",
    &setup_memwrite_pread_pce_0_common,
    { { &setup_memwrite_pread_pc6_0_proc0 }, { &setup_memwrite_pread_pec_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc6_1",
    &setup_memwrite_pread_pce_0_common,
    { { &setup_memwrite_pread_pc6_0_proc0 }, { &setup_memwrite_pread_pec_1_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc5_0",
    &setup_memwrite_pread_pd5_1_common,
    { { &setup_memwrite_pread_pc5_0_proc0 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc5_1",
    &setup_memwrite_pread_pcd_1_common,
    { { &setup_memwrite_pread_pc5_0_proc0 }, { &setup_memwrite_pread_pc5_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pdd_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcd_1_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc5_2",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pc8_0_proc0 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcd_2_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc5_3",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pc8_0_proc0 }, { &setup_memwrite_pread_pc5_3_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcd_3_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc48_0",
    &setup_memwrite_pread_pcc8_0_common,
    { { &setup_memwrite_pread_pc48_0_proc0 }, { &setup_memwrite_pread_pd40_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcc8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc48_1",
    &setup_memwrite_pread_pcc8_0_common,
    { { &setup_memwrite_pread_pc48_0_proc0 }, { &setup_memwrite_pread_pc48_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pcc8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc48_2",
    &setup_memwrite_pread_pc48_2_common,
    { { &setup_memwrite_pread_pc48_2_proc0 }, { &setup_memwrite_pread_pc48_2_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pd40_1_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc48_3",
    &setup_memwrite_pread_pc48_2_common,
    { { &setup_memwrite_pread_pc48_2_proc0 }, { &setup_memwrite_pread_pd40_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pd40_1_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pc0_0",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pc8_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb8_0",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pb8_0_proc0 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb8_1",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pb8_1_proc0 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb8_2",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pb8_2_proc0 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb8_3",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pb8_3_proc0 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb4_0",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pb4_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb4_1",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pb4_1_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb4_2",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pb4_2_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb4_3",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pb4_3_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb4_4",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pb4_4_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb0_0",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pb4_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb0_1",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pb4_1_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb0_2",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pb0_2_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb0_3",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pb4_4_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pb0_4",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pb4_3_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pa_0",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pa_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_pa_1",
    &setup_memwrite_pread_pf0_0_common,
    { { &setup_memwrite_pread_pa_1_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_procfinal,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p98_0",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_p98_0_proc0 }, { &setup_memwrite_pread_pec_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p98_1",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_p98_1_proc0 }, { &setup_memwrite_pread_pec_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p98_2",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_p98_0_proc0 }, { &setup_memwrite_pread_pec_1_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p98_3",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_p98_1_proc0 }, { &setup_memwrite_pread_pec_1_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p94_0",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_p94_0_proc0 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p94_1",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pa_1_proc0 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p94_2",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pa_0_proc0 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p94_3",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pa_0_proc0 }, { &setup_memwrite_pread_pea_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p94_4",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pa_1_proc0 }, { &setup_memwrite_pread_pea_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p90_0",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_p94_0_proc0 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p90_1",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pa_1_proc0 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p90_2",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pa_1_proc0 }, { &setup_memwrite_pread_pea_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p90_3",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pa_0_proc0 }, { &setup_memwrite_pread_pd5_2_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p90_4",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pa_0_proc0 }, { &setup_memwrite_pread_pea_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p8_0",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pa_0_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p8_1",
    &setup_memwrite_pread_pf0_0_common,
    { { &setup_memwrite_pread_pa_1_proc0 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_procfinal,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p7_0",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pec_0_proc1 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p7_1",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pec_1_proc1 }, { &setup_memwrite_pread_pfc_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p68_0",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pea_0_proc1 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p68_1",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pea_1_proc1 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p60_0",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pea_0_proc1 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p60_1",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pea_1_proc1 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p4_0",
    &setup_memwrite_pread_pf0_0_common,
    { { &setup_memwrite_pread_pfa_0_proc1 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_procfinal,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p3_0",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pfc_0_proc1 }, { &setup_memwrite_pread_pec_0_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p3_1",
    &setup_memwrite_pread_pfc_0_common,
    { { &setup_memwrite_pread_pfc_0_proc1 }, { &setup_memwrite_pread_pec_1_proc1 } },
    &setup_memwrite_pread_pfc_0_procfinal,
    &setup_memwrite_pread_pfc_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p28_0",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pfa_0_proc1 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p28_1",
    &setup_memwrite_pread_pfa_0_common,
    { { &setup_memwrite_pread_pfa_0_proc1 }, { &setup_memwrite_pread_pea_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p20_0",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pfa_0_proc1 }, { &setup_memwrite_pread_pea_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p20_1",
    &setup_memwrite_pread_pf8_0_common,
    { { &setup_memwrite_pread_pfa_0_proc1 }, { &setup_memwrite_pread_pea_1_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_final,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pread_p0_0",
    &setup_memwrite_pread_pf0_0_common,
    { { &setup_memwrite_pread_pfa_0_proc1 }, { &setup_memwrite_pread_pfa_0_proc1 } },
    &setup_memwrite_pread_pfa_0_procfinal,
    &setup_memwrite_pread_pfa_0_procfinal,
    { { &test_memwrite_pread_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-memwrite_pwrite_pfc_0",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pfc_0_proc0 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pfc_1",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pfc_1_proc0 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pfa_0",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pfa_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pfa_1",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pfa_1_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pf8_0",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pf8_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pf8_1",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pfa_1_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pf0_0",
    &setup_memwrite_pwrite_pf0_0_common,
    { { &setup_memwrite_pwrite_pf0_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_procfinal,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pec_0",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pec_0_proc0 }, { &setup_memwrite_pwrite_pec_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pec_1",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pec_0_proc0 }, { &setup_memwrite_pwrite_pec_1_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pea_0",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pf0_0_proc0 }, { &setup_memwrite_pwrite_pea_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pea_1",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pf0_0_proc0 }, { &setup_memwrite_pwrite_pea_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pe8_0",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pf0_0_proc0 }, { &setup_memwrite_pwrite_pe8_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pe8_1",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pf0_0_proc0 }, { &setup_memwrite_pwrite_pea_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pe0_0",
    &setup_memwrite_pwrite_pf0_0_common,
    { { &setup_memwrite_pwrite_pf0_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_procfinal,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pde_0",
    &setup_memwrite_pwrite_pde_0_common,
    { { &setup_memwrite_pwrite_pde_0_proc0 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pde_1",
    &setup_memwrite_pwrite_pde_0_common,
    { { &setup_memwrite_pwrite_pde_1_proc0 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pdd8_0",
    &setup_memwrite_pwrite_pdd8_0_common,
    { { &setup_memwrite_pwrite_pdd8_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pdd8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pdd8_1",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pdd8_1_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pdd8_2",
    &setup_memwrite_pwrite_pdd8_2_common,
    { { &setup_memwrite_pwrite_pdd8_2_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pdd8_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pdd8_3",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pdd8_3_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pdc0_0",
    &setup_memwrite_pwrite_pdd8_0_common,
    { { &setup_memwrite_pwrite_pdc0_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pdc0_1",
    &setup_memwrite_pwrite_pdc0_1_common,
    { { &setup_memwrite_pwrite_pdc0_1_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pdc0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pdc0_2",
    &setup_memwrite_pwrite_pdc0_2_common,
    { { &setup_memwrite_pwrite_pdc0_2_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pdc0_3",
    &setup_memwrite_pwrite_pdc0_1_common,
    { { &setup_memwrite_pwrite_pdc0_3_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd8_0",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pd8_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd6_0",
    &setup_memwrite_pwrite_pde_0_common,
    { { &setup_memwrite_pwrite_pd6_0_proc0 }, { &setup_memwrite_pwrite_pec_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd6_1",
    &setup_memwrite_pwrite_pde_0_common,
    { { &setup_memwrite_pwrite_pd6_0_proc0 }, { &setup_memwrite_pwrite_pec_1_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd58_0",
    &setup_memwrite_pwrite_pdd8_0_common,
    { { &setup_memwrite_pwrite_pd58_0_proc0 }, { &setup_memwrite_pwrite_pd58_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pdd8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd58_1",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pd58_1_proc0 }, { &setup_memwrite_pwrite_pd58_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd58_2",
    &setup_memwrite_pwrite_pdd8_2_common,
    { { &setup_memwrite_pwrite_pd58_2_proc0 }, { &setup_memwrite_pwrite_pd58_2_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pdd8_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd58_3",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pd58_1_proc0 }, { &setup_memwrite_pwrite_pd58_3_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd40_0",
    &setup_memwrite_pwrite_pdd8_0_common,
    { { &setup_memwrite_pwrite_pd58_0_proc0 }, { &setup_memwrite_pwrite_pe8_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd40_1",
    &setup_memwrite_pwrite_pdc0_1_common,
    { { &setup_memwrite_pwrite_pd40_1_proc0 }, { &setup_memwrite_pwrite_pd40_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pdc0_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd40_2",
    &setup_memwrite_pwrite_pdd8_2_common,
    { { &setup_memwrite_pwrite_pd40_2_proc0 }, { &setup_memwrite_pwrite_pd40_2_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pdc0_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd40_3",
    &setup_memwrite_pwrite_pdc0_1_common,
    { { &setup_memwrite_pwrite_pd40_1_proc0 }, { &setup_memwrite_pwrite_pd40_2_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pdc0_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pd0_0",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pd8_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pde_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pce_0",
    &setup_memwrite_pwrite_pce_0_common,
    { { &setup_memwrite_pwrite_pde_0_proc0 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pce_1",
    &setup_memwrite_pwrite_pce_0_common,
    { { &setup_memwrite_pwrite_pde_1_proc0 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pcd0_0",
    &setup_memwrite_pwrite_pcd0_0_common,
    { { &setup_memwrite_pwrite_pcd0_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pcd0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pcd0_1",
    &setup_memwrite_pwrite_pcd0_1_common,
    { { &setup_memwrite_pwrite_pcd0_1_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pcd0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pcd0_2",
    &setup_memwrite_pwrite_pcd0_0_common,
    { { &setup_memwrite_pwrite_pcd0_2_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pcd0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pcd0_3",
    &setup_memwrite_pwrite_pcd0_0_common,
    { { &setup_memwrite_pwrite_pcd0_3_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pcd0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pcc0_0",
    &setup_memwrite_pwrite_pcc0_0_common,
    { { &setup_memwrite_pwrite_pcc0_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pcc0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pcc0_1",
    &setup_memwrite_pwrite_pcc0_1_common,
    { { &setup_memwrite_pwrite_pcc0_1_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pcd0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pcc0_2",
    &setup_memwrite_pwrite_pcc0_2_common,
    { { &setup_memwrite_pwrite_pcc0_2_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pcc0_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pcc0_3",
    &setup_memwrite_pwrite_pcc0_3_common,
    { { &setup_memwrite_pwrite_pcc0_3_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pcc0_4",
    &setup_memwrite_pwrite_pcc0_3_common,
    { { &setup_memwrite_pwrite_pcc0_4_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc8_0",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pd8_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc6_0",
    &setup_memwrite_pwrite_pce_0_common,
    { { &setup_memwrite_pwrite_pd6_0_proc0 }, { &setup_memwrite_pwrite_pec_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc6_1",
    &setup_memwrite_pwrite_pce_0_common,
    { { &setup_memwrite_pwrite_pd6_0_proc0 }, { &setup_memwrite_pwrite_pec_1_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc50_0",
    &setup_memwrite_pwrite_pc50_0_common,
    { { &setup_memwrite_pwrite_pc50_0_proc0 }, { &setup_memwrite_pwrite_pc50_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pc50_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc50_1",
    &setup_memwrite_pwrite_pcd0_1_common,
    { { &setup_memwrite_pwrite_pc50_1_proc0 }, { &setup_memwrite_pwrite_pd58_3_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pdd8_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pcd0_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc50_2",
    &setup_memwrite_pwrite_pc50_0_common,
    { { &setup_memwrite_pwrite_pc50_0_proc0 }, { &setup_memwrite_pwrite_pd40_2_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pc50_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc40_0",
    &setup_memwrite_pwrite_pcc0_0_common,
    { { &setup_memwrite_pwrite_pd58_1_proc0 }, { &setup_memwrite_pwrite_pd40_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pcc0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc40_1",
    &setup_memwrite_pwrite_pc40_1_common,
    { { &setup_memwrite_pwrite_pc40_1_proc0 }, { &setup_memwrite_pwrite_pc40_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pcd0_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc40_2",
    &setup_memwrite_pwrite_pc40_2_common,
    { { &setup_memwrite_pwrite_pc40_2_proc0 }, { &setup_memwrite_pwrite_pc40_2_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pc40_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc40_3",
    &setup_memwrite_pwrite_pc40_2_common,
    { { &setup_memwrite_pwrite_pc40_2_proc0 }, { &setup_memwrite_pwrite_pd40_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pc40_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pc0_0",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pd8_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pfc_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb8_0",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pb8_0_proc0 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb8_1",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pb8_1_proc0 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb8_2",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pb8_2_proc0 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb8_3",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pb8_3_proc0 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb4_0",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pb4_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb4_1",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pb4_1_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb4_2",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pb4_2_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb4_3",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pb4_3_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb4_4",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pb4_4_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb4_5",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pb4_5_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb0_0",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pb0_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb0_1",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pb0_1_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb0_2",
    &setup_memwrite_pwrite_pb0_2_common,
    { { &setup_memwrite_pwrite_pb4_4_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pdd8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb0_3",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pb4_3_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb0_4",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pb4_4_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pb0_5",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pb4_5_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pa_0",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pa_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_pa_1",
    &setup_memwrite_pwrite_pf0_0_common,
    { { &setup_memwrite_pwrite_pa_1_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_procfinal,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p98_0",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_p98_0_proc0 }, { &setup_memwrite_pwrite_pec_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p98_1",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_p98_1_proc0 }, { &setup_memwrite_pwrite_pec_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p98_2",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_p98_0_proc0 }, { &setup_memwrite_pwrite_pec_1_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p98_3",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_p98_1_proc0 }, { &setup_memwrite_pwrite_pec_1_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p94_0",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_p94_0_proc0 }, { &setup_memwrite_pwrite_pea_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p94_1",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_p94_1_proc0 }, { &setup_memwrite_pwrite_pc40_2_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p94_2",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pa_0_proc0 }, { &setup_memwrite_pwrite_pd58_3_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p94_3",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pa_1_proc0 }, { &setup_memwrite_pwrite_p94_3_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p94_4",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pa_0_proc0 }, { &setup_memwrite_pwrite_pea_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p94_5",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pa_1_proc0 }, { &setup_memwrite_pwrite_pea_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p90_0",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_p90_0_proc0 }, { &setup_memwrite_pwrite_pe8_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p90_1",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_p94_0_proc0 }, { &setup_memwrite_pwrite_pd58_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p90_2",
    &setup_memwrite_pwrite_pb0_2_common,
    { { &setup_memwrite_pwrite_p90_2_proc0 }, { &setup_memwrite_pwrite_pea_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pdd8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p90_3",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pa_1_proc0 }, { &setup_memwrite_pwrite_pd40_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p90_4",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pa_1_proc0 }, { &setup_memwrite_pwrite_pea_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p90_5",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pa_0_proc0 }, { &setup_memwrite_pwrite_pea_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p8_0",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pa_0_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p8_1",
    &setup_memwrite_pwrite_pf0_0_common,
    { { &setup_memwrite_pwrite_pa_1_proc0 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_procfinal,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p7_0",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pec_0_proc1 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p7_1",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pec_1_proc1 }, { &setup_memwrite_pwrite_pfc_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p68_0",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pd58_0_proc1 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p68_1",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pea_1_proc1 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p60_0",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pd58_1_proc1 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p60_1",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pea_1_proc1 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p4_0",
    &setup_memwrite_pwrite_pf0_0_common,
    { { &setup_memwrite_pwrite_pfa_0_proc1 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_procfinal,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p3_0",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pfc_0_proc1 }, { &setup_memwrite_pwrite_pec_0_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p3_1",
    &setup_memwrite_pwrite_pfc_0_common,
    { { &setup_memwrite_pwrite_pfc_0_proc1 }, { &setup_memwrite_pwrite_pec_1_proc1 } },
    &setup_memwrite_pwrite_pfc_0_procfinal,
    &setup_memwrite_pwrite_pfc_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p28_0",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pfa_0_proc1 }, { &setup_memwrite_pwrite_pea_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p28_1",
    &setup_memwrite_pwrite_pfa_0_common,
    { { &setup_memwrite_pwrite_pfa_0_proc1 }, { &setup_memwrite_pwrite_pea_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p20_0",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pfa_0_proc1 }, { &setup_memwrite_pwrite_pe8_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p20_1",
    &setup_memwrite_pwrite_pf8_0_common,
    { { &setup_memwrite_pwrite_pfa_0_proc1 }, { &setup_memwrite_pwrite_pea_1_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_final,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_pwrite_p0_0",
    &setup_memwrite_pwrite_pf0_0_common,
    { { &setup_memwrite_pwrite_pfa_0_proc1 }, { &setup_memwrite_pwrite_pfa_0_proc1 } },
    &setup_memwrite_pwrite_pfa_0_procfinal,
    &setup_memwrite_pwrite_pfa_0_procfinal,
    { { &test_memwrite_pwrite_pb8_0_0, 0, "memwrite" },
      { &test_memwrite_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-memwrite_read_pfe_0",
    &setup_memwrite_read_pfe_0_common,
    { { &setup_memwrite_read_pfe_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pfd8_0",
    &setup_memwrite_read_pfd8_0_common,
    { { &setup_memwrite_read_pfd8_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pfd0_0",
    &setup_memwrite_read_pfd0_0_common,
    { { &setup_memwrite_read_pfd0_0_proc0 }, { &setup_memwrite_read_pfd0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pfc_0",
    &setup_memwrite_read_pfc_0_common,
    { { &setup_memwrite_read_pfd8_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pfa_0",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pfa_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pf8_0",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pf8_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pf0_0",
    &setup_memwrite_read_pf0_0_common,
    { { &setup_memwrite_read_pf0_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_procfinal,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pee_0",
    &setup_memwrite_read_pfe_0_common,
    { { &setup_memwrite_read_pee_0_proc0 }, { &setup_memwrite_read_pee_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_ped8_0",
    &setup_memwrite_read_pfd8_0_common,
    { { &setup_memwrite_read_pee_0_proc0 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_ped0_0",
    &setup_memwrite_read_pfd0_0_common,
    { { &setup_memwrite_read_ped0_0_proc0 }, { &setup_memwrite_read_ped0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pec_0",
    &setup_memwrite_read_pfc_0_common,
    { { &setup_memwrite_read_pee_0_proc0 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pea_0",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pf0_0_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pe8_0",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pf0_0_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pe0_0",
    &setup_memwrite_read_pf0_0_common,
    { { &setup_memwrite_read_pf0_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_procfinal,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pdf_0",
    &setup_memwrite_read_pdf_0_common,
    { { &setup_memwrite_read_pdf_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pdec_0",
    &setup_memwrite_read_pdec_0_common,
    { { &setup_memwrite_read_pdec_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pde8_0",
    &setup_memwrite_read_pdec_0_common,
    { { &setup_memwrite_read_pde8_0_proc0 }, { &setup_memwrite_read_pfd0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pde0_0",
    &setup_memwrite_read_pde0_0_common,
    { { &setup_memwrite_read_pde0_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pdd_0",
    &setup_memwrite_read_pdd_0_common,
    { { &setup_memwrite_read_pdd_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pdd_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pdd_1",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pdd_1_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pdd_2",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pdd_2_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pdc0_0",
    &setup_memwrite_read_pdc0_0_common,
    { { &setup_memwrite_read_pdc0_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pdd_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pdc0_1",
    &setup_memwrite_read_pdc0_1_common,
    { { &setup_memwrite_read_pdc0_1_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd8_0",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pd8_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd7_0",
    &setup_memwrite_read_pdf_0_common,
    { { &setup_memwrite_read_pd7_0_proc0 }, { &setup_memwrite_read_pee_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd6c_0",
    &setup_memwrite_read_pdec_0_common,
    { { &setup_memwrite_read_pd6c_0_proc0 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd68_0",
    &setup_memwrite_read_pdec_0_common,
    { { &setup_memwrite_read_pd68_0_proc0 }, { &setup_memwrite_read_ped0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd60_0",
    &setup_memwrite_read_pde0_0_common,
    { { &setup_memwrite_read_pd7_0_proc0 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd5_0",
    &setup_memwrite_read_pd5_0_common,
    { { &setup_memwrite_read_pd5_0_proc0 }, { &setup_memwrite_read_pd5_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pdd_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd5_1",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pd8_0_proc0 }, { &setup_memwrite_read_pd5_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd5_2",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pd8_0_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd40_0",
    &setup_memwrite_read_pdc0_0_common,
    { { &setup_memwrite_read_pd5_0_proc0 }, { &setup_memwrite_read_pd40_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pdd_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd40_1",
    &setup_memwrite_read_pdc0_1_common,
    { { &setup_memwrite_read_pd40_1_proc0 }, { &setup_memwrite_read_pd40_1_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pd0_0",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pd8_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pdf_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pcf_0",
    &setup_memwrite_read_pcf_0_common,
    { { &setup_memwrite_read_pdf_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pcec_0",
    &setup_memwrite_read_pcec_0_common,
    { { &setup_memwrite_read_pcec_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pce8_0",
    &setup_memwrite_read_pcec_0_common,
    { { &setup_memwrite_read_pce8_0_proc0 }, { &setup_memwrite_read_pfd0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pce0_0",
    &setup_memwrite_read_pce0_0_common,
    { { &setup_memwrite_read_pde0_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pcd_0",
    &setup_memwrite_read_pcd_0_common,
    { { &setup_memwrite_read_pdd_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pdd_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pcd_1",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pcd_1_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pcc8_0",
    &setup_memwrite_read_pcc8_0_common,
    { { &setup_memwrite_read_pcc8_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pcc8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pcc8_1",
    &setup_memwrite_read_pcc8_1_common,
    { { &setup_memwrite_read_pdd_2_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pc8_0",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pd8_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pc7_0",
    &setup_memwrite_read_pcf_0_common,
    { { &setup_memwrite_read_pd7_0_proc0 }, { &setup_memwrite_read_pee_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pc6c_0",
    &setup_memwrite_read_pcec_0_common,
    { { &setup_memwrite_read_pc6c_0_proc0 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pc68_0",
    &setup_memwrite_read_pcec_0_common,
    { { &setup_memwrite_read_pc68_0_proc0 }, { &setup_memwrite_read_ped0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pc60_0",
    &setup_memwrite_read_pce0_0_common,
    { { &setup_memwrite_read_pd7_0_proc0 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pc5_0",
    &setup_memwrite_read_pc5_0_common,
    { { &setup_memwrite_read_pd5_0_proc0 }, { &setup_memwrite_read_pd5_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pdd_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pc5_1",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pd8_0_proc0 }, { &setup_memwrite_read_pc5_1_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pc48_0",
    &setup_memwrite_read_pcc8_0_common,
    { { &setup_memwrite_read_pc48_0_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pcc8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pc48_1",
    &setup_memwrite_read_pcc8_1_common,
    { { &setup_memwrite_read_pd8_0_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pc0_0",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pd8_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pfe_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_pbc_0",
    &setup_memwrite_read_pfe_0_common,
    { { &setup_memwrite_read_pbc_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pbc_1",
    &setup_memwrite_read_pfe_0_common,
    { { &setup_memwrite_read_pbc_1_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pbb_0",
    &setup_memwrite_read_pfd8_0_common,
    { { &setup_memwrite_read_pbb_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pbb_1",
    &setup_memwrite_read_pfd8_0_common,
    { { &setup_memwrite_read_pbb_1_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pba_0",
    &setup_memwrite_read_pfd0_0_common,
    { { &setup_memwrite_read_pba_0_proc0 }, { &setup_memwrite_read_pfd0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pba_1",
    &setup_memwrite_read_pfd0_0_common,
    { { &setup_memwrite_read_pba_1_proc0 }, { &setup_memwrite_read_pfd0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pb8_0",
    &setup_memwrite_read_pfc_0_common,
    { { &setup_memwrite_read_pbb_0_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pb8_1",
    &setup_memwrite_read_pfc_0_common,
    { { &setup_memwrite_read_pbb_1_proc0 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pb4_0",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pb4_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pb4_1",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pb4_1_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pb4_2",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pb4_2_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pb0_0",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pb0_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pb0_1",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pb0_1_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pb0_2",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pb0_2_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pa_0",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pa_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_pa_1",
    &setup_memwrite_read_pf0_0_common,
    { { &setup_memwrite_read_pa_1_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_procfinal,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_p9c_0",
    &setup_memwrite_read_pfe_0_common,
    { { &setup_memwrite_read_p9c_0_proc0 }, { &setup_memwrite_read_pee_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p9c_1",
    &setup_memwrite_read_pfe_0_common,
    { { &setup_memwrite_read_p9c_1_proc0 }, { &setup_memwrite_read_pee_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p9b_0",
    &setup_memwrite_read_pfd8_0_common,
    { { &setup_memwrite_read_p9b_0_proc0 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p9b_1",
    &setup_memwrite_read_pfd8_0_common,
    { { &setup_memwrite_read_p9c_1_proc0 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p9a_0",
    &setup_memwrite_read_pfd0_0_common,
    { { &setup_memwrite_read_p9a_0_proc0 }, { &setup_memwrite_read_ped0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p9a_1",
    &setup_memwrite_read_pfd8_0_common,
    { { &setup_memwrite_read_p9a_1_proc0 }, { &setup_memwrite_read_ped0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p98_0",
    &setup_memwrite_read_pfc_0_common,
    { { &setup_memwrite_read_p9b_0_proc0 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p98_1",
    &setup_memwrite_read_pfc_0_common,
    { { &setup_memwrite_read_p9c_1_proc0 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p94_0",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_p94_0_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p94_1",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pa_1_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p94_2",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pa_0_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p90_0",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_p90_0_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p90_1",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pa_0_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p90_2",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pa_1_proc0 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p8_0",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pa_0_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p8_1",
    &setup_memwrite_read_pf0_0_common,
    { { &setup_memwrite_read_pa_1_proc0 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_procfinal,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p78_0",
    &setup_memwrite_read_pfe_0_common,
    { { &setup_memwrite_read_pee_0_proc1 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_p76_0",
    &setup_memwrite_read_pfd8_0_common,
    { { &setup_memwrite_read_ped8_0_proc1 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_p74_0",
    &setup_memwrite_read_pfd0_0_common,
    { { &setup_memwrite_read_ped0_0_proc1 }, { &setup_memwrite_read_pfd0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_p70_0",
    &setup_memwrite_read_pfc_0_common,
    { { &setup_memwrite_read_ped8_0_proc1 }, { &setup_memwrite_read_pfe_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_p68_0",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pd5_0_proc1 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_p60_0",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pea_0_proc1 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_p4_0",
    &setup_memwrite_read_pf0_0_common,
    { { &setup_memwrite_read_pfa_0_proc1 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_procfinal,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-memwrite_read_p38_0",
    &setup_memwrite_read_pfe_0_common,
    { { &setup_memwrite_read_pfe_0_proc1 }, { &setup_memwrite_read_pee_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p36_0",
    &setup_memwrite_read_pfd8_0_common,
    { { &setup_memwrite_read_pfe_0_proc1 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p34_0",
    &setup_memwrite_read_pfd0_0_common,
    { { &setup_memwrite_read_pfd0_0_proc1 }, { &setup_memwrite_read_ped0_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p30_0",
    &setup_memwrite_read_pfc_0_common,
    { { &setup_memwrite_read_pfe_0_proc1 }, { &setup_memwrite_read_ped8_0_proc1 } },
    &setup_memwrite_read_pfe_0_procfinal,
    &setup_memwrite_read_pfe_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p28_0",
    &setup_memwrite_read_pfa_0_common,
    { { &setup_memwrite_read_pfa_0_proc1 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p20_0",
    &setup_memwrite_read_pf8_0_common,
    { { &setup_memwrite_read_pfa_0_proc1 }, { &setup_memwrite_read_pea_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_final,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_read_p0_0",
    &setup_memwrite_read_pf0_0_common,
    { { &setup_memwrite_read_pfa_0_proc1 }, { &setup_memwrite_read_pfa_0_proc1 } },
    &setup_memwrite_read_pfa_0_procfinal,
    &setup_memwrite_read_pfa_0_procfinal,
    { { &test_memwrite_read_pbc_0_0, 0, "memwrite" },
      { &test_memwrite_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-memwrite_rename_pf8_0",
    &setup_memwrite_rename_pf8_0_common,
    { { &setup_memwrite_rename_pf8_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pf4_0",
    &setup_memwrite_rename_pf4_0_common,
    { { &setup_memwrite_rename_pf8_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pf0_0",
    &setup_memwrite_rename_pf8_0_common,
    { { &setup_memwrite_rename_pf8_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pe_0",
    &setup_memwrite_rename_pe_0_common,
    { { &setup_memwrite_rename_pf8_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_procfinal,
    { { &test_memwrite_rename_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pdc_0",
    &setup_memwrite_rename_pf8_0_common,
    { { &setup_memwrite_rename_pdc_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pda_0",
    &setup_memwrite_rename_pda_0_common,
    { { &setup_memwrite_rename_pda_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pda_0_final,
    { { &test_memwrite_rename_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pda_1",
    &setup_memwrite_rename_pda_1_common,
    { { &setup_memwrite_rename_pdc_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pda_0_final,
    { { &test_memwrite_rename_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pda_2",
    &setup_memwrite_rename_pf4_0_common,
    { { &setup_memwrite_rename_pdc_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pd8_0",
    &setup_memwrite_rename_pf8_0_common,
    { { &setup_memwrite_rename_pdc_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pd0_0",
    &setup_memwrite_rename_pd0_0_common,
    { { &setup_memwrite_rename_pdc_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pdc_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pcc_0",
    &setup_memwrite_rename_pcc_0_common,
    { { &setup_memwrite_rename_pcc_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pca_0",
    &setup_memwrite_rename_pca_0_common,
    { { &setup_memwrite_rename_pca_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pda_0_final,
    { { &test_memwrite_rename_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pca_1",
    &setup_memwrite_rename_pca_1_common,
    { { &setup_memwrite_rename_pcc_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pda_0_final,
    { { &test_memwrite_rename_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pca_2",
    &setup_memwrite_rename_pca_2_common,
    { { &setup_memwrite_rename_pcc_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pc8_0",
    &setup_memwrite_rename_pcc_0_common,
    { { &setup_memwrite_rename_pcc_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pc0_0",
    &setup_memwrite_rename_pc0_0_common,
    { { &setup_memwrite_rename_pcc_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pf8_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pb_0",
    &setup_memwrite_rename_pf8_0_common,
    { { &setup_memwrite_rename_pb_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pb_1",
    &setup_memwrite_rename_pf8_0_common,
    { { &setup_memwrite_rename_pb_1_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pa8_0",
    &setup_memwrite_rename_pf4_0_common,
    { { &setup_memwrite_rename_pa8_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pa8_1",
    &setup_memwrite_rename_pf4_0_common,
    { { &setup_memwrite_rename_pb_1_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pa0_0",
    &setup_memwrite_rename_pf8_0_common,
    { { &setup_memwrite_rename_pb_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_pa0_1",
    &setup_memwrite_rename_pf8_0_common,
    { { &setup_memwrite_rename_pb_1_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_p8_0",
    &setup_memwrite_rename_pd0_0_common,
    { { &setup_memwrite_rename_pb_0_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_p8_1",
    &setup_memwrite_rename_pe_0_common,
    { { &setup_memwrite_rename_pb_1_proc0 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_procfinal,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_p6_0",
    &setup_memwrite_rename_pf8_0_common,
    { { &setup_memwrite_rename_pf8_0_proc1 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_p50_0",
    &setup_memwrite_rename_pf4_0_common,
    { { &setup_memwrite_rename_pf8_0_proc1 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_p4_0",
    &setup_memwrite_rename_pf8_0_common,
    { { &setup_memwrite_rename_pf8_0_proc1 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_final,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_rename_p0_0",
    &setup_memwrite_rename_pe_0_common,
    { { &setup_memwrite_rename_pf8_0_proc1 }, { &setup_memwrite_rename_pf8_0_proc1 } },
    &setup_memwrite_rename_pf8_0_procfinal,
    &setup_memwrite_rename_pf8_0_procfinal,
    { { &test_memwrite_rename_pb_0_0, 0, "memwrite" },
      { &test_memwrite_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-memwrite_stat_pf_0",
    &setup_memwrite_stat_pf_0_common,
    { { &setup_memwrite_stat_pf_0_proc0 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_final,
    { { &test_memwrite_stat_pf_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_pe_0",
    &setup_memwrite_stat_pe_0_common,
    { { &setup_memwrite_stat_pf_0_proc0 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_procfinal,
    { { &test_memwrite_stat_pf_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_pd8_0",
    &setup_memwrite_stat_pf_0_common,
    { { &setup_memwrite_stat_pd8_0_proc0 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_final,
    { { &test_memwrite_stat_pd8_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_pd0_0",
    &setup_memwrite_stat_pd0_0_common,
    { { &setup_memwrite_stat_pd8_0_proc0 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_final,
    { { &test_memwrite_stat_pd8_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_pc8_0",
    &setup_memwrite_stat_pc8_0_common,
    { { &setup_memwrite_stat_pc8_0_proc0 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_final,
    { { &test_memwrite_stat_pf_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pc8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_pc0_0",
    &setup_memwrite_stat_pc0_0_common,
    { { &setup_memwrite_stat_pc8_0_proc0 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_final,
    { { &test_memwrite_stat_pf_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_pa_0",
    &setup_memwrite_stat_pf_0_common,
    { { &setup_memwrite_stat_pa_0_proc0 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_final,
    { { &test_memwrite_stat_pa_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_pa_1",
    &setup_memwrite_stat_pf_0_common,
    { { &setup_memwrite_stat_pa_1_proc0 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_final,
    { { &test_memwrite_stat_pa_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_p8_0",
    &setup_memwrite_stat_pd0_0_common,
    { { &setup_memwrite_stat_pa_0_proc0 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_final,
    { { &test_memwrite_stat_pa_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_p8_1",
    &setup_memwrite_stat_pe_0_common,
    { { &setup_memwrite_stat_pa_1_proc0 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_procfinal,
    { { &test_memwrite_stat_pa_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_p4_0",
    &setup_memwrite_stat_pf_0_common,
    { { &setup_memwrite_stat_pf_0_proc1 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_final,
    { { &test_memwrite_stat_pa_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_stat_p0_0",
    &setup_memwrite_stat_pe_0_common,
    { { &setup_memwrite_stat_pf_0_proc1 }, { &setup_memwrite_stat_pf_0_proc1 } },
    &setup_memwrite_stat_pf_0_procfinal,
    &setup_memwrite_stat_pf_0_procfinal,
    { { &test_memwrite_stat_pa_0_0, 0, "memwrite" },
      { &test_memwrite_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-memwrite_unlink_pf0_0",
    &setup_memwrite_unlink_pf0_0_common,
    { { &setup_memwrite_unlink_pf0_0_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_final,
    { { &test_memwrite_unlink_pf0_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_pe_0",
    &setup_memwrite_unlink_pe_0_common,
    { { &setup_memwrite_unlink_pf0_0_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_procfinal,
    { { &test_memwrite_unlink_pf0_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_pd8_0",
    &setup_memwrite_unlink_pd8_0_common,
    { { &setup_memwrite_unlink_pd8_0_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pd8_0_final,
    { { &test_memwrite_unlink_pd8_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_pd8_1",
    &setup_memwrite_unlink_pf0_0_common,
    { { &setup_memwrite_unlink_pd8_1_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_final,
    { { &test_memwrite_unlink_pd8_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_pd0_0",
    &setup_memwrite_unlink_pd0_0_common,
    { { &setup_memwrite_unlink_pd8_1_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_final,
    { { &test_memwrite_unlink_pd8_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_pc8_0",
    &setup_memwrite_unlink_pc8_0_common,
    { { &setup_memwrite_unlink_pd8_0_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pd8_0_final,
    { { &test_memwrite_unlink_pf0_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_pc8_1",
    &setup_memwrite_unlink_pc8_1_common,
    { { &setup_memwrite_unlink_pd8_1_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_final,
    { { &test_memwrite_unlink_pf0_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_pc0_0",
    &setup_memwrite_unlink_pc0_0_common,
    { { &setup_memwrite_unlink_pd8_1_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_final,
    { { &test_memwrite_unlink_pf0_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_pa_0",
    &setup_memwrite_unlink_pf0_0_common,
    { { &setup_memwrite_unlink_pa_0_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_final,
    { { &test_memwrite_unlink_pa_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_pa_1",
    &setup_memwrite_unlink_pf0_0_common,
    { { &setup_memwrite_unlink_pa_1_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_final,
    { { &test_memwrite_unlink_pa_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_p8_0",
    &setup_memwrite_unlink_pd0_0_common,
    { { &setup_memwrite_unlink_p8_0_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_final,
    { { &test_memwrite_unlink_pa_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_p8_1",
    &setup_memwrite_unlink_pe_0_common,
    { { &setup_memwrite_unlink_pa_1_proc0 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_procfinal,
    { { &test_memwrite_unlink_pa_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_p4_0",
    &setup_memwrite_unlink_pf0_0_common,
    { { &setup_memwrite_unlink_pf0_0_proc1 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_final,
    { { &test_memwrite_unlink_pa_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_unlink_p0_0",
    &setup_memwrite_unlink_pe_0_common,
    { { &setup_memwrite_unlink_pf0_0_proc1 }, { &setup_memwrite_unlink_pf0_0_proc1 } },
    &setup_memwrite_unlink_pf0_0_procfinal,
    &setup_memwrite_unlink_pf0_0_procfinal,
    { { &test_memwrite_unlink_pa_0_0, 0, "memwrite" },
      { &test_memwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-memwrite_write_pff_0",
    &setup_memwrite_write_pff_0_common,
    { { &setup_memwrite_write_pff_0_proc0 }, { &setup_memwrite_write_pff_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pfe_0",
    &setup_memwrite_write_pfe_0_common,
    { { &setup_memwrite_write_pfe_0_proc0 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pfc_0",
    &setup_memwrite_write_pfc_0_common,
    { { &setup_memwrite_write_pfc_0_proc0 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pfa_0",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pfa_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pf8_0",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pfa_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pf0_0",
    &setup_memwrite_write_pf0_0_common,
    { { &setup_memwrite_write_pf0_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_procfinal,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pef_0",
    &setup_memwrite_write_pff_0_common,
    { { &setup_memwrite_write_pef_0_proc0 }, { &setup_memwrite_write_pef_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pee_0",
    &setup_memwrite_write_pfe_0_common,
    { { &setup_memwrite_write_pee_0_proc0 }, { &setup_memwrite_write_pee_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pec_0",
    &setup_memwrite_write_pfc_0_common,
    { { &setup_memwrite_write_pee_0_proc0 }, { &setup_memwrite_write_pec_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pea_0",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pf0_0_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pe8_0",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pf0_0_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pe0_0",
    &setup_memwrite_write_pf0_0_common,
    { { &setup_memwrite_write_pf0_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_procfinal,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pdf8_0",
    &setup_memwrite_write_pdf8_0_common,
    { { &setup_memwrite_write_pdf8_0_proc0 }, { &setup_memwrite_write_pff_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pdf0_0",
    &setup_memwrite_write_pdf8_0_common,
    { { &setup_memwrite_write_pdf0_0_proc0 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pde_0",
    &setup_memwrite_write_pdf8_0_common,
    { { &setup_memwrite_write_pde_0_proc0 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pdd8_0",
    &setup_memwrite_write_pdd8_0_common,
    { { &setup_memwrite_write_pdd8_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pdd8_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pdd8_1",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pdd8_1_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pdc0_0",
    &setup_memwrite_write_pdc0_0_common,
    { { &setup_memwrite_write_pdc0_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pdd8_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pdc0_1",
    &setup_memwrite_write_pdc0_1_common,
    { { &setup_memwrite_write_pdc0_1_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pd8_0",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pd8_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pd78_0",
    &setup_memwrite_write_pdf8_0_common,
    { { &setup_memwrite_write_pd78_0_proc0 }, { &setup_memwrite_write_pef_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pd70_0",
    &setup_memwrite_write_pdf8_0_common,
    { { &setup_memwrite_write_pd70_0_proc0 }, { &setup_memwrite_write_pee_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pd6_0",
    &setup_memwrite_write_pdf8_0_common,
    { { &setup_memwrite_write_pd70_0_proc0 }, { &setup_memwrite_write_pec_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pd58_0",
    &setup_memwrite_write_pdd8_0_common,
    { { &setup_memwrite_write_pd58_0_proc0 }, { &setup_memwrite_write_pd58_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pdd8_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pd58_1",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pd58_1_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pd40_0",
    &setup_memwrite_write_pdc0_0_common,
    { { &setup_memwrite_write_pd58_0_proc0 }, { &setup_memwrite_write_pd40_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pdd8_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pd40_1",
    &setup_memwrite_write_pdc0_1_common,
    { { &setup_memwrite_write_pd40_1_proc0 }, { &setup_memwrite_write_pd40_1_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pd0_0",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pd8_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pdf8_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pcf8_0",
    &setup_memwrite_write_pcf8_0_common,
    { { &setup_memwrite_write_pdf8_0_proc0 }, { &setup_memwrite_write_pff_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pcf0_0",
    &setup_memwrite_write_pcf0_0_common,
    { { &setup_memwrite_write_pdf0_0_proc0 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pce_0",
    &setup_memwrite_write_pcf0_0_common,
    { { &setup_memwrite_write_pde_0_proc0 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pcd0_0",
    &setup_memwrite_write_pcd0_0_common,
    { { &setup_memwrite_write_pcd0_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pcd0_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pcd0_1",
    &setup_memwrite_write_pcd0_1_common,
    { { &setup_memwrite_write_pcd0_1_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pdd8_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pcd0_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pcc0_0",
    &setup_memwrite_write_pcc0_0_common,
    { { &setup_memwrite_write_pdd8_1_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pcd0_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pcc0_1",
    &setup_memwrite_write_pcc0_1_common,
    { { &setup_memwrite_write_pcc0_1_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pc8_0",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pd8_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pc78_0",
    &setup_memwrite_write_pcf8_0_common,
    { { &setup_memwrite_write_pd78_0_proc0 }, { &setup_memwrite_write_pef_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pc70_0",
    &setup_memwrite_write_pcf0_0_common,
    { { &setup_memwrite_write_pd70_0_proc0 }, { &setup_memwrite_write_pee_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pc6_0",
    &setup_memwrite_write_pcf0_0_common,
    { { &setup_memwrite_write_pd70_0_proc0 }, { &setup_memwrite_write_pec_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pc50_0",
    &setup_memwrite_write_pc50_0_common,
    { { &setup_memwrite_write_pd8_0_proc0 }, { &setup_memwrite_write_pd58_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pcd0_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pc50_1",
    &setup_memwrite_write_pcd0_1_common,
    { { &setup_memwrite_write_pc50_1_proc0 }, { &setup_memwrite_write_pc50_1_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pdd8_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pcd0_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pc40_0",
    &setup_memwrite_write_pcc0_0_common,
    { { &setup_memwrite_write_pd58_1_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pcd0_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pc40_1",
    &setup_memwrite_write_pcc0_1_common,
    { { &setup_memwrite_write_pd8_0_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pc0_0",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pd8_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pff_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_pbe_0",
    &setup_memwrite_write_pff_0_common,
    { { &setup_memwrite_write_pbe_0_proc0 }, { &setup_memwrite_write_pff_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pbe_1",
    &setup_memwrite_write_pff_0_common,
    { { &setup_memwrite_write_pbe_1_proc0 }, { &setup_memwrite_write_pff_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pbc_0",
    &setup_memwrite_write_pfe_0_common,
    { { &setup_memwrite_write_pbc_0_proc0 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pbc_1",
    &setup_memwrite_write_pfe_0_common,
    { { &setup_memwrite_write_pbc_1_proc0 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pb8_0",
    &setup_memwrite_write_pfc_0_common,
    { { &setup_memwrite_write_pb8_0_proc0 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pb8_1",
    &setup_memwrite_write_pfc_0_common,
    { { &setup_memwrite_write_pb8_1_proc0 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pb4_0",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pb4_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pb4_1",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pb4_1_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pb4_2",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pb4_2_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pb0_0",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pb4_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pb0_1",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pb4_1_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pb0_2",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pb4_2_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pa_0",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pa_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_pa_1",
    &setup_memwrite_write_pf0_0_common,
    { { &setup_memwrite_write_pa_1_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_procfinal,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_p9e_0",
    &setup_memwrite_write_pff_0_common,
    { { &setup_memwrite_write_p9e_0_proc0 }, { &setup_memwrite_write_pef_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p9e_1",
    &setup_memwrite_write_pff_0_common,
    { { &setup_memwrite_write_p9e_1_proc0 }, { &setup_memwrite_write_pef_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p9c_0",
    &setup_memwrite_write_pfe_0_common,
    { { &setup_memwrite_write_p9c_0_proc0 }, { &setup_memwrite_write_pee_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p9c_1",
    &setup_memwrite_write_pfe_0_common,
    { { &setup_memwrite_write_p9c_1_proc0 }, { &setup_memwrite_write_pee_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p98_0",
    &setup_memwrite_write_pfc_0_common,
    { { &setup_memwrite_write_p98_0_proc0 }, { &setup_memwrite_write_pec_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p98_1",
    &setup_memwrite_write_pfc_0_common,
    { { &setup_memwrite_write_p9c_1_proc0 }, { &setup_memwrite_write_pec_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p94_0",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_p94_0_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p94_1",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pa_0_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p94_2",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pa_1_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p90_0",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_p94_0_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p90_1",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pa_0_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p90_2",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pa_1_proc0 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p8_0",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pa_0_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p8_1",
    &setup_memwrite_write_pf0_0_common,
    { { &setup_memwrite_write_pa_1_proc0 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_procfinal,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p7c_0",
    &setup_memwrite_write_pff_0_common,
    { { &setup_memwrite_write_pef_0_proc1 }, { &setup_memwrite_write_pff_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_p78_0",
    &setup_memwrite_write_pfe_0_common,
    { { &setup_memwrite_write_pee_0_proc1 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_p70_0",
    &setup_memwrite_write_pfc_0_common,
    { { &setup_memwrite_write_pec_0_proc1 }, { &setup_memwrite_write_pfe_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_p68_0",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pea_0_proc1 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_p60_0",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pea_0_proc1 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_p4_0",
    &setup_memwrite_write_pf0_0_common,
    { { &setup_memwrite_write_pfa_0_proc1 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_procfinal,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-memwrite_write_p3c_0",
    &setup_memwrite_write_pff_0_common,
    { { &setup_memwrite_write_pff_0_proc1 }, { &setup_memwrite_write_pef_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p38_0",
    &setup_memwrite_write_pfe_0_common,
    { { &setup_memwrite_write_pfe_0_proc1 }, { &setup_memwrite_write_pee_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p30_0",
    &setup_memwrite_write_pfc_0_common,
    { { &setup_memwrite_write_pfe_0_proc1 }, { &setup_memwrite_write_pec_0_proc1 } },
    &setup_memwrite_write_pff_0_procfinal,
    &setup_memwrite_write_pff_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p28_0",
    &setup_memwrite_write_pfa_0_common,
    { { &setup_memwrite_write_pfa_0_proc1 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p20_0",
    &setup_memwrite_write_pf8_0_common,
    { { &setup_memwrite_write_pfa_0_proc1 }, { &setup_memwrite_write_pea_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_final,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-memwrite_write_p0_0",
    &setup_memwrite_write_pf0_0_common,
    { { &setup_memwrite_write_pfa_0_proc1 }, { &setup_memwrite_write_pfa_0_proc1 } },
    &setup_memwrite_write_pfa_0_procfinal,
    &setup_memwrite_write_pfa_0_procfinal,
    { { &test_memwrite_write_pbe_0_0, 0, "memwrite" },
      { &test_memwrite_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_2",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_3",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_4",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_5",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_5_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_6",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_7",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_5_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_8",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_9",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_10",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_11",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_12",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_13",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_14",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_15",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_16",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_17",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_18",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_19",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_20",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_20_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_21",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_20_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_22",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_22_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_23",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_23_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_24",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_22_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_25",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_23_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_26",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_26_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_27",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_27_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_28",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_28_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_29",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_27_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_30",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_28_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_31",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_32",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_33",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_34",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_35",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_35_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_36",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_26_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_37",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_37_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_38",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_39",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_40",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_40_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_41",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_42",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_43",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_43_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_44",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_44_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_45",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_45_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_46",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_47",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_48",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_49",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_50",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_51",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_52",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_35_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_53",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_37_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_54",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_55",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_56",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_57",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_43_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_58",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_59",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_40_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_60",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_61",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_44_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_62",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_45_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_63",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_64",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_65",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_66",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_26_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_67",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_37_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_68",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_45_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_69",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_43_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_70",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_35_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_71",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_72",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_44_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_73",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_74",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_40_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_75",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_76",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_77",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_78",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_79",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_80",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_26_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_81",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_37_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_82",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_83",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_43_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_84",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_45_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_85",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_86",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_35_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_87",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_44_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_88",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_89",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_40_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_90",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_91",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_6_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_92",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_93",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf8_94",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf6_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf6_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf6_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf6_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf6_4",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_2_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_3_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_6_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_7",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_7_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_8",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_8_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_9",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_10",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_10_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_11",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_11_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_12",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_13",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_14",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_15",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_16",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_16_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_17",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_18",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_18_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_19",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_20",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_20_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_21",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_22",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_22_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_23",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_23_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_24",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_24_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_25",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_25_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_26",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_26_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_27",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_27_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_28",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_29",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_29_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_30",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_31",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_32",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_33",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_33_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_34",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_34_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_35",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_35_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_36",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_36_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_37",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_37_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_38",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_39",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_40",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_40_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_41",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_41_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_42",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_43",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_43_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_44",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_44_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_45",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_45_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_46",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_47",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_48",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_49",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_50",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_51",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_52",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_52_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_53",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_53_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_54",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_54_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_55",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_55_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_56",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_56_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_57",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_57_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_58",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_58_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_59",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_59_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_60",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_60_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_61",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_61_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_62",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_62_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_63",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_63_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_64",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_64_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_65",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_65_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_66",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_66_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_67",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_67_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_68",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_68_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_69",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_69_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_70",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_70_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_71",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_71_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_72",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_72_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_73",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_73_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf4_74",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_74_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf0_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pf0_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_2",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_3",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_4",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_5",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_6",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_7",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_8",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_9",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_10",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_11",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_12",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_13",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_14",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_15",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_16",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_17",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_18",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pec_19",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe6_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe6_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe6_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe6_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe6_4",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_3_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_3_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_11_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_8",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_9",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_10",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_11",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_11_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_12",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_13",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_14",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_15",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_16",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_17",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_18",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_19",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_20",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_21",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_22",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_23",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_24",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_25",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_26",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_27",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_28",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_29",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_30",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_31",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_32",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_33",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_34",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_35",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_36",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_36_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_37",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_37_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_38",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_39",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_40",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_40_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_41",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_42",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_43",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_43_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_44",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_44_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_45",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_46",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_47",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_48",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_49",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_49_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_50",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_51",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_52",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_52_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_53",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_54",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_36_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_55",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_56",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_37_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_57",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_58",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_40_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_59",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_60",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_61",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_43_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_62",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_44_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_63",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_64",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_65",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_49_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_66",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_67",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_68",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_69",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe50_70",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_52_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe0_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pe0_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pd8_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pd6_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pd6_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pd4_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pd0_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pcc_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pcc_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pc6_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pc6_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pc50_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pc50_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pc0_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf8_0_0, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbe_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbe_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbe_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbe_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbd8_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbd8_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbd8_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbd8_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbd8_4",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbd8_5",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbd0_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbd0_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbd0_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbc_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbc_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_4",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_5",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_6",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_6_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_7",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_8",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_6_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_9",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_9_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_10",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pe50_44_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_11",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_12",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pe50_44_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_13",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_13_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_14",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_13_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_15",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_15_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_16",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_15_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_17",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pe50_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_18",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_18_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_19",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_19_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_20",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_20_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_21",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pe50_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_22",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_18_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_23",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_19_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_24",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_20_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_25",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pe50_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_26",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_27",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pe50_52_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_28",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_29",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pe50_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_30",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_31",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pe50_52_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_32",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_33",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_33_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_34",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_34_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_35",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_35_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_36",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_34_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_37",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_35_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_38",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_38_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_39",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_33_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_40",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_38_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_41",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_41_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_42",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_42_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_43",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_43_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_44",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_45",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_45_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_46",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_47",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_47_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_48",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_48_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_49",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_50",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_9_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_51",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_42_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_52",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_41_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_53",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_43_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_54",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_55",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_45_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_56",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_57",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_47_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pbb0_58",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_48_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb98_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb98_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb98_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb98_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb98_4",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb98_5",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_2",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbd0_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_3",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbd0_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_4",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_11_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_6",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_11_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_8",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_9",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_43_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_10",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_11",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_43_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_12",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_13_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_13",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_13_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_14",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_15",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_16",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_44_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_17",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_18",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_19",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_20",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_49_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_21",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_22",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_23",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_52_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_24",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_15_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_25",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_26",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_27",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_19_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_28",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_29",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_33_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_30",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_30_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_31",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_38_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_32",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_44_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_33",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_34",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_35",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_36",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_49_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_37",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_38",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_39",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_52_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_40",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_15_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_41",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_42",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_43",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_19_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_44",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_45",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_33_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_46",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb94_30_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb94_47",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_38_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb8_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb8_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb6_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb6_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb58_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb58_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb58_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb58_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb50_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb50_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb4_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb4_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb30_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb30_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb30_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb30_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb18_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb18_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb18_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb18_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb14_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb14_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb14_2",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pb14_2_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb14_3",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pb14_2_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb14_4",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb14_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pb14_2_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb14_6",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb14_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pb14_2_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb0_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pb0_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_2_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_3_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_6_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_7",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_8",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_8_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_9",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_7_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_10",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_10_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_11",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_11_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_12",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_13",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_14",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_15",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_16",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_20_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_17",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_18",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_18_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_19",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_20",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_20_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_21",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_22",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_22_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_23",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_23_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_24",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_25",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_26",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_27",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_27_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_28",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_29",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_29_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_30",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_31",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_32",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_33",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_33_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_34",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_34_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_35",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_35_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_36",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_36_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_37",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_37_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_38",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_39",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_40",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_40_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_41",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_41_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_42",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_43",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_43_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_44",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_44_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_45",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_45_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_46",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_47",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_48",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_49",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_50",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_50_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_51",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_51_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_52",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_52_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_53",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_53_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_54",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_54_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_55",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_55_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_56",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_57",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_57_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_58",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_59",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_59_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_60",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_60_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_61",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_61_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_62",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_62_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_63",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_74_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_64",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_66_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_65",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_63_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_66",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_66_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_67",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_67_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_68",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_68_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_69",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_69_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_70",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_70_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_71",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_71_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_72",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_62_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_73",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_73_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pae_74",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_74_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pae_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad8_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad8_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pad8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_0",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_1",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_2",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_3",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_4",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_5",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_5_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_6",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_5_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_7",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_7_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_8",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_9",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_7_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_10",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_11",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_11_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_12",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_13",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_14",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_15",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_11_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_16",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_17",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_18",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_5_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_19",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_20",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_11_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_21",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_22",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_5_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_23",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_11_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_24",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_25",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_7_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_26",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_27",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_28",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_7_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_29",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_30",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_31",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_32",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_33",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_34",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_35",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_36",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_37",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_38",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_39",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_40",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_41",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_42",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_43",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_44",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_6_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_45",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_46",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_47",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_48",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_49",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_50",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_51",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_52",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_53",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_7_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_54",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_54_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_55",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_7_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_56",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_54_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_57",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_57_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_58",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_6_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_59",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_57_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_60",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_6_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_61",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_57_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_62",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_6_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_63",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_57_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_64",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_65",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_66",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_67",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_68",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_69",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_69_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_70",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_70_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_71",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_72",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_73",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_74",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_75",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_75_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_76",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_77",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_69_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_78",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_70_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_79",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_80",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_81",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_69_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_82",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_70_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_83",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_84",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_85",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_86",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_87",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_69_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_88",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_89",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_90",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_75_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_91",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_91_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_92",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_92_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_93",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_93_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_94",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_94_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_95",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_96",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_97",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_98",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_98_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_99",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_23_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_100",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_100_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_101",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_101_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_102",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_92_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_103",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_93_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_104",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_94_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_105",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_106",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_107",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_108",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_98_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_109",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_23_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_110",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_100_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_111",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_101_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_112",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_92_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_113",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_93_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_114",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_94_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_115",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_116",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_117",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_118",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_98_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_119",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_23_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_120",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_100_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_121",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_101_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_122",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_92_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_123",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_93_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_124",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_94_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_125",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_126",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_127",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_128",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_98_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_129",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_23_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_130",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_100_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_131",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_101_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_132",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_132_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_133",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_133_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_134",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_134_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_135",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_135_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_136",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_136_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_137",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_138",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_138_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_139",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_139_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_140",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_140_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_141",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_27_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_142",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_142_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_143",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_143_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_144",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_144_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_145",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_145_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_146",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_146_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_147",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_147_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_148",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_139_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_149",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_140_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_150",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_27_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_151",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_142_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_152",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_143_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_153",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_133_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_154",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_134_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_155",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_135_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_156",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_136_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_157",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_158",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_138_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_159",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_144_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_160",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_145_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_161",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_146_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_162",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_147_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_163",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_139_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_164",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_140_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_165",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_27_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_166",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_142_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_167",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_143_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_168",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_139_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_169",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_140_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_170",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_27_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_171",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_142_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_172",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_143_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_173",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_91_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_174",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_174_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_175",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_175_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_176",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_176_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_177",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_177_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_178",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_178_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_179",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_179_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_180",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_180_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_181",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_181_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_182",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_182_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_183",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_184",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_184_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_185",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_185_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_186",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_187",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_187_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_188",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_188_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_189",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_179_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_190",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_190_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_191",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_192",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_192_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_193",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_193_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_194",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_195",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_196",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_197",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_197_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_198",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_91_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_199",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_174_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_200",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_175_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_201",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_176_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_202",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_177_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_203",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_178_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_204",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_180_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_205",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_181_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_206",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_182_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_207",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_208",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_184_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_209",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_209_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_210",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_210_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_211",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_212",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_212_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_213",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_213_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_214",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_185_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_215",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_216",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_187_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_217",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_188_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_218",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_179_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_219",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_219_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_220",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_220_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_221",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_43_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_222",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_222_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_223",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_223_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_224",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_190_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_225",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_226",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_192_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_227",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_193_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_228",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_209_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_229",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_210_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_230",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_231",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_212_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_232",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_213_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_233",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_185_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_234",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_235",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_187_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_236",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_188_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_237",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_219_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_238",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_220_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_239",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_43_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_240",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_222_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_241",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_223_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_242",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_190_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_243",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_244",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_192_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_245",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_193_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_246",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_91_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_247",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_185_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_248",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_249",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_187_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_250",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_188_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_251",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_179_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_252",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_190_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_253",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_254",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_192_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_255",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_193_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_256",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_257",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_258",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_259",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_197_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_260",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_132_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_261",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_262",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_262_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_263",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_264",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_265",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_266",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_266_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_267",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_268",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_268_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_269",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_270",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_271",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_272",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_272_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_273",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_273_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_274",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_274_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_274_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_275",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_275_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_275_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_276",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_277",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_262_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_278",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_279",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_280",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_268_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_281",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_282",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_282_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_283",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_283_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_284",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_284_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_285",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_213_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_286",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_147_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_287",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_223_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_288",
    &setup_mmap_mmap_pad0_288_common,
    { { &setup_mmap_mmap_pad0_288_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_288_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_289",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_289_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_290",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_290_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_291",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_291_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_292",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_292_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_293",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_293_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_294",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_294_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_295",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_295_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_296",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_296_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_297",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_297_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_298",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_298_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_299",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_299_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_300",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_300_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_301",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_301_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_302",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_302_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_303",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_303_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_304",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_304_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_305",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_305_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_306",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_306_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_307",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_307_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_308",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_308_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_309",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_309_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_310",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_310_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_311",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_311_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_312",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_272_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_313",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_273_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_314",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_274_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_315",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_289_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_316",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_295_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_317",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_296_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_318",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_266_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_319",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_290_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_320",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_291_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_321",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_292_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_322",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_293_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_323",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_294_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_324",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_297_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_325",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_298_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_326",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_299_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_327",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_300_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_328",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_301_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_329",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_302_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_330",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_303_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_331",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_304_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_332",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_305_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_333",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_306_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_334",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_307_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_335",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_308_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_336",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_309_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_337",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_310_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_338",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_311_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_339",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_340",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_262_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_341",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_342",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_343",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_268_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_344",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_345",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_132_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_346",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_272_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_347",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_273_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_348",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_274_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_349",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_289_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_350",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_295_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_351",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_296_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_352",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_266_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_353",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_290_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_354",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_291_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_355",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_292_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_356",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_293_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_357",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_294_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_358",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_297_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_359",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_298_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_360",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_299_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_361",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_300_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_362",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_301_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_363",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_302_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_364",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_303_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_365",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_304_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_366",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_305_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_367",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_306_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_368",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_307_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_369",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_308_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_370",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_309_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_371",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_310_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pf4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_372",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_311_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_68_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_373",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_374",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_262_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_375",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_376",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_377",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_268_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_378",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_379",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_295_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_380",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_282_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_381",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_147_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_382",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_283_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_383",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_213_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_384",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_284_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_385",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_223_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_386",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_272_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_387",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_273_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_388",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_274_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_389",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_289_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_390",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_290_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_391",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_291_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_392",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_292_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_393",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_293_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_394",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_294_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_395",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_296_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_396",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_297_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_397",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_298_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_398",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_266_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_399",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_299_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_400",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_300_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_401",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_301_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_402",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_302_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_403",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_303_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_404",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_304_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_405",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_305_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_406",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_306_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_407",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_307_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_408",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_308_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_409",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_309_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_410",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_310_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_411",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_311_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_76_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_412",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_413",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_414",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_415",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_416",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_417",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_418",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_419",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_420",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_421",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_422",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_423",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_424",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_425",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_426",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_427",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_428",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_429",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_430",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_431",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_432",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_433",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_434",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pad0_435",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pac_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_8_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_8",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_9",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_10",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_11",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_8_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_12",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_13",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_14",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_15",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_16",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_17",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_18",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_19",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_57_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_20",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_21",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_22",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_23",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_59_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_24",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_25",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_26",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_27",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_57_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_28",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pab0_29",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_59_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa98_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa98_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pad8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_0",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_1",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_2",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_3",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_4",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pa94_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_5",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pa94_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_6",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pa94_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_7",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pa94_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_8",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_9",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_10",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_11",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_12",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_13",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_14",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_15",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_16",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pa94_16_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_17",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_18",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pa94_16_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_19",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_20",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pa94_16_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_21",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_22",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pa94_16_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_23",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_24",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_25",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_26",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_27",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_28",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_29",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_30",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_31",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_32",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_33",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_34",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_35",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_36",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_37",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_38",
    &setup_mmap_mmap_pa94_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pa94_0_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa94_39",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pad0_2_0, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa8_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa6_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa58_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa58_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa50_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa4_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa30_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa30_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa18_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa18_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa14_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa14_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa14_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa14_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_pa0_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pd4_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p9c_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p9c_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p9b_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p9b_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p9a_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p98_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p98_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_2",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_3",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_4",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_5",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_6",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_7",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_8",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_36_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_9",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_10",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_11",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_40_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_12",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_13",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_14",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_15",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_16",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_36_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_17",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_18",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p96_19",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_40_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p93_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p93_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_3_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_5",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_3_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_7",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_8",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_36_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_9",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_10",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_11",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_12",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_37_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_13",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_14",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_15",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_40_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_16",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_36_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_17",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_18",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_37_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_19",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_38_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_20",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_21",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_39_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_22",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p928_23",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_40_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p90_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p90_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p8c_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p8b_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p8b_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p8a_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p88_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p86_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p86_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p83_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p83_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p828_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p828_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p828_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p828_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p80_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pf0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_2",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_3",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_4",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_5",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_6",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_7",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_8",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_9",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_10",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_11",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_12",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_13",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_14",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_15",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_16",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_17",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_18",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p7c_19",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_4",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_9_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_5",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_6",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_7",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_8",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_9",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_10",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_11",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_12",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_13",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_14",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_15",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_16",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_17",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_45_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_18",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_18_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_19",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_20",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_18_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_21",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_21_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_22",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_22_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_23",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_23_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_24",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_41_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_25",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_26",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_42_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_27",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_27_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_28",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_43_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_29",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_29_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_30",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_22_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_31",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_21_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_32",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_23_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_33",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_41_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_34",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_35",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_42_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_36",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_27_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_37",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_43_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_38",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_29_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_39",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_39_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_40",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_40_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_41",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_41_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_42",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_40_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_43",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_39_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_44",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_41_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_45",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_47_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_46",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_47",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_48",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_48_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_49",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_48_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_50",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_51",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_52",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_48_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_53",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_47_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_54",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_55",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_48_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p770_56",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_p770_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_5",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_3_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_3_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_7",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_3_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_8",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_3_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_9",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_10",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_11",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_11_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_12",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_13",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_14",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_15",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_11_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_16",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_17",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_18",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_19",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_20",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_21",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_11_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_22",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_23",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_11_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_24",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_25",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_26",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_27",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_28",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_29",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_30",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_31",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_32",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_33",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_34",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_35",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_36",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_37",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_38",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_39",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_40",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_41",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_42",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_43",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_44",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_45",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_46",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_47",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_48",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_49",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_50",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_51",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_13_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_52",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_53",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_54",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_55",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_56",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_57",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_14_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_58",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p750_59",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_2",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_3",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_4",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_5",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_6",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_7",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_8",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_9",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_10",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_11",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_12",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_32_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_13",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_31_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_14",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_33_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_15",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_16",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_17",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_18",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p72_19",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p6e_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p6e_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p6e_2",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p6e_3",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p670_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p670_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p670_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p670_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p670_4",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p670_5",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p670_6",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p670_7",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p670_8",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p670_9",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_8",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_9",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_10",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_11",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_12",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_13",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_14",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_15",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_16",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_17",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_18",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_19",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_20",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_21",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p658_22",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p62_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p62_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p62_2",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p62_3",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p5c_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p5c_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p570_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p570_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p570_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p570_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p550_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p550_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p52_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p52_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p4e_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p4e_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p4e_2",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p4e_3",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p470_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p470_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p470_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p470_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p458_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p458_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p458_2",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p458_3",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p42_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p42_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pec_2_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3e_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3e_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3e_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3e_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3d8_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3d8_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3d8_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3d8_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3d8_4",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3d8_5",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3d0_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3d0_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbd0_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3c_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3c_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_4",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_5",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_6",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_13_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_7",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_8",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_9",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p3b0_10",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbb0_13_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p398_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p398_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p398_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p398_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p398_4",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pbd8_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p398_5",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p394_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p394_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf4_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p394_2",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbd0_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p394_3",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbd0_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p394_4",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p394_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_13_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p394_6",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pe50_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p394_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pbb0_13_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p38_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p38_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p36_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p36_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p358_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p358_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p358_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p358_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p350_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p350_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p34_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p34_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p330_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p330_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p330_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p330_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p318_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p318_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p318_2",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p318_3",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p314_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p314_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p314_2",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p314_3",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pb50_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p314_4",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pb14_2_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p314_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pb14_2_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p314_6",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pb14_2_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p314_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pb14_2_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p30_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p30_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pd6_1_proc1 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe6_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_5",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_7",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_8",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_9",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_10",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_11",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_8_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_12",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_13",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_14",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_15",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_8_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_16",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_17",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_18",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_19",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_20",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_21",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_8_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_22",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_23",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_8_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_24",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_25",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_26",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_27",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_75_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_28",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_29",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_30",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_31",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_32",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_33",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_75_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_34",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_35",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_36",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_37",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_75_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_38",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_39",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_75_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_40",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_41",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_42",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_43",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_44",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_45",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_46",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_47",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_48",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_49",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_197_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_50",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_51",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_52",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_53",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_54",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_197_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_55",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_56",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_57",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_58",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_59",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_197_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_60",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_61",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_62",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_197_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_63",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_64",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_65",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_66",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_67",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_68",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_69",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_70",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_71",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_72",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_73",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_57_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_74",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_75",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_59_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_76",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_29_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_77",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_78",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_79",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_80",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_81",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_82",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_83",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_57_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_84",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_85",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_59_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_86",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_29_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_87",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_88",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_89",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_90",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_91",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_92",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_93",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_57_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_94",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_95",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_59_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_96",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_29_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_97",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_98",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_99",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_100",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_101",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_102",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_103",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_57_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_104",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_105",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_59_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_106",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_29_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_107",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_108",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_109",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_110",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_111",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_27_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_112",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_113",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_114",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_115",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_116",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_27_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_117",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_118",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_119",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_120",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_121",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_27_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_122",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_123",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_124",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_42_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_125",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2f0_126",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_27_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_p2f0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_8_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_2",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pad8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_3",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_4",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pad8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_6",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_8_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_8",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_9",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_10",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_57_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_11",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_12",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_59_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_13",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_14",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_15",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_16",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_27_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_17",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_18",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_29_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_19",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_28_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_20",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_21",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_26_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_22",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2f0_51_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_23",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_27_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_24",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_57_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_25",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_25_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_26",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_59_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_27",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_29_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_28",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_29",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_29_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_30",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_18_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_31",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_31_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_32",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_33",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_48_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_34",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_34_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_35",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_36",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_36_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_37",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_38",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_39",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_29_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_40",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_18_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_41",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_34_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_42",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_46_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_43",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_31_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_44",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_32_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_45",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_48_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_46",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p2dc_36_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2dc_47",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_p770_50_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_0",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_1",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_2",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_3",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_4",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_11_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_5",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_11_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_6",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_11_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_7",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_11_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_8",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_9",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_10",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_11",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_12",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_13",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_14",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_15",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_9_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_16",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_17",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_18",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_19",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_20",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_5_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_21",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_22",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_23",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_24",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_25",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_26",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_5_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_27",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_28",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_29",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_30",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_41_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_31",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_32",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_33",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_262_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_34",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_35",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_36",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_93_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_37",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_38",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_39",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_40",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_41",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_42",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_93_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_43",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_94_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_44",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_p2d4_44_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_45",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_46",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_47",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_48",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_49",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_50",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_51",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_262_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_52",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_53",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_54",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_55",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_56",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_268_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_57",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_58",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_59",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_60",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_262_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_61",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_62",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_63",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_93_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_64",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_65",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_66",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_67",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_68",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_69",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_93_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_70",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_94_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_71",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_p2d4_44_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_72",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_15_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_73",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_74",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_12_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_75",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_76",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_261_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_77",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_17_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_78",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_262_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_79",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_46_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_80",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_81",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_267_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_82",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_19_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_83",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_268_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_84",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_48_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_42_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2d4_85",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pad0_2_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_4_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_5",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_75_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_7",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_75_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_8",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_9",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_10",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_11",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_12",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_197_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_13",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_14",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_15",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_16",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_73_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_17",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_21_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_18",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_197_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_19",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_97_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_20",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_47_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_21",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_265_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_22",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_49_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2c8_23",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pad0_271_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_8",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_9",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_10",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_8_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_11",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_12",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_13",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_14",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_15",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_16",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_17",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_18",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_19",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_20",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_21",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p2b8_22",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p29c_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p29c_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pad8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p29c_2",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pae_5_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p29c_3",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pad8_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p29c_4",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p29c_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_2_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p29c_6",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p29c_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pf6_3_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p296_0",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p296_1",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p296_2",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p296_3",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_0_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p296_4",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p296_5",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p296_6",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p296_7",
    &setup_mmap_mmap_pad0_0_common,
    { { &setup_mmap_mmap_pad0_5_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pad0_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p296_8",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p288_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p288_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p288_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p288_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p270_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p270_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p25c_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p25c_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p25c_2",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb14_2_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p25c_3",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb14_2_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p25c_4",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p25c_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb14_2_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p25c_6",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p25c_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb14_2_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p254_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p254_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p254_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p254_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p248_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p248_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p248_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p248_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p238_0",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p238_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p238_2",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p238_3",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p21c_0",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p21c_1",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p21c_2",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p21c_3",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb50_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p21c_4",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb14_2_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p21c_5",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb14_2_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p21c_6",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb14_2_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p21c_7",
    &setup_mmap_mmap_pf4_5_common,
    { { &setup_mmap_mmap_pb14_2_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p216_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p216_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p216_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p216_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p216_4",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p216_5",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p216_6",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p216_7",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p208_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p208_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pae_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p208_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p208_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf0_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pc50_1_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p1c_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p1c_1",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbe_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p1b_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p1b_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p1a_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbd0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p18_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p18_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p16_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p16_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p16_2",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p16_3",
    &setup_mmap_mmap_pf8_4_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pbb0_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p13_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_1_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p13_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_4_proc0 }, { &setup_mmap_mmap_pf6_0_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p128_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p128_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf4_1_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p128_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p128_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pe50_30_proc0 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe50_2_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p10_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_1_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p10_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 0, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p0c_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf8_0_0, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p0b_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p0b_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p0a_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pd4_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p08_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pf0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p06_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p06_1",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pec_2_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p03_0",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pf6_0_proc0 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p03_1",
    &setup_mmap_mmap_pf6_0_common,
    { { &setup_mmap_mmap_pf6_0_proc1 }, { &setup_mmap_mmap_pd6_1_proc1 } },
    &setup_mmap_mmap_pf6_0_procfinal,
    &setup_mmap_mmap_pf6_0_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe6_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p028_0",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p028_1",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pae_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p028_2",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p028_3",
    &setup_mmap_mmap_pf4_1_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf0_1_proc0 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_4_final,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pc50_1_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mmap_p00_0",
    &setup_mmap_mmap_pf8_0_common,
    { { &setup_mmap_mmap_pf8_0_proc1 }, { &setup_mmap_mmap_pf8_0_proc1 } },
    &setup_mmap_mmap_pf8_0_procfinal,
    &setup_mmap_mmap_pf8_0_procfinal,
    { { &test_mmap_mmap_pe0_0_1, 0, "mmap" },
      { &test_mmap_mmap_pe0_0_1, 1, "mmap" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_1_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_1_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_3",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_3_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_4",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_1_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_5",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_3_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_6",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_1_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_7",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_3_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_8",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_3_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_9",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_9_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_10",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_10_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_11",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_11_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_12",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_12_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_13",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_13_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_14",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_15",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_10_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_16",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_12_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_17",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_13_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_18",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_18_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_19",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_19_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_20",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_20_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_21",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_11_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_22",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_18_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_23",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_19_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_24",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_20_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_25",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_26",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_10_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_27",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_11_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_28",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_12_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_29",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_13_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_30",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_18_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_31",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_19_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_32",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_20_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_33",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_34",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_10_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_35",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_11_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_36",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_12_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_37",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_13_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_38",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_18_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_39",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_19_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_40",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_20_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_41",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_42",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_43",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_44",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_45",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_45_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_46",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_46_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_47",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_45_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_48",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_46_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_49",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_45_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_50",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_46_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_51",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_45_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_52",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_46_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_53",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_53_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_54",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_54_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_55",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_55_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_56",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_9_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_57",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_57_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_58",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_53_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_59",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_54_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_60",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_60_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_61",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_61_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_62",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_55_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_63",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_63_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_64",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_9_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_65",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_57_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_66",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_53_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_67",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_54_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_68",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_60_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_69",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_61_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_70",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_55_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_71",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_63_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_72",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_9_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_73",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_53_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_74",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_54_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_75",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_55_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_76",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_76_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_77",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_77_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_78",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_76_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pf8_79",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_77_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_4_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pe0_0",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pe0_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pe0_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pe0_3",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_76_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pe0_4",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_77_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pd0_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_41_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pd0_1",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_76_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pd0_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_43_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pd0_3",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_77_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pc0_0",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_pf8_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pbc_0",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_0_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pbc_1",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_1_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pbc_2",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_2_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pbc_3",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_3_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pbc_4",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_4_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pbc_5",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_5_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pbc_6",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_6_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pbc_7",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_7_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pbc_8",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_8_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pbc_9",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_9_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb8_0",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb8_1",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb8_2",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_0_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb8_3",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_2_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb4_0",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pb4_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb4_1",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pb4_1_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb4_2",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pb4_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb4_3",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pb4_1_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb4_4",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pb4_4_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb4_5",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pb4_4_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb4_6",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pb4_6_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb4_7",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pb4_6_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb0_0",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pb0_1",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_pbc_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_1_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_1_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_3",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_3_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_4",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_4_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_5",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_5_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_6",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_4_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_7",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_3_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_8",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_5_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_9",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_9_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_10",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_10_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_11",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_11_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_12",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_12_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_13",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_13_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_14",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_14_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_15",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_15_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_16",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_16_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_17",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_18",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_10_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_19",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_11_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_20",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_12_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_21",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_13_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_22",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_14_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_23",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_15_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_24",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_16_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_25",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_25_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_26",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_26_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_27",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_27_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_28",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_28_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_29",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_9_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_30",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_25_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_31",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_27_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_32",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_28_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_33",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_33_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_34",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_34_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_35",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_35_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_36",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_26_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_37",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_33_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_38",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_34_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_39",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_35_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_40",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_40_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_41",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_42",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_42_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_43",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_44",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_45",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_1_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_46",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_4_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_47",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_3_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_48",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_5_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_49",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_1_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_50",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_3_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_51",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_4_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_52",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_5_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_53",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_9_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_54",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_10_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_55",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_11_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_56",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_12_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_57",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_13_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_58",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_14_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_59",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_16_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_60",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_15_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_61",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_25_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_62",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_35_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_63",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_28_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_64",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_27_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_65",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_33_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_66",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_34_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_67",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_26_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_68",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_69",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_9_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_70",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_10_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_71",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_11_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_72",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_12_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_73",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_13_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_74",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_25_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_75",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_28_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_76",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_27_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_77",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_14_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_78",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_26_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_79",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_16_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_80",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_15_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_81",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_33_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_82",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_34_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_83",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_35_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_2_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_84",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_40_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_85",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_42_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_86",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pae_87",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_44_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pa8_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pa8_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_40_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pa8_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_42_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pa8_3",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pa8_4",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pa4_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_41_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pa4_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_76_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pa4_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_43_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pa4_3",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_77_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_pa0_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_pae_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p98_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p98_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_1_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p98_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_3_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p98_3",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_45_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p98_4",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_46_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p90_0",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p90_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pe0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p88_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_41_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p88_1",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_76_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p88_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_43_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p88_3",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_77_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p80_0",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p98_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_3",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_4",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_5",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_6",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_7",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_8",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_76_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_9",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_77_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_10",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_76_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_11",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_77_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_12",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_76_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_13",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_76_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_14",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_77_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p7c_15",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_77_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p68_0",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p68_1",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p58_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_41_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p58_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_41_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p58_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_43_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p58_3",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_43_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p58_4",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_76_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p58_5",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_77_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p58_6",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_76_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p58_7",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_77_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p48_0",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p48_1",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p7c_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p3c_0",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_0_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p3c_1",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_p3c_1_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p3c_2",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_p3c_2_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p3c_3",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_p3c_3_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p3c_4",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pbc_2_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p3c_5",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_p3c_5_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p3c_6",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_p3c_6_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p3c_7",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_p3c_7_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p38_0",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p38_1",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p34_0",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pb4_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p34_1",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pb4_1_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p34_2",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pb4_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p34_3",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pb4_1_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p34_4",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pb4_4_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p34_5",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pb4_4_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p34_6",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pb4_6_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p34_7",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pb4_6_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p30_0",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_0_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p30_1",
    &setup_mmap_mprotect_pbc_0_common,
    { { &setup_mmap_mprotect_pb8_1_proc0 }, { &setup_mmap_mprotect_pbc_0_proc1 } },
    &setup_mmap_mprotect_pbc_0_procfinal,
    &setup_mmap_mprotect_pbc_0_final,
    { { &test_mmap_mprotect_p3c_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_40_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_40_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_40_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_3",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_40_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_4",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_42_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_5",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_42_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_6",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_42_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_7",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_42_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_8",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_9",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_10",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_11",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_12",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_13",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_14",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2f_15",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pae_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_42_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2a_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p2a_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p26_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_41_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p26_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_76_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p26_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_41_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p26_3",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_76_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p26_4",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_43_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p26_5",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_43_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p26_6",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_77_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p26_7",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_77_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p22_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p22_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pa8_0_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p2f_2_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p18_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_41_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p18_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p18_1",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_43_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p18_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p18_2",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_76_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p18_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p18_3",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_77_proc0 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p18_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p10_0",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p18_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p08_0",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_41_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p18_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p08_1",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_76_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p18_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p08_2",
    &setup_mmap_mprotect_pf8_0_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_43_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_final,
    { { &test_mmap_mprotect_p18_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p08_3",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_77_proc0 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p18_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pf8_41_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_mprotect_p00_0",
    &setup_mmap_mprotect_pf8_9_common,
    { { &setup_mmap_mprotect_pf8_0_proc1 }, { &setup_mmap_mprotect_pf8_0_proc1 } },
    &setup_mmap_mprotect_pf8_0_procfinal,
    &setup_mmap_mprotect_pf8_0_procfinal,
    { { &test_mmap_mprotect_p18_0_0, 0, "mmap" },
      { &test_mmap_mprotect_pc0_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mmap_munmap_pe_0",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_0_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_1",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_1_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_2",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_2_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_3",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_3_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_4",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_4_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_5",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_5_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_6",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_6_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_7",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_7_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_8",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_8_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_9",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_9_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_10",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_10_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_11",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_11_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_12",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_12_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_13",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_13_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_14",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_14_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_15",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_15_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_16",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_16_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_17",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_17_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_18",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_18_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_19",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_19_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_20",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_20_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_21",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_21_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_22",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_22_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_23",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_23_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pe_24",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_24_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pc_0",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_0_proc1 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_pe_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pb8_0",
    &setup_mmap_munmap_pb8_0_common,
    { { &setup_mmap_munmap_pb8_0_proc0 }, { &setup_mmap_munmap_pb8_0_proc1 } },
    &setup_mmap_munmap_pb8_0_procfinal,
    &setup_mmap_munmap_pb8_0_final,
    { { &test_mmap_munmap_pb8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pb8_1",
    &setup_mmap_munmap_pb8_0_common,
    { { &setup_mmap_munmap_pb8_1_proc0 }, { &setup_mmap_munmap_pb8_0_proc1 } },
    &setup_mmap_munmap_pb8_0_procfinal,
    &setup_mmap_munmap_pb8_0_final,
    { { &test_mmap_munmap_pb8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pb0_0",
    &setup_mmap_munmap_pb8_0_common,
    { { &setup_mmap_munmap_pb8_0_proc0 }, { &setup_mmap_munmap_pb8_0_proc1 } },
    &setup_mmap_munmap_pb8_0_procfinal,
    &setup_mmap_munmap_pb8_0_final,
    { { &test_mmap_munmap_pb8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pb0_1",
    &setup_mmap_munmap_pb8_0_common,
    { { &setup_mmap_munmap_pb8_1_proc0 }, { &setup_mmap_munmap_pb8_0_proc1 } },
    &setup_mmap_munmap_pb8_0_procfinal,
    &setup_mmap_munmap_pb8_0_final,
    { { &test_mmap_munmap_pb8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_0",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_0_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_1",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_1_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_2",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_2_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_3",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_3_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_4",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_4_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_5",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_5_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_6",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_6_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_7",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_7_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_8",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_8_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_9",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_9_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_10",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_10_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_11",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_11_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_12",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_12_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_13",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_13_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_14",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_14_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_15",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_15_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_16",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_16_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_17",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_17_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_18",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_18_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_19",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_19_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_20",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_20_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_21",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_21_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_22",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_22_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_23",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_23_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa8_24",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_24_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_pa0_0",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_0_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_pa8_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p9_0",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_0_proc1 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p9_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p8_0",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_0_proc1 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p9_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p70_0",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_0_proc1 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p70_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p70_1",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_0_proc1 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p70_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p70_2",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_3_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p70_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p70_3",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_11_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p70_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p70_4",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_6_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p70_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p70_5",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_13_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p70_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p70_6",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_3_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p70_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p70_7",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pe_6_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p70_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p70_8",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_11_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p70_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p70_9",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_13_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p70_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p50_0",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_0_proc1 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p70_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p50_1",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_0_proc1 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p70_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p38_0",
    &setup_mmap_munmap_pb8_0_common,
    { { &setup_mmap_munmap_pb8_0_proc0 }, { &setup_mmap_munmap_pb8_0_proc1 } },
    &setup_mmap_munmap_pb8_0_procfinal,
    &setup_mmap_munmap_pb8_0_final,
    { { &test_mmap_munmap_p38_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p38_1",
    &setup_mmap_munmap_pb8_0_common,
    { { &setup_mmap_munmap_pb8_1_proc0 }, { &setup_mmap_munmap_pb8_0_proc1 } },
    &setup_mmap_munmap_pb8_0_procfinal,
    &setup_mmap_munmap_pb8_0_final,
    { { &test_mmap_munmap_p38_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p30_0",
    &setup_mmap_munmap_pb8_0_common,
    { { &setup_mmap_munmap_pb8_0_proc0 }, { &setup_mmap_munmap_pb8_0_proc1 } },
    &setup_mmap_munmap_pb8_0_procfinal,
    &setup_mmap_munmap_pb8_0_final,
    { { &test_mmap_munmap_p38_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p30_1",
    &setup_mmap_munmap_pb8_0_common,
    { { &setup_mmap_munmap_pb8_1_proc0 }, { &setup_mmap_munmap_pb8_0_proc1 } },
    &setup_mmap_munmap_pb8_0_procfinal,
    &setup_mmap_munmap_pb8_0_final,
    { { &test_mmap_munmap_p38_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p2c_0",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_0_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p2c_1",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_0_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p2c_2",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_3_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p2c_3",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_4_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p2c_4",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_16_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p2c_5",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_17_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p2c_6",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_3_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p2c_7",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_16_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p2c_8",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_4_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p2c_9",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_17_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p24_0",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_0_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p24_1",
    &setup_mmap_munmap_pe_1_common,
    { { &setup_mmap_munmap_pa8_0_proc0 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_1_final,
    { { &test_mmap_munmap_p2c_1_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p1_0",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_0_proc1 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p1_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mmap_munmap_p0_0",
    &setup_mmap_munmap_pe_0_common,
    { { &setup_mmap_munmap_pe_0_proc1 }, { &setup_mmap_munmap_pe_0_proc1 } },
    &setup_mmap_munmap_pe_0_procfinal,
    &setup_mmap_munmap_pe_0_procfinal,
    { { &test_mmap_munmap_p1_0_0, 0, "mmap" },
      { &test_mmap_munmap_pc_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mmap_open_pf8_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pf70_0",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pf70_1",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf70_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pf70_2",
    &setup_mmap_open_pf70_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pf50_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pf30_0",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pf30_1",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf30_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pf30_2",
    &setup_mmap_open_pf30_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pf10_0",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pee_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pee_1",
    &setup_mmap_open_pee_1_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pee_2",
    &setup_mmap_open_pee_2_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pea_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pe6_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pe6_1",
    &setup_mmap_open_pee_1_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pe6_2",
    &setup_mmap_open_pee_2_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pe2_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pde_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pde_1",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pde_2",
    &setup_mmap_open_pde_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pda_0",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pd6_0",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pd6_1",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf30_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pd6_2",
    &setup_mmap_open_pf30_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pd2_0",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pc0_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_pf8_0_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pbe_0",
    &setup_mmap_open_pbe_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pbe_1",
    &setup_mmap_open_pbe_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pbdc_0",
    &setup_mmap_open_pde_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pbdc_1",
    &setup_mmap_open_pbdc_1_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pbd4_0",
    &setup_mmap_open_pbd4_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pbd4_1",
    &setup_mmap_open_pbd4_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pbcc_0",
    &setup_mmap_open_pf30_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pbcc_1",
    &setup_mmap_open_pf30_2_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pbc4_0",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pbc4_1",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pbb8_0",
    &setup_mmap_open_pbb8_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pbb8_1",
    &setup_mmap_open_pbb8_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pba8_0",
    &setup_mmap_open_pba8_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pba8_1",
    &setup_mmap_open_pba8_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pb98_0",
    &setup_mmap_open_pb98_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pb98_1",
    &setup_mmap_open_pbb8_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pb88_0",
    &setup_mmap_open_pb88_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pb88_1",
    &setup_mmap_open_pba8_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pb78_0",
    &setup_mmap_open_pf70_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pb78_1",
    &setup_mmap_open_pbdc_1_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pb68_0",
    &setup_mmap_open_pbd4_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pb68_1",
    &setup_mmap_open_pbd4_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pb58_0",
    &setup_mmap_open_pf30_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pb58_1",
    &setup_mmap_open_pf30_2_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pb48_0",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pb48_1",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pb0_0",
    &setup_mmap_open_pb0_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pb0_1",
    &setup_mmap_open_pb0_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_pbe_0_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pae_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_padc_0",
    &setup_mmap_open_padc_0_common,
    { { &setup_mmap_open_pf70_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_padc_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_padc_1",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pad4_0",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pad4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pacc_0",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf30_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pac4_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pac4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pab8_0",
    &setup_mmap_open_pab8_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_paa8_0",
    &setup_mmap_open_pee_2_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pa98_0",
    &setup_mmap_open_pa98_0_common,
    { { &setup_mmap_open_pa98_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pa88_0",
    &setup_mmap_open_pa98_0_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pa78_0",
    &setup_mmap_open_padc_0_common,
    { { &setup_mmap_open_pf70_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_padc_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pa78_1",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf70_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pa68_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pa68_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pa58_0",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf30_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_pa48_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pac4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_pa0_0",
    &setup_mmap_open_pa98_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_pae_0_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p9c_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p9b4_0",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p9a8_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p994_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p988_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p968_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p950_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p928_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p910_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p8e8_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p8d0_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p8a8_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p89_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p80_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p9c_0_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p7c_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p7c_1",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p778_0",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p778_1",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf70_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p778_2",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p778_3",
    &setup_mmap_open_pde_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p778_4",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p778_5",
    &setup_mmap_open_pbdc_1_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p758_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p758_1",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p738_0",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p738_1",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p738_2",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf30_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p738_3",
    &setup_mmap_open_pf30_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p738_4",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf30_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p738_5",
    &setup_mmap_open_pf30_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p718_0",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p718_1",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p6f0_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p6f0_1",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p6f0_2",
    &setup_mmap_open_pee_1_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p6f0_3",
    &setup_mmap_open_pee_2_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p6f0_4",
    &setup_mmap_open_p6f0_4_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p6f0_5",
    &setup_mmap_open_pee_2_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p6b0_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p6b0_1",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p670_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p670_1",
    &setup_mmap_open_pee_1_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p670_2",
    &setup_mmap_open_pee_2_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p670_3",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p670_4",
    &setup_mmap_open_p6f0_4_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p670_5",
    &setup_mmap_open_p670_5_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p630_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p630_1",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p5f0_0",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p5f0_1",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p5f0_2",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p5f0_3",
    &setup_mmap_open_pbdc_1_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p5f0_4",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf70_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p5f0_5",
    &setup_mmap_open_pf70_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p5b0_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p5b0_1",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p570_0",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p570_1",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p570_2",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf30_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p570_3",
    &setup_mmap_open_pf30_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p570_4",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf30_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p570_5",
    &setup_mmap_open_pf30_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p530_0",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p530_1",
    &setup_mmap_open_pf30_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p48_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p7c_0_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p48_1",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p7c_1_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p3e_0",
    &setup_mmap_open_pbe_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p3e_1",
    &setup_mmap_open_pbe_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p3dc_0",
    &setup_mmap_open_pbdc_1_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p3dc_1",
    &setup_mmap_open_pf70_2_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p3d4_0",
    &setup_mmap_open_p3d4_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p3d4_1",
    &setup_mmap_open_p3d4_1_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p3cc_0",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p3cc_1",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p3c4_0",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p3c4_1",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p3b8_0",
    &setup_mmap_open_pbb8_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p3b8_1",
    &setup_mmap_open_pbb8_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p3a8_0",
    &setup_mmap_open_pb88_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p3a8_1",
    &setup_mmap_open_pb88_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p398_0",
    &setup_mmap_open_pbb8_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p398_1",
    &setup_mmap_open_pbb8_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p388_0",
    &setup_mmap_open_pba8_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p388_1",
    &setup_mmap_open_pb88_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p378_0",
    &setup_mmap_open_pde_2_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p378_1",
    &setup_mmap_open_pf70_2_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p368_0",
    &setup_mmap_open_p3d4_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p368_1",
    &setup_mmap_open_p3d4_1_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p358_0",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p358_1",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p348_0",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p348_1",
    &setup_mmap_open_pbc4_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p30_0",
    &setup_mmap_open_pb0_0_common,
    { { &setup_mmap_open_pf70_2_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p30_1",
    &setup_mmap_open_pb0_0_common,
    { { &setup_mmap_open_pbe_1_proc0 }, { &setup_mmap_open_pf70_2_proc1 } },
    &setup_mmap_open_pf70_2_procfinal,
    &setup_mmap_open_pf70_2_final,
    { { &test_mmap_open_p3e_0_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2f_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2f_1",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2de_0",
    &setup_mmap_open_p2de_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_padc_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2de_1",
    &setup_mmap_open_p2de_1_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_padc_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2de_2",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2de_3",
    &setup_mmap_open_p2de_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_padc_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2de_4",
    &setup_mmap_open_p2de_1_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_padc_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2de_5",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2de_6",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2de_7",
    &setup_mmap_open_p2de_7_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2d6_0",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pad4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2d6_1",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2d6_2",
    &setup_mmap_open_p2de_7_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2d6_3",
    &setup_mmap_open_p2d6_3_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2ce_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pac4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2ce_1",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pac4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2ce_2",
    &setup_mmap_open_p2ce_2_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2ce_3",
    &setup_mmap_open_p2ce_2_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2c6_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pac4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2c6_1",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pac4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2c6_2",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2c6_3",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2bc_0",
    &setup_mmap_open_p670_5_common,
    { { &setup_mmap_open_p2bc_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2bc_1",
    &setup_mmap_open_p670_5_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2bc_2",
    &setup_mmap_open_pa98_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2bc_3",
    &setup_mmap_open_p2bc_3_common,
    { { &setup_mmap_open_pf70_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2bc_3_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p2ac_0",
    &setup_mmap_open_pee_2_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2ac_1",
    &setup_mmap_open_pee_2_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2ac_2",
    &setup_mmap_open_p670_5_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p2ac_3",
    &setup_mmap_open_p670_5_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p29c_0",
    &setup_mmap_open_pa98_0_common,
    { { &setup_mmap_open_pa98_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p29c_1",
    &setup_mmap_open_p29c_1_common,
    { { &setup_mmap_open_p29c_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p29c_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p29c_2",
    &setup_mmap_open_p29c_2_common,
    { { &setup_mmap_open_p29c_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p29c_3",
    &setup_mmap_open_p2bc_3_common,
    { { &setup_mmap_open_pf70_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2bc_3_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p28c_0",
    &setup_mmap_open_pee_2_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p28c_1",
    &setup_mmap_open_p670_5_common,
    { { &setup_mmap_open_pee_2_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p28c_2",
    &setup_mmap_open_pee_2_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p28c_3",
    &setup_mmap_open_p670_5_common,
    { { &setup_mmap_open_p28c_3_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p28c_3_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p27c_0",
    &setup_mmap_open_p2de_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_padc_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p27c_1",
    &setup_mmap_open_p2de_1_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_padc_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p27c_2",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p27c_3",
    &setup_mmap_open_padc_0_common,
    { { &setup_mmap_open_pf70_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_padc_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p27c_4",
    &setup_mmap_open_padc_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_padc_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p27c_5",
    &setup_mmap_open_p2ce_2_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p27c_6",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf70_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p27c_7",
    &setup_mmap_open_p2de_7_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p26c_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pa68_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p26c_1",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pde_1_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p26c_2",
    &setup_mmap_open_p2de_7_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p26c_3",
    &setup_mmap_open_p2d6_3_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p25c_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pac4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p25c_1",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pac4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p25c_2",
    &setup_mmap_open_p2ce_2_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p25c_3",
    &setup_mmap_open_p2ce_2_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p24c_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pac4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p24c_1",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pac4_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p24c_2",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p24c_3",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p22_0",
    &setup_mmap_open_pa98_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_0_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p22_1",
    &setup_mmap_open_pa98_0_common,
    { { &setup_mmap_open_pae_0_proc0 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p2f_1_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p1c_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pf8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p1b4_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p1a8_0",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p194_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p188_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p168_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p150_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pf70_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p128_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p110_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pf30_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p0e8_0",
    &setup_mmap_open_pf70_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p0d0_0",
    &setup_mmap_open_pf8_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pde_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p0a8_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_open_p09_0",
    &setup_mmap_open_pf50_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_final,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pd6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mmap_open_p00_0",
    &setup_mmap_open_pee_0_common,
    { { &setup_mmap_open_pf8_0_proc1 }, { &setup_mmap_open_pf8_0_proc1 } },
    &setup_mmap_open_pf8_0_procfinal,
    &setup_mmap_open_pf8_0_procfinal,
    { { &test_mmap_open_p1c_0_0, 0, "mmap" },
      { &test_mmap_open_pc0_0_1, 0, "open" } },
    &cleanup },
  { "fs-mmap_pipe_pf8_0",
    &setup_mmap_pipe_pf8_0_common,
    { { &setup_mmap_pipe_pf8_0_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_0_final,
    { { &test_mmap_pipe_pf8_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_pf8_1",
    &setup_mmap_pipe_pf8_1_common,
    { { &setup_mmap_pipe_pf8_1_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_pf8_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_pf8_2",
    &setup_mmap_pipe_pf8_2_common,
    { { &setup_mmap_pipe_pf8_2_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_pf8_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_pf8_3",
    &setup_mmap_pipe_pf8_2_common,
    { { &setup_mmap_pipe_pf8_3_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_pf8_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_pd8_0",
    &setup_mmap_pipe_pf8_0_common,
    { { &setup_mmap_pipe_pf8_0_proc1 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_0_procfinal,
    { { &test_mmap_pipe_pf8_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_pbe_0",
    &setup_mmap_pipe_pf8_2_common,
    { { &setup_mmap_pipe_pf8_2_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_pbe_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_pbe_1",
    &setup_mmap_pipe_pf8_2_common,
    { { &setup_mmap_pipe_pf8_3_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_pbe_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_pb6_0",
    &setup_mmap_pipe_pb6_0_common,
    { { &setup_mmap_pipe_pf8_2_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_pbe_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_pb6_1",
    &setup_mmap_pipe_pb6_0_common,
    { { &setup_mmap_pipe_pf8_3_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_pbe_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_pae_0",
    &setup_mmap_pipe_pae_0_common,
    { { &setup_mmap_pipe_pae_0_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_pae_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_pa6_0",
    &setup_mmap_pipe_pae_0_common,
    { { &setup_mmap_pipe_pae_0_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_pae_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p96_0",
    &setup_mmap_pipe_pf8_0_common,
    { { &setup_mmap_pipe_pf8_0_proc1 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_0_procfinal,
    { { &test_mmap_pipe_p96_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p8c_0",
    &setup_mmap_pipe_pf8_0_common,
    { { &setup_mmap_pipe_pf8_0_proc1 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_0_procfinal,
    { { &test_mmap_pipe_p96_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p7c_0",
    &setup_mmap_pipe_pf8_0_common,
    { { &setup_mmap_pipe_pf8_0_proc1 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_0_procfinal,
    { { &test_mmap_pipe_p7c_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p7c_1",
    &setup_mmap_pipe_pf8_0_common,
    { { &setup_mmap_pipe_pf8_0_proc1 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_0_procfinal,
    { { &test_mmap_pipe_p7c_1_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p7c_2",
    &setup_mmap_pipe_pae_0_common,
    { { &setup_mmap_pipe_pae_0_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_p7c_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p7c_3",
    &setup_mmap_pipe_pb6_0_common,
    { { &setup_mmap_pipe_pf8_2_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_p7c_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p7c_4",
    &setup_mmap_pipe_pf8_2_common,
    { { &setup_mmap_pipe_pf8_3_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_p7c_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p7c_5",
    &setup_mmap_pipe_pae_0_common,
    { { &setup_mmap_pipe_p7c_5_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_p7c_1_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p7c_6",
    &setup_mmap_pipe_pb6_0_common,
    { { &setup_mmap_pipe_pf8_2_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_p7c_1_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p7c_7",
    &setup_mmap_pipe_pb6_0_common,
    { { &setup_mmap_pipe_pf8_3_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_p7c_1_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p5c_0",
    &setup_mmap_pipe_pf8_0_common,
    { { &setup_mmap_pipe_pf8_0_proc1 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_0_procfinal,
    { { &test_mmap_pipe_p7c_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p5c_1",
    &setup_mmap_pipe_pf8_0_common,
    { { &setup_mmap_pipe_pf8_0_proc1 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_0_procfinal,
    { { &test_mmap_pipe_p7c_1_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p3e_0",
    &setup_mmap_pipe_pb6_0_common,
    { { &setup_mmap_pipe_pf8_2_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_p3e_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p3e_1",
    &setup_mmap_pipe_pb6_0_common,
    { { &setup_mmap_pipe_pf8_3_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_p3e_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p36_0",
    &setup_mmap_pipe_pb6_0_common,
    { { &setup_mmap_pipe_pf8_2_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_p3e_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p36_1",
    &setup_mmap_pipe_p36_1_common,
    { { &setup_mmap_pipe_pf8_3_proc0 }, { &setup_mmap_pipe_pf8_2_proc1 } },
    &setup_mmap_pipe_pf8_2_procfinal,
    &setup_mmap_pipe_pf8_2_final,
    { { &test_mmap_pipe_p3e_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p2f0_0",
    &setup_mmap_pipe_pae_0_common,
    { { &setup_mmap_pipe_pae_0_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_p2f0_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p2f0_1",
    &setup_mmap_pipe_pae_0_common,
    { { &setup_mmap_pipe_pae_0_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_p2f0_1_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p2f0_2",
    &setup_mmap_pipe_pae_0_common,
    { { &setup_mmap_pipe_p2f0_2_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_p2f0_2_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p2f0_3",
    &setup_mmap_pipe_pf8_1_common,
    { { &setup_mmap_pipe_p2f0_3_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_p2f0_1_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p270_0",
    &setup_mmap_pipe_pae_0_common,
    { { &setup_mmap_pipe_pae_0_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_p2f0_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p270_1",
    &setup_mmap_pipe_pf8_1_common,
    { { &setup_mmap_pipe_pf8_1_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_p2f0_1_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p270_2",
    &setup_mmap_pipe_p270_2_common,
    { { &setup_mmap_pipe_p2f0_3_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_p2f0_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p270_3",
    &setup_mmap_pipe_p270_2_common,
    { { &setup_mmap_pipe_p2f0_3_proc0 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_1_final,
    { { &test_mmap_pipe_p2f0_1_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p16_0",
    &setup_mmap_pipe_pf8_0_common,
    { { &setup_mmap_pipe_pf8_0_proc1 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_0_procfinal,
    { { &test_mmap_pipe_p16_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mmap_pipe_p0c_0",
    &setup_mmap_pipe_pf8_0_common,
    { { &setup_mmap_pipe_pf8_0_proc1 }, { &setup_mmap_pipe_pf8_0_proc1 } },
    &setup_mmap_pipe_pf8_0_procfinal,
    &setup_mmap_pipe_pf8_0_procfinal,
    { { &test_mmap_pipe_p16_0_0, 0, "mmap" },
      { &test_mmap_pipe_pf8_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mmap_pread_pf8_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf8_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf8_2",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf8_3",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf8_4",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_4_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf4_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf4_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf4_2",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf4_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf4_3",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf4_4",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_4_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf4_5",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf4_5_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf0_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf0_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf0_2",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pf0_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf0_3",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf0_4",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_4_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pf0_5",
    &setup_mmap_pread_pf0_5_common,
    { { &setup_mmap_pread_pf4_5_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pe0_0",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pe0_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pd8_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pd8_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pd4_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pd4_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pd0_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pd0_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pc0_0",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_pf8_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbe_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pbe_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbe_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pbe_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbe_2",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pbe_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbe_3",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pbe_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbe_4",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbe_5",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbd_0",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf4_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbd_1",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pbd_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbd_2",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf4_5_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbd_3",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pbd_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbc0_0",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pf0_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbc0_1",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pbc0_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbc0_2",
    &setup_mmap_pread_pbc0_2_common,
    { { &setup_mmap_pread_pf4_5_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pbc0_3",
    &setup_mmap_pread_pf0_5_common,
    { { &setup_mmap_pread_pbd_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb8_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb8_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb6_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb6_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb6_2",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb6_3",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb5_0",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pb5_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb5_1",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pb5_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb5_2",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pb5_2_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb5_3",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pb5_2_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb40_0",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pb40_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb40_1",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pb40_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb40_2",
    &setup_mmap_pread_pbc0_2_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pb5_2_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb40_3",
    &setup_mmap_pread_pf0_5_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pb5_2_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb0_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pb0_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pbe_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pae_0",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pae_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pae_1",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pae_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pad_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pad_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pad_2",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pad_3",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pac0_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pac0_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pac0_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pac0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pac0_2",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pac0_3",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pa8_0",
    &setup_mmap_pread_pa8_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pa6_0",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pb5_0_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pa6_1",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pb5_0_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pa5_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pa5_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pa40_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pac0_1_proc0 }, { &setup_mmap_pread_pac0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pa40_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_pa0_0",
    &setup_mmap_pread_pa8_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_pae_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p9c_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p9c_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_4_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p9a_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p9a_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_4_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p98_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p98_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_4_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p90_0",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p90_1",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p8c_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p8c_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p8a_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p8a_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p88_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pac0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p88_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p80_0",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_p9c_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p7c_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p7c_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p7c_2",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p7c_3",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p7c_4",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p7c_5",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p7c_6",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p7c_7",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_4_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p7c_8",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_4_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p7c_9",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_2",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_3",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_4",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf4_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_5",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf4_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_6",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_7",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_4_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_8",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf4_5_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_9",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_10",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_4_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p76_11",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf4_5_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_2",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_3",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_4",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pf0_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_5",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pf0_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_6",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_7",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_4_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_8",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_4_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_9",
    &setup_mmap_pread_pbc0_2_common,
    { { &setup_mmap_pread_pf4_5_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_10",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p72_11",
    &setup_mmap_pread_pf0_5_common,
    { { &setup_mmap_pread_pf4_5_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p68_0",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p68_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p68_2",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p68_3",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p5c_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p5c_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p5c_2",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p5c_3",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p56_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p56_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p56_2",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p56_3",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p52_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p52_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p52_2",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p52_3",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p48_0",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_p7c_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p48_1",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_p7c_3_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3e_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pbe_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3e_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pbe_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3e_2",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pbe_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3e_3",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3e_4",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pbe_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3e_5",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3d_0",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf4_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3d_1",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pbd_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3d_2",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf4_5_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3d_3",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pbd_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3c0_0",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pf0_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3c0_1",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pbc0_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3c0_2",
    &setup_mmap_pread_pbc0_2_common,
    { { &setup_mmap_pread_pf4_5_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p3c0_3",
    &setup_mmap_pread_pf0_5_common,
    { { &setup_mmap_pread_pbd_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p38_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p38_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p36_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p36_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p36_2",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p36_3",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p35_0",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pb5_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p35_1",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pb5_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p35_2",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pb5_2_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p35_3",
    &setup_mmap_pread_pf4_2_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pb5_2_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p340_0",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pb40_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p340_1",
    &setup_mmap_pread_pf0_2_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pb40_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p340_2",
    &setup_mmap_pread_pbc0_2_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pb5_2_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p340_3",
    &setup_mmap_pread_pf0_5_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pb5_2_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p30_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p30_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pd8_1_proc1 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p3e_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2f_0",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pae_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2f_1",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pae_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2f_2",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pf8_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2f_3",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pf8_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2f_4",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pae_0_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2f_5",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pf8_2_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2f_6",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pae_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2f_7",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pf8_3_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2d8_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2d8_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2d8_2",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2d8_3",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2d8_4",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2d8_5",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2d8_6",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2d8_7",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2c8_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pac0_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2c8_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pac0_0_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2c8_2",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2c8_3",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pac0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2c8_4",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pac0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2c8_5",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2c8_6",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_3_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2c8_7",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2a_0",
    &setup_mmap_pread_pa8_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2a_1",
    &setup_mmap_pread_pa8_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2a_2",
    &setup_mmap_pread_pa8_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p2a_3",
    &setup_mmap_pread_pa8_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p27_0",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pb5_0_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p27_1",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pb5_0_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p27_2",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pb5_0_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p27_3",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pb5_0_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p27_4",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pb5_2_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p27_5",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pb5_2_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p27_6",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pb5_2_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p27_7",
    &setup_mmap_pread_pae_0_common,
    { { &setup_mmap_pread_pb5_2_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p258_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p258_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p258_2",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p258_3",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p248_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pac0_1_proc0 }, { &setup_mmap_pread_pac0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p248_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pac0_1_proc0 }, { &setup_mmap_pread_pac0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p248_2",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p248_3",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p22_0",
    &setup_mmap_pread_pa8_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p22_1",
    &setup_mmap_pread_pa8_0_common,
    { { &setup_mmap_pread_pd4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p22_2",
    &setup_mmap_pread_pa8_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p22_3",
    &setup_mmap_pread_pa8_0_common,
    { { &setup_mmap_pread_pe0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p2f_4_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p1c_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_1_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p1c_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_4_proc0 }, { &setup_mmap_pread_pf8_0_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p1a_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p1a_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_4_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p18_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf0_1_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p18_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_4_proc0 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p10_0",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_1_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p10_1",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p0c_0",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc1 }, { &setup_mmap_pread_pf8_0_proc0 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p0c_1",
    &setup_mmap_pread_pf8_0_common,
    { { &setup_mmap_pread_pf8_0_proc1 }, { &setup_mmap_pread_pd8_1_proc1 } },
    &setup_mmap_pread_pf8_0_procfinal,
    &setup_mmap_pread_pf8_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p0a_0",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pd4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p0a_1",
    &setup_mmap_pread_pf4_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p08_0",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pac0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p08_1",
    &setup_mmap_pread_pf0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pe0_1_proc0 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_final,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pread_p00_0",
    &setup_mmap_pread_pe0_0_common,
    { { &setup_mmap_pread_pf4_0_proc1 }, { &setup_mmap_pread_pf4_0_proc1 } },
    &setup_mmap_pread_pf4_0_procfinal,
    &setup_mmap_pread_pf4_0_procfinal,
    { { &test_mmap_pread_p1c_0_0, 0, "mmap" },
      { &test_mmap_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mmap_pwrite_pf8_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf8_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_1_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf8_2",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_2_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf8_3",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf8_4",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf4_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf4_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf4_2",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf4_3",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf4_4",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pf4_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf4_5",
    &setup_mmap_pwrite_pf4_5_common,
    { { &setup_mmap_pwrite_pf4_5_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf0_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf0_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf0_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf0_2",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf0_3",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf0_4",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pf0_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pf0_5",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pf4_5_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pe0_0",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pe0_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pd8_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc1 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pd8_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc1 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pd4_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pd4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pd4_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pd0_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pd0_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pd0_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pc0_0",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_pf8_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbe_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pbe_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbe_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pbe_1_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbe_2",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pbe_2_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbe_3",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pbe_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbe_4",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbe_5",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbd0_0",
    &setup_mmap_pwrite_pf4_5_common,
    { { &setup_mmap_pwrite_pf0_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbd0_1",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pf4_5_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbd0_2",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pbd0_2_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbd0_3",
    &setup_mmap_pwrite_pf4_5_common,
    { { &setup_mmap_pwrite_pbd0_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbc0_0",
    &setup_mmap_pwrite_pbc0_0_common,
    { { &setup_mmap_pwrite_pbc0_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbc0_1",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pf4_5_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbc0_2",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pbc0_2_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pbc0_3",
    &setup_mmap_pwrite_pbc0_3_common,
    { { &setup_mmap_pwrite_pbd0_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb8_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb8_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb6_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb6_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb6_2",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb6_3",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb50_0",
    &setup_mmap_pwrite_pf4_5_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pb50_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb50_1",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pb50_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb50_2",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pb50_2_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb50_3",
    &setup_mmap_pwrite_pf4_5_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pb50_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb40_0",
    &setup_mmap_pwrite_pbc0_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pb40_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb40_1",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pb50_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb40_2",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pb50_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb40_3",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pb50_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb0_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pb0_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pbe_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pae_0",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pae_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pae_1",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pae_1_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pad0_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pad0_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pad0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pad0_2",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pad0_3",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pac0_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf0_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pac0_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pac0_2",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pac0_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pac0_3",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa8_0",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pa8_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa6_0",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pa6_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa6_1",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pa6_0_proc0 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa50_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pac0_2_proc0 }, { &setup_mmap_pwrite_pd4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa50_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pa50_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa50_2",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pa50_2_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa50_3",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa40_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pa40_0_proc0 }, { &setup_mmap_pwrite_pd0_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa40_1",
    &setup_mmap_pwrite_pa40_1_common,
    { { &setup_mmap_pwrite_pa40_1_proc0 }, { &setup_mmap_pwrite_pa8_0_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pa40_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa40_2",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pa50_2_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa40_3",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_pa0_0",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pa8_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_pae_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p9c_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_1_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p9c_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p9a_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p9a_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p98_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_p98_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p98_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p90_0",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p90_1",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p8c_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc1 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p8c_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc1 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p8a_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pd4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p8a_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p88_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pd0_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p88_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p80_0",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_p9c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p7c_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p7c_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_1_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p7c_2",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_2_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p7c_3",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p7c_4",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_2_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p7c_5",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_1_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p7c_6",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p7c_7",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p7c_8",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p7c_9",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_2",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_3",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_4",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_5",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_p76_5_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_6",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pf4_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_7",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pf4_5_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_8",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_p76_8_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_9",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_10",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pf4_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p76_11",
    &setup_mmap_pwrite_pf4_5_common,
    { { &setup_mmap_pwrite_pf4_5_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf0_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_2",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_3",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pf0_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_4",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_5",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pf4_5_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_6",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_7",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_8",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_9",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_10",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pf0_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p72_11",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pf4_5_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p68_0",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p68_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p68_2",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p68_3",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p5c_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc1 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p5c_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc1 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p5c_2",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc1 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p5c_3",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc1 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p56_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pd4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p56_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p56_2",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pac0_2_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p56_3",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p52_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pd0_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p52_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p52_2",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pd4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p52_3",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p48_0",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_p7c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p48_1",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_p7c_3_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3e_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pbe_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3e_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pbe_1_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3e_2",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pbe_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3e_3",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3e_4",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3d0_0",
    &setup_mmap_pwrite_pf4_5_common,
    { { &setup_mmap_pwrite_pf0_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3d0_1",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pf4_5_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3d0_2",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pbd0_2_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3d0_3",
    &setup_mmap_pwrite_pf4_5_common,
    { { &setup_mmap_pwrite_pbd0_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3c0_0",
    &setup_mmap_pwrite_pbc0_0_common,
    { { &setup_mmap_pwrite_pbc0_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3c0_1",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pf4_5_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3c0_2",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pbc0_2_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p3c0_3",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pbd0_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p38_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p38_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p36_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p36_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p36_2",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p36_3",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p350_0",
    &setup_mmap_pwrite_pf4_5_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pb50_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p350_1",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pb50_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p350_2",
    &setup_mmap_pwrite_pf4_4_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pb50_2_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p350_3",
    &setup_mmap_pwrite_pf4_5_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pb50_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p340_0",
    &setup_mmap_pwrite_pbc0_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pb40_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p340_1",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pb50_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p340_2",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pb50_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p340_3",
    &setup_mmap_pwrite_pf0_4_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pb50_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p30_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p30_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pd8_1_proc1 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p3e_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2f_0",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pae_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2f_1",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pae_1_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2f_2",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pf8_2_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2f_3",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pf8_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2f_4",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pae_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2f_5",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pf8_2_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2f_6",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pae_1_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2f_7",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pf8_3_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_p2d8_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_2",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_p76_8_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_3",
    &setup_mmap_pwrite_p2d8_3_common,
    { { &setup_mmap_pwrite_p2d8_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_p2d8_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_4",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_p2d8_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_5",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_p2d8_5_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2d8_5_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_6",
    &setup_mmap_pwrite_p2d8_3_common,
    { { &setup_mmap_pwrite_p2d8_6_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2d8_6_0, 0, "mmap" },
      { &test_mmap_pwrite_p2d8_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_7",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_8",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_9",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_10",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_11",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pac0_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_12",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pa50_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2d8_5_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_13",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pa40_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2d8_14",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2c8_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf0_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2c8_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pac0_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2c8_2",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2c8_3",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_p2c8_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2c8_4",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2c8_5",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2c8_6",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2c8_7",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pac0_2_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2c8_8",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2a_0",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pa8_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2a_1",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pa8_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2a_2",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p2a_3",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p27_0",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pa6_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p27_1",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pa6_0_proc0 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p27_2",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pa6_0_proc0 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p27_3",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pa6_0_proc0 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p27_4",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pb50_1_proc1 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p27_5",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pb50_1_proc1 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p27_6",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pb50_1_proc1 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p27_7",
    &setup_mmap_pwrite_pae_0_common,
    { { &setup_mmap_pwrite_pb50_1_proc1 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pac0_2_proc0 }, { &setup_mmap_pwrite_pd4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pac0_2_proc0 }, { &setup_mmap_pwrite_pac0_2_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_2",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_p258_2_proc0 }, { &setup_mmap_pwrite_pa40_0_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p258_2_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_3",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_4",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pac0_2_proc0 }, { &setup_mmap_pwrite_pd4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_5",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_p2d8_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_6",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pa50_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p258_6_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_7",
    &setup_mmap_pwrite_p258_7_common,
    { { &setup_mmap_pwrite_p2d8_1_proc0 }, { &setup_mmap_pwrite_pad0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p258_7_0, 0, "mmap" },
      { &test_mmap_pwrite_p258_7_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_8",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pa50_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_9",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_10",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pa50_2_proc0 }, { &setup_mmap_pwrite_pa50_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2d8_5_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_11",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pa50_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_12",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pa50_2_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p258_13",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pa40_0_proc0 }, { &setup_mmap_pwrite_pd0_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pac0_2_proc0 }, { &setup_mmap_pwrite_pac0_2_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_2",
    &setup_mmap_pwrite_p258_7_common,
    { { &setup_mmap_pwrite_p248_2_proc0 }, { &setup_mmap_pwrite_pac0_2_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p248_2_0, 0, "mmap" },
      { &test_mmap_pwrite_p248_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_3",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_p2d8_1_proc0 }, { &setup_mmap_pwrite_p248_3_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_4",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_p248_4_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_5",
    &setup_mmap_pwrite_pa40_1_common,
    { { &setup_mmap_pwrite_pa50_1_proc0 }, { &setup_mmap_pwrite_pa8_0_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p248_5_0, 0, "mmap" },
      { &test_mmap_pwrite_pa40_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_6",
    &setup_mmap_pwrite_p258_7_common,
    { { &setup_mmap_pwrite_p248_6_proc0 }, { &setup_mmap_pwrite_p248_6_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p258_7_0, 0, "mmap" },
      { &test_mmap_pwrite_p248_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_7",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2d8_5_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_8",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pac0_2_proc0 }, { &setup_mmap_pwrite_pac0_2_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_9",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pa50_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pa50_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_10",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pa50_2_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_11",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_p248_11_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_12",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p248_13",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p22_0",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pa8_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p22_1",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pa8_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p22_2",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p22_3",
    &setup_mmap_pwrite_pa8_0_common,
    { { &setup_mmap_pwrite_pe0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p2f_4_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p1c_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_1_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p1c_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_4_proc0 }, { &setup_mmap_pwrite_pf8_0_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p1a_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf0_1_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p1a_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p18_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_p98_0_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p18_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_3_proc0 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p10_0",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p10_1",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p0c_0",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc1 }, { &setup_mmap_pwrite_pf8_0_proc0 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p0c_1",
    &setup_mmap_pwrite_pf8_0_common,
    { { &setup_mmap_pwrite_pf8_0_proc1 }, { &setup_mmap_pwrite_pd8_1_proc1 } },
    &setup_mmap_pwrite_pf8_0_procfinal,
    &setup_mmap_pwrite_pf8_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pf8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p0a_0",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pd4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p0a_1",
    &setup_mmap_pwrite_pf4_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p08_0",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pd0_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p08_1",
    &setup_mmap_pwrite_pf0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pe0_1_proc0 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_final,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_pwrite_p00_0",
    &setup_mmap_pwrite_pe0_0_common,
    { { &setup_mmap_pwrite_pf4_0_proc1 }, { &setup_mmap_pwrite_pf4_0_proc1 } },
    &setup_mmap_pwrite_pf4_0_procfinal,
    &setup_mmap_pwrite_pf4_0_procfinal,
    { { &test_mmap_pwrite_p1c_0_0, 0, "mmap" },
      { &test_mmap_pwrite_pe0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mmap_read_pfc_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfc_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfc_2",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfc_3",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfb0_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfb0_1",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfb0_2",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfb0_3",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfa0_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfa0_1",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_1_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfa0_2",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_2_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pfa0_3",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_pfa0_3_proc0 }, { &setup_mmap_read_pfa0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pf8_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pf8_1",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pf8_2",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pf8_3",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pf4_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pf4_1",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pf4_2",
    &setup_mmap_read_pf4_2_common,
    { { &setup_mmap_read_pf4_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pf0_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pf0_1",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pf0_2",
    &setup_mmap_read_pf0_2_common,
    { { &setup_mmap_read_pf0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pe0_0",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pe0_1",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pdc_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pdb0_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pdb0_1",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pdb0_2",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pdb0_3",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pda0_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_1_proc1 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pda0_1",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_1_proc0 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pda0_2",
    &setup_mmap_read_pda0_2_common,
    { { &setup_mmap_read_pda0_2_proc0 }, { &setup_mmap_read_pda0_2_proc1 } },
    &setup_mmap_read_pda0_2_procfinal,
    &setup_mmap_read_pda0_2_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pda0_3",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_pda0_3_proc0 }, { &setup_mmap_read_pda0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pda0_4",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_0_proc1 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pd8_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pd4_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pd4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pd0_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pe0_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pc0_0",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_pfc_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pbf_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pbf_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbf_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbf_2",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbec_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbec_1",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbec_2",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbe8_0",
    &setup_mmap_read_pbe8_0_common,
    { { &setup_mmap_read_pbe8_0_proc0 }, { &setup_mmap_read_pfa0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbe8_1",
    &setup_mmap_read_pbe8_0_common,
    { { &setup_mmap_read_pfa0_3_proc0 }, { &setup_mmap_read_pfa0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbe8_2",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pbe8_2_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbe8_3",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_0_proc1 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbe0_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbe0_1",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbe0_2",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbd_0",
    &setup_mmap_read_pf4_2_common,
    { { &setup_mmap_read_pf4_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbd_1",
    &setup_mmap_read_pbd_1_common,
    { { &setup_mmap_read_pbd_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbc0_0",
    &setup_mmap_read_pf0_2_common,
    { { &setup_mmap_read_pf0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pbc0_1",
    &setup_mmap_read_pbc0_1_common,
    { { &setup_mmap_read_pbc0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pb8_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pb8_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pb7_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb7_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb6c_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb6c_1",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb68_0",
    &setup_mmap_read_pda0_2_common,
    { { &setup_mmap_read_pda0_2_proc0 }, { &setup_mmap_read_pda0_2_proc1 } },
    &setup_mmap_read_pda0_2_procfinal,
    &setup_mmap_read_pda0_2_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb68_1",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_pda0_3_proc0 }, { &setup_mmap_read_pda0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb68_2",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_0_proc1 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb60_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb60_1",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb5_0",
    &setup_mmap_read_pf4_2_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pb5_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb5_1",
    &setup_mmap_read_pf4_2_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pb5_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb40_0",
    &setup_mmap_read_pf0_2_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pb40_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb40_1",
    &setup_mmap_read_pf0_2_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pb40_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb0_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pb0_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_pbf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_paf_0",
    &setup_mmap_read_paf_0_common,
    { { &setup_mmap_read_paf_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_paec_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pae8_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_2_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pae0_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pad_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pad_1",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pd4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pac0_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pac0_1",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pa8_0",
    &setup_mmap_read_pa8_0_common,
    { { &setup_mmap_read_pa8_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_pa7_0",
    &setup_mmap_read_paf_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pa6c_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pa68_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_1_proc0 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pa60_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pa5_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pd4_0_proc1 }, { &setup_mmap_read_pd4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pa40_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pe0_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_pa0_0",
    &setup_mmap_read_pa8_0_common,
    { { &setup_mmap_read_pa8_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_paf_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p9e_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p9d8_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p9d0_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_1_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p9c_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p9a_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_p9a_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p98_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p90_0",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p90_1",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p8e_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p8d8_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p8d0_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_1_proc1 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p8c_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p8a_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pd4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p88_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pe0_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p80_0",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_p9e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p7e_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7e_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7e_2",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7e_3",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7e_4",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7e_5",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7e_6",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7e_7",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pbf_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7b8_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7b8_1",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7b8_2",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7b8_3",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7b8_4",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7b8_5",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7b8_6",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7b8_7",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7a8_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7a8_1",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_1_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7a8_2",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_2_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7a8_3",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_1_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7a8_4",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_pfa0_3_proc0 }, { &setup_mmap_read_pfa0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7a8_5",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_2_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7a8_6",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_pbe8_0_proc0 }, { &setup_mmap_read_pfa0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7a8_7",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p7a8_8",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_pfa0_3_proc0 }, { &setup_mmap_read_pfa0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p790_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p790_1",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p790_2",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p790_3",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p790_4",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p790_5",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p790_6",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p790_7",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p76_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p76_1",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p76_2",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p76_3",
    &setup_mmap_read_pbd_1_common,
    { { &setup_mmap_read_p76_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p76_4",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_p76_4_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p76_5",
    &setup_mmap_read_pf4_2_common,
    { { &setup_mmap_read_pf4_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p72_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p72_1",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p72_2",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p72_3",
    &setup_mmap_read_pbc0_1_common,
    { { &setup_mmap_read_pf0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p72_4",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p72_5",
    &setup_mmap_read_pf0_2_common,
    { { &setup_mmap_read_pf0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p68_0",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p68_1",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p68_2",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p68_3",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p5e_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5e_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5b8_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5b8_1",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5b8_2",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5b8_3",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5b8_4",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5b8_5",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5b8_6",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5b8_7",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5a8_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_1_proc1 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5a8_1",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_1_proc0 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5a8_2",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_1_proc1 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5a8_3",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_1_proc0 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5a8_4",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_pda0_3_proc0 }, { &setup_mmap_read_pda0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5a8_5",
    &setup_mmap_read_pda0_2_common,
    { { &setup_mmap_read_pda0_2_proc0 }, { &setup_mmap_read_pda0_2_proc1 } },
    &setup_mmap_read_pda0_2_procfinal,
    &setup_mmap_read_pda0_2_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5a8_6",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5a8_7",
    &setup_mmap_read_pda0_2_common,
    { { &setup_mmap_read_pda0_2_proc0 }, { &setup_mmap_read_pda0_2_proc1 } },
    &setup_mmap_read_pda0_2_procfinal,
    &setup_mmap_read_pda0_2_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5a8_8",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p5a8_9",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_pda0_3_proc0 }, { &setup_mmap_read_pda0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p590_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p590_1",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p56_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pd4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p56_1",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pd4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p52_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pe0_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p52_1",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pe0_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p48_0",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_p7e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p48_1",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_p7e_4_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p3f_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pbf_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3f_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3f_2",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3ec_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3ec_1",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3ec_2",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3e8_0",
    &setup_mmap_read_p3e8_0_common,
    { { &setup_mmap_read_p3e8_0_proc0 }, { &setup_mmap_read_p3e8_0_proc1 } },
    &setup_mmap_read_pda0_2_procfinal,
    &setup_mmap_read_pda0_2_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3e8_1",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3e8_2",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_pfa0_3_proc0 }, { &setup_mmap_read_pfa0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3e8_3",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_0_proc1 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3e0_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3e0_1",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3e0_2",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3d_0",
    &setup_mmap_read_pf4_2_common,
    { { &setup_mmap_read_pf4_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3d_1",
    &setup_mmap_read_pbd_1_common,
    { { &setup_mmap_read_pbd_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3c0_0",
    &setup_mmap_read_pf0_2_common,
    { { &setup_mmap_read_pf0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p3c0_1",
    &setup_mmap_read_pbc0_1_common,
    { { &setup_mmap_read_pbc0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p38_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p38_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p37_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p37_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p36c_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p36c_1",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p368_0",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_p368_0_proc0 }, { &setup_mmap_read_pda0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p368_1",
    &setup_mmap_read_pfa0_3_common,
    { { &setup_mmap_read_pda0_3_proc0 }, { &setup_mmap_read_pda0_3_proc1 } },
    &setup_mmap_read_pfa0_3_procfinal,
    &setup_mmap_read_pfa0_3_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p368_2",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_0_proc1 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p360_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p360_1",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p35_0",
    &setup_mmap_read_pf4_2_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pb5_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p35_1",
    &setup_mmap_read_pf4_2_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pb5_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p340_0",
    &setup_mmap_read_pf0_2_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pb40_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p340_1",
    &setup_mmap_read_pf0_2_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pb40_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p30_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pdb0_0_proc1 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p30_1",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p3f_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p2f8_0",
    &setup_mmap_read_paf_0_common,
    { { &setup_mmap_read_paf_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2f8_1",
    &setup_mmap_read_paf_0_common,
    { { &setup_mmap_read_paf_0_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2f8_2",
    &setup_mmap_read_paf_0_common,
    { { &setup_mmap_read_pfc_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2f8_3",
    &setup_mmap_read_paf_0_common,
    { { &setup_mmap_read_pfc_3_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2ee_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2ee_1",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2ee_2",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_p2ee_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2ee_2_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2ee_3",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_p2ee_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2ee_3_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2ea_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_p2ea_0_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2ea_1",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_p2ea_1_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2ee_2_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2ea_2",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_2_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2ea_3",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_p2ea_1_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2ee_3_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2e4_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2e4_1",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2e4_2",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_p2e4_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2e4_3",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_p2e4_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2d8_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2d8_1",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_p2d8_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2d8_2",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_p76_4_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2d8_3",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_p2d8_3_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2d8_4",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf0_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2d8_5",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_p2d8_5_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2d8_5_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2d8_6",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_p2d8_6_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2d8_6_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2d8_7",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2d8_8",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf0_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2d8_9",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2c8_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2c8_1",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2c8_2",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2c8_3",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2a_0",
    &setup_mmap_read_pa8_0_common,
    { { &setup_mmap_read_pa8_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2a_1",
    &setup_mmap_read_pa8_0_common,
    { { &setup_mmap_read_pa8_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2a_2",
    &setup_mmap_read_pa8_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p2a_3",
    &setup_mmap_read_pa8_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p278_0",
    &setup_mmap_read_paf_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p278_1",
    &setup_mmap_read_paf_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p278_2",
    &setup_mmap_read_paf_0_common,
    { { &setup_mmap_read_pb40_0_proc1 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p278_3",
    &setup_mmap_read_paf_0_common,
    { { &setup_mmap_read_pb40_0_proc1 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p26e_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p26e_1",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p26e_2",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_p26e_2_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2ee_2_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p26e_3",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_p26e_2_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2ee_3_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p26a_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_1_proc0 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p26a_1",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pda0_1_proc0 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p26a_2",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_p26a_2_proc0 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2ee_2_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p26a_3",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_p26a_2_proc0 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2ee_3_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p264_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p264_1",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pdb0_1_proc0 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p264_2",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pb40_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p264_3",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pb40_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p258_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pd4_0_proc1 }, { &setup_mmap_read_pd4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p258_1",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_p258_1_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p258_2",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_p2d8_1_proc0 }, { &setup_mmap_read_p2d8_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p258_3",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_p2d8_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p258_4",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pe0_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p258_5",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pe0_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p248_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pe0_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p248_1",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pe0_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p22_0",
    &setup_mmap_read_pa8_0_common,
    { { &setup_mmap_read_pa8_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p22_1",
    &setup_mmap_read_pa8_0_common,
    { { &setup_mmap_read_pa8_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p22_2",
    &setup_mmap_read_pa8_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p22_3",
    &setup_mmap_read_pa8_0_common,
    { { &setup_mmap_read_pe0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p2f8_1_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p1e_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_2_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p1d8_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pfb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p1d0_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_1_proc0 }, { &setup_mmap_read_pfa0_1_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p1c_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfb0_1_proc0 }, { &setup_mmap_read_pfc_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p1a_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_p9a_0_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pfa0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p18_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf0_1_proc0 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p10_0",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_1_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p10_1",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-mmap_read_p0e_0",
    &setup_mmap_read_pfc_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pfc_0_proc0 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p0d8_0",
    &setup_mmap_read_pfb0_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pdb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p0d0_0",
    &setup_mmap_read_pfa0_0_common,
    { { &setup_mmap_read_pfa0_1_proc1 }, { &setup_mmap_read_pda0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p0c_0",
    &setup_mmap_read_pf8_0_common,
    { { &setup_mmap_read_pfc_0_proc1 }, { &setup_mmap_read_pdb0_0_proc1 } },
    &setup_mmap_read_pfc_0_procfinal,
    &setup_mmap_read_pfc_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p0a_0",
    &setup_mmap_read_pf4_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pd4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pda0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p08_0",
    &setup_mmap_read_pf0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pe0_1_proc0 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_final,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_read_p00_0",
    &setup_mmap_read_pe0_0_common,
    { { &setup_mmap_read_pf4_0_proc1 }, { &setup_mmap_read_pf4_0_proc1 } },
    &setup_mmap_read_pf4_0_procfinal,
    &setup_mmap_read_pf4_0_procfinal,
    { { &test_mmap_read_p1e_0_0, 0, "mmap" },
      { &test_mmap_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-mmap_rename_pf0_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pf0_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_pf0_0_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pe8_0",
    &setup_mmap_rename_pe8_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_pf0_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pe0_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_pf0_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pc_0",
    &setup_mmap_rename_pc_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_procfinal,
    { { &test_mmap_rename_pf0_0_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pbc_0",
    &setup_mmap_rename_pbc_0_common,
    { { &setup_mmap_rename_pbc_0_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_pbc_0_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pbc_1",
    &setup_mmap_rename_pbc_0_common,
    { { &setup_mmap_rename_pbc_1_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_pbc_0_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pba_0",
    &setup_mmap_rename_pba_0_common,
    { { &setup_mmap_rename_pbc_0_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_pbc_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pba_1",
    &setup_mmap_rename_pba_0_common,
    { { &setup_mmap_rename_pbc_1_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_pbc_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pb8_0",
    &setup_mmap_rename_pbc_0_common,
    { { &setup_mmap_rename_pbc_0_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_pbc_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pb8_1",
    &setup_mmap_rename_pbc_0_common,
    { { &setup_mmap_rename_pbc_1_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_pbc_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pb0_0",
    &setup_mmap_rename_pb0_0_common,
    { { &setup_mmap_rename_pbc_0_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_pbc_0_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pb0_1",
    &setup_mmap_rename_pb0_0_common,
    { { &setup_mmap_rename_pbc_1_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_pbc_0_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pac_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_pac_0_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_paa_0",
    &setup_mmap_rename_pe8_0_common,
    { { &setup_mmap_rename_paa_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_pac_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pa8_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_pac_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_pa0_0",
    &setup_mmap_rename_pa0_0_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_pac_0_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p98_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p98_0_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p94_0",
    &setup_mmap_rename_pe8_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p98_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p90_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p98_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p8_0",
    &setup_mmap_rename_pc_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_procfinal,
    { { &test_mmap_rename_p98_0_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p78_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p78_0_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p78_1",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p78_1_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p6c_0",
    &setup_mmap_rename_pe8_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p78_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p6c_1",
    &setup_mmap_rename_pe8_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p78_1_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p64_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p78_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p64_1",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p78_1_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p50_0",
    &setup_mmap_rename_pc_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_procfinal,
    { { &test_mmap_rename_p78_0_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p50_1",
    &setup_mmap_rename_pc_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_procfinal,
    { { &test_mmap_rename_p78_1_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p3c_0",
    &setup_mmap_rename_pbc_0_common,
    { { &setup_mmap_rename_pbc_0_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_p3c_0_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p3c_1",
    &setup_mmap_rename_pbc_0_common,
    { { &setup_mmap_rename_pbc_1_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_p3c_0_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p3a_0",
    &setup_mmap_rename_pba_0_common,
    { { &setup_mmap_rename_pbc_0_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_p3c_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p3a_1",
    &setup_mmap_rename_pba_0_common,
    { { &setup_mmap_rename_pbc_1_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_p3c_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p38_0",
    &setup_mmap_rename_pbc_0_common,
    { { &setup_mmap_rename_pbc_0_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_p3c_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p38_1",
    &setup_mmap_rename_pbc_0_common,
    { { &setup_mmap_rename_pbc_1_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_p3c_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p30_0",
    &setup_mmap_rename_pb0_0_common,
    { { &setup_mmap_rename_pbc_0_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_p3c_0_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p30_1",
    &setup_mmap_rename_pb0_0_common,
    { { &setup_mmap_rename_pbc_1_proc0 }, { &setup_mmap_rename_pbc_0_proc1 } },
    &setup_mmap_rename_pbc_0_procfinal,
    &setup_mmap_rename_pbc_0_final,
    { { &test_mmap_rename_p3c_0_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p2e_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p2e_0_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p2e_1",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p2e_1_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p2b0_0",
    &setup_mmap_rename_pe8_0_common,
    { { &setup_mmap_rename_paa_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p2e_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p2b0_1",
    &setup_mmap_rename_pe8_0_common,
    { { &setup_mmap_rename_paa_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p2e_1_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p2b0_2",
    &setup_mmap_rename_p2b0_2_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p2e_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p2b0_3",
    &setup_mmap_rename_p2b0_2_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p2e_1_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p29_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p2e_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p29_1",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p2e_1_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p24_0",
    &setup_mmap_rename_pa0_0_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p2e_0_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p24_1",
    &setup_mmap_rename_pa0_0_common,
    { { &setup_mmap_rename_pac_0_proc0 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p2e_1_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p18_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p18_0_0, 0, "mmap" },
      { &test_mmap_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p14_0",
    &setup_mmap_rename_pe8_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p18_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p10_0",
    &setup_mmap_rename_pf0_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_final,
    { { &test_mmap_rename_p18_0_0, 0, "mmap" },
      { &test_mmap_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_rename_p0_0",
    &setup_mmap_rename_pc_0_common,
    { { &setup_mmap_rename_pf0_0_proc1 }, { &setup_mmap_rename_pf0_0_proc1 } },
    &setup_mmap_rename_pf0_0_procfinal,
    &setup_mmap_rename_pf0_0_procfinal,
    { { &test_mmap_rename_p18_0_0, 0, "mmap" },
      { &test_mmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mmap_stat_pe_0",
    &setup_mmap_stat_pe_0_common,
    { { &setup_mmap_stat_pe_0_proc0 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_pe_0_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_pc_0",
    &setup_mmap_stat_pc_0_common,
    { { &setup_mmap_stat_pe_0_proc1 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_procfinal,
    { { &test_mmap_stat_pe_0_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_pb8_0",
    &setup_mmap_stat_pb8_0_common,
    { { &setup_mmap_stat_pb8_0_proc0 }, { &setup_mmap_stat_pb8_0_proc1 } },
    &setup_mmap_stat_pb8_0_procfinal,
    &setup_mmap_stat_pb8_0_final,
    { { &test_mmap_stat_pb8_0_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_pb8_1",
    &setup_mmap_stat_pb8_0_common,
    { { &setup_mmap_stat_pb8_1_proc0 }, { &setup_mmap_stat_pb8_0_proc1 } },
    &setup_mmap_stat_pb8_0_procfinal,
    &setup_mmap_stat_pb8_0_final,
    { { &test_mmap_stat_pb8_0_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_pb0_0",
    &setup_mmap_stat_pb0_0_common,
    { { &setup_mmap_stat_pb8_0_proc0 }, { &setup_mmap_stat_pb8_0_proc1 } },
    &setup_mmap_stat_pb8_0_procfinal,
    &setup_mmap_stat_pb8_0_final,
    { { &test_mmap_stat_pb8_0_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_pb0_1",
    &setup_mmap_stat_pb0_0_common,
    { { &setup_mmap_stat_pb8_1_proc0 }, { &setup_mmap_stat_pb8_0_proc1 } },
    &setup_mmap_stat_pb8_0_procfinal,
    &setup_mmap_stat_pb8_0_final,
    { { &test_mmap_stat_pb8_0_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_pa8_0",
    &setup_mmap_stat_pe_0_common,
    { { &setup_mmap_stat_pa8_0_proc0 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_pa8_0_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_pa0_0",
    &setup_mmap_stat_pa0_0_common,
    { { &setup_mmap_stat_pa8_0_proc0 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_pa8_0_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p9_0",
    &setup_mmap_stat_pe_0_common,
    { { &setup_mmap_stat_pe_0_proc1 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_p9_0_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p8_0",
    &setup_mmap_stat_pc_0_common,
    { { &setup_mmap_stat_pe_0_proc1 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_procfinal,
    { { &test_mmap_stat_p9_0_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p70_0",
    &setup_mmap_stat_pe_0_common,
    { { &setup_mmap_stat_pe_0_proc1 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_p70_0_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p70_1",
    &setup_mmap_stat_pe_0_common,
    { { &setup_mmap_stat_pe_0_proc1 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_p70_1_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p50_0",
    &setup_mmap_stat_pc_0_common,
    { { &setup_mmap_stat_pe_0_proc1 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_procfinal,
    { { &test_mmap_stat_p70_0_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p50_1",
    &setup_mmap_stat_pc_0_common,
    { { &setup_mmap_stat_pe_0_proc1 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_procfinal,
    { { &test_mmap_stat_p70_1_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p38_0",
    &setup_mmap_stat_pb8_0_common,
    { { &setup_mmap_stat_pb8_0_proc0 }, { &setup_mmap_stat_pb8_0_proc1 } },
    &setup_mmap_stat_pb8_0_procfinal,
    &setup_mmap_stat_pb8_0_final,
    { { &test_mmap_stat_p38_0_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p38_1",
    &setup_mmap_stat_pb8_0_common,
    { { &setup_mmap_stat_pb8_1_proc0 }, { &setup_mmap_stat_pb8_0_proc1 } },
    &setup_mmap_stat_pb8_0_procfinal,
    &setup_mmap_stat_pb8_0_final,
    { { &test_mmap_stat_p38_0_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p30_0",
    &setup_mmap_stat_pb0_0_common,
    { { &setup_mmap_stat_pb8_0_proc0 }, { &setup_mmap_stat_pb8_0_proc1 } },
    &setup_mmap_stat_pb8_0_procfinal,
    &setup_mmap_stat_pb8_0_final,
    { { &test_mmap_stat_p38_0_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p30_1",
    &setup_mmap_stat_pb0_0_common,
    { { &setup_mmap_stat_pb8_1_proc0 }, { &setup_mmap_stat_pb8_0_proc1 } },
    &setup_mmap_stat_pb8_0_procfinal,
    &setup_mmap_stat_pb8_0_final,
    { { &test_mmap_stat_p38_0_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p2c_0",
    &setup_mmap_stat_pe_0_common,
    { { &setup_mmap_stat_pa8_0_proc0 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_p2c_0_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p2c_1",
    &setup_mmap_stat_pe_0_common,
    { { &setup_mmap_stat_pa8_0_proc0 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_p2c_1_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p24_0",
    &setup_mmap_stat_pa0_0_common,
    { { &setup_mmap_stat_pa8_0_proc0 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_p2c_0_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p24_1",
    &setup_mmap_stat_pa0_0_common,
    { { &setup_mmap_stat_pa8_0_proc0 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_p2c_1_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p1_0",
    &setup_mmap_stat_pe_0_common,
    { { &setup_mmap_stat_pe_0_proc1 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_final,
    { { &test_mmap_stat_p1_0_0, 0, "mmap" },
      { &test_mmap_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_stat_p0_0",
    &setup_mmap_stat_pc_0_common,
    { { &setup_mmap_stat_pe_0_proc1 }, { &setup_mmap_stat_pe_0_proc1 } },
    &setup_mmap_stat_pe_0_procfinal,
    &setup_mmap_stat_pe_0_procfinal,
    { { &test_mmap_stat_p1_0_0, 0, "mmap" },
      { &test_mmap_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mmap_unlink_pe_0",
    &setup_mmap_unlink_pe_0_common,
    { { &setup_mmap_unlink_pe_0_proc0 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_pe_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_pc_0",
    &setup_mmap_unlink_pc_0_common,
    { { &setup_mmap_unlink_pe_0_proc1 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_procfinal,
    { { &test_mmap_unlink_pe_0_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_pb8_0",
    &setup_mmap_unlink_pb8_0_common,
    { { &setup_mmap_unlink_pb8_0_proc0 }, { &setup_mmap_unlink_pb8_0_proc1 } },
    &setup_mmap_unlink_pb8_0_procfinal,
    &setup_mmap_unlink_pb8_0_final,
    { { &test_mmap_unlink_pb8_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_pb8_1",
    &setup_mmap_unlink_pb8_0_common,
    { { &setup_mmap_unlink_pb8_1_proc0 }, { &setup_mmap_unlink_pb8_0_proc1 } },
    &setup_mmap_unlink_pb8_0_procfinal,
    &setup_mmap_unlink_pb8_0_final,
    { { &test_mmap_unlink_pb8_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_pb0_0",
    &setup_mmap_unlink_pb0_0_common,
    { { &setup_mmap_unlink_pb8_0_proc0 }, { &setup_mmap_unlink_pb8_0_proc1 } },
    &setup_mmap_unlink_pb8_0_procfinal,
    &setup_mmap_unlink_pb8_0_final,
    { { &test_mmap_unlink_pb8_0_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_pb0_1",
    &setup_mmap_unlink_pb0_0_common,
    { { &setup_mmap_unlink_pb8_1_proc0 }, { &setup_mmap_unlink_pb8_0_proc1 } },
    &setup_mmap_unlink_pb8_0_procfinal,
    &setup_mmap_unlink_pb8_0_final,
    { { &test_mmap_unlink_pb8_0_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_pa8_0",
    &setup_mmap_unlink_pe_0_common,
    { { &setup_mmap_unlink_pa8_0_proc0 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_pa8_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_pa0_0",
    &setup_mmap_unlink_pa0_0_common,
    { { &setup_mmap_unlink_pa0_0_proc0 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_pa8_0_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p90_0",
    &setup_mmap_unlink_pe_0_common,
    { { &setup_mmap_unlink_pe_0_proc1 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_p90_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p8_0",
    &setup_mmap_unlink_pc_0_common,
    { { &setup_mmap_unlink_pe_0_proc1 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_procfinal,
    { { &test_mmap_unlink_p90_0_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p70_0",
    &setup_mmap_unlink_pe_0_common,
    { { &setup_mmap_unlink_pe_0_proc1 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_p70_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p70_1",
    &setup_mmap_unlink_pe_0_common,
    { { &setup_mmap_unlink_pe_0_proc1 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_p70_1_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p50_0",
    &setup_mmap_unlink_pc_0_common,
    { { &setup_mmap_unlink_pe_0_proc1 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_procfinal,
    { { &test_mmap_unlink_p70_0_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p50_1",
    &setup_mmap_unlink_pc_0_common,
    { { &setup_mmap_unlink_pe_0_proc1 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_procfinal,
    { { &test_mmap_unlink_p70_1_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p38_0",
    &setup_mmap_unlink_pb8_0_common,
    { { &setup_mmap_unlink_pb8_0_proc0 }, { &setup_mmap_unlink_pb8_0_proc1 } },
    &setup_mmap_unlink_pb8_0_procfinal,
    &setup_mmap_unlink_pb8_0_final,
    { { &test_mmap_unlink_p38_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p38_1",
    &setup_mmap_unlink_pb8_0_common,
    { { &setup_mmap_unlink_pb8_1_proc0 }, { &setup_mmap_unlink_pb8_0_proc1 } },
    &setup_mmap_unlink_pb8_0_procfinal,
    &setup_mmap_unlink_pb8_0_final,
    { { &test_mmap_unlink_p38_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p30_0",
    &setup_mmap_unlink_pb0_0_common,
    { { &setup_mmap_unlink_pb8_0_proc0 }, { &setup_mmap_unlink_pb8_0_proc1 } },
    &setup_mmap_unlink_pb8_0_procfinal,
    &setup_mmap_unlink_pb8_0_final,
    { { &test_mmap_unlink_p38_0_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p30_1",
    &setup_mmap_unlink_pb0_0_common,
    { { &setup_mmap_unlink_pb8_1_proc0 }, { &setup_mmap_unlink_pb8_0_proc1 } },
    &setup_mmap_unlink_pb8_0_procfinal,
    &setup_mmap_unlink_pb8_0_final,
    { { &test_mmap_unlink_p38_0_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p2c_0",
    &setup_mmap_unlink_pe_0_common,
    { { &setup_mmap_unlink_pa8_0_proc0 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_p2c_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p2c_1",
    &setup_mmap_unlink_pe_0_common,
    { { &setup_mmap_unlink_pa8_0_proc0 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_p2c_1_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p2c_2",
    &setup_mmap_unlink_p2c_2_common,
    { { &setup_mmap_unlink_pa0_0_proc0 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_p2c_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p2c_3",
    &setup_mmap_unlink_p2c_2_common,
    { { &setup_mmap_unlink_pa0_0_proc0 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_p2c_1_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p24_0",
    &setup_mmap_unlink_pa0_0_common,
    { { &setup_mmap_unlink_pa0_0_proc0 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_p2c_0_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p24_1",
    &setup_mmap_unlink_pa0_0_common,
    { { &setup_mmap_unlink_pa0_0_proc0 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_p2c_1_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p10_0",
    &setup_mmap_unlink_pe_0_common,
    { { &setup_mmap_unlink_pe_0_proc1 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_final,
    { { &test_mmap_unlink_p10_0_0, 0, "mmap" },
      { &test_mmap_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_unlink_p0_0",
    &setup_mmap_unlink_pc_0_common,
    { { &setup_mmap_unlink_pe_0_proc1 }, { &setup_mmap_unlink_pe_0_proc1 } },
    &setup_mmap_unlink_pe_0_procfinal,
    &setup_mmap_unlink_pe_0_procfinal,
    { { &test_mmap_unlink_p10_0_0, 0, "mmap" },
      { &test_mmap_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mmap_write_pfe_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pfe_1",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_1_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pfe_2",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_2_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pfe_3",
    &setup_mmap_write_pfe_3_common,
    { { &setup_mmap_write_pfe_3_proc0 }, { &setup_mmap_write_pfe_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pfc_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pfc_1",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pfc_2",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pfc_3",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pf8_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pf8_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pf8_2",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pf8_3",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pf4_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pf4_1",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pf4_2",
    &setup_mmap_write_pf4_2_common,
    { { &setup_mmap_write_pf4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pf0_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pf0_1",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pf0_2",
    &setup_mmap_write_pf0_2_common,
    { { &setup_mmap_write_pf4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pe0_0",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pe0_1",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pde_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pde_1",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pde_1_proc0 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pde_2",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pfe_1_proc1 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pde_3",
    &setup_mmap_write_pde_3_common,
    { { &setup_mmap_write_pde_3_proc0 }, { &setup_mmap_write_pde_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pdc_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc1 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pdc_1",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pdc_1_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pdc_2",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pdc_3",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pd8_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc1 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pd4_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pd0_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pc0_0",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_pfe_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pbf8_0",
    &setup_mmap_write_pfe_3_common,
    { { &setup_mmap_write_pfe_3_proc0 }, { &setup_mmap_write_pfe_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbf8_1",
    &setup_mmap_write_pbf8_1_common,
    { { &setup_mmap_write_pbf8_1_proc0 }, { &setup_mmap_write_pbf8_1_proc1 } },
    &setup_mmap_write_pbf8_1_procfinal,
    &setup_mmap_write_pbf8_1_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbf8_2",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pde_1_proc1 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbf0_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbf0_1",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbf0_2",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbe_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pbe_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbe_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbe_2",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbd0_0",
    &setup_mmap_write_pf4_2_common,
    { { &setup_mmap_write_pf4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbd0_1",
    &setup_mmap_write_pbd0_1_common,
    { { &setup_mmap_write_pbd0_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbc0_0",
    &setup_mmap_write_pf0_2_common,
    { { &setup_mmap_write_pf4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pbc0_1",
    &setup_mmap_write_pbc0_1_common,
    { { &setup_mmap_write_pbd0_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pb8_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pb8_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pb78_0",
    &setup_mmap_write_pde_3_common,
    { { &setup_mmap_write_pb78_0_proc0 }, { &setup_mmap_write_pde_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb78_1",
    &setup_mmap_write_pde_3_common,
    { { &setup_mmap_write_pde_3_proc0 }, { &setup_mmap_write_pde_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb78_2",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pde_1_proc1 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb70_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb70_1",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb6_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb6_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb50_0",
    &setup_mmap_write_pf4_2_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pb50_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb50_1",
    &setup_mmap_write_pf4_2_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pb50_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb40_0",
    &setup_mmap_write_pf0_2_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pb50_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb40_1",
    &setup_mmap_write_pf0_2_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pb50_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb0_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pb0_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_pbf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_paf8_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_2_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_paf0_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pae_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pae_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pad0_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pad0_1",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pac0_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pac0_1",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pa8_0",
    &setup_mmap_write_pa8_0_common,
    { { &setup_mmap_write_pa8_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_pa78_0",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pde_1_proc0 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pa70_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pdc_1_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pa6_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pdc_1_proc0 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pa50_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pa40_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_pa0_0",
    &setup_mmap_write_pa8_0_common,
    { { &setup_mmap_write_pa8_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_paf8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p9f_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_1_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p9e_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p9c_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p9a_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p98_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p90_0",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p90_1",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p8f_0",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pfe_1_proc1 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p8e_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc1 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p8c_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc1 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p8a_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p88_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p80_0",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_p9f_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p7f0_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7f0_1",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_1_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7f0_2",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_1_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7f0_3",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_2_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7f0_4",
    &setup_mmap_write_pfe_3_common,
    { { &setup_mmap_write_pfe_3_proc0 }, { &setup_mmap_write_pfe_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7f0_5",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_2_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7f0_6",
    &setup_mmap_write_pfe_3_common,
    { { &setup_mmap_write_pfe_3_proc0 }, { &setup_mmap_write_pfe_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7f0_7",
    &setup_mmap_write_pfe_3_common,
    { { &setup_mmap_write_p7f0_7_proc0 }, { &setup_mmap_write_pfe_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7f0_8",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_p7f0_8_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7d0_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7d0_1",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7d0_2",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7d0_3",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7d0_4",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7d0_5",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7d0_6",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7d0_7",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7a_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7a_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7a_2",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7a_3",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7a_4",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7a_5",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7a_6",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p7a_7",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p76_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p76_1",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p76_2",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p76_3",
    &setup_mmap_write_pbd0_1_common,
    { { &setup_mmap_write_pf4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p76_4",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p76_5",
    &setup_mmap_write_pf4_2_common,
    { { &setup_mmap_write_pf4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p72_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p72_1",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p72_2",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p72_3",
    &setup_mmap_write_pbc0_1_common,
    { { &setup_mmap_write_pf4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p72_4",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p72_5",
    &setup_mmap_write_pf0_2_common,
    { { &setup_mmap_write_pf4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p68_0",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p68_1",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p68_2",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p68_3",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p5f0_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5f0_1",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pfe_1_proc1 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5f0_2",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pfe_1_proc1 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5f0_3",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pde_1_proc0 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5f0_4",
    &setup_mmap_write_pde_3_common,
    { { &setup_mmap_write_pde_3_proc0 }, { &setup_mmap_write_pde_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5f0_5",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pde_1_proc0 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5f0_6",
    &setup_mmap_write_pde_3_common,
    { { &setup_mmap_write_pde_3_proc0 }, { &setup_mmap_write_pde_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5f0_7",
    &setup_mmap_write_pde_3_common,
    { { &setup_mmap_write_pb78_0_proc0 }, { &setup_mmap_write_pde_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5f0_8",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pde_1_proc1 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5d0_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc1 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5d0_1",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pdc_1_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5d0_2",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc1 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5d0_3",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pdc_1_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5d0_4",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5d0_5",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5d0_6",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5d0_7",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5a_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc1 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p5a_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc1 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p56_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p56_1",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p52_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p52_1",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p48_0",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_p7f0_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p48_1",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_p7f0_2_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p3f8_0",
    &setup_mmap_write_pfe_3_common,
    { { &setup_mmap_write_p7f0_7_proc0 }, { &setup_mmap_write_pfe_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3f8_1",
    &setup_mmap_write_pfe_3_common,
    { { &setup_mmap_write_pfe_3_proc0 }, { &setup_mmap_write_pfe_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3f8_2",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_p7f0_8_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3f8_3",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pde_1_proc1 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3f0_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3f0_1",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3f0_2",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3e_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pbe_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3e_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3e_2",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3d0_0",
    &setup_mmap_write_pf4_2_common,
    { { &setup_mmap_write_pf4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3d0_1",
    &setup_mmap_write_pbd0_1_common,
    { { &setup_mmap_write_pbd0_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3c0_0",
    &setup_mmap_write_pf0_2_common,
    { { &setup_mmap_write_pf4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p3c0_1",
    &setup_mmap_write_pbc0_1_common,
    { { &setup_mmap_write_pbd0_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p38_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p38_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p378_0",
    &setup_mmap_write_pde_3_common,
    { { &setup_mmap_write_pb78_0_proc0 }, { &setup_mmap_write_pde_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p378_1",
    &setup_mmap_write_pde_3_common,
    { { &setup_mmap_write_pde_3_proc0 }, { &setup_mmap_write_pde_3_proc1 } },
    &setup_mmap_write_pfe_3_procfinal,
    &setup_mmap_write_pfe_3_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p378_2",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pde_1_proc1 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p370_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p370_1",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p36_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p36_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p350_0",
    &setup_mmap_write_pf4_2_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pb50_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p350_1",
    &setup_mmap_write_pf4_2_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pb50_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p340_0",
    &setup_mmap_write_pf0_2_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pb50_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p340_1",
    &setup_mmap_write_pf0_2_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pb50_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p30_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p30_1",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p3f8_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p2fc_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_2_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2fc_1",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_2_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2fc_2",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_p2fc_2_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2fc_3",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_p2fc_2_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2f4_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2f4_1",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_3_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2f4_2",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_p2f4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2f4_3",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_p2f4_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2e8_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pae_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2e8_1",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pf8_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2e8_2",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pae_0_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2e8_3",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pf8_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2d8_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2d8_1",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2d8_2",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2d8_3",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2c8_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2c8_1",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2c8_2",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2c8_3",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2a_0",
    &setup_mmap_write_pa8_0_common,
    { { &setup_mmap_write_pa8_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2a_1",
    &setup_mmap_write_pa8_0_common,
    { { &setup_mmap_write_pa8_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2a_2",
    &setup_mmap_write_pa8_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p2a_3",
    &setup_mmap_write_pa8_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p27c_0",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pde_1_proc0 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p27c_1",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pde_1_proc0 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p27c_2",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_p27c_2_proc0 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p27c_3",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_p27c_2_proc0 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p274_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pdc_1_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p274_1",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pdc_1_proc0 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p274_2",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pb50_0_proc1 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p274_3",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pb50_0_proc1 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p268_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pdc_1_proc0 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p268_1",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pdc_1_proc0 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p268_2",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pb50_0_proc1 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p268_3",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pb50_0_proc1 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p258_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p258_1",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p248_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p248_1",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p22_0",
    &setup_mmap_write_pa8_0_common,
    { { &setup_mmap_write_pa8_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p22_1",
    &setup_mmap_write_pa8_0_common,
    { { &setup_mmap_write_pa8_0_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p22_2",
    &setup_mmap_write_pa8_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p22_3",
    &setup_mmap_write_pa8_0_common,
    { { &setup_mmap_write_pe0_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p2fc_1_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p1f_0",
    &setup_mmap_write_pfe_0_common,
    { { &setup_mmap_write_pfe_1_proc0 }, { &setup_mmap_write_pfe_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p1e_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfc_2_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p1c_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pf8_1_proc0 }, { &setup_mmap_write_pfe_0_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p1a_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p18_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_1_proc0 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p10_0",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_1_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p10_1",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mmap_write_p0f_0",
    &setup_mmap_write_pde_1_common,
    { { &setup_mmap_write_pfe_1_proc1 }, { &setup_mmap_write_pde_1_proc1 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p0e_0",
    &setup_mmap_write_pfc_0_common,
    { { &setup_mmap_write_pfe_0_proc1 }, { &setup_mmap_write_pfe_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p0c_0",
    &setup_mmap_write_pf8_0_common,
    { { &setup_mmap_write_pfe_0_proc1 }, { &setup_mmap_write_pf8_0_proc0 } },
    &setup_mmap_write_pfe_0_procfinal,
    &setup_mmap_write_pfe_0_final,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p0a_0",
    &setup_mmap_write_pf4_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p08_0",
    &setup_mmap_write_pf0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pe0_1_proc0 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_final,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pdc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mmap_write_p00_0",
    &setup_mmap_write_pe0_0_common,
    { { &setup_mmap_write_pf4_0_proc1 }, { &setup_mmap_write_pf4_0_proc1 } },
    &setup_mmap_write_pf4_0_procfinal,
    &setup_mmap_write_pf4_0_procfinal,
    { { &test_mmap_write_p1f_0_0, 0, "mmap" },
      { &test_mmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_0",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_0_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_1",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_0_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_2",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_0_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_3",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_0_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_4",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_4_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_5",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_5_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_6",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_5_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_7",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_5_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_8",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_5_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_9",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_9_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_10",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_10_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_11",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_11_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_12",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_10_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_13",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_11_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_14",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_10_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_15",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_10_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_16",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_11_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_17",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_11_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_18",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_18_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_19",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_19_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_20",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_18_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_21",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_19_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_22",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_4_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_23",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_23_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_24",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_23_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_25",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_4_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_26",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_18_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_27",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_23_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_28",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_19_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_29",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_4_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_30",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_18_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_31",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_23_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_32",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_19_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_33",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_33_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_34",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_34_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_35",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_35_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_36",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_33_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_37",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_35_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_38",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_33_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_39",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_33_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_40",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_35_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_41",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_35_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_42",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_42_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_43",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_34_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_44",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_42_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_45",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_34_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_46",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_42_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_47",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_34_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_48",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_42_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_49",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_49_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_50",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_50_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_51",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_9_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_52",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_50_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_53",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_9_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_54",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_9_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_55",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_50_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_56",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_50_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_57",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_57_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_58",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_49_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_59",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_57_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_60",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_49_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_61",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_57_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_62",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_49_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_63",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_57_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_1_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_64",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_64_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_65",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_65_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_66",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_64_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_67",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_65_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_68",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_68_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_69",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_69_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_70",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_68_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pe_71",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_69_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_2_0, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pc_0",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_64_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pc_1",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_68_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pc_2",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_65_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pc_3",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_69_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_0",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_64_proc0 }, { &setup_mprotect_mprotect_pe_64_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_1",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_64_proc0 }, { &setup_mprotect_mprotect_pe_68_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_2",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_68_proc0 }, { &setup_mprotect_mprotect_pe_64_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_3",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_68_proc0 }, { &setup_mprotect_mprotect_pe_68_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_4",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_65_proc0 }, { &setup_mprotect_mprotect_pe_64_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_5",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_69_proc0 }, { &setup_mprotect_mprotect_pe_64_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_6",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_65_proc0 }, { &setup_mprotect_mprotect_pe_68_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_7",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_69_proc0 }, { &setup_mprotect_mprotect_pe_68_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_8",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_64_proc0 }, { &setup_mprotect_mprotect_pe_65_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_9",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_65_proc0 }, { &setup_mprotect_mprotect_pe_65_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_10",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_64_proc0 }, { &setup_mprotect_mprotect_pe_69_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_11",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_65_proc0 }, { &setup_mprotect_mprotect_pe_69_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_12",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_68_proc0 }, { &setup_mprotect_mprotect_pe_65_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_13",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_68_proc0 }, { &setup_mprotect_mprotect_pe_69_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_14",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_69_proc0 }, { &setup_mprotect_mprotect_pe_65_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_pa_15",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_69_proc0 }, { &setup_mprotect_mprotect_pe_69_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p8_0",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_64_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_p8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p8_1",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_68_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_p8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p8_2",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_65_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_p8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p8_3",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_69_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_pe_0_0, 0, "mprotect" },
      { &test_mprotect_mprotect_p8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p6_0",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_p6_0_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p6_1",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_p6_1_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p6_2",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_p6_2_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p6_3",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_p6_3_proc0 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p4_0",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_0_proc1 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_pc_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p4_1",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_0_proc1 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p2_0",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_0_proc1 }, { &setup_mprotect_mprotect_pe_64_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p2_1",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_0_proc1 }, { &setup_mprotect_mprotect_pe_68_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p2_2",
    &setup_mprotect_mprotect_pe_0_common,
    { { &setup_mprotect_mprotect_pe_0_proc1 }, { &setup_mprotect_mprotect_pe_65_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_final,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p2_3",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_0_proc1 }, { &setup_mprotect_mprotect_pe_69_proc0 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_pe_0_0, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_mprotect_p0_0",
    &setup_mprotect_mprotect_pe_4_common,
    { { &setup_mprotect_mprotect_pe_0_proc1 }, { &setup_mprotect_mprotect_pe_0_proc1 } },
    &setup_mprotect_mprotect_pe_0_procfinal,
    &setup_mprotect_mprotect_pe_0_procfinal,
    { { &test_mprotect_mprotect_p8_0_1, 0, "mprotect" },
      { &test_mprotect_mprotect_p8_0_1, 1, "mprotect" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_0",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_0_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_1",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_1_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_2",
    &setup_mprotect_munmap_pe_2_common,
    { { &setup_mprotect_munmap_pe_2_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_procfinal,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_3",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_3_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_4",
    &setup_mprotect_munmap_pe_2_common,
    { { &setup_mprotect_munmap_pe_4_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_procfinal,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_5",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_5_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_6",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_6_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_7",
    &setup_mprotect_munmap_pe_2_common,
    { { &setup_mprotect_munmap_pe_7_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_procfinal,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_8",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_8_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_9",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_9_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_10",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_10_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_11",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_11_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_12",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_12_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_13",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_13_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_14",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_14_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_15",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_15_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_16",
    &setup_mprotect_munmap_pe_2_common,
    { { &setup_mprotect_munmap_pe_16_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_procfinal,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_17",
    &setup_mprotect_munmap_pe_2_common,
    { { &setup_mprotect_munmap_pe_17_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_procfinal,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_18",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_18_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_pe_19",
    &setup_mprotect_munmap_pe_2_common,
    { { &setup_mprotect_munmap_pe_19_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_procfinal,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_pe_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_p8_0",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_1_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_p8_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_p8_1",
    &setup_mprotect_munmap_pe_2_common,
    { { &setup_mprotect_munmap_pe_2_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_procfinal,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_p8_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_p8_2",
    &setup_mprotect_munmap_pe_0_common,
    { { &setup_mprotect_munmap_pe_3_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_final,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_p8_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_p8_3",
    &setup_mprotect_munmap_pe_2_common,
    { { &setup_mprotect_munmap_pe_4_proc0 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_procfinal,
    { { &test_mprotect_munmap_pe_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_p8_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_p4_0",
    &setup_mprotect_munmap_pe_2_common,
    { { &setup_mprotect_munmap_pe_0_proc1 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_procfinal,
    { { &test_mprotect_munmap_p4_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_p8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-mprotect_munmap_p0_0",
    &setup_mprotect_munmap_pe_2_common,
    { { &setup_mprotect_munmap_pe_0_proc1 }, { &setup_mprotect_munmap_pe_0_proc1 } },
    &setup_mprotect_munmap_pe_0_procfinal,
    &setup_mprotect_munmap_pe_0_procfinal,
    { { &test_mprotect_munmap_p4_0_0, 0, "mprotect" },
      { &test_mprotect_munmap_p8_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-mprotect_open_pf_0",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pf_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pf_1",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pf_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pf_2",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_2_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pf_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pf_3",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pf_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pee_0",
    &setup_mprotect_open_pee_0_common,
    { { &setup_mprotect_open_pee_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pee_1",
    &setup_mprotect_open_pee_1_common,
    { { &setup_mprotect_open_pee_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pee_2",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pee_3",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pea_0",
    &setup_mprotect_open_pee_1_common,
    { { &setup_mprotect_open_pea_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pea_1",
    &setup_mprotect_open_pee_0_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pea_2",
    &setup_mprotect_open_pee_0_common,
    { { &setup_mprotect_open_pea_2_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pea_3",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pe6_0",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pe6_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pe6_1",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pe6_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pe6_2",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pe6_3",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pe2_0",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pe6_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pe2_1",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pe6_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pe2_2",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pe2_3",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pdc_0",
    &setup_mprotect_open_pdc_0_common,
    { { &setup_mprotect_open_pdc_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pdc_1",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pdc_2",
    &setup_mprotect_open_pdc_2_common,
    { { &setup_mprotect_open_pdc_2_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pdc_3",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pd4_0",
    &setup_mprotect_open_pdc_0_common,
    { { &setup_mprotect_open_pdc_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pd4_1",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pd4_2",
    &setup_mprotect_open_pdc_0_common,
    { { &setup_mprotect_open_pd4_2_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pd4_3",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pcc_0",
    &setup_mprotect_open_pdc_0_common,
    { { &setup_mprotect_open_pdc_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pcc_1",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pcc_2",
    &setup_mprotect_open_pcc_2_common,
    { { &setup_mprotect_open_pdc_2_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pcc_3",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pc4_0",
    &setup_mprotect_open_pcc_2_common,
    { { &setup_mprotect_open_pc4_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pc4_1",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pc4_2",
    &setup_mprotect_open_pdc_0_common,
    { { &setup_mprotect_open_pd4_2_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pc4_3",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pbc_0",
    &setup_mprotect_open_pee_1_common,
    { { &setup_mprotect_open_pea_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pbc_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pbc_1",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pea_2_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pbc_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pbc_2",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pbc_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pbc_3",
    &setup_mprotect_open_pee_0_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pbc_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pb4_0",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pea_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pbc_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pb4_1",
    &setup_mprotect_open_pee_1_common,
    { { &setup_mprotect_open_pee_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pbc_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pb4_2",
    &setup_mprotect_open_pee_1_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pbc_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pb4_3",
    &setup_mprotect_open_pee_0_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pbc_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pac_0",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pe6_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pac_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pac_1",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pe6_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pac_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pac_2",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pac_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pac_3",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pac_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_pa4_0",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pe6_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pac_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pa4_1",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pe6_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pac_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pa4_2",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pac_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_pa4_3",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_pac_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_p8_0",
    &setup_mprotect_open_pdc_2_common,
    { { &setup_mprotect_open_pf_0_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_p8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p8_1",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_1_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_p8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p8_2",
    &setup_mprotect_open_pdc_2_common,
    { { &setup_mprotect_open_pf_2_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_p8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p8_3",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_3_proc0 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_pf_0_0, 0, "mprotect" },
      { &test_mprotect_open_p8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p7_0",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pf_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p6e_0",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p6a_0",
    &setup_mprotect_open_pee_0_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_p66_0",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p62_0",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_p5c_0",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p54_0",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pee_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_p4c_0",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p44_0",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pe6_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_p3c_0",
    &setup_mprotect_open_pf_0_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pbc_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p34_0",
    &setup_mprotect_open_pee_1_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pbc_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_p2c_0",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pac_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_open_p24_0",
    &setup_mprotect_open_pe6_0_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_final,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_pac_0_1, 1, "open" } },
    &cleanup },
  { "fs-mprotect_open_p0_0",
    &setup_mprotect_open_pdc_1_common,
    { { &setup_mprotect_open_pf_0_proc1 }, { &setup_mprotect_open_pf_0_proc1 } },
    &setup_mprotect_open_pf_0_procfinal,
    &setup_mprotect_open_pf_0_procfinal,
    { { &test_mprotect_open_p7_0_0, 0, "mprotect" },
      { &test_mprotect_open_p8_0_1, 0, "open" } },
    &cleanup },
  { "fs-mprotect_pipe_pf0_0",
    &setup_mprotect_pipe_pf0_0_common,
    { { &setup_mprotect_pipe_pf0_0_proc0 }, { &setup_mprotect_pipe_pf0_0_proc1 } },
    &setup_mprotect_pipe_pf0_0_procfinal,
    &setup_mprotect_pipe_pf0_0_final,
    { { &test_mprotect_pipe_pf0_0_0, 0, "mprotect" },
      { &test_mprotect_pipe_pf0_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mprotect_pipe_pf0_1",
    &setup_mprotect_pipe_pf0_0_common,
    { { &setup_mprotect_pipe_pf0_1_proc0 }, { &setup_mprotect_pipe_pf0_0_proc1 } },
    &setup_mprotect_pipe_pf0_0_procfinal,
    &setup_mprotect_pipe_pf0_0_final,
    { { &test_mprotect_pipe_pf0_0_0, 0, "mprotect" },
      { &test_mprotect_pipe_pf0_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mprotect_pipe_pf0_2",
    &setup_mprotect_pipe_pf0_2_common,
    { { &setup_mprotect_pipe_pf0_2_proc0 }, { &setup_mprotect_pipe_pf0_0_proc1 } },
    &setup_mprotect_pipe_pf0_0_procfinal,
    &setup_mprotect_pipe_pf0_0_procfinal,
    { { &test_mprotect_pipe_pf0_0_0, 0, "mprotect" },
      { &test_mprotect_pipe_pf0_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mprotect_pipe_pf0_3",
    &setup_mprotect_pipe_pf0_2_common,
    { { &setup_mprotect_pipe_pf0_3_proc0 }, { &setup_mprotect_pipe_pf0_0_proc1 } },
    &setup_mprotect_pipe_pf0_0_procfinal,
    &setup_mprotect_pipe_pf0_0_procfinal,
    { { &test_mprotect_pipe_pf0_0_0, 0, "mprotect" },
      { &test_mprotect_pipe_pf0_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mprotect_pipe_pb0_0",
    &setup_mprotect_pipe_pf0_0_common,
    { { &setup_mprotect_pipe_pf0_0_proc0 }, { &setup_mprotect_pipe_pf0_0_proc1 } },
    &setup_mprotect_pipe_pf0_0_procfinal,
    &setup_mprotect_pipe_pf0_0_final,
    { { &test_mprotect_pipe_pf0_0_0, 0, "mprotect" },
      { &test_mprotect_pipe_pf0_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mprotect_pipe_pb0_1",
    &setup_mprotect_pipe_pf0_0_common,
    { { &setup_mprotect_pipe_pf0_1_proc0 }, { &setup_mprotect_pipe_pf0_0_proc1 } },
    &setup_mprotect_pipe_pf0_0_procfinal,
    &setup_mprotect_pipe_pf0_0_final,
    { { &test_mprotect_pipe_pf0_0_0, 0, "mprotect" },
      { &test_mprotect_pipe_pf0_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mprotect_pipe_pb0_2",
    &setup_mprotect_pipe_pf0_2_common,
    { { &setup_mprotect_pipe_pf0_2_proc0 }, { &setup_mprotect_pipe_pf0_0_proc1 } },
    &setup_mprotect_pipe_pf0_0_procfinal,
    &setup_mprotect_pipe_pf0_0_procfinal,
    { { &test_mprotect_pipe_pf0_0_0, 0, "mprotect" },
      { &test_mprotect_pipe_pf0_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mprotect_pipe_pb0_3",
    &setup_mprotect_pipe_pf0_2_common,
    { { &setup_mprotect_pipe_pf0_3_proc0 }, { &setup_mprotect_pipe_pf0_0_proc1 } },
    &setup_mprotect_pipe_pf0_0_procfinal,
    &setup_mprotect_pipe_pf0_0_procfinal,
    { { &test_mprotect_pipe_pf0_0_0, 0, "mprotect" },
      { &test_mprotect_pipe_pf0_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mprotect_pipe_p70_0",
    &setup_mprotect_pipe_pf0_2_common,
    { { &setup_mprotect_pipe_pf0_0_proc1 }, { &setup_mprotect_pipe_pf0_0_proc1 } },
    &setup_mprotect_pipe_pf0_0_procfinal,
    &setup_mprotect_pipe_pf0_0_procfinal,
    { { &test_mprotect_pipe_p70_0_0, 0, "mprotect" },
      { &test_mprotect_pipe_pf0_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-mprotect_pipe_p30_0",
    &setup_mprotect_pipe_pf0_2_common,
    { { &setup_mprotect_pipe_pf0_0_proc1 }, { &setup_mprotect_pipe_pf0_0_proc1 } },
    &setup_mprotect_pipe_pf0_0_procfinal,
    &setup_mprotect_pipe_pf0_0_procfinal,
    { { &test_mprotect_pipe_p70_0_0, 0, "mprotect" },
      { &test_mprotect_pipe_pf0_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-mprotect_pread_pf_0",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pf_0_proc0 }, { &setup_mprotect_pread_pf_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pf_1",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pf_1_proc0 }, { &setup_mprotect_pread_pf_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pf_2",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pf_2_proc0 }, { &setup_mprotect_pread_pf_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pf_3",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pf_3_proc0 }, { &setup_mprotect_pread_pf_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pf_4",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pf_4_proc0 }, { &setup_mprotect_pread_pf_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pf_5",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pf_5_proc0 }, { &setup_mprotect_pread_pf_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pf_6",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pf_6_proc0 }, { &setup_mprotect_pread_pf_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pf_7",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pf_7_proc0 }, { &setup_mprotect_pread_pf_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe8_0",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_0_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe8_1",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_1_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe8_2",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_2_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe8_3",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_3_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe8_4",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_4_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe8_5",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_5_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe8_6",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_6_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe8_7",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_7_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe8_8",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_8_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe8_9",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_9_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe0_0",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe8_0_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe0_1",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe8_1_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe0_2",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe8_2_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe0_3",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe8_3_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe0_4",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe0_4_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe0_5",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe8_5_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe0_6",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe8_8_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe0_7",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe0_7_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe0_8",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe8_7_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pe0_9",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe8_9_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pc_0",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_0_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pc_1",
    &setup_mprotect_pread_pc_1_common,
    { { &setup_mprotect_pread_pc_1_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_procfinal,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pc_2",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_2_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pc_3",
    &setup_mprotect_pread_pc_1_common,
    { { &setup_mprotect_pread_pc_3_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_procfinal,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pb_0",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pb_0_proc0 }, { &setup_mprotect_pread_pb_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pb_1",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pb_1_proc0 }, { &setup_mprotect_pread_pb_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pb_2",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pb_2_proc0 }, { &setup_mprotect_pread_pb_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pb_3",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pb_3_proc0 }, { &setup_mprotect_pread_pb_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pb_4",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pb_0_proc0 }, { &setup_mprotect_pread_pb_4_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pb_5",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pb_2_proc0 }, { &setup_mprotect_pread_pb_4_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pb_6",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pb_1_proc0 }, { &setup_mprotect_pread_pb_4_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pb_7",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pb_3_proc0 }, { &setup_mprotect_pread_pb_4_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa8_0",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pa8_0_proc0 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa8_1",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_1_proc0 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa8_2",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pa8_2_proc0 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa8_3",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_3_proc0 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa8_4",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_0_proc0 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa8_5",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_2_proc0 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa8_6",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_0_proc0 }, { &setup_mprotect_pread_pa8_6_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa8_7",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_2_proc0 }, { &setup_mprotect_pread_pa8_6_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa8_8",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_1_proc0 }, { &setup_mprotect_pread_pa8_6_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa8_9",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_3_proc0 }, { &setup_mprotect_pread_pa8_6_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa0_0",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pa8_0_proc0 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa0_1",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pc_1_proc0 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa0_2",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pa8_2_proc0 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa0_3",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pc_3_proc0 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa0_4",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pc_0_proc0 }, { &setup_mprotect_pread_pa0_4_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa0_5",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pc_0_proc0 }, { &setup_mprotect_pread_pa8_6_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa0_6",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pc_2_proc0 }, { &setup_mprotect_pread_pa0_4_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa0_7",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pc_1_proc0 }, { &setup_mprotect_pread_pa8_6_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa0_8",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pc_2_proc0 }, { &setup_mprotect_pread_pa8_6_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_pa0_9",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pc_3_proc0 }, { &setup_mprotect_pread_pa8_6_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p8_0",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_0_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p8_1",
    &setup_mprotect_pread_pc_1_common,
    { { &setup_mprotect_pread_pc_1_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_procfinal,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p8_2",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pc_2_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p8_3",
    &setup_mprotect_pread_pc_1_common,
    { { &setup_mprotect_pread_pc_3_proc0 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_procfinal,
    { { &test_mprotect_pread_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p7_0",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pb_0_proc1 }, { &setup_mprotect_pread_pf_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p7_1",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pb_4_proc1 }, { &setup_mprotect_pread_pf_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p68_0",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pa8_0_proc1 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p68_1",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pa8_6_proc1 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p60_0",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pa8_0_proc1 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p60_1",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pa8_6_proc1 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p4_0",
    &setup_mprotect_pread_pc_1_common,
    { { &setup_mprotect_pread_pe8_0_proc1 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_procfinal,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p3_0",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pf_0_proc1 }, { &setup_mprotect_pread_pb_0_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p3_1",
    &setup_mprotect_pread_pf_0_common,
    { { &setup_mprotect_pread_pf_0_proc1 }, { &setup_mprotect_pread_pb_4_proc1 } },
    &setup_mprotect_pread_pf_0_procfinal,
    &setup_mprotect_pread_pf_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pf_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p28_0",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_0_proc1 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p28_1",
    &setup_mprotect_pread_pe8_0_common,
    { { &setup_mprotect_pread_pe8_0_proc1 }, { &setup_mprotect_pread_pa8_6_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p20_0",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe8_0_proc1 }, { &setup_mprotect_pread_pa8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p20_1",
    &setup_mprotect_pread_pe0_0_common,
    { { &setup_mprotect_pread_pe8_0_proc1 }, { &setup_mprotect_pread_pa8_6_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_final,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pe0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pread_p0_0",
    &setup_mprotect_pread_pc_1_common,
    { { &setup_mprotect_pread_pe8_0_proc1 }, { &setup_mprotect_pread_pe8_0_proc1 } },
    &setup_mprotect_pread_pe8_0_procfinal,
    &setup_mprotect_pread_pe8_0_procfinal,
    { { &test_mprotect_pread_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-mprotect_pwrite_pf_0",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pf_0_proc0 }, { &setup_mprotect_pwrite_pf_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pf_1",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pf_1_proc0 }, { &setup_mprotect_pwrite_pf_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pf_2",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pf_2_proc0 }, { &setup_mprotect_pwrite_pf_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pf_3",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pf_3_proc0 }, { &setup_mprotect_pwrite_pf_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pf_4",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pf_4_proc0 }, { &setup_mprotect_pwrite_pf_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pf_5",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pf_5_proc0 }, { &setup_mprotect_pwrite_pf_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pf_6",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pf_6_proc0 }, { &setup_mprotect_pwrite_pf_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pf_7",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pf_7_proc0 }, { &setup_mprotect_pwrite_pf_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_0",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_0_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_1",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_1_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_2",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_2_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_3",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_3_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_4",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_4_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_5",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_5_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_6",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_6_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_7",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_7_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_8",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_8_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_9",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_9_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_10",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_10_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe8_11",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_11_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_0",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe0_0_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_1",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe0_1_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_2",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe0_2_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_3",
    &setup_mprotect_pwrite_pe0_3_common,
    { { &setup_mprotect_pwrite_pe0_3_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe0_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_4",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe8_4_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_5",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe0_5_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_6",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe8_8_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_7",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe0_7_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_8",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe8_9_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_9",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe0_9_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pe0_10",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe8_11_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pc_0",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_0_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pc_1",
    &setup_mprotect_pwrite_pc_1_common,
    { { &setup_mprotect_pwrite_pc_1_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_procfinal,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pc_2",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_2_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pc_3",
    &setup_mprotect_pwrite_pc_1_common,
    { { &setup_mprotect_pwrite_pc_3_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_procfinal,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pb_0",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pb_0_proc0 }, { &setup_mprotect_pwrite_pb_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pb_1",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pb_1_proc0 }, { &setup_mprotect_pwrite_pb_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pb_2",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pb_0_proc0 }, { &setup_mprotect_pwrite_pb_2_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pb_3",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pb_1_proc0 }, { &setup_mprotect_pwrite_pb_2_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pb_4",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pb_4_proc0 }, { &setup_mprotect_pwrite_pb_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pb_5",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pb_4_proc0 }, { &setup_mprotect_pwrite_pb_2_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pb_6",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pb_6_proc0 }, { &setup_mprotect_pwrite_pb_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pb_7",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pb_6_proc0 }, { &setup_mprotect_pwrite_pb_2_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_0",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pa8_0_proc0 }, { &setup_mprotect_pwrite_pa8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_1",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pa8_1_proc0 }, { &setup_mprotect_pwrite_pa8_1_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_2",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_1_proc0 }, { &setup_mprotect_pwrite_pa8_2_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_3",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_0_proc0 }, { &setup_mprotect_pwrite_pa8_3_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_4",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_0_proc0 }, { &setup_mprotect_pwrite_pa8_4_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_5",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pa8_5_proc0 }, { &setup_mprotect_pwrite_pa8_2_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_6",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pa8_6_proc0 }, { &setup_mprotect_pwrite_pa8_1_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_7",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_2_proc0 }, { &setup_mprotect_pwrite_pa8_3_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_8",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_2_proc0 }, { &setup_mprotect_pwrite_pa8_4_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_9",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_1_proc0 }, { &setup_mprotect_pwrite_pa8_4_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_10",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_3_proc0 }, { &setup_mprotect_pwrite_pa8_10_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa8_11",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_3_proc0 }, { &setup_mprotect_pwrite_pa8_4_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_0",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pa0_0_proc0 }, { &setup_mprotect_pwrite_pa0_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_1",
    &setup_mprotect_pwrite_pe0_3_common,
    { { &setup_mprotect_pwrite_pc_0_proc0 }, { &setup_mprotect_pwrite_pa8_3_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_2",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pa0_2_proc0 }, { &setup_mprotect_pwrite_pa0_2_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_3",
    &setup_mprotect_pwrite_pa0_3_common,
    { { &setup_mprotect_pwrite_pa0_3_proc0 }, { &setup_mprotect_pwrite_pa0_3_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pa0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_4",
    &setup_mprotect_pwrite_pe0_3_common,
    { { &setup_mprotect_pwrite_pa0_4_proc0 }, { &setup_mprotect_pwrite_pa8_3_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_5",
    &setup_mprotect_pwrite_pa0_3_common,
    { { &setup_mprotect_pwrite_pc_1_proc0 }, { &setup_mprotect_pwrite_pa0_3_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pa0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_6",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pc_2_proc0 }, { &setup_mprotect_pwrite_pa0_6_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_7",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pc_3_proc0 }, { &setup_mprotect_pwrite_pa8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_8",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pc_1_proc0 }, { &setup_mprotect_pwrite_pa8_4_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_9",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pc_2_proc0 }, { &setup_mprotect_pwrite_pa8_4_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_pa0_10",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pc_3_proc0 }, { &setup_mprotect_pwrite_pa8_4_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p8_0",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_0_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p8_1",
    &setup_mprotect_pwrite_pc_1_common,
    { { &setup_mprotect_pwrite_pc_1_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_procfinal,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p8_2",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pc_2_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p8_3",
    &setup_mprotect_pwrite_pc_1_common,
    { { &setup_mprotect_pwrite_pc_3_proc0 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_procfinal,
    { { &test_mprotect_pwrite_pf_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p7_0",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pb_0_proc1 }, { &setup_mprotect_pwrite_pf_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p7_1",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pb_2_proc1 }, { &setup_mprotect_pwrite_pf_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p68_0",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pa8_10_proc1 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p68_1",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pa8_4_proc1 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p60_0",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pa0_6_proc1 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p60_1",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pa8_4_proc1 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p4_0",
    &setup_mprotect_pwrite_pc_1_common,
    { { &setup_mprotect_pwrite_pe8_0_proc1 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_procfinal,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p3_0",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pf_0_proc1 }, { &setup_mprotect_pwrite_pb_0_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p3_1",
    &setup_mprotect_pwrite_pf_0_common,
    { { &setup_mprotect_pwrite_pf_0_proc1 }, { &setup_mprotect_pwrite_pb_2_proc1 } },
    &setup_mprotect_pwrite_pf_0_procfinal,
    &setup_mprotect_pwrite_pf_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pf_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p28_0",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_0_proc1 }, { &setup_mprotect_pwrite_pa8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p28_1",
    &setup_mprotect_pwrite_pe8_0_common,
    { { &setup_mprotect_pwrite_pe8_0_proc1 }, { &setup_mprotect_pwrite_pa8_4_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p20_0",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe8_0_proc1 }, { &setup_mprotect_pwrite_pa0_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p20_1",
    &setup_mprotect_pwrite_pe0_0_common,
    { { &setup_mprotect_pwrite_pe8_0_proc1 }, { &setup_mprotect_pwrite_pa8_4_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_final,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pe8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_pwrite_p0_0",
    &setup_mprotect_pwrite_pc_1_common,
    { { &setup_mprotect_pwrite_pe8_0_proc1 }, { &setup_mprotect_pwrite_pe8_0_proc1 } },
    &setup_mprotect_pwrite_pe8_0_procfinal,
    &setup_mprotect_pwrite_pe8_0_procfinal,
    { { &test_mprotect_pwrite_p7_0_0, 0, "mprotect" },
      { &test_mprotect_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-mprotect_read_pf8_0",
    &setup_mprotect_read_pf8_0_common,
    { { &setup_mprotect_read_pf8_0_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf8_1",
    &setup_mprotect_read_pf8_0_common,
    { { &setup_mprotect_read_pf8_1_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf8_2",
    &setup_mprotect_read_pf8_0_common,
    { { &setup_mprotect_read_pf8_2_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf8_3",
    &setup_mprotect_read_pf8_0_common,
    { { &setup_mprotect_read_pf8_3_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf6_0",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pf6_0_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf6_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf6_1",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pf6_1_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf6_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf6_2",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pf6_2_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf6_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf6_3",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pf6_3_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf6_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf4_0",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pf4_0_proc0 }, { &setup_mprotect_read_pf4_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf4_1",
    &setup_mprotect_read_pf4_1_common,
    { { &setup_mprotect_read_pf4_1_proc0 }, { &setup_mprotect_read_pf4_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf4_2",
    &setup_mprotect_read_pf4_1_common,
    { { &setup_mprotect_read_pf4_2_proc0 }, { &setup_mprotect_read_pf4_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf4_3",
    &setup_mprotect_read_pf4_1_common,
    { { &setup_mprotect_read_pf4_3_proc0 }, { &setup_mprotect_read_pf4_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf0_0",
    &setup_mprotect_read_pf0_0_common,
    { { &setup_mprotect_read_pf6_0_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf0_1",
    &setup_mprotect_read_pf0_0_common,
    { { &setup_mprotect_read_pf6_1_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf0_2",
    &setup_mprotect_read_pf0_0_common,
    { { &setup_mprotect_read_pf6_2_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pf0_3",
    &setup_mprotect_read_pf0_0_common,
    { { &setup_mprotect_read_pf6_3_proc0 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe8_0",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pe8_0_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe8_1",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pe8_1_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe8_2",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pe8_2_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe8_3",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pe8_3_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe8_4",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pe8_4_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe8_5",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pe8_5_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe0_0",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pe0_0_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe0_1",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pe0_1_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe0_2",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pe0_2_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe0_3",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pe0_3_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe0_4",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pe0_4_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pe0_5",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pe0_5_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pc_0",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pc_0_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pc_1",
    &setup_mprotect_read_pc_1_common,
    { { &setup_mprotect_read_pc_1_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_procfinal,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pc_2",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pc_2_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pc_3",
    &setup_mprotect_read_pc_1_common,
    { { &setup_mprotect_read_pc_3_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_procfinal,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb8_0",
    &setup_mprotect_read_pf8_0_common,
    { { &setup_mprotect_read_pb8_0_proc0 }, { &setup_mprotect_read_pb8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb8_1",
    &setup_mprotect_read_pf8_0_common,
    { { &setup_mprotect_read_pb8_1_proc0 }, { &setup_mprotect_read_pb8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb8_2",
    &setup_mprotect_read_pf8_0_common,
    { { &setup_mprotect_read_pb8_2_proc0 }, { &setup_mprotect_read_pb8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb8_3",
    &setup_mprotect_read_pf8_0_common,
    { { &setup_mprotect_read_pb8_3_proc0 }, { &setup_mprotect_read_pb8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb6_0",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pb6_0_proc0 }, { &setup_mprotect_read_pb6_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf6_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb6_1",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pb6_1_proc0 }, { &setup_mprotect_read_pb6_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf6_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb6_2",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pb8_2_proc0 }, { &setup_mprotect_read_pb6_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf6_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb6_3",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pb8_3_proc0 }, { &setup_mprotect_read_pb6_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf6_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb4_0",
    &setup_mprotect_read_pf4_1_common,
    { { &setup_mprotect_read_pb4_0_proc0 }, { &setup_mprotect_read_pb4_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb4_1",
    &setup_mprotect_read_pf4_1_common,
    { { &setup_mprotect_read_pb4_1_proc0 }, { &setup_mprotect_read_pb4_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb4_2",
    &setup_mprotect_read_pf4_1_common,
    { { &setup_mprotect_read_pb4_2_proc0 }, { &setup_mprotect_read_pb4_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb4_3",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pb4_3_proc0 }, { &setup_mprotect_read_pb4_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb0_0",
    &setup_mprotect_read_pf0_0_common,
    { { &setup_mprotect_read_pb6_0_proc0 }, { &setup_mprotect_read_pb6_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb0_1",
    &setup_mprotect_read_pf0_0_common,
    { { &setup_mprotect_read_pb6_1_proc0 }, { &setup_mprotect_read_pb6_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb0_2",
    &setup_mprotect_read_pf0_0_common,
    { { &setup_mprotect_read_pb8_2_proc0 }, { &setup_mprotect_read_pb6_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pb0_3",
    &setup_mprotect_read_pf0_0_common,
    { { &setup_mprotect_read_pb8_3_proc0 }, { &setup_mprotect_read_pb6_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa8_0",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pa8_0_proc0 }, { &setup_mprotect_read_pa8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa8_1",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pa8_1_proc0 }, { &setup_mprotect_read_pa8_1_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa8_2",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pa8_2_proc0 }, { &setup_mprotect_read_pa8_2_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa8_3",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pa8_3_proc0 }, { &setup_mprotect_read_pa8_2_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa8_4",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pc_1_proc0 }, { &setup_mprotect_read_pa8_1_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa8_5",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pc_3_proc0 }, { &setup_mprotect_read_pa8_1_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa0_0",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pa8_0_proc0 }, { &setup_mprotect_read_pa0_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa0_1",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pa8_1_proc0 }, { &setup_mprotect_read_pa0_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa0_2",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pc_0_proc0 }, { &setup_mprotect_read_pa0_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa0_3",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pc_2_proc0 }, { &setup_mprotect_read_pa0_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa0_4",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pc_1_proc0 }, { &setup_mprotect_read_pa0_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_pa0_5",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pc_3_proc0 }, { &setup_mprotect_read_pa0_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p8_0",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pc_0_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p8_1",
    &setup_mprotect_read_pc_1_common,
    { { &setup_mprotect_read_pc_1_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_procfinal,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p8_2",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pc_2_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p8_3",
    &setup_mprotect_read_pc_1_common,
    { { &setup_mprotect_read_pc_3_proc0 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_procfinal,
    { { &test_mprotect_read_pf8_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p78_0",
    &setup_mprotect_read_pf8_0_common,
    { { &setup_mprotect_read_pb8_0_proc1 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_p76_0",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pb6_0_proc1 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf6_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_p74_0",
    &setup_mprotect_read_pf4_1_common,
    { { &setup_mprotect_read_pb4_0_proc1 }, { &setup_mprotect_read_pf4_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_p70_0",
    &setup_mprotect_read_pf0_0_common,
    { { &setup_mprotect_read_pb6_0_proc1 }, { &setup_mprotect_read_pf8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_p68_0",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pa8_0_proc1 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_p60_0",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pa0_0_proc1 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_p4_0",
    &setup_mprotect_read_pc_1_common,
    { { &setup_mprotect_read_pe8_0_proc1 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_procfinal,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-mprotect_read_p38_0",
    &setup_mprotect_read_pf8_0_common,
    { { &setup_mprotect_read_pf8_0_proc1 }, { &setup_mprotect_read_pb8_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p36_0",
    &setup_mprotect_read_pf6_0_common,
    { { &setup_mprotect_read_pf8_0_proc1 }, { &setup_mprotect_read_pb6_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf6_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p34_0",
    &setup_mprotect_read_pf4_1_common,
    { { &setup_mprotect_read_pf4_0_proc1 }, { &setup_mprotect_read_pb4_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p30_0",
    &setup_mprotect_read_pf0_0_common,
    { { &setup_mprotect_read_pf8_0_proc1 }, { &setup_mprotect_read_pb6_0_proc1 } },
    &setup_mprotect_read_pf8_0_procfinal,
    &setup_mprotect_read_pf8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p28_0",
    &setup_mprotect_read_pe8_0_common,
    { { &setup_mprotect_read_pe8_0_proc1 }, { &setup_mprotect_read_pa8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf4_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p20_0",
    &setup_mprotect_read_pe0_0_common,
    { { &setup_mprotect_read_pe8_0_proc1 }, { &setup_mprotect_read_pa0_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_final,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf0_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_read_p0_0",
    &setup_mprotect_read_pc_1_common,
    { { &setup_mprotect_read_pe8_0_proc1 }, { &setup_mprotect_read_pe8_0_proc1 } },
    &setup_mprotect_read_pe8_0_procfinal,
    &setup_mprotect_read_pe8_0_procfinal,
    { { &test_mprotect_read_p78_0_0, 0, "mprotect" },
      { &test_mprotect_read_pf8_0_1, 1, "read" } },
    &cleanup },
  { "fs-mprotect_rename_pe_0",
    &setup_mprotect_rename_pe_0_common,
    { { &setup_mprotect_rename_pe_0_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pe_1",
    &setup_mprotect_rename_pe_0_common,
    { { &setup_mprotect_rename_pe_1_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pe_2",
    &setup_mprotect_rename_pe_0_common,
    { { &setup_mprotect_rename_pe_2_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pe_3",
    &setup_mprotect_rename_pe_0_common,
    { { &setup_mprotect_rename_pe_3_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pd0_0",
    &setup_mprotect_rename_pd0_0_common,
    { { &setup_mprotect_rename_pd0_0_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pd0_1",
    &setup_mprotect_rename_pd0_0_common,
    { { &setup_mprotect_rename_pe_2_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pd0_2",
    &setup_mprotect_rename_pd0_0_common,
    { { &setup_mprotect_rename_pd0_2_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pd0_3",
    &setup_mprotect_rename_pd0_0_common,
    { { &setup_mprotect_rename_pe_3_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pc_0",
    &setup_mprotect_rename_pe_0_common,
    { { &setup_mprotect_rename_pe_0_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pc_1",
    &setup_mprotect_rename_pe_0_common,
    { { &setup_mprotect_rename_pe_2_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pc_2",
    &setup_mprotect_rename_pe_0_common,
    { { &setup_mprotect_rename_pe_1_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_pc_3",
    &setup_mprotect_rename_pe_0_common,
    { { &setup_mprotect_rename_pe_3_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_p8_0",
    &setup_mprotect_rename_p8_0_common,
    { { &setup_mprotect_rename_pe_0_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_p8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_p8_1",
    &setup_mprotect_rename_p8_1_common,
    { { &setup_mprotect_rename_pe_2_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_procfinal,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_p8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_p8_2",
    &setup_mprotect_rename_p8_0_common,
    { { &setup_mprotect_rename_pe_1_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_p8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_p8_3",
    &setup_mprotect_rename_p8_1_common,
    { { &setup_mprotect_rename_pe_3_proc0 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_procfinal,
    { { &test_mprotect_rename_pe_0_0, 0, "mprotect" },
      { &test_mprotect_rename_p8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_p6_0",
    &setup_mprotect_rename_pe_0_common,
    { { &setup_mprotect_rename_pe_0_proc1 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_p6_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_p50_0",
    &setup_mprotect_rename_pd0_0_common,
    { { &setup_mprotect_rename_pe_0_proc1 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_p6_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_p4_0",
    &setup_mprotect_rename_pe_0_common,
    { { &setup_mprotect_rename_pe_0_proc1 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_final,
    { { &test_mprotect_rename_p6_0_0, 0, "mprotect" },
      { &test_mprotect_rename_pd0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_rename_p0_0",
    &setup_mprotect_rename_p8_1_common,
    { { &setup_mprotect_rename_pe_0_proc1 }, { &setup_mprotect_rename_pe_0_proc1 } },
    &setup_mprotect_rename_pe_0_procfinal,
    &setup_mprotect_rename_pe_0_procfinal,
    { { &test_mprotect_rename_p6_0_0, 0, "mprotect" },
      { &test_mprotect_rename_p8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-mprotect_stat_pc_0",
    &setup_mprotect_stat_pc_0_common,
    { { &setup_mprotect_stat_pc_0_proc0 }, { &setup_mprotect_stat_pc_0_proc1 } },
    &setup_mprotect_stat_pc_0_procfinal,
    &setup_mprotect_stat_pc_0_final,
    { { &test_mprotect_stat_pc_0_0, 0, "mprotect" },
      { &test_mprotect_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mprotect_stat_pc_1",
    &setup_mprotect_stat_pc_0_common,
    { { &setup_mprotect_stat_pc_1_proc0 }, { &setup_mprotect_stat_pc_0_proc1 } },
    &setup_mprotect_stat_pc_0_procfinal,
    &setup_mprotect_stat_pc_0_final,
    { { &test_mprotect_stat_pc_0_0, 0, "mprotect" },
      { &test_mprotect_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mprotect_stat_pc_2",
    &setup_mprotect_stat_pc_0_common,
    { { &setup_mprotect_stat_pc_2_proc0 }, { &setup_mprotect_stat_pc_0_proc1 } },
    &setup_mprotect_stat_pc_0_procfinal,
    &setup_mprotect_stat_pc_0_final,
    { { &test_mprotect_stat_pc_0_0, 0, "mprotect" },
      { &test_mprotect_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mprotect_stat_pc_3",
    &setup_mprotect_stat_pc_0_common,
    { { &setup_mprotect_stat_pc_3_proc0 }, { &setup_mprotect_stat_pc_0_proc1 } },
    &setup_mprotect_stat_pc_0_procfinal,
    &setup_mprotect_stat_pc_0_final,
    { { &test_mprotect_stat_pc_0_0, 0, "mprotect" },
      { &test_mprotect_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mprotect_stat_p8_0",
    &setup_mprotect_stat_p8_0_common,
    { { &setup_mprotect_stat_pc_0_proc0 }, { &setup_mprotect_stat_pc_0_proc1 } },
    &setup_mprotect_stat_pc_0_procfinal,
    &setup_mprotect_stat_pc_0_final,
    { { &test_mprotect_stat_pc_0_0, 0, "mprotect" },
      { &test_mprotect_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mprotect_stat_p8_1",
    &setup_mprotect_stat_p8_0_common,
    { { &setup_mprotect_stat_pc_1_proc0 }, { &setup_mprotect_stat_pc_0_proc1 } },
    &setup_mprotect_stat_pc_0_procfinal,
    &setup_mprotect_stat_pc_0_final,
    { { &test_mprotect_stat_pc_0_0, 0, "mprotect" },
      { &test_mprotect_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mprotect_stat_p8_2",
    &setup_mprotect_stat_p8_2_common,
    { { &setup_mprotect_stat_pc_2_proc0 }, { &setup_mprotect_stat_pc_0_proc1 } },
    &setup_mprotect_stat_pc_0_procfinal,
    &setup_mprotect_stat_pc_0_procfinal,
    { { &test_mprotect_stat_pc_0_0, 0, "mprotect" },
      { &test_mprotect_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mprotect_stat_p8_3",
    &setup_mprotect_stat_p8_2_common,
    { { &setup_mprotect_stat_pc_3_proc0 }, { &setup_mprotect_stat_pc_0_proc1 } },
    &setup_mprotect_stat_pc_0_procfinal,
    &setup_mprotect_stat_pc_0_procfinal,
    { { &test_mprotect_stat_pc_0_0, 0, "mprotect" },
      { &test_mprotect_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mprotect_stat_p4_0",
    &setup_mprotect_stat_pc_0_common,
    { { &setup_mprotect_stat_pc_0_proc1 }, { &setup_mprotect_stat_pc_0_proc1 } },
    &setup_mprotect_stat_pc_0_procfinal,
    &setup_mprotect_stat_pc_0_final,
    { { &test_mprotect_stat_p4_0_0, 0, "mprotect" },
      { &test_mprotect_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mprotect_stat_p0_0",
    &setup_mprotect_stat_p8_2_common,
    { { &setup_mprotect_stat_pc_0_proc1 }, { &setup_mprotect_stat_pc_0_proc1 } },
    &setup_mprotect_stat_pc_0_procfinal,
    &setup_mprotect_stat_pc_0_procfinal,
    { { &test_mprotect_stat_p4_0_0, 0, "mprotect" },
      { &test_mprotect_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-mprotect_unlink_pc_0",
    &setup_mprotect_unlink_pc_0_common,
    { { &setup_mprotect_unlink_pc_0_proc0 }, { &setup_mprotect_unlink_pc_0_proc1 } },
    &setup_mprotect_unlink_pc_0_procfinal,
    &setup_mprotect_unlink_pc_0_final,
    { { &test_mprotect_unlink_pc_0_0, 0, "mprotect" },
      { &test_mprotect_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mprotect_unlink_pc_1",
    &setup_mprotect_unlink_pc_0_common,
    { { &setup_mprotect_unlink_pc_1_proc0 }, { &setup_mprotect_unlink_pc_0_proc1 } },
    &setup_mprotect_unlink_pc_0_procfinal,
    &setup_mprotect_unlink_pc_0_final,
    { { &test_mprotect_unlink_pc_0_0, 0, "mprotect" },
      { &test_mprotect_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mprotect_unlink_pc_2",
    &setup_mprotect_unlink_pc_0_common,
    { { &setup_mprotect_unlink_pc_2_proc0 }, { &setup_mprotect_unlink_pc_0_proc1 } },
    &setup_mprotect_unlink_pc_0_procfinal,
    &setup_mprotect_unlink_pc_0_final,
    { { &test_mprotect_unlink_pc_0_0, 0, "mprotect" },
      { &test_mprotect_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mprotect_unlink_pc_3",
    &setup_mprotect_unlink_pc_0_common,
    { { &setup_mprotect_unlink_pc_3_proc0 }, { &setup_mprotect_unlink_pc_0_proc1 } },
    &setup_mprotect_unlink_pc_0_procfinal,
    &setup_mprotect_unlink_pc_0_final,
    { { &test_mprotect_unlink_pc_0_0, 0, "mprotect" },
      { &test_mprotect_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mprotect_unlink_p8_0",
    &setup_mprotect_unlink_p8_0_common,
    { { &setup_mprotect_unlink_p8_0_proc0 }, { &setup_mprotect_unlink_pc_0_proc1 } },
    &setup_mprotect_unlink_pc_0_procfinal,
    &setup_mprotect_unlink_pc_0_final,
    { { &test_mprotect_unlink_pc_0_0, 0, "mprotect" },
      { &test_mprotect_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mprotect_unlink_p8_1",
    &setup_mprotect_unlink_p8_1_common,
    { { &setup_mprotect_unlink_pc_2_proc0 }, { &setup_mprotect_unlink_pc_0_proc1 } },
    &setup_mprotect_unlink_pc_0_procfinal,
    &setup_mprotect_unlink_pc_0_procfinal,
    { { &test_mprotect_unlink_pc_0_0, 0, "mprotect" },
      { &test_mprotect_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mprotect_unlink_p8_2",
    &setup_mprotect_unlink_p8_0_common,
    { { &setup_mprotect_unlink_p8_2_proc0 }, { &setup_mprotect_unlink_pc_0_proc1 } },
    &setup_mprotect_unlink_pc_0_procfinal,
    &setup_mprotect_unlink_pc_0_final,
    { { &test_mprotect_unlink_pc_0_0, 0, "mprotect" },
      { &test_mprotect_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mprotect_unlink_p8_3",
    &setup_mprotect_unlink_p8_1_common,
    { { &setup_mprotect_unlink_pc_3_proc0 }, { &setup_mprotect_unlink_pc_0_proc1 } },
    &setup_mprotect_unlink_pc_0_procfinal,
    &setup_mprotect_unlink_pc_0_procfinal,
    { { &test_mprotect_unlink_pc_0_0, 0, "mprotect" },
      { &test_mprotect_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mprotect_unlink_p4_0",
    &setup_mprotect_unlink_pc_0_common,
    { { &setup_mprotect_unlink_pc_0_proc1 }, { &setup_mprotect_unlink_pc_0_proc1 } },
    &setup_mprotect_unlink_pc_0_procfinal,
    &setup_mprotect_unlink_pc_0_final,
    { { &test_mprotect_unlink_p4_0_0, 0, "mprotect" },
      { &test_mprotect_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mprotect_unlink_p0_0",
    &setup_mprotect_unlink_p8_1_common,
    { { &setup_mprotect_unlink_pc_0_proc1 }, { &setup_mprotect_unlink_pc_0_proc1 } },
    &setup_mprotect_unlink_pc_0_procfinal,
    &setup_mprotect_unlink_pc_0_procfinal,
    { { &test_mprotect_unlink_p4_0_0, 0, "mprotect" },
      { &test_mprotect_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-mprotect_write_pfc_0",
    &setup_mprotect_write_pfc_0_common,
    { { &setup_mprotect_write_pfc_0_proc0 }, { &setup_mprotect_write_pfc_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pfc_1",
    &setup_mprotect_write_pfc_0_common,
    { { &setup_mprotect_write_pfc_1_proc0 }, { &setup_mprotect_write_pfc_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pfc_2",
    &setup_mprotect_write_pfc_0_common,
    { { &setup_mprotect_write_pfc_2_proc0 }, { &setup_mprotect_write_pfc_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pfc_3",
    &setup_mprotect_write_pfc_0_common,
    { { &setup_mprotect_write_pfc_3_proc0 }, { &setup_mprotect_write_pfc_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pf8_0",
    &setup_mprotect_write_pf8_0_common,
    { { &setup_mprotect_write_pf8_0_proc0 }, { &setup_mprotect_write_pf8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pf8_1",
    &setup_mprotect_write_pf8_0_common,
    { { &setup_mprotect_write_pf8_1_proc0 }, { &setup_mprotect_write_pf8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pf8_2",
    &setup_mprotect_write_pf8_0_common,
    { { &setup_mprotect_write_pf8_2_proc0 }, { &setup_mprotect_write_pf8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pf8_3",
    &setup_mprotect_write_pf8_0_common,
    { { &setup_mprotect_write_pf8_3_proc0 }, { &setup_mprotect_write_pf8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pf0_0",
    &setup_mprotect_write_pf0_0_common,
    { { &setup_mprotect_write_pf0_0_proc0 }, { &setup_mprotect_write_pf8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pf0_1",
    &setup_mprotect_write_pf0_0_common,
    { { &setup_mprotect_write_pf0_1_proc0 }, { &setup_mprotect_write_pf8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pf0_2",
    &setup_mprotect_write_pf0_0_common,
    { { &setup_mprotect_write_pf0_2_proc0 }, { &setup_mprotect_write_pf8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pf0_3",
    &setup_mprotect_write_pf0_0_common,
    { { &setup_mprotect_write_pf0_3_proc0 }, { &setup_mprotect_write_pf8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe8_0",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pe8_0_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe8_1",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pe8_1_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe8_2",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pe8_2_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe8_3",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pe8_3_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe8_4",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pe8_4_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe8_5",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pe8_5_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe0_0",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pe8_0_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe0_1",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pe8_1_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe0_2",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pe8_2_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe0_3",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pe8_3_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe0_4",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pe8_4_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pe0_5",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pe8_5_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pc_0",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pc_0_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pc_1",
    &setup_mprotect_write_pc_1_common,
    { { &setup_mprotect_write_pc_1_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_procfinal,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pc_2",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pc_2_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pc_3",
    &setup_mprotect_write_pc_1_common,
    { { &setup_mprotect_write_pc_3_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_procfinal,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_pbc_0",
    &setup_mprotect_write_pfc_0_common,
    { { &setup_mprotect_write_pbc_0_proc0 }, { &setup_mprotect_write_pbc_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pbc_1",
    &setup_mprotect_write_pfc_0_common,
    { { &setup_mprotect_write_pbc_1_proc0 }, { &setup_mprotect_write_pbc_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pbc_2",
    &setup_mprotect_write_pfc_0_common,
    { { &setup_mprotect_write_pbc_2_proc0 }, { &setup_mprotect_write_pbc_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pbc_3",
    &setup_mprotect_write_pfc_0_common,
    { { &setup_mprotect_write_pbc_3_proc0 }, { &setup_mprotect_write_pbc_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pb8_0",
    &setup_mprotect_write_pf8_0_common,
    { { &setup_mprotect_write_pb8_0_proc0 }, { &setup_mprotect_write_pb8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pb8_1",
    &setup_mprotect_write_pf8_0_common,
    { { &setup_mprotect_write_pb8_1_proc0 }, { &setup_mprotect_write_pb8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pb8_2",
    &setup_mprotect_write_pf8_0_common,
    { { &setup_mprotect_write_pb8_2_proc0 }, { &setup_mprotect_write_pb8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pb8_3",
    &setup_mprotect_write_pf8_0_common,
    { { &setup_mprotect_write_pb8_3_proc0 }, { &setup_mprotect_write_pb8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pb0_0",
    &setup_mprotect_write_pf0_0_common,
    { { &setup_mprotect_write_pb0_0_proc0 }, { &setup_mprotect_write_pb0_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pb0_1",
    &setup_mprotect_write_pf0_0_common,
    { { &setup_mprotect_write_pb8_1_proc0 }, { &setup_mprotect_write_pb0_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pb0_2",
    &setup_mprotect_write_pf0_0_common,
    { { &setup_mprotect_write_pb0_2_proc0 }, { &setup_mprotect_write_pb0_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pb0_3",
    &setup_mprotect_write_pf0_0_common,
    { { &setup_mprotect_write_pb8_3_proc0 }, { &setup_mprotect_write_pb0_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa8_0",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pa8_0_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa8_1",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pa8_1_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa8_2",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pc_0_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa8_3",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pc_2_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa8_4",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pc_1_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa8_5",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pc_3_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa0_0",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pa8_0_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa0_1",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pa8_1_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa0_2",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pc_0_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa0_3",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pc_2_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa0_4",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pc_1_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_pa0_5",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pc_3_proc0 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_p8_0",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pc_0_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_p8_1",
    &setup_mprotect_write_pc_1_common,
    { { &setup_mprotect_write_pc_1_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_procfinal,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_p8_2",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pc_2_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_p8_3",
    &setup_mprotect_write_pc_1_common,
    { { &setup_mprotect_write_pc_3_proc0 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_procfinal,
    { { &test_mprotect_write_pfc_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_p7c_0",
    &setup_mprotect_write_pfc_0_common,
    { { &setup_mprotect_write_pbc_0_proc1 }, { &setup_mprotect_write_pfc_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_p78_0",
    &setup_mprotect_write_pf8_0_common,
    { { &setup_mprotect_write_pb8_0_proc1 }, { &setup_mprotect_write_pf8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_p70_0",
    &setup_mprotect_write_pf0_0_common,
    { { &setup_mprotect_write_pb0_0_proc1 }, { &setup_mprotect_write_pf8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_p68_0",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pa8_0_proc1 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_p60_0",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pa8_0_proc1 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_p4_0",
    &setup_mprotect_write_pc_1_common,
    { { &setup_mprotect_write_pe8_0_proc1 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_procfinal,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-mprotect_write_p3c_0",
    &setup_mprotect_write_pfc_0_common,
    { { &setup_mprotect_write_pfc_0_proc1 }, { &setup_mprotect_write_pbc_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_p38_0",
    &setup_mprotect_write_pf8_0_common,
    { { &setup_mprotect_write_pf8_0_proc1 }, { &setup_mprotect_write_pb8_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_p30_0",
    &setup_mprotect_write_pf0_0_common,
    { { &setup_mprotect_write_pf8_0_proc1 }, { &setup_mprotect_write_pb0_0_proc1 } },
    &setup_mprotect_write_pfc_0_procfinal,
    &setup_mprotect_write_pfc_0_final,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_p28_0",
    &setup_mprotect_write_pe8_0_common,
    { { &setup_mprotect_write_pe8_0_proc1 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_p20_0",
    &setup_mprotect_write_pe0_0_common,
    { { &setup_mprotect_write_pe8_0_proc1 }, { &setup_mprotect_write_pa8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_final,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-mprotect_write_p0_0",
    &setup_mprotect_write_pc_1_common,
    { { &setup_mprotect_write_pe8_0_proc1 }, { &setup_mprotect_write_pe8_0_proc1 } },
    &setup_mprotect_write_pe8_0_procfinal,
    &setup_mprotect_write_pe8_0_procfinal,
    { { &test_mprotect_write_p7c_0_0, 0, "mprotect" },
      { &test_mprotect_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-munmap_munmap_p8_0",
    &setup_munmap_munmap_p8_0_common,
    { { &setup_munmap_munmap_p8_0_proc0 }, { &setup_munmap_munmap_p8_0_proc1 } },
    &setup_munmap_munmap_p8_0_procfinal,
    &setup_munmap_munmap_p8_0_final,
    { { &test_munmap_munmap_p8_0_0, 0, "munmap" },
      { &test_munmap_munmap_p8_0_1, 0, "munmap" } },
    &cleanup },
  { "fs-munmap_munmap_p0_0",
    &setup_munmap_munmap_p8_0_common,
    { { &setup_munmap_munmap_p8_0_proc1 }, { &setup_munmap_munmap_p8_0_proc1 } },
    &setup_munmap_munmap_p8_0_procfinal,
    &setup_munmap_munmap_p8_0_procfinal,
    { { &test_munmap_munmap_p8_0_1, 0, "munmap" },
      { &test_munmap_munmap_p8_0_1, 1, "munmap" } },
    &cleanup },
  { "fs-munmap_open_pe_0",
    &setup_munmap_open_pe_0_common,
    { { &setup_munmap_open_pe_0_proc0 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_final,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_pe_0_1, 0, "open" } },
    &cleanup },
  { "fs-munmap_open_pdc_0",
    &setup_munmap_open_pdc_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_final,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_pdc_0_1, 0, "open" } },
    &cleanup },
  { "fs-munmap_open_pd4_0",
    &setup_munmap_open_pdc_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_final,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_pdc_0_1, 1, "open" } },
    &cleanup },
  { "fs-munmap_open_pcc_0",
    &setup_munmap_open_pcc_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_final,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_pcc_0_1, 0, "open" } },
    &cleanup },
  { "fs-munmap_open_pc4_0",
    &setup_munmap_open_pcc_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_final,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_pcc_0_1, 1, "open" } },
    &cleanup },
  { "fs-munmap_open_pb8_0",
    &setup_munmap_open_pb8_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_procfinal,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_pdc_0_1, 0, "open" } },
    &cleanup },
  { "fs-munmap_open_pa8_0",
    &setup_munmap_open_pb8_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_procfinal,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_pdc_0_1, 1, "open" } },
    &cleanup },
  { "fs-munmap_open_p98_0",
    &setup_munmap_open_pb8_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_procfinal,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_pcc_0_1, 0, "open" } },
    &cleanup },
  { "fs-munmap_open_p88_0",
    &setup_munmap_open_pb8_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_procfinal,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_pcc_0_1, 1, "open" } },
    &cleanup },
  { "fs-munmap_open_p78_0",
    &setup_munmap_open_pdc_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_final,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_p78_0_1, 0, "open" } },
    &cleanup },
  { "fs-munmap_open_p68_0",
    &setup_munmap_open_pdc_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_final,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_p78_0_1, 1, "open" } },
    &cleanup },
  { "fs-munmap_open_p58_0",
    &setup_munmap_open_pcc_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_final,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_p58_0_1, 0, "open" } },
    &cleanup },
  { "fs-munmap_open_p48_0",
    &setup_munmap_open_pcc_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_final,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_p58_0_1, 1, "open" } },
    &cleanup },
  { "fs-munmap_open_p0_0",
    &setup_munmap_open_pb8_0_common,
    { { &setup_munmap_open_pe_0_proc1 }, { &setup_munmap_open_pe_0_proc1 } },
    &setup_munmap_open_pe_0_procfinal,
    &setup_munmap_open_pe_0_procfinal,
    { { &test_munmap_open_pe_0_0, 0, "munmap" },
      { &test_munmap_open_p0_0_1, 0, "open" } },
    &cleanup },
  { "fs-munmap_pipe_pe_0",
    &setup_munmap_pipe_pe_0_common,
    { { &setup_munmap_pipe_pe_0_proc0 }, { &setup_munmap_pipe_pe_0_proc1 } },
    &setup_munmap_pipe_pe_0_procfinal,
    &setup_munmap_pipe_pe_0_final,
    { { &test_munmap_pipe_pe_0_0, 0, "munmap" },
      { &test_munmap_pipe_pe_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-munmap_pipe_p6_0",
    &setup_munmap_pipe_pe_0_common,
    { { &setup_munmap_pipe_pe_0_proc1 }, { &setup_munmap_pipe_pe_0_proc1 } },
    &setup_munmap_pipe_pe_0_procfinal,
    &setup_munmap_pipe_pe_0_procfinal,
    { { &test_munmap_pipe_pe_0_0, 0, "munmap" },
      { &test_munmap_pipe_pe_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-munmap_pread_pe_0",
    &setup_munmap_pread_pe_0_common,
    { { &setup_munmap_pread_pe_0_proc0 }, { &setup_munmap_pread_pe_0_proc1 } },
    &setup_munmap_pread_pe_0_procfinal,
    &setup_munmap_pread_pe_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-munmap_pread_pe_1",
    &setup_munmap_pread_pe_0_common,
    { { &setup_munmap_pread_pe_1_proc0 }, { &setup_munmap_pread_pe_0_proc1 } },
    &setup_munmap_pread_pe_0_procfinal,
    &setup_munmap_pread_pe_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-munmap_pread_pd_0",
    &setup_munmap_pread_pd_0_common,
    { { &setup_munmap_pread_pd_0_proc0 }, { &setup_munmap_pread_pd_0_proc1 } },
    &setup_munmap_pread_pd_0_procfinal,
    &setup_munmap_pread_pd_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pd_0_1, 0, "pread" } },
    &cleanup },
  { "fs-munmap_pread_pd_1",
    &setup_munmap_pread_pd_0_common,
    { { &setup_munmap_pread_pd_1_proc0 }, { &setup_munmap_pread_pd_0_proc1 } },
    &setup_munmap_pread_pd_0_procfinal,
    &setup_munmap_pread_pd_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pd_0_1, 0, "pread" } },
    &cleanup },
  { "fs-munmap_pread_pc0_0",
    &setup_munmap_pread_pc0_0_common,
    { { &setup_munmap_pread_pd_0_proc0 }, { &setup_munmap_pread_pd_0_proc1 } },
    &setup_munmap_pread_pd_0_procfinal,
    &setup_munmap_pread_pd_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pc0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-munmap_pread_pc0_1",
    &setup_munmap_pread_pc0_0_common,
    { { &setup_munmap_pread_pd_1_proc0 }, { &setup_munmap_pread_pd_0_proc1 } },
    &setup_munmap_pread_pd_0_procfinal,
    &setup_munmap_pread_pd_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pc0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-munmap_pread_p8_0",
    &setup_munmap_pread_p8_0_common,
    { { &setup_munmap_pread_pd_0_proc1 }, { &setup_munmap_pread_pd_0_proc1 } },
    &setup_munmap_pread_pd_0_procfinal,
    &setup_munmap_pread_pd_0_procfinal,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_p8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-munmap_pread_p6_0",
    &setup_munmap_pread_pe_0_common,
    { { &setup_munmap_pread_pe_0_proc1 }, { &setup_munmap_pread_pe_0_proc0 } },
    &setup_munmap_pread_pe_0_procfinal,
    &setup_munmap_pread_pe_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-munmap_pread_p6_1",
    &setup_munmap_pread_pe_0_common,
    { { &setup_munmap_pread_pe_0_proc1 }, { &setup_munmap_pread_pe_1_proc0 } },
    &setup_munmap_pread_pe_0_procfinal,
    &setup_munmap_pread_pe_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pe_0_1, 1, "pread" } },
    &cleanup },
  { "fs-munmap_pread_p5_0",
    &setup_munmap_pread_pd_0_common,
    { { &setup_munmap_pread_pd_0_proc1 }, { &setup_munmap_pread_pd_0_proc0 } },
    &setup_munmap_pread_pd_0_procfinal,
    &setup_munmap_pread_pd_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pd_0_1, 1, "pread" } },
    &cleanup },
  { "fs-munmap_pread_p5_1",
    &setup_munmap_pread_pd_0_common,
    { { &setup_munmap_pread_pd_0_proc1 }, { &setup_munmap_pread_pd_1_proc0 } },
    &setup_munmap_pread_pd_0_procfinal,
    &setup_munmap_pread_pd_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pd_0_1, 1, "pread" } },
    &cleanup },
  { "fs-munmap_pread_p40_0",
    &setup_munmap_pread_pc0_0_common,
    { { &setup_munmap_pread_pd_0_proc1 }, { &setup_munmap_pread_pd_0_proc0 } },
    &setup_munmap_pread_pd_0_procfinal,
    &setup_munmap_pread_pd_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pc0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-munmap_pread_p40_1",
    &setup_munmap_pread_pc0_0_common,
    { { &setup_munmap_pread_pd_0_proc1 }, { &setup_munmap_pread_pd_1_proc0 } },
    &setup_munmap_pread_pd_0_procfinal,
    &setup_munmap_pread_pd_0_final,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_pc0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-munmap_pread_p0_0",
    &setup_munmap_pread_p8_0_common,
    { { &setup_munmap_pread_pd_0_proc1 }, { &setup_munmap_pread_pd_0_proc1 } },
    &setup_munmap_pread_pd_0_procfinal,
    &setup_munmap_pread_pd_0_procfinal,
    { { &test_munmap_pread_pe_0_0, 0, "munmap" },
      { &test_munmap_pread_p8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-munmap_pwrite_pe_0",
    &setup_munmap_pwrite_pe_0_common,
    { { &setup_munmap_pwrite_pe_0_proc0 }, { &setup_munmap_pwrite_pe_0_proc1 } },
    &setup_munmap_pwrite_pe_0_procfinal,
    &setup_munmap_pwrite_pe_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_pe_1",
    &setup_munmap_pwrite_pe_0_common,
    { { &setup_munmap_pwrite_pe_1_proc0 }, { &setup_munmap_pwrite_pe_0_proc1 } },
    &setup_munmap_pwrite_pe_0_procfinal,
    &setup_munmap_pwrite_pe_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_pd0_0",
    &setup_munmap_pwrite_pd0_0_common,
    { { &setup_munmap_pwrite_pd0_0_proc0 }, { &setup_munmap_pwrite_pd0_0_proc1 } },
    &setup_munmap_pwrite_pd0_0_procfinal,
    &setup_munmap_pwrite_pd0_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pd0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_pd0_1",
    &setup_munmap_pwrite_pd0_0_common,
    { { &setup_munmap_pwrite_pd0_1_proc0 }, { &setup_munmap_pwrite_pd0_0_proc1 } },
    &setup_munmap_pwrite_pd0_0_procfinal,
    &setup_munmap_pwrite_pd0_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pd0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_pc0_0",
    &setup_munmap_pwrite_pc0_0_common,
    { { &setup_munmap_pwrite_pc0_0_proc0 }, { &setup_munmap_pwrite_pd0_0_proc1 } },
    &setup_munmap_pwrite_pd0_0_procfinal,
    &setup_munmap_pwrite_pd0_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pd0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_pc0_1",
    &setup_munmap_pwrite_pc0_0_common,
    { { &setup_munmap_pwrite_pd0_1_proc0 }, { &setup_munmap_pwrite_pd0_0_proc1 } },
    &setup_munmap_pwrite_pd0_0_procfinal,
    &setup_munmap_pwrite_pd0_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pd0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_p8_0",
    &setup_munmap_pwrite_p8_0_common,
    { { &setup_munmap_pwrite_pd0_0_proc1 }, { &setup_munmap_pwrite_pd0_0_proc1 } },
    &setup_munmap_pwrite_pd0_0_procfinal,
    &setup_munmap_pwrite_pd0_0_procfinal,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_p8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_p6_0",
    &setup_munmap_pwrite_pe_0_common,
    { { &setup_munmap_pwrite_pe_0_proc1 }, { &setup_munmap_pwrite_pe_0_proc0 } },
    &setup_munmap_pwrite_pe_0_procfinal,
    &setup_munmap_pwrite_pe_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_p6_1",
    &setup_munmap_pwrite_pe_0_common,
    { { &setup_munmap_pwrite_pe_0_proc1 }, { &setup_munmap_pwrite_pe_1_proc0 } },
    &setup_munmap_pwrite_pe_0_procfinal,
    &setup_munmap_pwrite_pe_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pe_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_p50_0",
    &setup_munmap_pwrite_pd0_0_common,
    { { &setup_munmap_pwrite_pd0_0_proc1 }, { &setup_munmap_pwrite_p50_0_proc1 } },
    &setup_munmap_pwrite_pd0_0_procfinal,
    &setup_munmap_pwrite_pd0_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pd0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_p50_1",
    &setup_munmap_pwrite_pd0_0_common,
    { { &setup_munmap_pwrite_pd0_0_proc1 }, { &setup_munmap_pwrite_pd0_1_proc0 } },
    &setup_munmap_pwrite_pd0_0_procfinal,
    &setup_munmap_pwrite_pd0_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pd0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_p40_0",
    &setup_munmap_pwrite_pc0_0_common,
    { { &setup_munmap_pwrite_pd0_0_proc1 }, { &setup_munmap_pwrite_p40_0_proc1 } },
    &setup_munmap_pwrite_pd0_0_procfinal,
    &setup_munmap_pwrite_pd0_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pd0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_p40_1",
    &setup_munmap_pwrite_pc0_0_common,
    { { &setup_munmap_pwrite_pd0_0_proc1 }, { &setup_munmap_pwrite_pd0_1_proc0 } },
    &setup_munmap_pwrite_pd0_0_procfinal,
    &setup_munmap_pwrite_pd0_0_final,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_pd0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-munmap_pwrite_p0_0",
    &setup_munmap_pwrite_p8_0_common,
    { { &setup_munmap_pwrite_pd0_0_proc1 }, { &setup_munmap_pwrite_pd0_0_proc1 } },
    &setup_munmap_pwrite_pd0_0_procfinal,
    &setup_munmap_pwrite_pd0_0_procfinal,
    { { &test_munmap_pwrite_pe_0_0, 0, "munmap" },
      { &test_munmap_pwrite_p8_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-munmap_read_pf_0",
    &setup_munmap_read_pf_0_common,
    { { &setup_munmap_read_pf_0_proc0 }, { &setup_munmap_read_pf_0_proc1 } },
    &setup_munmap_read_pf_0_procfinal,
    &setup_munmap_read_pf_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pf_0_1, 0, "read" } },
    &cleanup },
  { "fs-munmap_read_pec_0",
    &setup_munmap_read_pec_0_common,
    { { &setup_munmap_read_pec_0_proc0 }, { &setup_munmap_read_pf_0_proc1 } },
    &setup_munmap_read_pf_0_procfinal,
    &setup_munmap_read_pf_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pec_0_1, 0, "read" } },
    &cleanup },
  { "fs-munmap_read_pe8_0",
    &setup_munmap_read_pec_0_common,
    { { &setup_munmap_read_pe8_0_proc0 }, { &setup_munmap_read_pe8_0_proc1 } },
    &setup_munmap_read_pf_0_procfinal,
    &setup_munmap_read_pf_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pe8_0_1, 0, "read" } },
    &cleanup },
  { "fs-munmap_read_pe0_0",
    &setup_munmap_read_pe0_0_common,
    { { &setup_munmap_read_pec_0_proc0 }, { &setup_munmap_read_pf_0_proc1 } },
    &setup_munmap_read_pf_0_procfinal,
    &setup_munmap_read_pf_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pe0_0_1, 0, "read" } },
    &cleanup },
  { "fs-munmap_read_pd_0",
    &setup_munmap_read_pd_0_common,
    { { &setup_munmap_read_pd_0_proc0 }, { &setup_munmap_read_pd_0_proc1 } },
    &setup_munmap_read_pd_0_procfinal,
    &setup_munmap_read_pd_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pe8_0_1, 0, "read" } },
    &cleanup },
  { "fs-munmap_read_pc0_0",
    &setup_munmap_read_pc0_0_common,
    { { &setup_munmap_read_pc0_0_proc0 }, { &setup_munmap_read_pd_0_proc1 } },
    &setup_munmap_read_pd_0_procfinal,
    &setup_munmap_read_pd_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pe0_0_1, 0, "read" } },
    &cleanup },
  { "fs-munmap_read_p8_0",
    &setup_munmap_read_p8_0_common,
    { { &setup_munmap_read_pd_0_proc1 }, { &setup_munmap_read_pd_0_proc1 } },
    &setup_munmap_read_pd_0_procfinal,
    &setup_munmap_read_pd_0_procfinal,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pf_0_1, 0, "read" } },
    &cleanup },
  { "fs-munmap_read_p7_0",
    &setup_munmap_read_pf_0_common,
    { { &setup_munmap_read_pf_0_proc1 }, { &setup_munmap_read_pf_0_proc0 } },
    &setup_munmap_read_pf_0_procfinal,
    &setup_munmap_read_pf_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pf_0_1, 1, "read" } },
    &cleanup },
  { "fs-munmap_read_p6c_0",
    &setup_munmap_read_pec_0_common,
    { { &setup_munmap_read_pf_0_proc1 }, { &setup_munmap_read_pec_0_proc0 } },
    &setup_munmap_read_pf_0_procfinal,
    &setup_munmap_read_pf_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-munmap_read_p68_0",
    &setup_munmap_read_pec_0_common,
    { { &setup_munmap_read_pe8_0_proc1 }, { &setup_munmap_read_pe8_0_proc0 } },
    &setup_munmap_read_pf_0_procfinal,
    &setup_munmap_read_pf_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pe8_0_1, 1, "read" } },
    &cleanup },
  { "fs-munmap_read_p60_0",
    &setup_munmap_read_pe0_0_common,
    { { &setup_munmap_read_pf_0_proc1 }, { &setup_munmap_read_pec_0_proc0 } },
    &setup_munmap_read_pf_0_procfinal,
    &setup_munmap_read_pf_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pe0_0_1, 1, "read" } },
    &cleanup },
  { "fs-munmap_read_p5_0",
    &setup_munmap_read_pd_0_common,
    { { &setup_munmap_read_pd_0_proc1 }, { &setup_munmap_read_pd_0_proc0 } },
    &setup_munmap_read_pd_0_procfinal,
    &setup_munmap_read_pd_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pe8_0_1, 1, "read" } },
    &cleanup },
  { "fs-munmap_read_p40_0",
    &setup_munmap_read_pc0_0_common,
    { { &setup_munmap_read_pd_0_proc1 }, { &setup_munmap_read_pc0_0_proc0 } },
    &setup_munmap_read_pd_0_procfinal,
    &setup_munmap_read_pd_0_final,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pe0_0_1, 1, "read" } },
    &cleanup },
  { "fs-munmap_read_p0_0",
    &setup_munmap_read_p8_0_common,
    { { &setup_munmap_read_pd_0_proc1 }, { &setup_munmap_read_pd_0_proc1 } },
    &setup_munmap_read_pd_0_procfinal,
    &setup_munmap_read_pd_0_procfinal,
    { { &test_munmap_read_pf_0_0, 0, "munmap" },
      { &test_munmap_read_pf_0_1, 1, "read" } },
    &cleanup },
  { "fs-munmap_rename_pc_0",
    &setup_munmap_rename_pc_0_common,
    { { &setup_munmap_rename_pc_0_proc0 }, { &setup_munmap_rename_pc_0_proc1 } },
    &setup_munmap_rename_pc_0_procfinal,
    &setup_munmap_rename_pc_0_final,
    { { &test_munmap_rename_pc_0_0, 0, "munmap" },
      { &test_munmap_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-munmap_rename_pa_0",
    &setup_munmap_rename_pa_0_common,
    { { &setup_munmap_rename_pc_0_proc1 }, { &setup_munmap_rename_pc_0_proc1 } },
    &setup_munmap_rename_pc_0_procfinal,
    &setup_munmap_rename_pc_0_final,
    { { &test_munmap_rename_pc_0_0, 0, "munmap" },
      { &test_munmap_rename_pa_0_1, 0, "rename" } },
    &cleanup },
  { "fs-munmap_rename_p8_0",
    &setup_munmap_rename_pc_0_common,
    { { &setup_munmap_rename_pc_0_proc1 }, { &setup_munmap_rename_pc_0_proc1 } },
    &setup_munmap_rename_pc_0_procfinal,
    &setup_munmap_rename_pc_0_final,
    { { &test_munmap_rename_pc_0_0, 0, "munmap" },
      { &test_munmap_rename_pa_0_1, 0, "rename" } },
    &cleanup },
  { "fs-munmap_rename_p0_0",
    &setup_munmap_rename_p0_0_common,
    { { &setup_munmap_rename_pc_0_proc1 }, { &setup_munmap_rename_pc_0_proc1 } },
    &setup_munmap_rename_pc_0_procfinal,
    &setup_munmap_rename_pc_0_procfinal,
    { { &test_munmap_rename_pc_0_0, 0, "munmap" },
      { &test_munmap_rename_p0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-munmap_stat_p8_0",
    &setup_munmap_stat_p8_0_common,
    { { &setup_munmap_stat_p8_0_proc0 }, { &setup_munmap_stat_p8_0_proc1 } },
    &setup_munmap_stat_p8_0_procfinal,
    &setup_munmap_stat_p8_0_final,
    { { &test_munmap_stat_p8_0_0, 0, "munmap" },
      { &test_munmap_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-munmap_stat_p0_0",
    &setup_munmap_stat_p0_0_common,
    { { &setup_munmap_stat_p8_0_proc1 }, { &setup_munmap_stat_p8_0_proc1 } },
    &setup_munmap_stat_p8_0_procfinal,
    &setup_munmap_stat_p8_0_procfinal,
    { { &test_munmap_stat_p8_0_0, 0, "munmap" },
      { &test_munmap_stat_p0_0_1, 0, "stat" } },
    &cleanup },
  { "fs-munmap_unlink_p8_0",
    &setup_munmap_unlink_p8_0_common,
    { { &setup_munmap_unlink_p8_0_proc0 }, { &setup_munmap_unlink_p8_0_proc1 } },
    &setup_munmap_unlink_p8_0_procfinal,
    &setup_munmap_unlink_p8_0_final,
    { { &test_munmap_unlink_p8_0_0, 0, "munmap" },
      { &test_munmap_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-munmap_unlink_p0_0",
    &setup_munmap_unlink_p0_0_common,
    { { &setup_munmap_unlink_p8_0_proc1 }, { &setup_munmap_unlink_p8_0_proc1 } },
    &setup_munmap_unlink_p8_0_procfinal,
    &setup_munmap_unlink_p8_0_procfinal,
    { { &test_munmap_unlink_p8_0_0, 0, "munmap" },
      { &test_munmap_unlink_p0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-munmap_write_pf8_0",
    &setup_munmap_write_pf8_0_common,
    { { &setup_munmap_write_pf8_0_proc0 }, { &setup_munmap_write_pf8_0_proc1 } },
    &setup_munmap_write_pf8_0_procfinal,
    &setup_munmap_write_pf8_0_final,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-munmap_write_pf0_0",
    &setup_munmap_write_pf0_0_common,
    { { &setup_munmap_write_pf0_0_proc0 }, { &setup_munmap_write_pf0_0_proc1 } },
    &setup_munmap_write_pf8_0_procfinal,
    &setup_munmap_write_pf8_0_final,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-munmap_write_pe_0",
    &setup_munmap_write_pe_0_common,
    { { &setup_munmap_write_pe_0_proc0 }, { &setup_munmap_write_pf0_0_proc1 } },
    &setup_munmap_write_pf8_0_procfinal,
    &setup_munmap_write_pf8_0_final,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pe_0_1, 0, "write" } },
    &cleanup },
  { "fs-munmap_write_pd0_0",
    &setup_munmap_write_pd0_0_common,
    { { &setup_munmap_write_pd0_0_proc0 }, { &setup_munmap_write_pd0_0_proc1 } },
    &setup_munmap_write_pd0_0_procfinal,
    &setup_munmap_write_pd0_0_final,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-munmap_write_pc0_0",
    &setup_munmap_write_pc0_0_common,
    { { &setup_munmap_write_pd0_0_proc0 }, { &setup_munmap_write_pd0_0_proc1 } },
    &setup_munmap_write_pd0_0_procfinal,
    &setup_munmap_write_pd0_0_final,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-munmap_write_p8_0",
    &setup_munmap_write_p8_0_common,
    { { &setup_munmap_write_pd0_0_proc1 }, { &setup_munmap_write_pd0_0_proc1 } },
    &setup_munmap_write_pd0_0_procfinal,
    &setup_munmap_write_pd0_0_procfinal,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pe_0_1, 0, "write" } },
    &cleanup },
  { "fs-munmap_write_p78_0",
    &setup_munmap_write_pf8_0_common,
    { { &setup_munmap_write_pf8_0_proc1 }, { &setup_munmap_write_pf8_0_proc0 } },
    &setup_munmap_write_pf8_0_procfinal,
    &setup_munmap_write_pf8_0_final,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-munmap_write_p70_0",
    &setup_munmap_write_pf0_0_common,
    { { &setup_munmap_write_pf0_0_proc1 }, { &setup_munmap_write_pf0_0_proc0 } },
    &setup_munmap_write_pf8_0_procfinal,
    &setup_munmap_write_pf8_0_final,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-munmap_write_p6_0",
    &setup_munmap_write_pe_0_common,
    { { &setup_munmap_write_pf0_0_proc1 }, { &setup_munmap_write_pe_0_proc0 } },
    &setup_munmap_write_pf8_0_procfinal,
    &setup_munmap_write_pf8_0_final,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pe_0_1, 1, "write" } },
    &cleanup },
  { "fs-munmap_write_p50_0",
    &setup_munmap_write_pd0_0_common,
    { { &setup_munmap_write_pd0_0_proc1 }, { &setup_munmap_write_pd0_0_proc0 } },
    &setup_munmap_write_pd0_0_procfinal,
    &setup_munmap_write_pd0_0_final,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-munmap_write_p40_0",
    &setup_munmap_write_pc0_0_common,
    { { &setup_munmap_write_pd0_0_proc1 }, { &setup_munmap_write_pd0_0_proc0 } },
    &setup_munmap_write_pd0_0_procfinal,
    &setup_munmap_write_pd0_0_final,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-munmap_write_p0_0",
    &setup_munmap_write_p8_0_common,
    { { &setup_munmap_write_pd0_0_proc1 }, { &setup_munmap_write_pd0_0_proc1 } },
    &setup_munmap_write_pd0_0_procfinal,
    &setup_munmap_write_pd0_0_procfinal,
    { { &test_munmap_write_pf8_0_0, 0, "munmap" },
      { &test_munmap_write_pe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_open_pfc_0",
    &setup_open_open_pfc_0_common,
    { { &setup_open_open_pfc_0_proc0 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pfc_1",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pfc_0_0, 0, "open" } },
    &cleanup },
  { "fs-open_open_pfb8_0",
    &setup_open_open_pfc_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pfb8_1",
    &setup_open_open_pfb8_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pfb8_1_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pfa8_0",
    &setup_open_open_pfa8_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pfa8_1",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pfb8_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pf98_0",
    &setup_open_open_pf98_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pf98_1",
    &setup_open_open_pf98_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pf98_1_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pf88_0",
    &setup_open_open_pf98_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pf88_1",
    &setup_open_open_pf98_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pf98_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pf70_0",
    &setup_open_open_pfb8_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pf50_0",
    &setup_open_open_pfb8_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pf30_0",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pf10_0",
    &setup_open_open_pfb8_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pef0_0",
    &setup_open_open_pef0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pef0_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pef0_1",
    &setup_open_open_pfb8_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pef0_1_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_ped0_0",
    &setup_open_open_pfa8_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_ped0_1",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pef0_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_peb_0",
    &setup_open_open_pf98_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_peb_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_peb_1",
    &setup_open_open_pf98_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_peb_1_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pe9_0",
    &setup_open_open_pf98_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pe9_1",
    &setup_open_open_pf98_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_peb_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pe0_0",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfc_0_0, 0, "open" },
      { &test_open_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pdf0_0",
    &setup_open_open_pfc_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pdf0_1",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pfc_0_0, 0, "open" } },
    &cleanup },
  { "fs-open_open_pdd6_0",
    &setup_open_open_pfc_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pdd6_1",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pfb8_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pdc6_0",
    &setup_open_open_pef0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pdc6_1",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pf98_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pdac_0",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pd8c_0",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pd6c_0",
    &setup_open_open_pfa8_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pd6c_1",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pef0_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pd4c_0",
    &setup_open_open_pef0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pd4c_1",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_peb_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pd2_0",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pcf_0",
    &setup_open_open_pf98_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pcf_1",
    &setup_open_open_pf98_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pfc_0_0, 0, "open" } },
    &cleanup },
  { "fs-open_open_pcd6_0",
    &setup_open_open_pcd6_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pcd6_1",
    &setup_open_open_pcd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pfb8_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pcc6_0",
    &setup_open_open_pfa8_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pcc6_1",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pf98_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pcac_0",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pc8c_0",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pc6c_0",
    &setup_open_open_pcd6_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pc6c_1",
    &setup_open_open_pcd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pef0_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pc4c_0",
    &setup_open_open_pfa8_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pc4c_1",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_peb_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pc2_0",
    &setup_open_open_pf98_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pbf0_0",
    &setup_open_open_pbf0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_pbae_0",
    &setup_open_open_pbae_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pba30_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pfb8_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pb8e_0",
    &setup_open_open_pb8e_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pb830_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pf98_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pb58_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pb18_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_padc_0",
    &setup_open_open_pbae_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pa9c_0",
    &setup_open_open_pb8e_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_pa4_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_pfb8_1_1, 0, "open" },
      { &test_open_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p9f0_0",
    &setup_open_open_pbf0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p9ae_0",
    &setup_open_open_pbae_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p9a30_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pfb8_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p98e_0",
    &setup_open_open_pb8e_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p9830_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pf98_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p958_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p918_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p8dc_0",
    &setup_open_open_pbf0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p89c_0",
    &setup_open_open_pb8e_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p84_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_pf98_1_1, 0, "open" },
      { &test_open_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p7e_0",
    &setup_open_open_pef0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p7e_1",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pfc_0_0, 0, "open" } },
    &cleanup },
  { "fs-open_open_p7ac_0",
    &setup_open_open_pfa8_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p7ac_1",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pfb8_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p78c_0",
    &setup_open_open_pef0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p78c_1",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pf98_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p758_0",
    &setup_open_open_pfc_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p718_0",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p6d8_0",
    &setup_open_open_pcd6_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p6d8_1",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pef0_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p698_0",
    &setup_open_open_pef0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p698_1",
    &setup_open_open_pfb8_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_peb_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p64_0",
    &setup_open_open_pfb8_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_pef0_1_1, 0, "open" },
      { &test_open_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p5e_0",
    &setup_open_open_pf98_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p5e_1",
    &setup_open_open_pf98_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pfc_0_0, 0, "open" } },
    &cleanup },
  { "fs-open_open_p5ac_0",
    &setup_open_open_p5ac_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p5ac_1",
    &setup_open_open_p5ac_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pfb8_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p58c_0",
    &setup_open_open_pfa8_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p58c_1",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pf98_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p558_0",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p518_0",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p4d8_0",
    &setup_open_open_pcd6_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p4d8_1",
    &setup_open_open_pcd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pef0_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p498_0",
    &setup_open_open_pfa8_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p498_1",
    &setup_open_open_pdd6_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_peb_1_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p44_0",
    &setup_open_open_pf98_1_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_peb_1_1, 0, "open" },
      { &test_open_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p38_0",
    &setup_open_open_pbae_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pfc_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p370_0",
    &setup_open_open_pbae_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p350_0",
    &setup_open_open_pbf0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p33_0",
    &setup_open_open_p33_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p31_0",
    &setup_open_open_p33_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p2d0_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pfb8_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p290_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pfb8_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p250_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pf98_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p210_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pf98_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p1e_0",
    &setup_open_open_pbf0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pef0_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p1a_0",
    &setup_open_open_pbf0_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pef0_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p16_0",
    &setup_open_open_p33_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_peb_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p12_0",
    &setup_open_open_p33_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_final,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_peb_0_1, 1, "open" } },
    &cleanup },
  { "fs-open_open_p0_0",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_pe0_0_1, 0, "open" } },
    &cleanup },
  { "fs-open_open_p0_1",
    &setup_open_open_pba30_0_common,
    { { &setup_open_open_pfc_0_proc1 }, { &setup_open_open_pfc_0_proc1 } },
    &setup_open_open_pfc_0_procfinal,
    &setup_open_open_pfc_0_procfinal,
    { { &test_open_open_p38_0_0, 0, "open" },
      { &test_open_open_p38_0_0, 0, "open" } },
    &cleanup },
  { "fs-open_pipe_pfc_0",
    &setup_open_pipe_pfc_0_common,
    { { &setup_open_pipe_pfc_0_proc0 }, { &setup_open_pipe_pfc_0_proc1 } },
    &setup_open_pipe_pfc_0_procfinal,
    &setup_open_pipe_pfc_0_final,
    { { &test_open_pipe_pfc_0_0, 0, "open" },
      { &test_open_pipe_pfc_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-open_pipe_pec_0",
    &setup_open_pipe_pfc_0_common,
    { { &setup_open_pipe_pfc_0_proc1 }, { &setup_open_pipe_pfc_0_proc1 } },
    &setup_open_pipe_pfc_0_procfinal,
    &setup_open_pipe_pfc_0_final,
    { { &test_open_pipe_pfc_0_0, 0, "open" },
      { &test_open_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-open_pipe_pd70_0",
    &setup_open_pipe_pd70_0_common,
    { { &setup_open_pipe_pfc_0_proc1 }, { &setup_open_pipe_pfc_0_proc1 } },
    &setup_open_pipe_pfc_0_procfinal,
    &setup_open_pipe_pfc_0_final,
    { { &test_open_pipe_pd70_0_0, 0, "open" },
      { &test_open_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-open_pipe_pc70_0",
    &setup_open_pipe_pc70_0_common,
    { { &setup_open_pipe_pfc_0_proc1 }, { &setup_open_pipe_pfc_0_proc1 } },
    &setup_open_pipe_pfc_0_procfinal,
    &setup_open_pipe_pfc_0_final,
    { { &test_open_pipe_pc70_0_0, 0, "open" },
      { &test_open_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-open_pipe_pae_0",
    &setup_open_pipe_pae_0_common,
    { { &setup_open_pipe_pfc_0_proc1 }, { &setup_open_pipe_pfc_0_proc1 } },
    &setup_open_pipe_pfc_0_procfinal,
    &setup_open_pipe_pfc_0_procfinal,
    { { &test_open_pipe_pd70_0_0, 0, "open" },
      { &test_open_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-open_pipe_p8e_0",
    &setup_open_pipe_pae_0_common,
    { { &setup_open_pipe_pfc_0_proc1 }, { &setup_open_pipe_pfc_0_proc1 } },
    &setup_open_pipe_pfc_0_procfinal,
    &setup_open_pipe_pfc_0_procfinal,
    { { &test_open_pipe_pc70_0_0, 0, "open" },
      { &test_open_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-open_pipe_p6e_0",
    &setup_open_pipe_pfc_0_common,
    { { &setup_open_pipe_pfc_0_proc1 }, { &setup_open_pipe_pfc_0_proc1 } },
    &setup_open_pipe_pfc_0_procfinal,
    &setup_open_pipe_pfc_0_final,
    { { &test_open_pipe_p6e_0_0, 0, "open" },
      { &test_open_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-open_pipe_p4e_0",
    &setup_open_pipe_pc70_0_common,
    { { &setup_open_pipe_pfc_0_proc1 }, { &setup_open_pipe_pfc_0_proc1 } },
    &setup_open_pipe_pfc_0_procfinal,
    &setup_open_pipe_pfc_0_final,
    { { &test_open_pipe_p4e_0_0, 0, "open" },
      { &test_open_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-open_pipe_p38_0",
    &setup_open_pipe_pae_0_common,
    { { &setup_open_pipe_pfc_0_proc1 }, { &setup_open_pipe_pfc_0_proc1 } },
    &setup_open_pipe_pfc_0_procfinal,
    &setup_open_pipe_pfc_0_procfinal,
    { { &test_open_pipe_p38_0_0, 0, "open" },
      { &test_open_pipe_pfc_0_1, 0, "pipe" } },
    &cleanup },
  { "fs-open_pipe_p18_0",
    &setup_open_pipe_pae_0_common,
    { { &setup_open_pipe_pfc_0_proc1 }, { &setup_open_pipe_pfc_0_proc1 } },
    &setup_open_pipe_pfc_0_procfinal,
    &setup_open_pipe_pfc_0_procfinal,
    { { &test_open_pipe_p38_0_0, 0, "open" },
      { &test_open_pipe_pfc_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-open_pread_pfc_0",
    &setup_open_pread_pfc_0_common,
    { { &setup_open_pread_pfc_0_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pfc_1",
    &setup_open_pread_pfc_0_common,
    { { &setup_open_pread_pfc_1_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pfa_0",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pfa_1",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pf8_0",
    &setup_open_pread_pf8_0_common,
    { { &setup_open_pread_pfa_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pf8_1",
    &setup_open_pread_pf8_0_common,
    { { &setup_open_pread_pfa_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pf0_0",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pec_0",
    &setup_open_pread_pfc_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_0_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pec_1",
    &setup_open_pread_pfc_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_1_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pea_0",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pea_1",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_1_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pe8_0",
    &setup_open_pread_pf8_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pe8_1",
    &setup_open_pread_pf8_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_1_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pe0_0",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pfc_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pdf0_0",
    &setup_open_pread_pdf0_0_common,
    { { &setup_open_pread_pfc_0_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pdf0_1",
    &setup_open_pread_pdf0_1_common,
    { { &setup_open_pread_pfc_1_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pdde_0",
    &setup_open_pread_pf8_0_common,
    { { &setup_open_pread_pdde_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pdde_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pdde_1",
    &setup_open_pread_pdde_1_common,
    { { &setup_open_pread_pdde_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pdde_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pdc8_0",
    &setup_open_pread_pdc8_0_common,
    { { &setup_open_pread_pdc8_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pdc8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pdc8_1",
    &setup_open_pread_pdc8_1_common,
    { { &setup_open_pread_pdc8_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pdc8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pda_0",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pd70_0",
    &setup_open_pread_pd70_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_0_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pd70_1",
    &setup_open_pread_pd70_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_1_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pd5c_0",
    &setup_open_pread_pd5c_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd5c_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pdde_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pd5c_1",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd5c_1_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pd5c_2",
    &setup_open_pread_pdc8_1_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd5c_2_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pd5c_2_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pd5c_3",
    &setup_open_pread_pd5c_3_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd5c_3_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pd5c_3_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pd48_0",
    &setup_open_pread_pd5c_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd48_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pd48_1",
    &setup_open_pread_pdc8_1_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pdc8_1_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pdc8_1_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pd2_0",
    &setup_open_pread_pd5c_3_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pcf_0",
    &setup_open_pread_pcf_0_common,
    { { &setup_open_pread_pfc_0_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pcf_1",
    &setup_open_pread_pcf_0_common,
    { { &setup_open_pread_pfc_1_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pcdc_0",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pcdc_1",
    &setup_open_pread_pcdc_1_common,
    { { &setup_open_pread_pcdc_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pcdc_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pccc_0",
    &setup_open_pread_pccc_0_common,
    { { &setup_open_pread_pdc8_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pdc8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pca_0",
    &setup_open_pread_pd5c_3_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pc7_0",
    &setup_open_pread_pc7_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_0_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pc7_1",
    &setup_open_pread_pc7_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_1_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pc58_0",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pc58_1",
    &setup_open_pread_pccc_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pc58_1_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pc58_1_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pc48_0",
    &setup_open_pread_pf8_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pc48_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pc48_1",
    &setup_open_pread_pdde_1_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd5c_2_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pc48_1_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pc2_0",
    &setup_open_pread_pd5c_3_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pbe_0",
    &setup_open_pread_pbe_0_common,
    { { &setup_open_pread_pfc_0_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pbe_1",
    &setup_open_pread_pbe_0_common,
    { { &setup_open_pread_pfc_1_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pbb8_0",
    &setup_open_pread_pbb8_0_common,
    { { &setup_open_pread_pbb8_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pdde_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pbb8_1",
    &setup_open_pread_pbb8_1_common,
    { { &setup_open_pread_pbb8_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pbb8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pb90_0",
    &setup_open_pread_pb90_0_common,
    { { &setup_open_pread_pb90_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pb90_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pb90_1",
    &setup_open_pread_pb90_1_common,
    { { &setup_open_pread_pdde_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pb90_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pb4_0",
    &setup_open_pread_pb4_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_procfinal,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_pae_0",
    &setup_open_pread_pae_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_0_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pae_1",
    &setup_open_pread_pae_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_1_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pab0_0",
    &setup_open_pread_pab0_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pdc8_1_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pab0_1",
    &setup_open_pread_pab0_1_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pbb8_1_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pbb8_1_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pa90_0",
    &setup_open_pread_pbb8_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pbb8_0_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pa90_1",
    &setup_open_pread_pb90_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pa90_1_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pb90_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_pa4_0",
    &setup_open_pread_pb4_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_procfinal,
    { { &test_open_pread_pdf0_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p9e_0",
    &setup_open_pread_p9e_0_common,
    { { &setup_open_pread_pfc_0_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p9e_1",
    &setup_open_pread_p9e_0_common,
    { { &setup_open_pread_pfc_1_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p9b8_0",
    &setup_open_pread_pbb8_0_common,
    { { &setup_open_pread_p9b8_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pdde_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p9b8_1",
    &setup_open_pread_pbb8_1_common,
    { { &setup_open_pread_pbb8_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pbb8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p990_0",
    &setup_open_pread_pb90_0_common,
    { { &setup_open_pread_p990_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pb90_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p990_1",
    &setup_open_pread_p990_1_common,
    { { &setup_open_pread_p990_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_p990_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p94_0",
    &setup_open_pread_pb4_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_procfinal,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p8e_0",
    &setup_open_pread_p8e_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_0_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p8e_1",
    &setup_open_pread_p8e_1_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_1_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p8b0_0",
    &setup_open_pread_pab0_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pdc8_1_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p8b0_1",
    &setup_open_pread_pab0_1_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pbb8_1_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pbb8_1_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p890_0",
    &setup_open_pread_pbb8_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pbb8_0_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p890_1",
    &setup_open_pread_pb90_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pa90_1_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pb90_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p84_0",
    &setup_open_pread_pb4_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_procfinal,
    { { &test_open_pread_pcf_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p7e_0",
    &setup_open_pread_pdf0_1_common,
    { { &setup_open_pread_pfc_0_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p7e_1",
    &setup_open_pread_pdf0_1_common,
    { { &setup_open_pread_pfc_1_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p7bc_0",
    &setup_open_pread_pf8_0_common,
    { { &setup_open_pread_pdde_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pdde_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p7bc_1",
    &setup_open_pread_pd5c_3_common,
    { { &setup_open_pread_pfa_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_p7bc_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p790_0",
    &setup_open_pread_pdc8_0_common,
    { { &setup_open_pread_pdc8_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pdc8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p790_1",
    &setup_open_pread_pdc8_1_common,
    { { &setup_open_pread_pdc8_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pdc8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p74_0",
    &setup_open_pread_p74_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p6e_0",
    &setup_open_pread_p6e_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_0_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p6e_1",
    &setup_open_pread_p6e_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_1_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p6b8_0",
    &setup_open_pread_pd5c_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd5c_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pdde_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p6b8_1",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd5c_1_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p6b8_2",
    &setup_open_pread_pdc8_1_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd5c_2_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pd5c_2_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p6b8_3",
    &setup_open_pread_pd5c_3_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd5c_3_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pd5c_3_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p690_0",
    &setup_open_pread_pd5c_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd48_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p690_1",
    &setup_open_pread_pdc8_1_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pdc8_1_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pdc8_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pdc8_1_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p64_0",
    &setup_open_pread_p74_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p7e_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p5e_0",
    &setup_open_pread_pcf_0_common,
    { { &setup_open_pread_pfc_0_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p5e_1",
    &setup_open_pread_pcf_0_common,
    { { &setup_open_pread_pfc_1_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p5b8_0",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p5b8_1",
    &setup_open_pread_pcdc_1_common,
    { { &setup_open_pread_pcdc_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pcdc_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p598_0",
    &setup_open_pread_pccc_0_common,
    { { &setup_open_pread_pdc8_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pdc8_1_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p54_0",
    &setup_open_pread_pd5c_3_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p4e_0",
    &setup_open_pread_pc7_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_0_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p4e_1",
    &setup_open_pread_pc7_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_1_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p4b_0",
    &setup_open_pread_pfa_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p4b_1",
    &setup_open_pread_pccc_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pc58_1_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pc58_1_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p490_0",
    &setup_open_pread_pf8_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pc48_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p490_1",
    &setup_open_pread_pdde_1_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pd5c_2_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pc48_1_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p44_0",
    &setup_open_pread_pd5c_3_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p5e_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p38_0",
    &setup_open_pread_p38_0_common,
    { { &setup_open_pread_pfc_0_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p38_1",
    &setup_open_pread_p38_0_common,
    { { &setup_open_pread_pfc_1_proc0 }, { &setup_open_pread_pfc_0_proc1 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p34_0",
    &setup_open_pread_pab0_0_common,
    { { &setup_open_pread_pfa_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p34_1",
    &setup_open_pread_pab0_0_common,
    { { &setup_open_pread_pfa_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p30_0",
    &setup_open_pread_pbb8_0_common,
    { { &setup_open_pread_pfa_0_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p30_1",
    &setup_open_pread_pbb8_0_common,
    { { &setup_open_pread_pfa_1_proc0 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p2_0",
    &setup_open_pread_pb4_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_procfinal,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-open_pread_p18_0",
    &setup_open_pread_p38_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_0_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p18_1",
    &setup_open_pread_p38_0_common,
    { { &setup_open_pread_pfc_0_proc1 }, { &setup_open_pread_pfc_1_proc0 } },
    &setup_open_pread_pfc_0_procfinal,
    &setup_open_pread_pfc_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p14_0",
    &setup_open_pread_pab0_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p14_1",
    &setup_open_pread_pab0_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_1_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pfa_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p10_0",
    &setup_open_pread_pbb8_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p10_1",
    &setup_open_pread_pbb8_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_1_proc0 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_final,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pf8_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pread_p0_0",
    &setup_open_pread_pb4_0_common,
    { { &setup_open_pread_pfa_0_proc1 }, { &setup_open_pread_pfa_0_proc1 } },
    &setup_open_pread_pfa_0_procfinal,
    &setup_open_pread_pfa_0_procfinal,
    { { &test_open_pread_p38_0_0, 0, "open" },
      { &test_open_pread_pf0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-open_pwrite_pfc_0",
    &setup_open_pwrite_pfc_0_common,
    { { &setup_open_pwrite_pfc_0_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pfc_1",
    &setup_open_pwrite_pfc_0_common,
    { { &setup_open_pwrite_pfc_1_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pfa_0",
    &setup_open_pwrite_pfa_0_common,
    { { &setup_open_pwrite_pfa_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pfa_1",
    &setup_open_pwrite_pfa_0_common,
    { { &setup_open_pwrite_pfa_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pf8_0",
    &setup_open_pwrite_pf8_0_common,
    { { &setup_open_pwrite_pf8_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pf8_1",
    &setup_open_pwrite_pf8_0_common,
    { { &setup_open_pwrite_pfa_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pf0_0",
    &setup_open_pwrite_pfa_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pec_0",
    &setup_open_pwrite_pfc_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_0_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pec_1",
    &setup_open_pwrite_pfc_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_1_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pea_0",
    &setup_open_pwrite_pfa_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pea_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pea_1",
    &setup_open_pwrite_pfa_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_1_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pe8_0",
    &setup_open_pwrite_pf8_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pe8_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pe8_1",
    &setup_open_pwrite_pf8_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_1_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pe0_0",
    &setup_open_pwrite_pfa_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pfc_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pdf0_0",
    &setup_open_pwrite_pdf0_0_common,
    { { &setup_open_pwrite_pfc_0_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pdf0_1",
    &setup_open_pwrite_pdf0_1_common,
    { { &setup_open_pwrite_pfc_1_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pdde_0",
    &setup_open_pwrite_pdde_0_common,
    { { &setup_open_pwrite_pdde_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pdde_1",
    &setup_open_pwrite_pdde_0_common,
    { { &setup_open_pwrite_pdde_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pdc8_0",
    &setup_open_pwrite_pdc8_0_common,
    { { &setup_open_pwrite_pdc8_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pdc8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pda_0",
    &setup_open_pwrite_pda_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pd70_0",
    &setup_open_pwrite_pd70_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_0_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pd70_1",
    &setup_open_pwrite_pd70_1_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_1_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pd5c_0",
    &setup_open_pwrite_pd5c_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pd5c_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pd5c_1",
    &setup_open_pwrite_pd5c_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pdde_1_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pd48_0",
    &setup_open_pwrite_pd5c_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pd48_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pd48_1",
    &setup_open_pwrite_pd48_1_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pd48_1_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pd48_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pd2_0",
    &setup_open_pwrite_pfa_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pcf_0",
    &setup_open_pwrite_pcf_0_common,
    { { &setup_open_pwrite_pfc_0_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pcf_1",
    &setup_open_pwrite_pcf_0_common,
    { { &setup_open_pwrite_pfc_1_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pcdc_0",
    &setup_open_pwrite_pcdc_0_common,
    { { &setup_open_pwrite_pcdc_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pcdc_1",
    &setup_open_pwrite_pcdc_0_common,
    { { &setup_open_pwrite_pdde_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pccc_0",
    &setup_open_pwrite_pccc_0_common,
    { { &setup_open_pwrite_pccc_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pccc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pca_0",
    &setup_open_pwrite_pca_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pc7_0",
    &setup_open_pwrite_pc7_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_0_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pc7_1",
    &setup_open_pwrite_pc7_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_1_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pc58_0",
    &setup_open_pwrite_pc58_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pccc_0_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pc58_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pc58_1",
    &setup_open_pwrite_pda_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pc58_1_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pc58_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pc48_0",
    &setup_open_pwrite_pf8_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pea_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pc48_1",
    &setup_open_pwrite_pc58_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pccc_0_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pccc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pc2_0",
    &setup_open_pwrite_pca_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pbe_0",
    &setup_open_pwrite_pbe_0_common,
    { { &setup_open_pwrite_pfc_0_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pbe_1",
    &setup_open_pwrite_pbe_0_common,
    { { &setup_open_pwrite_pfc_1_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pbb8_0",
    &setup_open_pwrite_pbb8_0_common,
    { { &setup_open_pwrite_pcdc_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pbb8_1",
    &setup_open_pwrite_pbb8_1_common,
    { { &setup_open_pwrite_pbb8_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pdc8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pb90_0",
    &setup_open_pwrite_pbb8_1_common,
    { { &setup_open_pwrite_pb90_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pb90_1",
    &setup_open_pwrite_pbb8_1_common,
    { { &setup_open_pwrite_pdde_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pb4_0",
    &setup_open_pwrite_pb4_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_procfinal,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pae_0",
    &setup_open_pwrite_pae_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_0_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pae_1",
    &setup_open_pwrite_pae_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_1_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pab0_0",
    &setup_open_pwrite_pab0_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pdde_0_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pab0_1",
    &setup_open_pwrite_pab0_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_1_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pa90_0",
    &setup_open_pwrite_pa90_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pa90_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pa90_1",
    &setup_open_pwrite_pa90_1_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pd48_1_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pd48_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_pa4_0",
    &setup_open_pwrite_pb4_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_procfinal,
    { { &test_open_pwrite_pdf0_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p9e_0",
    &setup_open_pwrite_pbe_0_common,
    { { &setup_open_pwrite_pfc_0_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p9e_1",
    &setup_open_pwrite_pbe_0_common,
    { { &setup_open_pwrite_pfc_1_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p9b8_0",
    &setup_open_pwrite_pbb8_0_common,
    { { &setup_open_pwrite_pcdc_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p9b8_1",
    &setup_open_pwrite_pbb8_0_common,
    { { &setup_open_pwrite_pdde_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p990_0",
    &setup_open_pwrite_p990_0_common,
    { { &setup_open_pwrite_pb90_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pd48_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p990_1",
    &setup_open_pwrite_pbb8_1_common,
    { { &setup_open_pwrite_pdde_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p94_0",
    &setup_open_pwrite_pb4_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_procfinal,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p8e_0",
    &setup_open_pwrite_pae_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_0_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p8e_1",
    &setup_open_pwrite_pae_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_1_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p8b0_0",
    &setup_open_pwrite_pa90_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pdde_0_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p8b0_1",
    &setup_open_pwrite_pa90_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pdde_1_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p890_0",
    &setup_open_pwrite_pa90_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pa90_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p890_1",
    &setup_open_pwrite_pa90_1_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pd48_1_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pd48_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p84_0",
    &setup_open_pwrite_pb4_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_procfinal,
    { { &test_open_pwrite_pcf_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p7e_0",
    &setup_open_pwrite_pdf0_1_common,
    { { &setup_open_pwrite_pfc_0_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p7e_1",
    &setup_open_pwrite_pdf0_0_common,
    { { &setup_open_pwrite_pfc_1_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p7bc_0",
    &setup_open_pwrite_pdde_0_common,
    { { &setup_open_pwrite_pcdc_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p7bc_1",
    &setup_open_pwrite_p7bc_1_common,
    { { &setup_open_pwrite_pd48_1_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pd48_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p74_0",
    &setup_open_pwrite_pca_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p6e_0",
    &setup_open_pwrite_pd70_1_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_0_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p6e_1",
    &setup_open_pwrite_pd70_1_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_1_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p6b8_0",
    &setup_open_pwrite_pd5c_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pd5c_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p6b8_1",
    &setup_open_pwrite_pd5c_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pdde_1_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p690_0",
    &setup_open_pwrite_pd5c_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_p690_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p690_1",
    &setup_open_pwrite_pd48_1_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pd48_1_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pdde_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pd48_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p64_0",
    &setup_open_pwrite_pda_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p7e_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p5e_0",
    &setup_open_pwrite_pcf_0_common,
    { { &setup_open_pwrite_pfc_0_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p5e_1",
    &setup_open_pwrite_pcf_0_common,
    { { &setup_open_pwrite_pfc_1_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p5b8_0",
    &setup_open_pwrite_pcdc_0_common,
    { { &setup_open_pwrite_pcdc_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p5b8_1",
    &setup_open_pwrite_pcdc_0_common,
    { { &setup_open_pwrite_pdde_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pdde_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p598_0",
    &setup_open_pwrite_p598_0_common,
    { { &setup_open_pwrite_pccc_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pdc8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p598_1",
    &setup_open_pwrite_pcdc_0_common,
    { { &setup_open_pwrite_pfa_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p54_0",
    &setup_open_pwrite_pca_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p4e_0",
    &setup_open_pwrite_pc7_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_0_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p4e_1",
    &setup_open_pwrite_pc7_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_1_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p4b0_0",
    &setup_open_pwrite_pc58_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pccc_0_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pc58_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p4b0_1",
    &setup_open_pwrite_pda_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pc58_1_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pc58_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p490_0",
    &setup_open_pwrite_pf8_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pea_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p490_1",
    &setup_open_pwrite_pc58_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pccc_0_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pccc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p44_0",
    &setup_open_pwrite_pca_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p5e_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p38_0",
    &setup_open_pwrite_p38_0_common,
    { { &setup_open_pwrite_pfc_0_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p38_1",
    &setup_open_pwrite_p38_0_common,
    { { &setup_open_pwrite_pfc_1_proc0 }, { &setup_open_pwrite_pfc_0_proc1 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p34_0",
    &setup_open_pwrite_pab0_0_common,
    { { &setup_open_pwrite_pfa_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p34_1",
    &setup_open_pwrite_pab0_0_common,
    { { &setup_open_pwrite_pfa_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p30_0",
    &setup_open_pwrite_pa90_0_common,
    { { &setup_open_pwrite_pf8_0_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p30_1",
    &setup_open_pwrite_pa90_0_common,
    { { &setup_open_pwrite_pfa_1_proc0 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p2_0",
    &setup_open_pwrite_pb4_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_procfinal,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p18_0",
    &setup_open_pwrite_p38_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_0_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p18_1",
    &setup_open_pwrite_p38_0_common,
    { { &setup_open_pwrite_pfc_0_proc1 }, { &setup_open_pwrite_pfc_1_proc0 } },
    &setup_open_pwrite_pfc_0_procfinal,
    &setup_open_pwrite_pfc_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p14_0",
    &setup_open_pwrite_pab0_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pea_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p14_1",
    &setup_open_pwrite_pab0_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_1_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p10_0",
    &setup_open_pwrite_pa90_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pe8_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p10_1",
    &setup_open_pwrite_pa90_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_1_proc0 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_final,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pfa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_pwrite_p0_0",
    &setup_open_pwrite_pb4_0_common,
    { { &setup_open_pwrite_pfa_0_proc1 }, { &setup_open_pwrite_pfa_0_proc1 } },
    &setup_open_pwrite_pfa_0_procfinal,
    &setup_open_pwrite_pfa_0_procfinal,
    { { &test_open_pwrite_p38_0_0, 0, "open" },
      { &test_open_pwrite_pf0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-open_read_pfe_0",
    &setup_open_read_pfe_0_common,
    { { &setup_open_read_pfe_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pfd8_0",
    &setup_open_read_pfd8_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pfd0_0",
    &setup_open_read_pfd0_0_common,
    { { &setup_open_read_pfd0_0_proc0 }, { &setup_open_read_pfd0_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pfc_0",
    &setup_open_read_pfc_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pfa_0",
    &setup_open_read_pfa_0_common,
    { { &setup_open_read_pfa_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pf8_0",
    &setup_open_read_pf8_0_common,
    { { &setup_open_read_pf8_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pf0_0",
    &setup_open_read_pfa_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pee_0",
    &setup_open_read_pfe_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfe_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_ped8_0",
    &setup_open_read_pfd8_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_ped0_0",
    &setup_open_read_pfd0_0_common,
    { { &setup_open_read_pfd0_0_proc1 }, { &setup_open_read_pfd0_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pec_0",
    &setup_open_read_pfc_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pea_0",
    &setup_open_read_pfa_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pf8_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pe8_0",
    &setup_open_read_pf8_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pf8_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pe0_0",
    &setup_open_read_pfa_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pfe_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pdf8_0",
    &setup_open_read_pdf8_0_common,
    { { &setup_open_read_pfe_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pdee_0",
    &setup_open_read_pdee_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pdea_0",
    &setup_open_read_pdea_0_common,
    { { &setup_open_read_pfd0_0_proc0 }, { &setup_open_read_pfd0_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pde4_0",
    &setup_open_read_pde4_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pdde_0",
    &setup_open_read_pdde_0_common,
    { { &setup_open_read_pdde_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pdde_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pdde_1",
    &setup_open_read_pdde_1_common,
    { { &setup_open_read_pdde_1_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pdc8_0",
    &setup_open_read_pdde_0_common,
    { { &setup_open_read_pdc8_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pdde_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pda_0",
    &setup_open_read_pda_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pd78_0",
    &setup_open_read_pd78_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfe_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pd6e_0",
    &setup_open_read_pd6e_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pd6a_0",
    &setup_open_read_pd6e_0_common,
    { { &setup_open_read_pfd0_0_proc1 }, { &setup_open_read_pfd0_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pd64_0",
    &setup_open_read_pfc_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pd5c_0",
    &setup_open_read_pd5c_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pdc8_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pdde_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pd5c_1",
    &setup_open_read_pdde_1_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pd5c_1_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pd48_0",
    &setup_open_read_pd48_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pdde_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pdde_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pd2_0",
    &setup_open_read_pda_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pcf8_0",
    &setup_open_read_pcf8_0_common,
    { { &setup_open_read_pfe_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pcee_0",
    &setup_open_read_pd6e_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pcea_0",
    &setup_open_read_pcea_0_common,
    { { &setup_open_read_pfd0_0_proc0 }, { &setup_open_read_pfd0_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pce4_0",
    &setup_open_read_pfc_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pcdc_0",
    &setup_open_read_pcdc_0_common,
    { { &setup_open_read_pcdc_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pccc_0",
    &setup_open_read_pcdc_0_common,
    { { &setup_open_read_pccc_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pca_0",
    &setup_open_read_pca_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pc78_0",
    &setup_open_read_pcf8_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfe_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pc6e_0",
    &setup_open_read_pfd8_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pc6a_0",
    &setup_open_read_pfd8_0_common,
    { { &setup_open_read_pfd0_0_proc1 }, { &setup_open_read_pfd0_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pc64_0",
    &setup_open_read_pfc_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pc58_0",
    &setup_open_read_pcdc_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pc48_0",
    &setup_open_read_pc48_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pc48_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pc2_0",
    &setup_open_read_pca_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pbf0_0",
    &setup_open_read_pbf0_0_common,
    { { &setup_open_read_pfe_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pbdc_0",
    &setup_open_read_pbdc_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pbd4_0",
    &setup_open_read_pbd4_0_common,
    { { &setup_open_read_pfd0_0_proc0 }, { &setup_open_read_pfd0_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pbc8_0",
    &setup_open_read_pbc8_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pbb8_0",
    &setup_open_read_pbb8_0_common,
    { { &setup_open_read_pbb8_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pb90_0",
    &setup_open_read_pb90_0_common,
    { { &setup_open_read_pb90_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_pb4_0",
    &setup_open_read_pb4_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_procfinal,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_paf0_0",
    &setup_open_read_paf0_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfe_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_padc_0",
    &setup_open_read_padc_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pad4_0",
    &setup_open_read_padc_0_common,
    { { &setup_open_read_pfd0_0_proc1 }, { &setup_open_read_pfd0_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pac8_0",
    &setup_open_read_pbc8_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pab0_0",
    &setup_open_read_pab0_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pab0_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pa90_0",
    &setup_open_read_pa90_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pccc_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_pa4_0",
    &setup_open_read_pb4_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_procfinal,
    { { &test_open_read_pdf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p9f0_0",
    &setup_open_read_p9f0_0_common,
    { { &setup_open_read_pfe_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p9dc_0",
    &setup_open_read_pbdc_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p9d4_0",
    &setup_open_read_pbd4_0_common,
    { { &setup_open_read_pfd0_0_proc0 }, { &setup_open_read_pfd0_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p9c8_0",
    &setup_open_read_p9c8_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p9b8_0",
    &setup_open_read_pbb8_0_common,
    { { &setup_open_read_p9b8_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p990_0",
    &setup_open_read_pb90_0_common,
    { { &setup_open_read_pb90_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p94_0",
    &setup_open_read_pb4_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_procfinal,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p8f0_0",
    &setup_open_read_p8f0_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfe_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p8dc_0",
    &setup_open_read_padc_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p8d4_0",
    &setup_open_read_pbdc_0_common,
    { { &setup_open_read_pfd0_0_proc1 }, { &setup_open_read_pfd0_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p8c8_0",
    &setup_open_read_pbc8_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p8b0_0",
    &setup_open_read_pab0_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pab0_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p890_0",
    &setup_open_read_pa90_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pccc_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p84_0",
    &setup_open_read_pb4_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_procfinal,
    { { &test_open_read_pcf8_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p7f0_0",
    &setup_open_read_pdf8_0_common,
    { { &setup_open_read_pfe_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p7dc_0",
    &setup_open_read_pdee_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p7d4_0",
    &setup_open_read_p7d4_0_common,
    { { &setup_open_read_pfd0_0_proc0 }, { &setup_open_read_pfd0_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p7c8_0",
    &setup_open_read_pde4_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p7bc_0",
    &setup_open_read_p7bc_0_common,
    { { &setup_open_read_p7bc_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pdde_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p7bc_1",
    &setup_open_read_pdde_1_common,
    { { &setup_open_read_pdde_1_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p790_0",
    &setup_open_read_pdde_0_common,
    { { &setup_open_read_pdc8_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pdde_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p74_0",
    &setup_open_read_pda_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p6f0_0",
    &setup_open_read_pd78_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfe_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p6dc_0",
    &setup_open_read_pd6e_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p6d4_0",
    &setup_open_read_pd6e_0_common,
    { { &setup_open_read_pfd0_0_proc1 }, { &setup_open_read_pfd0_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p6c8_0",
    &setup_open_read_p6c8_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p6b8_0",
    &setup_open_read_pd5c_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pdc8_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pdde_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p6b8_1",
    &setup_open_read_pdde_1_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pd5c_1_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p690_0",
    &setup_open_read_pd48_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pdde_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pdde_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p64_0",
    &setup_open_read_pca_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p7f0_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p5f_0",
    &setup_open_read_pcf8_0_common,
    { { &setup_open_read_pfe_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p5dc_0",
    &setup_open_read_pd6e_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p5d4_0",
    &setup_open_read_pd6e_0_common,
    { { &setup_open_read_pfd0_0_proc0 }, { &setup_open_read_pfd0_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p5c8_0",
    &setup_open_read_pfc_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p5b8_0",
    &setup_open_read_pcdc_0_common,
    { { &setup_open_read_pcdc_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p598_0",
    &setup_open_read_pcdc_0_common,
    { { &setup_open_read_pccc_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p54_0",
    &setup_open_read_pca_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p4f_0",
    &setup_open_read_pcf8_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfe_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p4dc_0",
    &setup_open_read_pfd8_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p4d4_0",
    &setup_open_read_pfd0_0_common,
    { { &setup_open_read_pfd0_0_proc1 }, { &setup_open_read_pfd0_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p4c8_0",
    &setup_open_read_pfc_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p4b_0",
    &setup_open_read_pcdc_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p490_0",
    &setup_open_read_pc48_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pc48_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p44_0",
    &setup_open_read_pca_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p5f_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p3c_0",
    &setup_open_read_p3c_0_common,
    { { &setup_open_read_pfe_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p3b_0",
    &setup_open_read_padc_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p3a_0",
    &setup_open_read_padc_0_common,
    { { &setup_open_read_pfd0_0_proc0 }, { &setup_open_read_pfd0_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p38_0",
    &setup_open_read_pbc8_0_common,
    { { &setup_open_read_pfd8_0_proc0 }, { &setup_open_read_pfe_0_proc1 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p34_0",
    &setup_open_read_p34_0_common,
    { { &setup_open_read_pfa_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p30_0",
    &setup_open_read_p30_0_common,
    { { &setup_open_read_pf8_0_proc0 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p2_0",
    &setup_open_read_pb4_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_procfinal,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-open_read_p1c_0",
    &setup_open_read_p3c_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfe_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p1b_0",
    &setup_open_read_padc_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfd8_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p1a_0",
    &setup_open_read_p1a_0_common,
    { { &setup_open_read_pfd0_0_proc1 }, { &setup_open_read_pfd0_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p18_0",
    &setup_open_read_pbc8_0_common,
    { { &setup_open_read_pfe_0_proc1 }, { &setup_open_read_pfd8_0_proc0 } },
    &setup_open_read_pfe_0_procfinal,
    &setup_open_read_pfe_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p14_0",
    &setup_open_read_p34_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pf8_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfd0_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p10_0",
    &setup_open_read_p30_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pf8_0_proc0 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_final,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfc_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_read_p0_0",
    &setup_open_read_pb4_0_common,
    { { &setup_open_read_pfa_0_proc1 }, { &setup_open_read_pfa_0_proc1 } },
    &setup_open_read_pfa_0_procfinal,
    &setup_open_read_pfa_0_procfinal,
    { { &test_open_read_p3c_0_0, 0, "open" },
      { &test_open_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-open_rename_pf8_0",
    &setup_open_rename_pf8_0_common,
    { { &setup_open_rename_pf8_0_proc0 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pf8_0_0, 0, "open" },
      { &test_open_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pf8_1",
    &setup_open_rename_pf8_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pf8_0_0, 0, "open" },
      { &test_open_rename_pf8_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pf6_0",
    &setup_open_rename_pf6_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pf8_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pf6_1",
    &setup_open_rename_pf8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pf8_0_0, 0, "open" },
      { &test_open_rename_pf6_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pf2_0",
    &setup_open_rename_pf8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pf8_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pe_0",
    &setup_open_rename_pf8_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pf8_0_0, 0, "open" },
      { &test_open_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pde_0",
    &setup_open_rename_pf8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pde_1",
    &setup_open_rename_pde_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pf8_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pdb8_0",
    &setup_open_rename_pdb8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pdb8_0_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pdb8_1",
    &setup_open_rename_pdb8_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pdb8_1_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pdb8_2",
    &setup_open_rename_pf8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pf6_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pd98_0",
    &setup_open_rename_pd98_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pd4_0",
    &setup_open_rename_pd4_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pce_0",
    &setup_open_rename_pce_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pce_1",
    &setup_open_rename_pce_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pf8_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pcb8_0",
    &setup_open_rename_pcb8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pdb8_1_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pcb8_1",
    &setup_open_rename_pcb8_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pcb8_2",
    &setup_open_rename_pcb8_2_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pf6_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pc98_0",
    &setup_open_rename_pce_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pc4_0",
    &setup_open_rename_pce_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pbe_0",
    &setup_open_rename_pbe_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pb78_0",
    &setup_open_rename_pb78_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pdb8_0_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pb78_1",
    &setup_open_rename_pb78_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pb30_0",
    &setup_open_rename_pbe_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_pa8_0",
    &setup_open_rename_pa8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_procfinal,
    { { &test_open_rename_pde_0_0, 0, "open" },
      { &test_open_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p9e_0",
    &setup_open_rename_p9e_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p978_0",
    &setup_open_rename_pb78_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pdb8_0_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p978_1",
    &setup_open_rename_pb78_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p930_0",
    &setup_open_rename_p9e_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p88_0",
    &setup_open_rename_pa8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_procfinal,
    { { &test_open_rename_pce_0_0, 0, "open" },
      { &test_open_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p7c_0",
    &setup_open_rename_p7c_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p7c_0_0, 0, "open" },
      { &test_open_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p7c_1",
    &setup_open_rename_pf8_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p7c_0_0, 0, "open" },
      { &test_open_rename_pf8_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p770_0",
    &setup_open_rename_p770_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pdb8_0_final,
    { { &test_open_rename_p7c_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p770_1",
    &setup_open_rename_p770_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p7c_0_0, 0, "open" },
      { &test_open_rename_pf6_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p730_0",
    &setup_open_rename_p730_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p7c_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p68_0",
    &setup_open_rename_pde_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p7c_0_0, 0, "open" },
      { &test_open_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p5c_0",
    &setup_open_rename_pce_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p5c_0_0, 0, "open" },
      { &test_open_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p5c_1",
    &setup_open_rename_pce_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p5c_0_0, 0, "open" },
      { &test_open_rename_pf8_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p570_0",
    &setup_open_rename_pcb8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pdb8_1_final,
    { { &test_open_rename_p5c_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p570_1",
    &setup_open_rename_pcb8_2_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p5c_0_0, 0, "open" },
      { &test_open_rename_pf6_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p53_0",
    &setup_open_rename_pce_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p5c_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p48_0",
    &setup_open_rename_pce_1_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p5c_0_0, 0, "open" },
      { &test_open_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p3_0",
    &setup_open_rename_pbe_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p3_0_0, 0, "open" },
      { &test_open_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p28_0",
    &setup_open_rename_p28_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p3_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p20_0",
    &setup_open_rename_pbe_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_final,
    { { &test_open_rename_p3_0_0, 0, "open" },
      { &test_open_rename_pf6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p0_0",
    &setup_open_rename_pa8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_procfinal,
    { { &test_open_rename_p3_0_0, 0, "open" },
      { &test_open_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-open_rename_p0_1",
    &setup_open_rename_pa8_0_common,
    { { &setup_open_rename_pf8_0_proc1 }, { &setup_open_rename_pf8_0_proc1 } },
    &setup_open_rename_pf8_0_procfinal,
    &setup_open_rename_pf8_0_procfinal,
    { { &test_open_rename_p3_0_0, 0, "open" },
      { &test_open_rename_p0_1_1, 0, "rename" } },
    &cleanup },
  { "fs-open_stat_pf_0",
    &setup_open_stat_pf_0_common,
    { { &setup_open_stat_pf_0_proc0 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pf_0_0, 0, "open" },
      { &test_open_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pf_1",
    &setup_open_stat_pf_1_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pf_0_0, 0, "open" },
      { &test_open_stat_pf_1_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pe_0",
    &setup_open_stat_pf_1_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pf_0_0, 0, "open" },
      { &test_open_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pdf8_0",
    &setup_open_stat_pdf8_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pdf8_0_final,
    { { &test_open_stat_pdf8_0_0, 0, "open" },
      { &test_open_stat_pdf8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pdf8_1",
    &setup_open_stat_pf_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pdf8_0_0, 0, "open" },
      { &test_open_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pdf8_2",
    &setup_open_stat_pf_1_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pdf8_0_0, 0, "open" },
      { &test_open_stat_pf_1_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pd4_0",
    &setup_open_stat_pd4_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pdf8_0_0, 0, "open" },
      { &test_open_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pcc_0",
    &setup_open_stat_pcc_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pcc_0_0, 0, "open" },
      { &test_open_stat_pcc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pcc_1",
    &setup_open_stat_pcc_1_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pcc_0_0, 0, "open" },
      { &test_open_stat_pcc_1_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pc4_0",
    &setup_open_stat_pcc_1_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pcc_0_0, 0, "open" },
      { &test_open_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pbc_0",
    &setup_open_stat_pbc_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pdf8_0_0, 0, "open" },
      { &test_open_stat_pbc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_pa8_0",
    &setup_open_stat_pa8_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_procfinal,
    { { &test_open_stat_pdf8_0_0, 0, "open" },
      { &test_open_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p9c_0",
    &setup_open_stat_pbc_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_pcc_0_0, 0, "open" },
      { &test_open_stat_pbc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p88_0",
    &setup_open_stat_pa8_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_procfinal,
    { { &test_open_stat_pcc_0_0, 0, "open" },
      { &test_open_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p7f0_0",
    &setup_open_stat_pdf8_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pdf8_0_final,
    { { &test_open_stat_p7f0_0_0, 0, "open" },
      { &test_open_stat_pdf8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p7f0_1",
    &setup_open_stat_pf_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_p7f0_0_0, 0, "open" },
      { &test_open_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p7f0_2",
    &setup_open_stat_pf_1_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_p7f0_0_0, 0, "open" },
      { &test_open_stat_pf_1_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p68_0",
    &setup_open_stat_pf_1_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_p7f0_0_0, 0, "open" },
      { &test_open_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p58_0",
    &setup_open_stat_pcc_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_p58_0_0, 0, "open" },
      { &test_open_stat_pcc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p58_1",
    &setup_open_stat_pcc_1_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_p58_0_0, 0, "open" },
      { &test_open_stat_pcc_1_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p48_0",
    &setup_open_stat_pcc_1_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_p58_0_0, 0, "open" },
      { &test_open_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p2_0",
    &setup_open_stat_p2_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_final,
    { { &test_open_stat_p2_0_0, 0, "open" },
      { &test_open_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p0_0",
    &setup_open_stat_pa8_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_procfinal,
    { { &test_open_stat_p2_0_0, 0, "open" },
      { &test_open_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-open_stat_p0_1",
    &setup_open_stat_pa8_0_common,
    { { &setup_open_stat_pf_0_proc1 }, { &setup_open_stat_pf_0_proc1 } },
    &setup_open_stat_pf_0_procfinal,
    &setup_open_stat_pf_0_procfinal,
    { { &test_open_stat_p2_0_0, 0, "open" },
      { &test_open_stat_p0_1_1, 0, "stat" } },
    &cleanup },
  { "fs-open_unlink_pf8_0",
    &setup_open_unlink_pf8_0_common,
    { { &setup_open_unlink_pf8_0_proc0 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_pf8_0_0, 0, "open" },
      { &test_open_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_pe_0",
    &setup_open_unlink_pe_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_pf8_0_0, 0, "open" },
      { &test_open_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_pde_0",
    &setup_open_unlink_pde_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pde_0_final,
    { { &test_open_unlink_pde_0_0, 0, "open" },
      { &test_open_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_pde_1",
    &setup_open_unlink_pde_1_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_pde_0_0, 0, "open" },
      { &test_open_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_pd4_0",
    &setup_open_unlink_pe_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_pde_0_0, 0, "open" },
      { &test_open_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_pce_0",
    &setup_open_unlink_pce_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_pce_0_0, 0, "open" },
      { &test_open_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_pc4_0",
    &setup_open_unlink_pc4_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_pce_0_0, 0, "open" },
      { &test_open_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_pbc_0",
    &setup_open_unlink_pbc_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_pde_0_0, 0, "open" },
      { &test_open_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_pa8_0",
    &setup_open_unlink_pa8_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_procfinal,
    { { &test_open_unlink_pde_0_0, 0, "open" },
      { &test_open_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_p9c_0",
    &setup_open_unlink_p9c_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_pce_0_0, 0, "open" },
      { &test_open_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_p88_0",
    &setup_open_unlink_pa8_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_procfinal,
    { { &test_open_unlink_pce_0_0, 0, "open" },
      { &test_open_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_p7c_0",
    &setup_open_unlink_pde_1_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_p7c_0_0, 0, "open" },
      { &test_open_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_p68_0",
    &setup_open_unlink_pe_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_p7c_0_0, 0, "open" },
      { &test_open_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_p5c_0",
    &setup_open_unlink_pce_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_p5c_0_0, 0, "open" },
      { &test_open_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_p48_0",
    &setup_open_unlink_pc4_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_p5c_0_0, 0, "open" },
      { &test_open_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_p2_0",
    &setup_open_unlink_p2_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_final,
    { { &test_open_unlink_p2_0_0, 0, "open" },
      { &test_open_unlink_pf8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_p0_0",
    &setup_open_unlink_pa8_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_procfinal,
    { { &test_open_unlink_p2_0_0, 0, "open" },
      { &test_open_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_unlink_p0_1",
    &setup_open_unlink_pa8_0_common,
    { { &setup_open_unlink_pf8_0_proc1 }, { &setup_open_unlink_pf8_0_proc1 } },
    &setup_open_unlink_pf8_0_procfinal,
    &setup_open_unlink_pf8_0_procfinal,
    { { &test_open_unlink_p2_0_0, 0, "open" },
      { &test_open_unlink_p0_1_1, 0, "unlink" } },
    &cleanup },
  { "fs-open_write_pff_0",
    &setup_open_write_pff_0_common,
    { { &setup_open_write_pff_0_proc0 }, { &setup_open_write_pff_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pfe_0",
    &setup_open_write_pfe_0_common,
    { { &setup_open_write_pfe_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pfc_0",
    &setup_open_write_pfc_0_common,
    { { &setup_open_write_pfc_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pfa_0",
    &setup_open_write_pfa_0_common,
    { { &setup_open_write_pfa_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pf8_0",
    &setup_open_write_pf8_0_common,
    { { &setup_open_write_pfa_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pf0_0",
    &setup_open_write_pfa_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pef_0",
    &setup_open_write_pff_0_common,
    { { &setup_open_write_pff_0_proc1 }, { &setup_open_write_pff_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pee_0",
    &setup_open_write_pfe_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfe_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pec_0",
    &setup_open_write_pfc_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfc_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pea_0",
    &setup_open_write_pfa_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc0 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pe8_0",
    &setup_open_write_pf8_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc0 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pe0_0",
    &setup_open_write_pfa_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pff_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pdfc_0",
    &setup_open_write_pdfc_0_common,
    { { &setup_open_write_pff_0_proc0 }, { &setup_open_write_pff_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pdf4_0",
    &setup_open_write_pdf4_0_common,
    { { &setup_open_write_pfe_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pde8_0",
    &setup_open_write_pde8_0_common,
    { { &setup_open_write_pfc_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pdde_0",
    &setup_open_write_pdde_0_common,
    { { &setup_open_write_pdde_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pdde_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pda_0",
    &setup_open_write_pda_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pd7c_0",
    &setup_open_write_pd7c_0_common,
    { { &setup_open_write_pff_0_proc1 }, { &setup_open_write_pff_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pd74_0",
    &setup_open_write_pd74_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfe_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pd68_0",
    &setup_open_write_pd68_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfc_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pd5c_0",
    &setup_open_write_pd5c_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pdde_0_proc0 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pdde_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pd48_0",
    &setup_open_write_pd48_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pd48_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pdde_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pd2_0",
    &setup_open_write_pd2_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pcfc_0",
    &setup_open_write_pcfc_0_common,
    { { &setup_open_write_pff_0_proc0 }, { &setup_open_write_pff_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pcf4_0",
    &setup_open_write_pff_0_common,
    { { &setup_open_write_pfe_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pce8_0",
    &setup_open_write_pce8_0_common,
    { { &setup_open_write_pfc_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pcdc_0",
    &setup_open_write_pcdc_0_common,
    { { &setup_open_write_pcdc_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pccc_0",
    &setup_open_write_pccc_0_common,
    { { &setup_open_write_pcdc_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pca_0",
    &setup_open_write_pda_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pc7c_0",
    &setup_open_write_pc7c_0_common,
    { { &setup_open_write_pff_0_proc1 }, { &setup_open_write_pff_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pc74_0",
    &setup_open_write_pff_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfe_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pc68_0",
    &setup_open_write_pff_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfc_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pc58_0",
    &setup_open_write_pc58_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pc58_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pc48_0",
    &setup_open_write_pc48_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pc58_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pc2_0",
    &setup_open_write_pda_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pbf8_0",
    &setup_open_write_pbf8_0_common,
    { { &setup_open_write_pff_0_proc0 }, { &setup_open_write_pff_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pbe8_0",
    &setup_open_write_pbe8_0_common,
    { { &setup_open_write_pfe_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pbd0_0",
    &setup_open_write_pbd0_0_common,
    { { &setup_open_write_pfc_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pbb8_0",
    &setup_open_write_pbb8_0_common,
    { { &setup_open_write_pcdc_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_pb4_0",
    &setup_open_write_pb4_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_procfinal,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_paf8_0",
    &setup_open_write_paf8_0_common,
    { { &setup_open_write_pff_0_proc1 }, { &setup_open_write_pff_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pae8_0",
    &setup_open_write_pae8_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfe_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pad0_0",
    &setup_open_write_pad0_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfc_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pab0_0",
    &setup_open_write_pab0_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc0 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pa90_0",
    &setup_open_write_pa90_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pa90_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_pa4_0",
    &setup_open_write_pb4_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_procfinal,
    { { &test_open_write_pdfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p9f8_0",
    &setup_open_write_p9f8_0_common,
    { { &setup_open_write_pff_0_proc0 }, { &setup_open_write_pff_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p9e8_0",
    &setup_open_write_pbe8_0_common,
    { { &setup_open_write_pfe_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p9d0_0",
    &setup_open_write_pbd0_0_common,
    { { &setup_open_write_pfc_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p9b8_0",
    &setup_open_write_pbb8_0_common,
    { { &setup_open_write_pcdc_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p990_0",
    &setup_open_write_p990_0_common,
    { { &setup_open_write_pcdc_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p94_0",
    &setup_open_write_pb4_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_procfinal,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p8f8_0",
    &setup_open_write_p8f8_0_common,
    { { &setup_open_write_pff_0_proc1 }, { &setup_open_write_pff_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p8e8_0",
    &setup_open_write_p8e8_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfe_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p8d0_0",
    &setup_open_write_p8d0_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfc_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p8b0_0",
    &setup_open_write_p8b0_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pcdc_0_proc0 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p890_0",
    &setup_open_write_pa90_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pa90_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p84_0",
    &setup_open_write_pb4_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_procfinal,
    { { &test_open_write_pcfc_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p7f8_0",
    &setup_open_write_pdfc_0_common,
    { { &setup_open_write_pff_0_proc0 }, { &setup_open_write_pff_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p7e8_0",
    &setup_open_write_p7e8_0_common,
    { { &setup_open_write_pfe_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p7d0_0",
    &setup_open_write_pd74_0_common,
    { { &setup_open_write_pfc_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p7bc_0",
    &setup_open_write_p7bc_0_common,
    { { &setup_open_write_pdde_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pdde_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p74_0",
    &setup_open_write_pda_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p6f8_0",
    &setup_open_write_pd74_0_common,
    { { &setup_open_write_pff_0_proc1 }, { &setup_open_write_pff_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p6e8_0",
    &setup_open_write_p6e8_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfe_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p6d0_0",
    &setup_open_write_pd68_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfc_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p6b8_0",
    &setup_open_write_pd5c_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pdde_0_proc0 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pdde_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p690_0",
    &setup_open_write_p690_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pdde_0_proc0 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pdde_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p64_0",
    &setup_open_write_pd2_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p7f8_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p5f8_0",
    &setup_open_write_p5f8_0_common,
    { { &setup_open_write_pff_0_proc0 }, { &setup_open_write_pff_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p5e8_0",
    &setup_open_write_pff_0_common,
    { { &setup_open_write_pfe_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p5d_0",
    &setup_open_write_pce8_0_common,
    { { &setup_open_write_pfc_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p5b8_0",
    &setup_open_write_pcdc_0_common,
    { { &setup_open_write_pcdc_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p598_0",
    &setup_open_write_pccc_0_common,
    { { &setup_open_write_pcdc_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p54_0",
    &setup_open_write_pda_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p4f8_0",
    &setup_open_write_pc7c_0_common,
    { { &setup_open_write_pff_0_proc1 }, { &setup_open_write_pff_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p4e8_0",
    &setup_open_write_pff_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfe_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p4d_0",
    &setup_open_write_pff_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfc_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p4b0_0",
    &setup_open_write_pc58_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pc58_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p490_0",
    &setup_open_write_pc48_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pc58_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p44_0",
    &setup_open_write_pda_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p5f8_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p3e_0",
    &setup_open_write_p3e_0_common,
    { { &setup_open_write_pff_0_proc0 }, { &setup_open_write_pff_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p3c_0",
    &setup_open_write_p3c_0_common,
    { { &setup_open_write_pfe_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p38_0",
    &setup_open_write_p38_0_common,
    { { &setup_open_write_pfc_0_proc0 }, { &setup_open_write_pfe_0_proc1 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p34_0",
    &setup_open_write_pab0_0_common,
    { { &setup_open_write_pfa_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p30_0",
    &setup_open_write_p8b0_0_common,
    { { &setup_open_write_pfa_0_proc0 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p2_0",
    &setup_open_write_pb4_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_procfinal,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-open_write_p1e_0",
    &setup_open_write_p3e_0_common,
    { { &setup_open_write_pff_0_proc1 }, { &setup_open_write_pff_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pff_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p1c_0",
    &setup_open_write_p3c_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfe_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p18_0",
    &setup_open_write_p38_0_common,
    { { &setup_open_write_pfe_0_proc1 }, { &setup_open_write_pfc_0_proc0 } },
    &setup_open_write_pff_0_procfinal,
    &setup_open_write_pff_0_final,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p14_0",
    &setup_open_write_pab0_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc0 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p10_0",
    &setup_open_write_p8b0_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc0 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_final,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-open_write_p0_0",
    &setup_open_write_pb4_0_common,
    { { &setup_open_write_pfa_0_proc1 }, { &setup_open_write_pfa_0_proc1 } },
    &setup_open_write_pfa_0_procfinal,
    &setup_open_write_pfa_0_procfinal,
    { { &test_open_write_p3e_0_0, 0, "open" },
      { &test_open_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-pipe_pipe_p78_0",
    &setup_pipe_pipe_p78_0_common,
    { { &setup_pipe_pipe_p78_0_proc0 }, { &setup_pipe_pipe_p78_0_proc1 } },
    &setup_pipe_pipe_p78_0_procfinal,
    &setup_pipe_pipe_p78_0_final,
    { { &test_pipe_pipe_p78_0_0, 0, "pipe" },
      { &test_pipe_pipe_p78_0_1, 1, "pipe" } },
    &cleanup },
  { "fs-pipe_pread_pfc_0",
    &setup_pipe_pread_pfc_0_common,
    { { &setup_pipe_pread_pfc_0_proc0 }, { &setup_pipe_pread_pfc_0_proc1 } },
    &setup_pipe_pread_pfc_0_procfinal,
    &setup_pipe_pread_pfc_0_final,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pipe_pread_pfc_1",
    &setup_pipe_pread_pfc_0_common,
    { { &setup_pipe_pread_pfc_1_proc0 }, { &setup_pipe_pread_pfc_0_proc1 } },
    &setup_pipe_pread_pfc_0_procfinal,
    &setup_pipe_pread_pfc_0_final,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_pfc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pipe_pread_pdc_0",
    &setup_pipe_pread_pdc_0_common,
    { { &setup_pipe_pread_pdc_0_proc0 }, { &setup_pipe_pread_pdc_0_proc1 } },
    &setup_pipe_pread_pdc_0_procfinal,
    &setup_pipe_pread_pdc_0_final,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_pdc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pipe_pread_pdc_1",
    &setup_pipe_pread_pdc_1_common,
    { { &setup_pipe_pread_pdc_1_proc0 }, { &setup_pipe_pread_pdc_0_proc1 } },
    &setup_pipe_pread_pdc_0_procfinal,
    &setup_pipe_pread_pdc_0_final,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_pdc_1_1, 0, "pread" } },
    &cleanup },
  { "fs-pipe_pread_pb0_0",
    &setup_pipe_pread_pb0_0_common,
    { { &setup_pipe_pread_pdc_0_proc1 }, { &setup_pipe_pread_pdc_0_proc1 } },
    &setup_pipe_pread_pdc_0_procfinal,
    &setup_pipe_pread_pdc_0_procfinal,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_pb0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pipe_pread_p78_0",
    &setup_pipe_pread_p78_0_common,
    { { &setup_pipe_pread_pfc_0_proc1 }, { &setup_pipe_pread_pfc_0_proc0 } },
    &setup_pipe_pread_pfc_0_procfinal,
    &setup_pipe_pread_pfc_0_final,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pipe_pread_p78_1",
    &setup_pipe_pread_p78_0_common,
    { { &setup_pipe_pread_pfc_0_proc1 }, { &setup_pipe_pread_pfc_1_proc0 } },
    &setup_pipe_pread_pfc_0_procfinal,
    &setup_pipe_pread_pfc_0_final,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_pfc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pipe_pread_p5c_0",
    &setup_pipe_pread_pdc_0_common,
    { { &setup_pipe_pread_pdc_0_proc1 }, { &setup_pipe_pread_pdc_0_proc0 } },
    &setup_pipe_pread_pdc_0_procfinal,
    &setup_pipe_pread_pdc_0_final,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_pdc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pipe_pread_p5c_1",
    &setup_pipe_pread_pdc_1_common,
    { { &setup_pipe_pread_pdc_0_proc1 }, { &setup_pipe_pread_pdc_1_proc0 } },
    &setup_pipe_pread_pdc_0_procfinal,
    &setup_pipe_pread_pdc_0_final,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_pdc_1_1, 1, "pread" } },
    &cleanup },
  { "fs-pipe_pread_p4c_0",
    &setup_pipe_pread_p4c_0_common,
    { { &setup_pipe_pread_pdc_0_proc1 }, { &setup_pipe_pread_pdc_0_proc0 } },
    &setup_pipe_pread_pdc_0_procfinal,
    &setup_pipe_pread_pdc_0_final,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_p4c_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pipe_pread_p4c_1",
    &setup_pipe_pread_pdc_1_common,
    { { &setup_pipe_pread_pdc_0_proc1 }, { &setup_pipe_pread_pdc_0_proc0 } },
    &setup_pipe_pread_pdc_0_procfinal,
    &setup_pipe_pread_pdc_0_final,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_p4c_1_1, 1, "pread" } },
    &cleanup },
  { "fs-pipe_pread_p30_0",
    &setup_pipe_pread_pb0_0_common,
    { { &setup_pipe_pread_pdc_0_proc1 }, { &setup_pipe_pread_pdc_0_proc1 } },
    &setup_pipe_pread_pdc_0_procfinal,
    &setup_pipe_pread_pdc_0_procfinal,
    { { &test_pipe_pread_pfc_0_0, 0, "pipe" },
      { &test_pipe_pread_pb0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pipe_pwrite_pfc_0",
    &setup_pipe_pwrite_pfc_0_common,
    { { &setup_pipe_pwrite_pfc_0_proc0 }, { &setup_pipe_pwrite_pfc_0_proc1 } },
    &setup_pipe_pwrite_pfc_0_procfinal,
    &setup_pipe_pwrite_pfc_0_final,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_pfc_1",
    &setup_pipe_pwrite_pfc_0_common,
    { { &setup_pipe_pwrite_pfc_1_proc0 }, { &setup_pipe_pwrite_pfc_0_proc1 } },
    &setup_pipe_pwrite_pfc_0_procfinal,
    &setup_pipe_pwrite_pfc_0_final,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pfc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_pdc_0",
    &setup_pipe_pwrite_pdc_0_common,
    { { &setup_pipe_pwrite_pdc_0_proc0 }, { &setup_pipe_pwrite_pdc_0_proc1 } },
    &setup_pipe_pwrite_pdc_0_procfinal,
    &setup_pipe_pwrite_pdc_0_final,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pdc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_pdc_1",
    &setup_pipe_pwrite_pdc_1_common,
    { { &setup_pipe_pwrite_pdc_1_proc0 }, { &setup_pipe_pwrite_pdc_0_proc1 } },
    &setup_pipe_pwrite_pdc_0_procfinal,
    &setup_pipe_pwrite_pdc_0_final,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pdc_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_pb0_0",
    &setup_pipe_pwrite_pb0_0_common,
    { { &setup_pipe_pwrite_pdc_0_proc1 }, { &setup_pipe_pwrite_pdc_0_proc1 } },
    &setup_pipe_pwrite_pdc_0_procfinal,
    &setup_pipe_pwrite_pdc_0_procfinal,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pb0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_p78_0",
    &setup_pipe_pwrite_p78_0_common,
    { { &setup_pipe_pwrite_pfc_0_proc1 }, { &setup_pipe_pwrite_pfc_0_proc0 } },
    &setup_pipe_pwrite_pfc_0_procfinal,
    &setup_pipe_pwrite_pfc_0_final,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_p78_1",
    &setup_pipe_pwrite_p78_0_common,
    { { &setup_pipe_pwrite_pfc_0_proc1 }, { &setup_pipe_pwrite_pfc_1_proc0 } },
    &setup_pipe_pwrite_pfc_0_procfinal,
    &setup_pipe_pwrite_pfc_0_final,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pfc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_p5c_0",
    &setup_pipe_pwrite_pdc_0_common,
    { { &setup_pipe_pwrite_pdc_0_proc1 }, { &setup_pipe_pwrite_p5c_0_proc1 } },
    &setup_pipe_pwrite_pdc_0_procfinal,
    &setup_pipe_pwrite_pdc_0_final,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pdc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_p5c_1",
    &setup_pipe_pwrite_pdc_1_common,
    { { &setup_pipe_pwrite_pdc_0_proc1 }, { &setup_pipe_pwrite_pdc_1_proc0 } },
    &setup_pipe_pwrite_pdc_0_procfinal,
    &setup_pipe_pwrite_pdc_0_final,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pdc_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_p4c_0",
    &setup_pipe_pwrite_p4c_0_common,
    { { &setup_pipe_pwrite_pdc_0_proc1 }, { &setup_pipe_pwrite_p4c_0_proc1 } },
    &setup_pipe_pwrite_pdc_0_procfinal,
    &setup_pipe_pwrite_pdc_0_final,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pdc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_p4c_1",
    &setup_pipe_pwrite_pdc_1_common,
    { { &setup_pipe_pwrite_pdc_0_proc1 }, { &setup_pipe_pwrite_p4c_1_proc1 } },
    &setup_pipe_pwrite_pdc_0_procfinal,
    &setup_pipe_pwrite_pdc_0_final,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_p4c_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pipe_pwrite_p30_0",
    &setup_pipe_pwrite_pb0_0_common,
    { { &setup_pipe_pwrite_pdc_0_proc1 }, { &setup_pipe_pwrite_pdc_0_proc1 } },
    &setup_pipe_pwrite_pdc_0_procfinal,
    &setup_pipe_pwrite_pdc_0_procfinal,
    { { &test_pipe_pwrite_pfc_0_0, 0, "pipe" },
      { &test_pipe_pwrite_pb0_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pipe_read_pfe_0",
    &setup_pipe_read_pfe_0_common,
    { { &setup_pipe_read_pfe_0_proc0 }, { &setup_pipe_read_pfe_0_proc1 } },
    &setup_pipe_read_pfe_0_procfinal,
    &setup_pipe_read_pfe_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-pipe_read_pf6_0",
    &setup_pipe_read_pf6_0_common,
    { { &setup_pipe_read_pf6_0_proc0 }, { &setup_pipe_read_pf6_0_proc1 } },
    &setup_pipe_read_pf6_0_procfinal,
    &setup_pipe_read_pf6_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-pipe_read_pef8_0",
    &setup_pipe_read_pef8_0_common,
    { { &setup_pipe_read_pef8_0_proc0 }, { &setup_pipe_read_pfe_0_proc1 } },
    &setup_pipe_read_pfe_0_procfinal,
    &setup_pipe_read_pfe_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pef8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pipe_read_peb0_0",
    &setup_pipe_read_peb0_0_common,
    { { &setup_pipe_read_peb0_0_proc0 }, { &setup_pipe_read_peb0_0_proc1 } },
    &setup_pipe_read_pfe_0_procfinal,
    &setup_pipe_read_pfe_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_peb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-pipe_read_pe6_0",
    &setup_pipe_read_pe6_0_common,
    { { &setup_pipe_read_pef8_0_proc0 }, { &setup_pipe_read_pfe_0_proc1 } },
    &setup_pipe_read_pfe_0_procfinal,
    &setup_pipe_read_pfe_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pe6_0_1, 0, "read" } },
    &cleanup },
  { "fs-pipe_read_pdc_0",
    &setup_pipe_read_pdc_0_common,
    { { &setup_pipe_read_pdc_0_proc0 }, { &setup_pipe_read_pf6_0_proc1 } },
    &setup_pipe_read_pf6_0_procfinal,
    &setup_pipe_read_pdc_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_peb0_0_1, 0, "read" } },
    &cleanup },
  { "fs-pipe_read_pcc_0",
    &setup_pipe_read_pcc_0_common,
    { { &setup_pipe_read_pcc_0_proc0 }, { &setup_pipe_read_pf6_0_proc1 } },
    &setup_pipe_read_pf6_0_procfinal,
    &setup_pipe_read_pdc_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pe6_0_1, 0, "read" } },
    &cleanup },
  { "fs-pipe_read_pb0_0",
    &setup_pipe_read_pf6_0_common,
    { { &setup_pipe_read_pf6_0_proc1 }, { &setup_pipe_read_pf6_0_proc1 } },
    &setup_pipe_read_pf6_0_procfinal,
    &setup_pipe_read_pf6_0_procfinal,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-pipe_read_p7c_0",
    &setup_pipe_read_p7c_0_common,
    { { &setup_pipe_read_pfe_0_proc1 }, { &setup_pipe_read_pfe_0_proc0 } },
    &setup_pipe_read_pfe_0_procfinal,
    &setup_pipe_read_pfe_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-pipe_read_p6f0_0",
    &setup_pipe_read_p6f0_0_common,
    { { &setup_pipe_read_pfe_0_proc1 }, { &setup_pipe_read_pef8_0_proc0 } },
    &setup_pipe_read_pfe_0_procfinal,
    &setup_pipe_read_pfe_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pef8_0_1, 1, "read" } },
    &cleanup },
  { "fs-pipe_read_p6b0_0",
    &setup_pipe_read_pef8_0_common,
    { { &setup_pipe_read_peb0_0_proc1 }, { &setup_pipe_read_peb0_0_proc0 } },
    &setup_pipe_read_pfe_0_procfinal,
    &setup_pipe_read_pfe_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_peb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-pipe_read_p66_0",
    &setup_pipe_read_pe6_0_common,
    { { &setup_pipe_read_pfe_0_proc1 }, { &setup_pipe_read_pef8_0_proc0 } },
    &setup_pipe_read_pfe_0_procfinal,
    &setup_pipe_read_pfe_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pe6_0_1, 1, "read" } },
    &cleanup },
  { "fs-pipe_read_p5c_0",
    &setup_pipe_read_p5c_0_common,
    { { &setup_pipe_read_pf6_0_proc1 }, { &setup_pipe_read_pdc_0_proc0 } },
    &setup_pipe_read_pf6_0_procfinal,
    &setup_pipe_read_pdc_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_peb0_0_1, 1, "read" } },
    &cleanup },
  { "fs-pipe_read_p4c_0",
    &setup_pipe_read_pcc_0_common,
    { { &setup_pipe_read_pf6_0_proc1 }, { &setup_pipe_read_pcc_0_proc0 } },
    &setup_pipe_read_pf6_0_procfinal,
    &setup_pipe_read_pdc_0_final,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pe6_0_1, 1, "read" } },
    &cleanup },
  { "fs-pipe_read_p30_0",
    &setup_pipe_read_pf6_0_common,
    { { &setup_pipe_read_pf6_0_proc1 }, { &setup_pipe_read_pf6_0_proc1 } },
    &setup_pipe_read_pf6_0_procfinal,
    &setup_pipe_read_pf6_0_procfinal,
    { { &test_pipe_read_pfe_0_0, 0, "pipe" },
      { &test_pipe_read_pfe_0_1, 1, "read" } },
    &cleanup },
  { "fs-pipe_rename_pf0_0",
    &setup_pipe_rename_pf0_0_common,
    { { &setup_pipe_rename_pf0_0_proc0 }, { &setup_pipe_rename_pf0_0_proc1 } },
    &setup_pipe_rename_pf0_0_procfinal,
    &setup_pipe_rename_pf0_0_final,
    { { &test_pipe_rename_pf0_0_0, 0, "pipe" },
      { &test_pipe_rename_pf0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pipe_rename_pb8_0",
    &setup_pipe_rename_pb8_0_common,
    { { &setup_pipe_rename_pf0_0_proc1 }, { &setup_pipe_rename_pf0_0_proc1 } },
    &setup_pipe_rename_pf0_0_procfinal,
    &setup_pipe_rename_pf0_0_final,
    { { &test_pipe_rename_pf0_0_0, 0, "pipe" },
      { &test_pipe_rename_pb8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pipe_rename_p98_0",
    &setup_pipe_rename_pf0_0_common,
    { { &setup_pipe_rename_pf0_0_proc1 }, { &setup_pipe_rename_pf0_0_proc1 } },
    &setup_pipe_rename_pf0_0_procfinal,
    &setup_pipe_rename_pf0_0_final,
    { { &test_pipe_rename_pf0_0_0, 0, "pipe" },
      { &test_pipe_rename_pb8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pipe_rename_p6_0",
    &setup_pipe_rename_p6_0_common,
    { { &setup_pipe_rename_pf0_0_proc1 }, { &setup_pipe_rename_pf0_0_proc1 } },
    &setup_pipe_rename_pf0_0_procfinal,
    &setup_pipe_rename_pf0_0_procfinal,
    { { &test_pipe_rename_pf0_0_0, 0, "pipe" },
      { &test_pipe_rename_p6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pipe_stat_pe_0",
    &setup_pipe_stat_pe_0_common,
    { { &setup_pipe_stat_pe_0_proc0 }, { &setup_pipe_stat_pe_0_proc1 } },
    &setup_pipe_stat_pe_0_procfinal,
    &setup_pipe_stat_pe_0_final,
    { { &test_pipe_stat_pe_0_0, 0, "pipe" },
      { &test_pipe_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pipe_stat_p6_0",
    &setup_pipe_stat_p6_0_common,
    { { &setup_pipe_stat_pe_0_proc1 }, { &setup_pipe_stat_pe_0_proc1 } },
    &setup_pipe_stat_pe_0_procfinal,
    &setup_pipe_stat_pe_0_procfinal,
    { { &test_pipe_stat_pe_0_0, 0, "pipe" },
      { &test_pipe_stat_p6_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pipe_unlink_pe_0",
    &setup_pipe_unlink_pe_0_common,
    { { &setup_pipe_unlink_pe_0_proc0 }, { &setup_pipe_unlink_pe_0_proc1 } },
    &setup_pipe_unlink_pe_0_procfinal,
    &setup_pipe_unlink_pe_0_final,
    { { &test_pipe_unlink_pe_0_0, 0, "pipe" },
      { &test_pipe_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pipe_unlink_p6_0",
    &setup_pipe_unlink_p6_0_common,
    { { &setup_pipe_unlink_pe_0_proc1 }, { &setup_pipe_unlink_pe_0_proc1 } },
    &setup_pipe_unlink_pe_0_procfinal,
    &setup_pipe_unlink_pe_0_procfinal,
    { { &test_pipe_unlink_pe_0_0, 0, "pipe" },
      { &test_pipe_unlink_p6_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pipe_write_pfe_0",
    &setup_pipe_write_pfe_0_common,
    { { &setup_pipe_write_pfe_0_proc0 }, { &setup_pipe_write_pfe_0_proc1 } },
    &setup_pipe_write_pfe_0_procfinal,
    &setup_pipe_write_pfe_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pipe_write_pf70_0",
    &setup_pipe_write_pf70_0_common,
    { { &setup_pipe_write_pf70_0_proc0 }, { &setup_pipe_write_pf70_0_proc1 } },
    &setup_pipe_write_pfe_0_procfinal,
    &setup_pipe_write_pfe_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pf70_0_1, 0, "write" } },
    &cleanup },
  { "fs-pipe_write_pee_0",
    &setup_pipe_write_pee_0_common,
    { { &setup_pipe_write_pee_0_proc0 }, { &setup_pipe_write_pf70_0_proc1 } },
    &setup_pipe_write_pfe_0_procfinal,
    &setup_pipe_write_pfe_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pee_0_1, 0, "write" } },
    &cleanup },
  { "fs-pipe_write_pe6_0",
    &setup_pipe_write_pe6_0_common,
    { { &setup_pipe_write_pe6_0_proc0 }, { &setup_pipe_write_pe6_0_proc1 } },
    &setup_pipe_write_pe6_0_procfinal,
    &setup_pipe_write_pe6_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pee_0_1, 0, "write" } },
    &cleanup },
  { "fs-pipe_write_pdc_0",
    &setup_pipe_write_pdc_0_common,
    { { &setup_pipe_write_pdc_0_proc0 }, { &setup_pipe_write_pe6_0_proc1 } },
    &setup_pipe_write_pe6_0_procfinal,
    &setup_pipe_write_pdc_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pf70_0_1, 0, "write" } },
    &cleanup },
  { "fs-pipe_write_pcc_0",
    &setup_pipe_write_pcc_0_common,
    { { &setup_pipe_write_pcc_0_proc0 }, { &setup_pipe_write_pe6_0_proc1 } },
    &setup_pipe_write_pe6_0_procfinal,
    &setup_pipe_write_pdc_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pf70_0_1, 0, "write" } },
    &cleanup },
  { "fs-pipe_write_pb0_0",
    &setup_pipe_write_pe6_0_common,
    { { &setup_pipe_write_pe6_0_proc1 }, { &setup_pipe_write_pe6_0_proc1 } },
    &setup_pipe_write_pe6_0_procfinal,
    &setup_pipe_write_pe6_0_procfinal,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pee_0_1, 0, "write" } },
    &cleanup },
  { "fs-pipe_write_p7e_0",
    &setup_pipe_write_p7e_0_common,
    { { &setup_pipe_write_pfe_0_proc1 }, { &setup_pipe_write_pfe_0_proc0 } },
    &setup_pipe_write_pfe_0_procfinal,
    &setup_pipe_write_pfe_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-pipe_write_p76_0",
    &setup_pipe_write_p76_0_common,
    { { &setup_pipe_write_pf70_0_proc1 }, { &setup_pipe_write_pf70_0_proc0 } },
    &setup_pipe_write_pfe_0_procfinal,
    &setup_pipe_write_pfe_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-pipe_write_p6c_0",
    &setup_pipe_write_p6c_0_common,
    { { &setup_pipe_write_pf70_0_proc1 }, { &setup_pipe_write_pee_0_proc0 } },
    &setup_pipe_write_pfe_0_procfinal,
    &setup_pipe_write_pfe_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pee_0_1, 1, "write" } },
    &cleanup },
  { "fs-pipe_write_p5c_0",
    &setup_pipe_write_pdc_0_common,
    { { &setup_pipe_write_pe6_0_proc1 }, { &setup_pipe_write_pdc_0_proc0 } },
    &setup_pipe_write_pe6_0_procfinal,
    &setup_pipe_write_pdc_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-pipe_write_p4c_0",
    &setup_pipe_write_pcc_0_common,
    { { &setup_pipe_write_pe6_0_proc1 }, { &setup_pipe_write_pcc_0_proc0 } },
    &setup_pipe_write_pe6_0_procfinal,
    &setup_pipe_write_pdc_0_final,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-pipe_write_p30_0",
    &setup_pipe_write_pe6_0_common,
    { { &setup_pipe_write_pe6_0_proc1 }, { &setup_pipe_write_pe6_0_proc1 } },
    &setup_pipe_write_pe6_0_procfinal,
    &setup_pipe_write_pe6_0_procfinal,
    { { &test_pipe_write_pfe_0_0, 0, "pipe" },
      { &test_pipe_write_pee_0_1, 1, "write" } },
    &cleanup },
  { "fs-pread_pread_pf8_0",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_0_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf8_1",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_1_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf8_2",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_2_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf8_3",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_3_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf8_4",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_4_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf4_0",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pf4_0_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf4_1",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pf4_1_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf4_2",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pf4_2_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf4_3",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pf4_3_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf0_0",
    &setup_pread_pread_pf0_0_common,
    { { &setup_pread_pread_pf0_0_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf0_1",
    &setup_pread_pread_pf0_0_common,
    { { &setup_pread_pread_pf0_1_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf0_2",
    &setup_pread_pread_pf0_2_common,
    { { &setup_pread_pread_pf4_2_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pf0_3",
    &setup_pread_pread_pf0_2_common,
    { { &setup_pread_pread_pf4_3_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pe_0",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_3_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pe_1",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_4_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd8_0",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_3_proc0 }, { &setup_pread_pread_pf8_3_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd8_1",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_4_proc0 }, { &setup_pread_pread_pf8_3_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd8_2",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_3_proc0 }, { &setup_pread_pread_pf8_4_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd8_3",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_4_proc0 }, { &setup_pread_pread_pf8_4_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd4_0",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pf8_3_proc0 }, { &setup_pread_pread_pd4_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd4_1",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pf8_4_proc0 }, { &setup_pread_pread_pd4_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd4_2",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pf8_3_proc0 }, { &setup_pread_pread_pd4_2_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd4_3",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pf8_4_proc0 }, { &setup_pread_pread_pd4_2_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd0_0",
    &setup_pread_pread_pf0_0_common,
    { { &setup_pread_pread_pf8_3_proc0 }, { &setup_pread_pread_pd0_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd0_1",
    &setup_pread_pread_pf0_0_common,
    { { &setup_pread_pread_pf8_4_proc0 }, { &setup_pread_pread_pd0_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd0_2",
    &setup_pread_pread_pf0_2_common,
    { { &setup_pread_pread_pf8_3_proc0 }, { &setup_pread_pread_pd4_2_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pd0_3",
    &setup_pread_pread_pd0_3_common,
    { { &setup_pread_pread_pf8_4_proc0 }, { &setup_pread_pread_pd4_2_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pc_0",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_3_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pc_1",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_4_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pf8_0_0, 0, "pread" },
      { &test_pread_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pbc_0",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pbc_0_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pbc_1",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pbc_1_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pbc_2",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pbc_2_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pbc_3",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pbc_3_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pba_0",
    &setup_pread_pread_pba_0_common,
    { { &setup_pread_pread_pba_0_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pba_1",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_1_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pba_2",
    &setup_pread_pread_pba_0_common,
    { { &setup_pread_pread_pba_2_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pba_3",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_3_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pba_4",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_4_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pba_5",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pb8_0",
    &setup_pread_pread_pb8_0_common,
    { { &setup_pread_pread_pb8_0_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pb8_1",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_1_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pb8_1_0, 0, "pread" },
      { &test_pread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pb8_2",
    &setup_pread_pread_pb8_2_common,
    { { &setup_pread_pread_pba_0_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pb8_1_0, 0, "pread" },
      { &test_pread_pread_pb8_2_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pb8_3",
    &setup_pread_pread_pb8_2_common,
    { { &setup_pread_pread_pb8_3_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pb8_1_0, 0, "pread" },
      { &test_pread_pread_pb8_2_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pb8_4",
    &setup_pread_pread_pb8_4_common,
    { { &setup_pread_pread_pb8_4_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pb8_4_0, 0, "pread" },
      { &test_pread_pread_pb8_4_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pb8_5",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pb8_1_0, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pb8_6",
    &setup_pread_pread_pb8_4_common,
    { { &setup_pread_pread_pb8_6_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pb8_4_0, 0, "pread" },
      { &test_pread_pread_pb8_6_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pb8_7",
    &setup_pread_pread_pb8_7_common,
    { { &setup_pread_pread_pb8_3_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pb8_1_0, 0, "pread" },
      { &test_pread_pread_pb8_7_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pb0_0",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_4_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pb0_1",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_pac_0",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pd4_0_proc1 }, { &setup_pread_pread_pf8_3_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pac_1",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pd4_0_proc1 }, { &setup_pread_pread_pf8_4_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pac_2",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pd4_2_proc1 }, { &setup_pread_pread_pf8_3_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pac_3",
    &setup_pread_pread_pf4_0_common,
    { { &setup_pread_pread_pd4_2_proc1 }, { &setup_pread_pread_pf8_4_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_paa_0",
    &setup_pread_pread_pba_0_common,
    { { &setup_pread_pread_pba_4_proc0 }, { &setup_pread_pread_paa_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_paa_1",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_4_proc0 }, { &setup_pread_pread_pba_4_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_paa_2",
    &setup_pread_pread_pba_0_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_paa_2_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_paa_3",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_pba_5_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pa8_0",
    &setup_pread_pread_pb8_0_common,
    { { &setup_pread_pread_pa8_0_proc0 }, { &setup_pread_pread_pa8_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pa8_1",
    &setup_pread_pread_pa8_1_common,
    { { &setup_pread_pread_pa8_1_proc0 }, { &setup_pread_pread_pa8_1_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pa8_1_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pa8_2",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_5_proc0 }, { &setup_pread_pread_pb8_5_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pb8_1_0, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pa8_3",
    &setup_pread_pread_pa8_3_common,
    { { &setup_pread_pread_pa8_3_proc0 }, { &setup_pread_pread_pa8_3_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pb8_1_0, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pa8_4",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pba_4_proc0 }, { &setup_pread_pread_pba_4_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pa8_4_0, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pa8_5",
    &setup_pread_pread_pb8_0_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_paa_2_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pa0_0",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_4_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_pa0_1",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd4_0_1, 0, "pread" },
      { &test_pread_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9c_0",
    &setup_pread_pread_pf0_0_common,
    { { &setup_pread_pread_p9c_0_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9c_1",
    &setup_pread_pread_pf0_0_common,
    { { &setup_pread_pread_p9c_1_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9c_2",
    &setup_pread_pread_pf0_2_common,
    { { &setup_pread_pread_pbc_2_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9c_3",
    &setup_pread_pread_pd0_3_common,
    { { &setup_pread_pread_pbc_3_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9a_0",
    &setup_pread_pread_p9a_0_common,
    { { &setup_pread_pread_p9a_0_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9a_1",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_1_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_p9a_1_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9a_2",
    &setup_pread_pread_p9a_2_common,
    { { &setup_pread_pread_pba_2_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_p9a_2_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9a_3",
    &setup_pread_pread_p9a_3_common,
    { { &setup_pread_pread_p9a_3_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_p9a_3_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9a_4",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pba_3_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_p9a_1_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9a_5",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pb8_1_0, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p9a_6",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pb8_1_0, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p98_0",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_1_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p98_1",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p98_2",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pba_3_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p98_3",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p90_0",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p90_1",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p8c_0",
    &setup_pread_pread_pf0_0_common,
    { { &setup_pread_pread_pd0_0_proc1 }, { &setup_pread_pread_pf8_3_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p8c_1",
    &setup_pread_pread_pf0_0_common,
    { { &setup_pread_pread_pd0_0_proc1 }, { &setup_pread_pread_pf8_4_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p8c_2",
    &setup_pread_pread_pf0_2_common,
    { { &setup_pread_pread_pd4_2_proc1 }, { &setup_pread_pread_pf8_3_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p8c_3",
    &setup_pread_pread_pd0_3_common,
    { { &setup_pread_pread_pd4_2_proc1 }, { &setup_pread_pread_pf8_4_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p8a_0",
    &setup_pread_pread_p9a_0_common,
    { { &setup_pread_pread_pb8_5_proc0 }, { &setup_pread_pread_p8a_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p8a_1",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_5_proc0 }, { &setup_pread_pread_pb8_5_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pb8_1_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p8a_2",
    &setup_pread_pread_p8a_2_common,
    { { &setup_pread_pread_pa8_3_proc0 }, { &setup_pread_pread_pa8_3_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_p8a_2_0, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p8a_3",
    &setup_pread_pread_p8a_3_common,
    { { &setup_pread_pread_p8a_3_proc0 }, { &setup_pread_pread_paa_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_final,
    { { &test_pread_pread_p8a_3_0, 0, "pread" },
      { &test_pread_pread_pa8_4_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p8a_4",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_p8a_4_proc0 }, { &setup_pread_pread_p8a_4_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_p8a_4_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p88_0",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_5_proc0 }, { &setup_pread_pread_pb8_5_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p88_1",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_pba_5_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p80_0",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pb8_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p80_1",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pba_5_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pd0_0_1, 0, "pread" },
      { &test_pread_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p7_0",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_p7_0_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p7_1",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_p7_1_proc0 }, { &setup_pread_pread_pf8_0_proc1 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p68_0",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_p68_0_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p68_1",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_p68_1_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pf4_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p60_0",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_p60_0_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p60_1",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_p68_1_proc0 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pf0_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p4_0",
    &setup_pread_pread_p4_0_common,
    { { &setup_pread_pread_pba_0_proc1 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_procfinal,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pe_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p4_1",
    &setup_pread_pread_p4_0_common,
    { { &setup_pread_pread_pba_0_proc1 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_procfinal,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pc_0_1, 0, "pread" } },
    &cleanup },
  { "fs-pread_pread_p3_0",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_0_proc1 }, { &setup_pread_pread_pf8_3_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p3_1",
    &setup_pread_pread_pf8_0_common,
    { { &setup_pread_pread_pf8_0_proc1 }, { &setup_pread_pread_pf8_4_proc0 } },
    &setup_pread_pread_pf8_0_procfinal,
    &setup_pread_pread_pf8_0_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pf8_0_0, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p28_0",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_0_proc1 }, { &setup_pread_pread_pba_4_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p28_1",
    &setup_pread_pread_pba_1_common,
    { { &setup_pread_pread_pba_0_proc1 }, { &setup_pread_pread_pba_5_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pd4_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p20_0",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pba_0_proc1 }, { &setup_pread_pread_pb8_5_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p20_1",
    &setup_pread_pread_pb8_1_common,
    { { &setup_pread_pread_pba_0_proc1 }, { &setup_pread_pread_pba_5_proc0 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_1_final,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pd0_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pread_p0_0",
    &setup_pread_pread_p4_0_common,
    { { &setup_pread_pread_pba_0_proc1 }, { &setup_pread_pread_pba_0_proc1 } },
    &setup_pread_pread_pba_0_procfinal,
    &setup_pread_pread_pba_0_procfinal,
    { { &test_pread_pread_pc_0_1, 0, "pread" },
      { &test_pread_pread_pc_0_1, 1, "pread" } },
    &cleanup },
  { "fs-pread_pwrite_pf8_0",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_0_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf8_1",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_1_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf8_2",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_2_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf8_3",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_3_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf8_4",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_4_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf4_0",
    &setup_pread_pwrite_pf4_0_common,
    { { &setup_pread_pwrite_pf4_0_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf4_1",
    &setup_pread_pwrite_pf4_1_common,
    { { &setup_pread_pwrite_pf4_1_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf4_2",
    &setup_pread_pwrite_pf4_1_common,
    { { &setup_pread_pwrite_pf4_2_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf4_3",
    &setup_pread_pwrite_pf4_1_common,
    { { &setup_pread_pwrite_pf4_3_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf0_0",
    &setup_pread_pwrite_pf0_0_common,
    { { &setup_pread_pwrite_pf0_0_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf0_1",
    &setup_pread_pwrite_pf0_1_common,
    { { &setup_pread_pwrite_pf4_1_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf0_2",
    &setup_pread_pwrite_pf0_1_common,
    { { &setup_pread_pwrite_pf0_2_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pf0_3",
    &setup_pread_pwrite_pf0_3_common,
    { { &setup_pread_pwrite_pf4_3_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pe_0",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_3_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pe_1",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_4_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd8_0",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_3_proc0 }, { &setup_pread_pwrite_pf8_3_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd8_1",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_4_proc0 }, { &setup_pread_pwrite_pf8_3_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd8_2",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_3_proc0 }, { &setup_pread_pwrite_pf8_4_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd8_3",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_4_proc0 }, { &setup_pread_pwrite_pf8_4_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd4_0",
    &setup_pread_pwrite_pf4_0_common,
    { { &setup_pread_pwrite_pf8_3_proc0 }, { &setup_pread_pwrite_pd4_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd4_1",
    &setup_pread_pwrite_pf4_1_common,
    { { &setup_pread_pwrite_pf8_3_proc0 }, { &setup_pread_pwrite_pd4_1_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd4_2",
    &setup_pread_pwrite_pf4_1_common,
    { { &setup_pread_pwrite_pf8_4_proc0 }, { &setup_pread_pwrite_pd4_2_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd4_3",
    &setup_pread_pwrite_pf4_0_common,
    { { &setup_pread_pwrite_pf8_4_proc0 }, { &setup_pread_pwrite_pd4_1_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd0_0",
    &setup_pread_pwrite_pf0_0_common,
    { { &setup_pread_pwrite_pf8_3_proc0 }, { &setup_pread_pwrite_pd0_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd0_1",
    &setup_pread_pwrite_pf0_1_common,
    { { &setup_pread_pwrite_pf8_3_proc0 }, { &setup_pread_pwrite_pd4_1_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd0_2",
    &setup_pread_pwrite_pf0_1_common,
    { { &setup_pread_pwrite_pf8_4_proc0 }, { &setup_pread_pwrite_pd4_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pd0_3",
    &setup_pread_pwrite_pf0_1_common,
    { { &setup_pread_pwrite_pf8_4_proc0 }, { &setup_pread_pwrite_pd4_1_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pc_0",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_3_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pc_1",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_4_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pf8_0_0, 0, "pread" },
      { &test_pread_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbc_0",
    &setup_pread_pwrite_pbc_0_common,
    { { &setup_pread_pwrite_pbc_0_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbc_1",
    &setup_pread_pwrite_pbc_0_common,
    { { &setup_pread_pwrite_pbc_1_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbc_2",
    &setup_pread_pwrite_pbc_0_common,
    { { &setup_pread_pwrite_pbc_2_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbc_3",
    &setup_pread_pwrite_pbc_0_common,
    { { &setup_pread_pwrite_pbc_3_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbb0_0",
    &setup_pread_pwrite_pbb0_0_common,
    { { &setup_pread_pwrite_pbb0_0_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pbb0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbb0_1",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pbb0_1_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbb0_2",
    &setup_pread_pwrite_pbb0_2_common,
    { { &setup_pread_pwrite_pbb0_2_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pbb0_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbb0_3",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pbb0_3_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbb0_4",
    &setup_pread_pwrite_pbb0_4_common,
    { { &setup_pread_pwrite_pbb0_4_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbb0_4_0, 0, "pread" },
      { &test_pread_pwrite_pbb0_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbb0_5",
    &setup_pread_pwrite_pbb0_4_common,
    { { &setup_pread_pwrite_pbb0_5_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbb0_4_0, 0, "pread" },
      { &test_pread_pwrite_pbb0_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbb0_6",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pbb0_6_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pbb0_7",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pb8_0",
    &setup_pread_pwrite_pbb0_0_common,
    { { &setup_pread_pwrite_pb8_0_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pb8_1",
    &setup_pread_pwrite_pb8_1_common,
    { { &setup_pread_pwrite_pb8_1_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pb8_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pb8_2",
    &setup_pread_pwrite_pb8_2_common,
    { { &setup_pread_pwrite_pbb0_2_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pb8_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pb8_3",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_pb8_3_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pb8_4",
    &setup_pread_pwrite_pb8_4_common,
    { { &setup_pread_pwrite_pb8_4_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pbb0_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pb8_5",
    &setup_pread_pwrite_pb8_5_common,
    { { &setup_pread_pwrite_pb8_5_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pb8_5_0, 0, "pread" },
      { &test_pread_pwrite_pbb0_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pb8_6",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_pb8_6_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pb8_7",
    &setup_pread_pwrite_pb8_5_common,
    { { &setup_pread_pwrite_pb8_7_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pb8_5_0, 0, "pread" },
      { &test_pread_pwrite_pb8_7_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pb0_0",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pb0_0_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pb0_1",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pb0_1_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pac_0",
    &setup_pread_pwrite_pbc_0_common,
    { { &setup_pread_pwrite_pac_0_proc0 }, { &setup_pread_pwrite_pf8_3_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pac_1",
    &setup_pread_pwrite_pbc_0_common,
    { { &setup_pread_pwrite_pac_0_proc0 }, { &setup_pread_pwrite_pf8_4_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pac_2",
    &setup_pread_pwrite_pbc_0_common,
    { { &setup_pread_pwrite_pd4_1_proc1 }, { &setup_pread_pwrite_pf8_3_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pac_3",
    &setup_pread_pwrite_pbc_0_common,
    { { &setup_pread_pwrite_pd4_1_proc1 }, { &setup_pread_pwrite_pf8_4_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pab0_0",
    &setup_pread_pwrite_pab0_0_common,
    { { &setup_pread_pwrite_pbb0_6_proc0 }, { &setup_pread_pwrite_pab0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pab0_1",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pbb0_6_proc0 }, { &setup_pread_pwrite_pb8_6_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pab0_2",
    &setup_pread_pwrite_pab0_2_common,
    { { &setup_pread_pwrite_pab0_2_proc0 }, { &setup_pread_pwrite_pab0_2_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pab0_2_0, 0, "pread" },
      { &test_pread_pwrite_pab0_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pab0_3",
    &setup_pread_pwrite_pbb0_0_common,
    { { &setup_pread_pwrite_pb0_0_proc0 }, { &setup_pread_pwrite_pab0_3_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pab0_3_0, 0, "pread" },
      { &test_pread_pwrite_pab0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pab0_4",
    &setup_pread_pwrite_pbb0_0_common,
    { { &setup_pread_pwrite_pb0_0_proc0 }, { &setup_pread_pwrite_pab0_3_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pab0_4_0, 0, "pread" },
      { &test_pread_pwrite_pab0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pab0_5",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_pbb0_7_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pab0_4_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pab0_6",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_pab0_6_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pab0_7",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pb0_1_proc0 }, { &setup_pread_pwrite_pbb0_7_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pa8_0",
    &setup_pread_pwrite_pbb0_0_common,
    { { &setup_pread_pwrite_pb8_6_proc0 }, { &setup_pread_pwrite_pa8_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pa8_1",
    &setup_pread_pwrite_pa8_1_common,
    { { &setup_pread_pwrite_pa8_1_proc0 }, { &setup_pread_pwrite_pa8_1_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pab0_4_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pa8_2",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_pb8_6_proc0 }, { &setup_pread_pwrite_pa8_2_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pa8_3",
    &setup_pread_pwrite_pbb0_0_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_pab0_2_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pa8_4",
    &setup_pread_pwrite_pa8_4_common,
    { { &setup_pread_pwrite_pa8_4_proc0 }, { &setup_pread_pwrite_pab0_6_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pa8_4_0, 0, "pread" },
      { &test_pread_pwrite_pa8_4_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pa8_5",
    &setup_pread_pwrite_pa8_5_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_pa8_1_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_pbb0_1_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pa8_6",
    &setup_pread_pwrite_pa8_4_common,
    { { &setup_pread_pwrite_pab0_6_proc1 }, { &setup_pread_pwrite_pa8_4_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pa8_4_0, 0, "pread" },
      { &test_pread_pwrite_pa8_4_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pa8_7",
    &setup_pread_pwrite_pb8_5_common,
    { { &setup_pread_pwrite_pb8_7_proc0 }, { &setup_pread_pwrite_pa8_7_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pb8_5_0, 0, "pread" },
      { &test_pread_pwrite_pb8_7_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pa0_0",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pb0_0_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_pa0_1",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pb0_1_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_pbc_0_0, 0, "pread" },
      { &test_pread_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9c_0",
    &setup_pread_pwrite_p9c_0_common,
    { { &setup_pread_pwrite_p9c_0_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9c_1",
    &setup_pread_pwrite_p9c_0_common,
    { { &setup_pread_pwrite_p9c_1_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9c_2",
    &setup_pread_pwrite_pf0_1_common,
    { { &setup_pread_pwrite_pbc_2_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9c_3",
    &setup_pread_pwrite_pf0_1_common,
    { { &setup_pread_pwrite_pbc_3_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9a_0",
    &setup_pread_pwrite_p9a_0_common,
    { { &setup_pread_pwrite_p9a_0_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_0_0, 0, "pread" },
      { &test_pread_pwrite_p9a_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9a_1",
    &setup_pread_pwrite_p9a_1_common,
    { { &setup_pread_pwrite_p9a_1_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_p9a_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9a_2",
    &setup_pread_pwrite_p9a_2_common,
    { { &setup_pread_pwrite_p9a_2_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p9a_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9a_3",
    &setup_pread_pwrite_p9a_3_common,
    { { &setup_pread_pwrite_pbb0_3_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p9a_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9a_4",
    &setup_pread_pwrite_p9a_4_common,
    { { &setup_pread_pwrite_p9a_4_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p9a_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9a_5",
    &setup_pread_pwrite_p9a_4_common,
    { { &setup_pread_pwrite_pbb0_2_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p9a_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9a_6",
    &setup_pread_pwrite_p9a_0_common,
    { { &setup_pread_pwrite_p9a_6_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_0_0, 0, "pread" },
      { &test_pread_pwrite_p9a_6_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p9a_7",
    &setup_pread_pwrite_p9a_0_common,
    { { &setup_pread_pwrite_pab0_2_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_0_0, 0, "pread" },
      { &test_pread_pwrite_p9a_6_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_0",
    &setup_pread_pwrite_p990_0_common,
    { { &setup_pread_pwrite_p990_0_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p990_0_0, 0, "pread" },
      { &test_pread_pwrite_p990_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_1",
    &setup_pread_pwrite_p990_1_common,
    { { &setup_pread_pwrite_p990_1_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p990_1_0, 0, "pread" },
      { &test_pread_pwrite_p9a_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_2",
    &setup_pread_pwrite_p990_2_common,
    { { &setup_pread_pwrite_p990_2_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p990_2_0, 0, "pread" },
      { &test_pread_pwrite_p990_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_3",
    &setup_pread_pwrite_p990_3_common,
    { { &setup_pread_pwrite_p9a_0_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p990_1_0, 0, "pread" },
      { &test_pread_pwrite_p9a_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_4",
    &setup_pread_pwrite_p990_4_common,
    { { &setup_pread_pwrite_pb8_4_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p9a_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_5",
    &setup_pread_pwrite_p990_3_common,
    { { &setup_pread_pwrite_p990_5_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p9a_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_6",
    &setup_pread_pwrite_p990_3_common,
    { { &setup_pread_pwrite_pbb0_3_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p9a_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_7",
    &setup_pread_pwrite_p990_7_common,
    { { &setup_pread_pwrite_p990_7_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p990_7_0, 0, "pread" },
      { &test_pread_pwrite_p990_7_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_8",
    &setup_pread_pwrite_p990_3_common,
    { { &setup_pread_pwrite_p9a_6_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p990_8_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_9",
    &setup_pread_pwrite_p990_3_common,
    { { &setup_pread_pwrite_pb0_0_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p990_8_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_10",
    &setup_pread_pwrite_p990_10_common,
    { { &setup_pread_pwrite_p990_10_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_pbb0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_11",
    &setup_pread_pwrite_p990_10_common,
    { { &setup_pread_pwrite_pbb0_6_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_pab0_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_12",
    &setup_pread_pwrite_p990_10_common,
    { { &setup_pread_pwrite_p990_12_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_pbb0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_13",
    &setup_pread_pwrite_p990_10_common,
    { { &setup_pread_pwrite_pbb0_3_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_pbb0_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p990_14",
    &setup_pread_pwrite_p990_10_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_pab0_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p90_0",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_pab0_2_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p90_1",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_pb0_1_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p8c_0",
    &setup_pread_pwrite_p9c_0_common,
    { { &setup_pread_pwrite_p8c_0_proc0 }, { &setup_pread_pwrite_pf8_3_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p8c_1",
    &setup_pread_pwrite_p9c_0_common,
    { { &setup_pread_pwrite_p8c_0_proc0 }, { &setup_pread_pwrite_pf8_4_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p8c_2",
    &setup_pread_pwrite_pf0_1_common,
    { { &setup_pread_pwrite_pd4_1_proc1 }, { &setup_pread_pwrite_pf8_3_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p8c_3",
    &setup_pread_pwrite_pf0_0_common,
    { { &setup_pread_pwrite_pd4_1_proc1 }, { &setup_pread_pwrite_pf8_4_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p8a_0",
    &setup_pread_pwrite_p9a_0_common,
    { { &setup_pread_pwrite_p9a_6_proc0 }, { &setup_pread_pwrite_p9a_6_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_0_0, 0, "pread" },
      { &test_pread_pwrite_p9a_6_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p8a_1",
    &setup_pread_pwrite_p9a_3_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_p8a_1_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p990_8_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p8a_2",
    &setup_pread_pwrite_p9a_2_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_p8a_2_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p990_8_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p8a_3",
    &setup_pread_pwrite_p8a_3_common,
    { { &setup_pread_pwrite_pa8_4_proc0 }, { &setup_pread_pwrite_pa8_4_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p990_2_0, 0, "pread" },
      { &test_pread_pwrite_p8a_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_0",
    &setup_pread_pwrite_p9a_3_common,
    { { &setup_pread_pwrite_pab0_2_proc0 }, { &setup_pread_pwrite_pab0_2_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p890_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_1",
    &setup_pread_pwrite_p890_1_common,
    { { &setup_pread_pwrite_pb0_0_proc0 }, { &setup_pread_pwrite_p890_1_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p990_8_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_2",
    &setup_pread_pwrite_p890_1_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_p890_2_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p990_8_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_3",
    &setup_pread_pwrite_p890_1_common,
    { { &setup_pread_pwrite_pb0_0_proc0 }, { &setup_pread_pwrite_p8a_2_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p990_8_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_4",
    &setup_pread_pwrite_p890_4_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_p890_4_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p9a_6_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_5",
    &setup_pread_pwrite_p890_5_common,
    { { &setup_pread_pwrite_pa8_7_proc1 }, { &setup_pread_pwrite_p890_5_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_p890_5_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_6",
    &setup_pread_pwrite_p890_5_common,
    { { &setup_pread_pwrite_pa8_4_proc0 }, { &setup_pread_pwrite_pa8_4_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p890_6_0, 0, "pread" },
      { &test_pread_pwrite_p8a_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_7",
    &setup_pread_pwrite_p990_10_common,
    { { &setup_pread_pwrite_pa8_1_proc0 }, { &setup_pread_pwrite_pbb0_6_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_pab0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_8",
    &setup_pread_pwrite_p890_8_common,
    { { &setup_pread_pwrite_pb0_0_proc0 }, { &setup_pread_pwrite_p890_8_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p990_7_0, 0, "pread" },
      { &test_pread_pwrite_p890_8_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_9",
    &setup_pread_pwrite_p990_10_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_pbb0_6_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_pab0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p890_10",
    &setup_pread_pwrite_p990_10_common,
    { { &setup_pread_pwrite_pbb0_7_proc0 }, { &setup_pread_pwrite_pbb0_7_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9a_2_0, 0, "pread" },
      { &test_pread_pwrite_pab0_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p80_0",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_pab0_2_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p80_1",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_pb0_1_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p9c_0_0, 0, "pread" },
      { &test_pread_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p7_0",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_p7_0_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p7_1",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_p7_1_proc0 }, { &setup_pread_pwrite_pf8_0_proc1 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p68_0",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_p68_0_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p68_1",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_p68_1_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p60_0",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_p60_0_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p60_1",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_p68_1_proc0 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p4_0",
    &setup_pread_pwrite_p4_0_common,
    { { &setup_pread_pwrite_pbb0_0_proc1 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_procfinal,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p4_1",
    &setup_pread_pwrite_p4_0_common,
    { { &setup_pread_pwrite_pbb0_0_proc1 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_procfinal,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p3_0",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_0_proc1 }, { &setup_pread_pwrite_pf8_3_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p3_1",
    &setup_pread_pwrite_pf8_0_common,
    { { &setup_pread_pwrite_pf8_0_proc1 }, { &setup_pread_pwrite_pf8_4_proc0 } },
    &setup_pread_pwrite_pf8_0_procfinal,
    &setup_pread_pwrite_pf8_0_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pf8_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p28_0",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pbb0_0_proc1 }, { &setup_pread_pwrite_pa8_2_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p28_1",
    &setup_pread_pwrite_pbb0_1_common,
    { { &setup_pread_pwrite_pbb0_0_proc1 }, { &setup_pread_pwrite_pb0_1_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p20_0",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_pbb0_0_proc1 }, { &setup_pread_pwrite_p20_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p20_1",
    &setup_pread_pwrite_pb8_3_common,
    { { &setup_pread_pwrite_pbb0_0_proc1 }, { &setup_pread_pwrite_pb0_1_proc0 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_1_final,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_pwrite_p0_0",
    &setup_pread_pwrite_p4_0_common,
    { { &setup_pread_pwrite_pbb0_0_proc1 }, { &setup_pread_pwrite_pbb0_0_proc1 } },
    &setup_pread_pwrite_pbb0_0_procfinal,
    &setup_pread_pwrite_pbb0_0_procfinal,
    { { &test_pread_pwrite_p7_0_0, 0, "pread" },
      { &test_pread_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pread_read_pfc_0",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pfc_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pfc_1",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pfc_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pfc_2",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pfc_2_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pfb_0",
    &setup_pread_read_pfb_0_common,
    { { &setup_pread_read_pfb_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pfb_1",
    &setup_pread_read_pfb_0_common,
    { { &setup_pread_read_pfb_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pfb_2",
    &setup_pread_read_pfb_0_common,
    { { &setup_pread_read_pfb_2_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfb_2_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pfa_0",
    &setup_pread_read_pfa_0_common,
    { { &setup_pread_read_pfa_0_proc0 }, { &setup_pread_read_pfa_0_proc1 } },
    &setup_pread_read_pfa_0_procfinal,
    &setup_pread_read_pfa_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pfa_1",
    &setup_pread_read_pfa_1_common,
    { { &setup_pread_read_pfa_1_proc0 }, { &setup_pread_read_pfa_0_proc1 } },
    &setup_pread_read_pfa_0_procfinal,
    &setup_pread_read_pfa_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pfa_2",
    &setup_pread_read_pfb_0_common,
    { { &setup_pread_read_pfa_2_proc0 }, { &setup_pread_read_pfa_2_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pfa_3",
    &setup_pread_read_pfa_3_common,
    { { &setup_pread_read_pfa_3_proc0 }, { &setup_pread_read_pfa_2_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pf8_0",
    &setup_pread_read_pf8_0_common,
    { { &setup_pread_read_pfb_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pf8_1",
    &setup_pread_read_pf8_0_common,
    { { &setup_pread_read_pfb_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pf8_2",
    &setup_pread_read_pf8_0_common,
    { { &setup_pread_read_pfb_2_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pf4_0",
    &setup_pread_read_pf4_0_common,
    { { &setup_pread_read_pf4_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pf4_1",
    &setup_pread_read_pf4_1_common,
    { { &setup_pread_read_pf4_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pf0_0",
    &setup_pread_read_pf0_0_common,
    { { &setup_pread_read_pf0_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pf0_1",
    &setup_pread_read_pf0_1_common,
    { { &setup_pread_read_pf0_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pe_0",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pfb_2_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pe_1",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pfc_2_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pdc_0",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pfb_2_proc0 }, { &setup_pread_read_pfc_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pdc_1",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pfc_2_proc0 }, { &setup_pread_read_pfc_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pdb_0",
    &setup_pread_read_pfb_0_common,
    { { &setup_pread_read_pfb_2_proc0 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pdb_1",
    &setup_pread_read_pfb_0_common,
    { { &setup_pread_read_pfc_2_proc0 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pda_0",
    &setup_pread_read_pda_0_common,
    { { &setup_pread_read_pda_0_proc0 }, { &setup_pread_read_pda_0_proc1 } },
    &setup_pread_read_pda_0_procfinal,
    &setup_pread_read_pda_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pda_1",
    &setup_pread_read_pfa_0_common,
    { { &setup_pread_read_pda_1_proc0 }, { &setup_pread_read_pda_1_proc1 } },
    &setup_pread_read_pfa_0_procfinal,
    &setup_pread_read_pfa_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pda_2",
    &setup_pread_read_pfa_3_common,
    { { &setup_pread_read_pfa_3_proc0 }, { &setup_pread_read_pfa_3_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pd8_0",
    &setup_pread_read_pf8_0_common,
    { { &setup_pread_read_pfb_2_proc0 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pd8_1",
    &setup_pread_read_pf8_0_common,
    { { &setup_pread_read_pfc_2_proc0 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pd4_0",
    &setup_pread_read_pf4_0_common,
    { { &setup_pread_read_pfb_2_proc0 }, { &setup_pread_read_pd4_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pd4_1",
    &setup_pread_read_pf4_0_common,
    { { &setup_pread_read_pfc_2_proc0 }, { &setup_pread_read_pd4_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pd0_0",
    &setup_pread_read_pf0_0_common,
    { { &setup_pread_read_pfb_2_proc0 }, { &setup_pread_read_pd0_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pd0_1",
    &setup_pread_read_pf0_0_common,
    { { &setup_pread_read_pfc_2_proc0 }, { &setup_pread_read_pd0_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pc_0",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pfb_2_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pc_1",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pfc_2_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pfc_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pbe_0",
    &setup_pread_read_pbe_0_common,
    { { &setup_pread_read_pbe_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pbe_1",
    &setup_pread_read_pbe_0_common,
    { { &setup_pread_read_pbe_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pbd8_0",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pbd8_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pbd8_1",
    &setup_pread_read_pbd8_1_common,
    { { &setup_pread_read_pbd8_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbd8_1_0, 0, "pread" },
      { &test_pread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pbd0_0",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pbd0_0_proc0 }, { &setup_pread_read_pfa_2_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pbd0_1",
    &setup_pread_read_pbd8_1_common,
    { { &setup_pread_read_pbd0_1_proc0 }, { &setup_pread_read_pfa_2_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbd8_1_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pbc_0",
    &setup_pread_read_pbc_0_common,
    { { &setup_pread_read_pbd8_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pbc_1",
    &setup_pread_read_pbc_0_common,
    { { &setup_pread_read_pbc_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pba_0",
    &setup_pread_read_pba_0_common,
    { { &setup_pread_read_pba_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pba_1",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pba_1_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pba_1_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pba_2",
    &setup_pread_read_pba_2_common,
    { { &setup_pread_read_pba_2_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_pba_2_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pba_3",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pba_3_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pba_1_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pba_4",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pba_4_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pba_5",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pba_5_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pba_6",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pb8_0",
    &setup_pread_read_pb8_0_common,
    { { &setup_pread_read_pb8_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pb8_1",
    &setup_pread_read_pb8_0_common,
    { { &setup_pread_read_pb8_1_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pb8_2",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_pba_5_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pba_1_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pb8_3",
    &setup_pread_read_pb8_3_common,
    { { &setup_pread_read_pb8_3_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pb8_3_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pb8_4",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pba_1_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pb0_0",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pb0_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pb0_1",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_pae_0",
    &setup_pread_read_pbe_0_common,
    { { &setup_pread_read_pae_0_proc0 }, { &setup_pread_read_pfc_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pae_1",
    &setup_pread_read_pbe_0_common,
    { { &setup_pread_read_pd0_0_proc1 }, { &setup_pread_read_pfc_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pad8_0",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pae_0_proc0 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pad8_1",
    &setup_pread_read_pbd8_1_common,
    { { &setup_pread_read_pad8_1_proc0 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbd8_1_0, 0, "pread" },
      { &test_pread_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pad0_0",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pad0_0_proc0 }, { &setup_pread_read_pfa_3_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pad0_1",
    &setup_pread_read_pbd8_1_common,
    { { &setup_pread_read_pad0_1_proc0 }, { &setup_pread_read_pfa_3_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbd8_1_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pac_0",
    &setup_pread_read_pbc_0_common,
    { { &setup_pread_read_pae_0_proc0 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pac_1",
    &setup_pread_read_pbc_0_common,
    { { &setup_pread_read_pd0_0_proc1 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_paa_0",
    &setup_pread_read_pba_0_common,
    { { &setup_pread_read_paa_0_proc0 }, { &setup_pread_read_paa_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_paa_1",
    &setup_pread_read_paa_1_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_paa_1_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_paa_2",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_paa_2_proc0 }, { &setup_pread_read_paa_2_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_paa_3",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_paa_0_proc0 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_paa_4",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_pba_6_proc0 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pa8_0",
    &setup_pread_read_pb8_0_common,
    { { &setup_pread_read_pa8_0_proc0 }, { &setup_pread_read_pa8_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pa8_1",
    &setup_pread_read_pb8_0_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_pa8_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pa8_2",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_pba_6_proc0 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pba_1_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pa8_3",
    &setup_pread_read_pb8_3_common,
    { { &setup_pread_read_pa8_3_proc0 }, { &setup_pread_read_pa8_3_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pb8_3_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pa0_0",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pb0_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_pa0_1",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_pbe_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p9e_0",
    &setup_pread_read_p9e_0_common,
    { { &setup_pread_read_p9e_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9e_1",
    &setup_pread_read_pf0_0_common,
    { { &setup_pread_read_pbe_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9d8_0",
    &setup_pread_read_p9d8_0_common,
    { { &setup_pread_read_p9d8_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9d8_1",
    &setup_pread_read_p9d8_1_common,
    { { &setup_pread_read_p9d8_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9d8_1_0, 0, "pread" },
      { &test_pread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9d0_0",
    &setup_pread_read_p9d8_0_common,
    { { &setup_pread_read_p9d0_0_proc0 }, { &setup_pread_read_pfa_2_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9d0_1",
    &setup_pread_read_p9d8_1_common,
    { { &setup_pread_read_p9d0_1_proc0 }, { &setup_pread_read_pfa_2_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9d8_1_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9c0_0",
    &setup_pread_read_pf0_1_common,
    { { &setup_pread_read_p9c0_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9c0_1",
    &setup_pread_read_p9c0_1_common,
    { { &setup_pread_read_pbc_1_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9a_0",
    &setup_pread_read_p9a_0_common,
    { { &setup_pread_read_pba_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9a_1",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_p9a_1_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9a_2",
    &setup_pread_read_p9a_2_common,
    { { &setup_pread_read_p9a_2_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_p9a_2_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9a_3",
    &setup_pread_read_p9a_3_common,
    { { &setup_pread_read_pa8_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9a_3_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p9a_4",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_p9a_4_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p98_0",
    &setup_pread_read_p98_0_common,
    { { &setup_pread_read_p98_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9d8_1_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p98_1",
    &setup_pread_read_p98_0_common,
    { { &setup_pread_read_pa8_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9d8_1_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p90_0",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_p90_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p90_1",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p8e_0",
    &setup_pread_read_p9e_0_common,
    { { &setup_pread_read_p8e_0_proc0 }, { &setup_pread_read_pfc_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8e_1",
    &setup_pread_read_pf0_0_common,
    { { &setup_pread_read_pd0_0_proc1 }, { &setup_pread_read_pfc_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8d8_0",
    &setup_pread_read_p9d8_0_common,
    { { &setup_pread_read_p8d8_0_proc0 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8d8_1",
    &setup_pread_read_p9d8_1_common,
    { { &setup_pread_read_p8d8_1_proc0 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9d8_1_0, 0, "pread" },
      { &test_pread_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8d0_0",
    &setup_pread_read_p9d8_0_common,
    { { &setup_pread_read_p8d0_0_proc0 }, { &setup_pread_read_pfa_3_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8d0_1",
    &setup_pread_read_p9d8_1_common,
    { { &setup_pread_read_p8d0_1_proc0 }, { &setup_pread_read_pfa_3_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9d8_1_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8c0_0",
    &setup_pread_read_pf0_1_common,
    { { &setup_pread_read_p8e_0_proc0 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8c0_1",
    &setup_pread_read_p9c0_1_common,
    { { &setup_pread_read_pd0_0_proc1 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8a_0",
    &setup_pread_read_p9a_0_common,
    { { &setup_pread_read_paa_0_proc0 }, { &setup_pread_read_paa_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8a_1",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_paa_2_proc1 }, { &setup_pread_read_paa_2_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8a_2",
    &setup_pread_read_p8a_2_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_p8a_2_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p8a_3",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_p8a_3_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p88_0",
    &setup_pread_read_p98_0_common,
    { { &setup_pread_read_pa8_0_proc0 }, { &setup_pread_read_pa8_0_proc0 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9d8_1_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p80_0",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_p90_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p80_1",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_pba_6_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p9e_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p78_0",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_p78_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p76_0",
    &setup_pread_read_pfb_0_common,
    { { &setup_pread_read_p76_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p74_0",
    &setup_pread_read_pfa_3_common,
    { { &setup_pread_read_p74_0_proc0 }, { &setup_pread_read_pfa_2_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p70_0",
    &setup_pread_read_pf8_0_common,
    { { &setup_pread_read_p76_0_proc0 }, { &setup_pread_read_pfc_0_proc1 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p68_0",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_p68_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p60_0",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_p60_0_proc0 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p4_0",
    &setup_pread_read_p4_0_common,
    { { &setup_pread_read_pba_0_proc1 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_procfinal,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p4_1",
    &setup_pread_read_p4_0_common,
    { { &setup_pread_read_pba_0_proc1 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_procfinal,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 0, "read" } },
    &cleanup },
  { "fs-pread_read_p38_0",
    &setup_pread_read_pfc_0_common,
    { { &setup_pread_read_pfc_0_proc1 }, { &setup_pread_read_pfc_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p36_0",
    &setup_pread_read_pfb_0_common,
    { { &setup_pread_read_pfc_0_proc1 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p34_0",
    &setup_pread_read_pfa_3_common,
    { { &setup_pread_read_pfa_2_proc1 }, { &setup_pread_read_pfa_3_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p30_0",
    &setup_pread_read_pf8_0_common,
    { { &setup_pread_read_pfc_0_proc1 }, { &setup_pread_read_pfb_2_proc0 } },
    &setup_pread_read_pfc_0_procfinal,
    &setup_pread_read_pfc_0_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p28_0",
    &setup_pread_read_pba_1_common,
    { { &setup_pread_read_pba_0_proc1 }, { &setup_pread_read_paa_0_proc0 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfa_3_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p20_0",
    &setup_pread_read_pb8_2_common,
    { { &setup_pread_read_pba_0_proc1 }, { &setup_pread_read_pba_6_proc0 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_1_final,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_read_p0_0",
    &setup_pread_read_p4_0_common,
    { { &setup_pread_read_pba_0_proc1 }, { &setup_pread_read_pba_0_proc1 } },
    &setup_pread_read_pba_0_procfinal,
    &setup_pread_read_pba_0_procfinal,
    { { &test_pread_read_p78_0_0, 0, "pread" },
      { &test_pread_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pread_rename_pf_0",
    &setup_pread_rename_pf_0_common,
    { { &setup_pread_rename_pf_0_proc0 }, { &setup_pread_rename_pf_0_proc1 } },
    &setup_pread_rename_pf_0_procfinal,
    &setup_pread_rename_pf_0_final,
    { { &test_pread_rename_pf_0_0, 0, "pread" },
      { &test_pread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pf_1",
    &setup_pread_rename_pf_0_common,
    { { &setup_pread_rename_pf_1_proc0 }, { &setup_pread_rename_pf_0_proc1 } },
    &setup_pread_rename_pf_0_procfinal,
    &setup_pread_rename_pf_0_final,
    { { &test_pread_rename_pf_0_0, 0, "pread" },
      { &test_pread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pe8_0",
    &setup_pread_rename_pe8_0_common,
    { { &setup_pread_rename_pf_0_proc0 }, { &setup_pread_rename_pf_0_proc1 } },
    &setup_pread_rename_pf_0_procfinal,
    &setup_pread_rename_pf_0_final,
    { { &test_pread_rename_pf_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pe8_1",
    &setup_pread_rename_pe8_0_common,
    { { &setup_pread_rename_pf_1_proc0 }, { &setup_pread_rename_pf_0_proc1 } },
    &setup_pread_rename_pf_0_procfinal,
    &setup_pread_rename_pf_0_final,
    { { &test_pread_rename_pf_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pe0_0",
    &setup_pread_rename_pf_0_common,
    { { &setup_pread_rename_pf_0_proc0 }, { &setup_pread_rename_pf_0_proc1 } },
    &setup_pread_rename_pf_0_procfinal,
    &setup_pread_rename_pf_0_final,
    { { &test_pread_rename_pf_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pe0_1",
    &setup_pread_rename_pf_0_common,
    { { &setup_pread_rename_pf_1_proc0 }, { &setup_pread_rename_pf_0_proc1 } },
    &setup_pread_rename_pf_0_procfinal,
    &setup_pread_rename_pf_0_final,
    { { &test_pread_rename_pf_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pc_0",
    &setup_pread_rename_pc_0_common,
    { { &setup_pread_rename_pf_0_proc0 }, { &setup_pread_rename_pf_0_proc1 } },
    &setup_pread_rename_pf_0_procfinal,
    &setup_pread_rename_pf_0_final,
    { { &test_pread_rename_pf_0_0, 0, "pread" },
      { &test_pread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pc_1",
    &setup_pread_rename_pc_0_common,
    { { &setup_pread_rename_pf_1_proc0 }, { &setup_pread_rename_pf_0_proc1 } },
    &setup_pread_rename_pf_0_procfinal,
    &setup_pread_rename_pf_0_final,
    { { &test_pread_rename_pf_0_0, 0, "pread" },
      { &test_pread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pb8_0",
    &setup_pread_rename_pb8_0_common,
    { { &setup_pread_rename_pb8_0_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_pb8_0_0, 0, "pread" },
      { &test_pread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pb8_1",
    &setup_pread_rename_pb8_0_common,
    { { &setup_pread_rename_pb8_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_pb8_0_0, 0, "pread" },
      { &test_pread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pb4_0",
    &setup_pread_rename_pb4_0_common,
    { { &setup_pread_rename_pb4_0_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb4_0_final,
    { { &test_pread_rename_pb8_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pb4_1",
    &setup_pread_rename_pb4_0_common,
    { { &setup_pread_rename_pb4_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb4_0_final,
    { { &test_pread_rename_pb4_1_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pb4_2",
    &setup_pread_rename_pb4_2_common,
    { { &setup_pread_rename_pb4_2_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb4_2_final,
    { { &test_pread_rename_pb8_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pb4_3",
    &setup_pread_rename_pb4_2_common,
    { { &setup_pread_rename_pb4_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb4_2_final,
    { { &test_pread_rename_pb4_1_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pb4_4",
    &setup_pread_rename_pb4_4_common,
    { { &setup_pread_rename_pb4_2_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_pb8_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pb4_5",
    &setup_pread_rename_pb4_4_common,
    { { &setup_pread_rename_pb8_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_pb8_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pb0_0",
    &setup_pread_rename_pb8_0_common,
    { { &setup_pread_rename_pb8_0_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_pb8_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pb0_1",
    &setup_pread_rename_pb8_0_common,
    { { &setup_pread_rename_pb8_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_pb8_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pa_0",
    &setup_pread_rename_pa_0_common,
    { { &setup_pread_rename_pb8_0_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_pb8_0_0, 0, "pread" },
      { &test_pread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_pa_1",
    &setup_pread_rename_pa_0_common,
    { { &setup_pread_rename_pb8_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_pb8_0_0, 0, "pread" },
      { &test_pread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p98_0",
    &setup_pread_rename_p98_0_common,
    { { &setup_pread_rename_pb8_0_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p98_1",
    &setup_pread_rename_p98_0_common,
    { { &setup_pread_rename_pb8_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p94_0",
    &setup_pread_rename_p94_0_common,
    { { &setup_pread_rename_pb4_0_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb4_0_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p94_1",
    &setup_pread_rename_p94_0_common,
    { { &setup_pread_rename_pb8_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb4_0_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p94_2",
    &setup_pread_rename_p94_2_common,
    { { &setup_pread_rename_pb4_2_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb4_2_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p94_3",
    &setup_pread_rename_p94_3_common,
    { { &setup_pread_rename_p94_3_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p94_4",
    &setup_pread_rename_p94_2_common,
    { { &setup_pread_rename_pb8_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb4_2_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p94_5",
    &setup_pread_rename_p94_3_common,
    { { &setup_pread_rename_pb8_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p90_0",
    &setup_pread_rename_p98_0_common,
    { { &setup_pread_rename_pb8_0_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p90_1",
    &setup_pread_rename_p98_0_common,
    { { &setup_pread_rename_pb8_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p80_0",
    &setup_pread_rename_p80_0_common,
    { { &setup_pread_rename_pb8_0_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p80_1",
    &setup_pread_rename_p80_0_common,
    { { &setup_pread_rename_pb8_1_proc0 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p98_0_0, 0, "pread" },
      { &test_pread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p6_0",
    &setup_pread_rename_pb8_0_common,
    { { &setup_pread_rename_pb8_0_proc1 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p6_0_0, 0, "pread" },
      { &test_pread_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p50_0",
    &setup_pread_rename_pb4_4_common,
    { { &setup_pread_rename_pb8_0_proc1 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p6_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p4_0",
    &setup_pread_rename_pb8_0_common,
    { { &setup_pread_rename_pb8_0_proc1 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_final,
    { { &test_pread_rename_p6_0_0, 0, "pread" },
      { &test_pread_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_rename_p0_0",
    &setup_pread_rename_p0_0_common,
    { { &setup_pread_rename_pb8_0_proc1 }, { &setup_pread_rename_pb8_0_proc1 } },
    &setup_pread_rename_pb8_0_procfinal,
    &setup_pread_rename_pb8_0_procfinal,
    { { &test_pread_rename_p6_0_0, 0, "pread" },
      { &test_pread_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pread_stat_pe_0",
    &setup_pread_stat_pe_0_common,
    { { &setup_pread_stat_pe_0_proc0 }, { &setup_pread_stat_pe_0_proc1 } },
    &setup_pread_stat_pe_0_procfinal,
    &setup_pread_stat_pe_0_final,
    { { &test_pread_stat_pe_0_0, 0, "pread" },
      { &test_pread_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_pe_1",
    &setup_pread_stat_pe_0_common,
    { { &setup_pread_stat_pe_1_proc0 }, { &setup_pread_stat_pe_0_proc1 } },
    &setup_pread_stat_pe_0_procfinal,
    &setup_pread_stat_pe_0_final,
    { { &test_pread_stat_pe_0_0, 0, "pread" },
      { &test_pread_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_pc_0",
    &setup_pread_stat_pc_0_common,
    { { &setup_pread_stat_pe_0_proc0 }, { &setup_pread_stat_pe_0_proc1 } },
    &setup_pread_stat_pe_0_procfinal,
    &setup_pread_stat_pe_0_final,
    { { &test_pread_stat_pe_0_0, 0, "pread" },
      { &test_pread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_pc_1",
    &setup_pread_stat_pc_0_common,
    { { &setup_pread_stat_pe_1_proc0 }, { &setup_pread_stat_pe_0_proc1 } },
    &setup_pread_stat_pe_0_procfinal,
    &setup_pread_stat_pe_0_final,
    { { &test_pread_stat_pe_0_0, 0, "pread" },
      { &test_pread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_pb_0",
    &setup_pread_stat_pb_0_common,
    { { &setup_pread_stat_pb_0_proc0 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_pb_0_final,
    { { &test_pread_stat_pb_0_0, 0, "pread" },
      { &test_pread_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_pb_1",
    &setup_pread_stat_pb_0_common,
    { { &setup_pread_stat_pb_1_proc0 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_pb_0_final,
    { { &test_pread_stat_pb_0_0, 0, "pread" },
      { &test_pread_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_pa_0",
    &setup_pread_stat_pa_0_common,
    { { &setup_pread_stat_pb_0_proc0 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_pb_0_final,
    { { &test_pread_stat_pb_0_0, 0, "pread" },
      { &test_pread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_pa_1",
    &setup_pread_stat_pa_0_common,
    { { &setup_pread_stat_pb_1_proc0 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_pb_0_final,
    { { &test_pread_stat_pb_0_0, 0, "pread" },
      { &test_pread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_p98_0",
    &setup_pread_stat_p98_0_common,
    { { &setup_pread_stat_p98_0_proc0 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_p98_0_final,
    { { &test_pread_stat_p98_0_0, 0, "pread" },
      { &test_pread_stat_p98_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_p98_1",
    &setup_pread_stat_p98_1_common,
    { { &setup_pread_stat_pb_0_proc0 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_pb_0_final,
    { { &test_pread_stat_p98_0_0, 0, "pread" },
      { &test_pread_stat_p98_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_p98_2",
    &setup_pread_stat_p98_0_common,
    { { &setup_pread_stat_pb_1_proc0 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_p98_0_final,
    { { &test_pread_stat_p98_0_0, 0, "pread" },
      { &test_pread_stat_p98_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_p98_3",
    &setup_pread_stat_p98_1_common,
    { { &setup_pread_stat_pb_1_proc0 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_pb_0_final,
    { { &test_pread_stat_p98_0_0, 0, "pread" },
      { &test_pread_stat_p98_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_p80_0",
    &setup_pread_stat_p80_0_common,
    { { &setup_pread_stat_pb_0_proc0 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_pb_0_final,
    { { &test_pread_stat_p98_0_0, 0, "pread" },
      { &test_pread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_p80_1",
    &setup_pread_stat_p80_0_common,
    { { &setup_pread_stat_pb_1_proc0 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_pb_0_final,
    { { &test_pread_stat_p98_0_0, 0, "pread" },
      { &test_pread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_p4_0",
    &setup_pread_stat_pb_0_common,
    { { &setup_pread_stat_pb_0_proc1 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_pb_0_final,
    { { &test_pread_stat_p4_0_0, 0, "pread" },
      { &test_pread_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_stat_p0_0",
    &setup_pread_stat_p0_0_common,
    { { &setup_pread_stat_pb_0_proc1 }, { &setup_pread_stat_pb_0_proc1 } },
    &setup_pread_stat_pb_0_procfinal,
    &setup_pread_stat_pb_0_procfinal,
    { { &test_pread_stat_p4_0_0, 0, "pread" },
      { &test_pread_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pread_unlink_pe_0",
    &setup_pread_unlink_pe_0_common,
    { { &setup_pread_unlink_pe_0_proc0 }, { &setup_pread_unlink_pe_0_proc1 } },
    &setup_pread_unlink_pe_0_procfinal,
    &setup_pread_unlink_pe_0_final,
    { { &test_pread_unlink_pe_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_pe_1",
    &setup_pread_unlink_pe_0_common,
    { { &setup_pread_unlink_pe_1_proc0 }, { &setup_pread_unlink_pe_0_proc1 } },
    &setup_pread_unlink_pe_0_procfinal,
    &setup_pread_unlink_pe_0_final,
    { { &test_pread_unlink_pe_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_pc_0",
    &setup_pread_unlink_pc_0_common,
    { { &setup_pread_unlink_pe_0_proc0 }, { &setup_pread_unlink_pe_0_proc1 } },
    &setup_pread_unlink_pe_0_procfinal,
    &setup_pread_unlink_pe_0_final,
    { { &test_pread_unlink_pe_0_0, 0, "pread" },
      { &test_pread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_pc_1",
    &setup_pread_unlink_pc_0_common,
    { { &setup_pread_unlink_pe_1_proc0 }, { &setup_pread_unlink_pe_0_proc1 } },
    &setup_pread_unlink_pe_0_procfinal,
    &setup_pread_unlink_pe_0_final,
    { { &test_pread_unlink_pe_0_0, 0, "pread" },
      { &test_pread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_pb0_0",
    &setup_pread_unlink_pb0_0_common,
    { { &setup_pread_unlink_pb0_0_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_0_final,
    { { &test_pread_unlink_pb0_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_pb0_1",
    &setup_pread_unlink_pb0_0_common,
    { { &setup_pread_unlink_pb0_1_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_0_final,
    { { &test_pread_unlink_pb0_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_pb0_2",
    &setup_pread_unlink_pb0_2_common,
    { { &setup_pread_unlink_pb0_2_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_2_final,
    { { &test_pread_unlink_pb0_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_pb0_3",
    &setup_pread_unlink_pb0_2_common,
    { { &setup_pread_unlink_pb0_1_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_2_final,
    { { &test_pread_unlink_pb0_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_pa_0",
    &setup_pread_unlink_pa_0_common,
    { { &setup_pread_unlink_pa_0_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_2_final,
    { { &test_pread_unlink_pb0_0_0, 0, "pread" },
      { &test_pread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_pa_1",
    &setup_pread_unlink_pa_0_common,
    { { &setup_pread_unlink_pb0_1_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_2_final,
    { { &test_pread_unlink_pb0_0_0, 0, "pread" },
      { &test_pread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_p90_0",
    &setup_pread_unlink_p90_0_common,
    { { &setup_pread_unlink_pb0_0_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_0_final,
    { { &test_pread_unlink_p90_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_p90_1",
    &setup_pread_unlink_p90_0_common,
    { { &setup_pread_unlink_pb0_1_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_0_final,
    { { &test_pread_unlink_p90_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_p90_2",
    &setup_pread_unlink_p90_2_common,
    { { &setup_pread_unlink_pb0_2_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_2_final,
    { { &test_pread_unlink_p90_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_p90_3",
    &setup_pread_unlink_p90_2_common,
    { { &setup_pread_unlink_pb0_1_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_2_final,
    { { &test_pread_unlink_p90_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_p80_0",
    &setup_pread_unlink_p80_0_common,
    { { &setup_pread_unlink_pa_0_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_2_final,
    { { &test_pread_unlink_p90_0_0, 0, "pread" },
      { &test_pread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_p80_1",
    &setup_pread_unlink_p80_0_common,
    { { &setup_pread_unlink_pb0_1_proc0 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_2_final,
    { { &test_pread_unlink_p90_0_0, 0, "pread" },
      { &test_pread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_p4_0",
    &setup_pread_unlink_pb0_2_common,
    { { &setup_pread_unlink_pb0_0_proc1 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_2_final,
    { { &test_pread_unlink_p4_0_0, 0, "pread" },
      { &test_pread_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_unlink_p0_0",
    &setup_pread_unlink_p0_0_common,
    { { &setup_pread_unlink_pb0_0_proc1 }, { &setup_pread_unlink_pb0_0_proc1 } },
    &setup_pread_unlink_pb0_0_procfinal,
    &setup_pread_unlink_pb0_0_procfinal,
    { { &test_pread_unlink_p4_0_0, 0, "pread" },
      { &test_pread_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pread_write_pfe_0",
    &setup_pread_write_pfe_0_common,
    { { &setup_pread_write_pfe_0_proc0 }, { &setup_pread_write_pfe_0_proc1 } },
    &setup_pread_write_pfe_0_procfinal,
    &setup_pread_write_pfe_0_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pfe_1",
    &setup_pread_write_pfe_0_common,
    { { &setup_pread_write_pfe_1_proc0 }, { &setup_pread_write_pfe_0_proc1 } },
    &setup_pread_write_pfe_0_procfinal,
    &setup_pread_write_pfe_0_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pfe_2",
    &setup_pread_write_pfe_2_common,
    { { &setup_pread_write_pfe_2_proc0 }, { &setup_pread_write_pfe_2_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pfe_3",
    &setup_pread_write_pfe_2_common,
    { { &setup_pread_write_pfe_3_proc0 }, { &setup_pread_write_pfe_2_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfe_3_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pfc_0",
    &setup_pread_write_pfc_0_common,
    { { &setup_pread_write_pfc_0_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pfc_1",
    &setup_pread_write_pfc_0_common,
    { { &setup_pread_write_pfc_1_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pfc_2",
    &setup_pread_write_pfc_0_common,
    { { &setup_pread_write_pfc_2_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pf8_0",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_pf8_0_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pf8_1",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_pf8_1_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pf8_2",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_pf8_2_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pf4_0",
    &setup_pread_write_pf4_0_common,
    { { &setup_pread_write_pf4_0_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pf4_1",
    &setup_pread_write_pf4_1_common,
    { { &setup_pread_write_pf4_1_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pf0_0",
    &setup_pread_write_pf0_0_common,
    { { &setup_pread_write_pf4_0_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pf0_1",
    &setup_pread_write_pf0_1_common,
    { { &setup_pread_write_pf4_1_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pe_0",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_pf8_2_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pe_1",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_pfc_2_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pde_0",
    &setup_pread_write_pde_0_common,
    { { &setup_pread_write_pde_0_proc0 }, { &setup_pread_write_pde_0_proc1 } },
    &setup_pread_write_pfe_0_procfinal,
    &setup_pread_write_pfe_0_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pde_1",
    &setup_pread_write_pde_0_common,
    { { &setup_pread_write_pde_1_proc0 }, { &setup_pread_write_pde_0_proc1 } },
    &setup_pread_write_pfe_0_procfinal,
    &setup_pread_write_pfe_0_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pde_2",
    &setup_pread_write_pde_2_common,
    { { &setup_pread_write_pfe_3_proc0 }, { &setup_pread_write_pfe_3_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pdc_0",
    &setup_pread_write_pfc_0_common,
    { { &setup_pread_write_pf8_2_proc0 }, { &setup_pread_write_pfc_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pdc_1",
    &setup_pread_write_pfc_0_common,
    { { &setup_pread_write_pfc_2_proc0 }, { &setup_pread_write_pfc_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pd8_0",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_pf8_2_proc0 }, { &setup_pread_write_pf8_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pd8_1",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_pfc_2_proc0 }, { &setup_pread_write_pf8_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pd4_0",
    &setup_pread_write_pf4_0_common,
    { { &setup_pread_write_pf8_2_proc0 }, { &setup_pread_write_pd4_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pd4_1",
    &setup_pread_write_pf4_0_common,
    { { &setup_pread_write_pfc_2_proc0 }, { &setup_pread_write_pd4_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pd0_0",
    &setup_pread_write_pf0_0_common,
    { { &setup_pread_write_pf8_2_proc0 }, { &setup_pread_write_pd4_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pd0_1",
    &setup_pread_write_pf0_0_common,
    { { &setup_pread_write_pfc_2_proc0 }, { &setup_pread_write_pd4_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pc_0",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_pf8_2_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pc_1",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_pfc_2_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pfe_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pbf_0",
    &setup_pread_write_pbf_0_common,
    { { &setup_pread_write_pbf_0_proc0 }, { &setup_pread_write_pfe_2_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pbf_1",
    &setup_pread_write_pbf_0_common,
    { { &setup_pread_write_pbf_1_proc0 }, { &setup_pread_write_pfe_2_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pbe_0",
    &setup_pread_write_pbe_0_common,
    { { &setup_pread_write_pbe_0_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pbe_1",
    &setup_pread_write_pbe_0_common,
    { { &setup_pread_write_pbe_1_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pbc_0",
    &setup_pread_write_pbe_0_common,
    { { &setup_pread_write_pbc_0_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pbc_1",
    &setup_pread_write_pbe_0_common,
    { { &setup_pread_write_pbc_1_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pbb0_0",
    &setup_pread_write_pbb0_0_common,
    { { &setup_pread_write_pbb0_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pbb0_1",
    &setup_pread_write_pbb0_1_common,
    { { &setup_pread_write_pbb0_1_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_pbb0_1_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pbb0_2",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_pbb0_2_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbb0_2_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pbb0_3",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_pbb0_3_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbb0_2_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pbb0_4",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbb0_2_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pb8_0",
    &setup_pread_write_pb8_0_common,
    { { &setup_pread_write_pb8_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pb8_1",
    &setup_pread_write_pb8_1_common,
    { { &setup_pread_write_pb8_1_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_pb8_1_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pb8_2",
    &setup_pread_write_pb8_2_common,
    { { &setup_pread_write_pbb0_2_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbb0_2_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pb8_3",
    &setup_pread_write_pb8_3_common,
    { { &setup_pread_write_pb8_3_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pb8_3_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pb8_4",
    &setup_pread_write_pb8_2_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbb0_2_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pb0_0",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_pb0_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_pb0_1",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_paf_0",
    &setup_pread_write_pbf_0_common,
    { { &setup_pread_write_paf_0_proc0 }, { &setup_pread_write_pfe_3_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_paf_1",
    &setup_pread_write_pbf_0_common,
    { { &setup_pread_write_paf_1_proc0 }, { &setup_pread_write_pfe_3_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pae_0",
    &setup_pread_write_pbe_0_common,
    { { &setup_pread_write_pae_0_proc0 }, { &setup_pread_write_pfc_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pae_1",
    &setup_pread_write_pbe_0_common,
    { { &setup_pread_write_pd4_0_proc1 }, { &setup_pread_write_pfc_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pac_0",
    &setup_pread_write_pbe_0_common,
    { { &setup_pread_write_pae_0_proc0 }, { &setup_pread_write_pf8_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pac_1",
    &setup_pread_write_pbe_0_common,
    { { &setup_pread_write_pd4_0_proc1 }, { &setup_pread_write_pf8_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pab0_0",
    &setup_pread_write_pbb0_0_common,
    { { &setup_pread_write_pab0_0_proc0 }, { &setup_pread_write_pab0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pab0_1",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pbb0_4_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbb0_2_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pab0_2",
    &setup_pread_write_pab0_2_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pab0_2_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pab0_3",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_pab0_0_proc0 }, { &setup_pread_write_pbb0_4_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbb0_2_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pa8_0",
    &setup_pread_write_pb8_0_common,
    { { &setup_pread_write_pa8_0_proc0 }, { &setup_pread_write_pab0_2_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pa8_1",
    &setup_pread_write_pb8_0_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pab0_2_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pa8_2",
    &setup_pread_write_pb8_2_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pbb0_4_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbb0_2_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pa8_3",
    &setup_pread_write_pb8_3_common,
    { { &setup_pread_write_pa8_3_proc0 }, { &setup_pread_write_pa8_3_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pb8_3_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pa0_0",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_pb0_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_pa0_1",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_pbf_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p9f0_0",
    &setup_pread_write_p9f0_0_common,
    { { &setup_pread_write_pbf_0_proc0 }, { &setup_pread_write_pfe_2_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p9f0_1",
    &setup_pread_write_p9f0_1_common,
    { { &setup_pread_write_pbf_1_proc0 }, { &setup_pread_write_pfe_2_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p9e0_0",
    &setup_pread_write_p9e0_0_common,
    { { &setup_pread_write_p9e0_0_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p9e0_1",
    &setup_pread_write_pf0_0_common,
    { { &setup_pread_write_pbe_1_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p9c_0",
    &setup_pread_write_p9f0_0_common,
    { { &setup_pread_write_p9c_0_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p9c_1",
    &setup_pread_write_p9f0_1_common,
    { { &setup_pread_write_pbc_1_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p9a_0",
    &setup_pread_write_p9a_0_common,
    { { &setup_pread_write_p9a_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9a_0_0, 0, "pread" },
      { &test_pread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p9a_1",
    &setup_pread_write_p9a_1_common,
    { { &setup_pread_write_p9a_1_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p9a_2",
    &setup_pread_write_p9a_2_common,
    { { &setup_pread_write_p9a_2_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p9a_3",
    &setup_pread_write_p9a_3_common,
    { { &setup_pread_write_pa8_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9a_3_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p990_0",
    &setup_pread_write_p990_0_common,
    { { &setup_pread_write_p990_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p990_1",
    &setup_pread_write_p990_1_common,
    { { &setup_pread_write_p990_1_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_p990_1_0, 0, "pread" },
      { &test_pread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p990_2",
    &setup_pread_write_p990_2_common,
    { { &setup_pread_write_p990_2_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p990_2_0, 0, "pread" },
      { &test_pread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p990_3",
    &setup_pread_write_p990_0_common,
    { { &setup_pread_write_p9a_2_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_p9a_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p990_4",
    &setup_pread_write_p990_4_common,
    { { &setup_pread_write_pbb0_2_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p990_5",
    &setup_pread_write_p990_2_common,
    { { &setup_pread_write_p990_5_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p990_2_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p990_6",
    &setup_pread_write_p990_6_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p90_0",
    &setup_pread_write_pb8_2_common,
    { { &setup_pread_write_p90_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p90_1",
    &setup_pread_write_pb8_2_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p8f0_0",
    &setup_pread_write_p9f0_0_common,
    { { &setup_pread_write_paf_0_proc0 }, { &setup_pread_write_pfe_3_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p8f0_1",
    &setup_pread_write_p9f0_1_common,
    { { &setup_pread_write_paf_1_proc0 }, { &setup_pread_write_pfe_3_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p8e0_0",
    &setup_pread_write_p9e0_0_common,
    { { &setup_pread_write_p8e0_0_proc0 }, { &setup_pread_write_pfc_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p8e0_1",
    &setup_pread_write_pf0_0_common,
    { { &setup_pread_write_pd4_0_proc1 }, { &setup_pread_write_pfc_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p8c_0",
    &setup_pread_write_p9f0_0_common,
    { { &setup_pread_write_p8e0_0_proc0 }, { &setup_pread_write_pf8_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p8c_1",
    &setup_pread_write_p9f0_1_common,
    { { &setup_pread_write_pd4_0_proc1 }, { &setup_pread_write_pf8_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p8a_0",
    &setup_pread_write_p9a_0_common,
    { { &setup_pread_write_p8a_0_proc0 }, { &setup_pread_write_p90_0_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9a_0_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p8a_1",
    &setup_pread_write_p8a_1_common,
    { { &setup_pread_write_pa8_3_proc1 }, { &setup_pread_write_p8a_1_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_p8a_1_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p8a_2",
    &setup_pread_write_p8a_2_common,
    { { &setup_pread_write_pa8_0_proc0 }, { &setup_pread_write_p8a_1_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_p8a_1_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p8a_3",
    &setup_pread_write_p9a_3_common,
    { { &setup_pread_write_p90_0_proc0 }, { &setup_pread_write_pa8_0_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9a_3_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p890_0",
    &setup_pread_write_p990_0_common,
    { { &setup_pread_write_p890_0_proc0 }, { &setup_pread_write_pab0_0_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p890_1",
    &setup_pread_write_p890_1_common,
    { { &setup_pread_write_p890_1_proc0 }, { &setup_pread_write_p890_1_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_p990_2_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p890_2",
    &setup_pread_write_p890_2_common,
    { { &setup_pread_write_pb0_0_proc0 }, { &setup_pread_write_p890_2_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_final,
    { { &test_pread_write_p990_2_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p890_3",
    &setup_pread_write_p890_3_common,
    { { &setup_pread_write_pab0_0_proc0 }, { &setup_pread_write_pab0_0_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p990_2_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p890_4",
    &setup_pread_write_p890_3_common,
    { { &setup_pread_write_pb0_0_proc0 }, { &setup_pread_write_pab0_0_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p990_2_0, 0, "pread" },
      { &test_pread_write_p9a_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p890_5",
    &setup_pread_write_p990_4_common,
    { { &setup_pread_write_pab0_0_proc0 }, { &setup_pread_write_pab0_0_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p990_1_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p80_0",
    &setup_pread_write_pb8_2_common,
    { { &setup_pread_write_p90_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p80_1",
    &setup_pread_write_pb8_2_common,
    { { &setup_pread_write_pbb0_4_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p9f0_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p7c_0",
    &setup_pread_write_pfe_2_common,
    { { &setup_pread_write_p7c_0_proc0 }, { &setup_pread_write_pfe_2_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p78_0",
    &setup_pread_write_pfc_0_common,
    { { &setup_pread_write_p78_0_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p70_0",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_p70_0_proc0 }, { &setup_pread_write_pfc_0_proc1 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p68_0",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_p68_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p60_0",
    &setup_pread_write_pb8_2_common,
    { { &setup_pread_write_p68_0_proc0 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p4_0",
    &setup_pread_write_p4_0_common,
    { { &setup_pread_write_pbb0_0_proc1 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_procfinal,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p4_1",
    &setup_pread_write_p4_0_common,
    { { &setup_pread_write_pbb0_0_proc1 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_procfinal,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 0, "write" } },
    &cleanup },
  { "fs-pread_write_p3c_0",
    &setup_pread_write_pde_2_common,
    { { &setup_pread_write_pfe_2_proc1 }, { &setup_pread_write_pfe_3_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p38_0",
    &setup_pread_write_pfc_0_common,
    { { &setup_pread_write_pfc_0_proc1 }, { &setup_pread_write_pfc_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p30_0",
    &setup_pread_write_pf8_0_common,
    { { &setup_pread_write_pfc_0_proc1 }, { &setup_pread_write_pf8_2_proc0 } },
    &setup_pread_write_pfe_2_procfinal,
    &setup_pread_write_pfe_2_final,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p28_0",
    &setup_pread_write_pbb0_2_common,
    { { &setup_pread_write_pbb0_0_proc1 }, { &setup_pread_write_pbb0_4_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p20_0",
    &setup_pread_write_pb8_2_common,
    { { &setup_pread_write_pbb0_0_proc1 }, { &setup_pread_write_pbb0_4_proc0 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_2_final,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pread_write_p0_0",
    &setup_pread_write_p4_0_common,
    { { &setup_pread_write_pbb0_0_proc1 }, { &setup_pread_write_pbb0_0_proc1 } },
    &setup_pread_write_pbb0_0_procfinal,
    &setup_pread_write_pbb0_0_procfinal,
    { { &test_pread_write_p7c_0_0, 0, "pread" },
      { &test_pread_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf8_0",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_0_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf8_1",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_1_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf8_2",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_2_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf8_3",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_3_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf8_4",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_4_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf4_0",
    &setup_pwrite_pwrite_pf4_0_common,
    { { &setup_pwrite_pwrite_pf4_0_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf4_1",
    &setup_pwrite_pwrite_pf4_1_common,
    { { &setup_pwrite_pwrite_pf4_1_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf4_2",
    &setup_pwrite_pwrite_pf4_1_common,
    { { &setup_pwrite_pwrite_pf4_2_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf4_3",
    &setup_pwrite_pwrite_pf4_1_common,
    { { &setup_pwrite_pwrite_pf4_3_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf0_0",
    &setup_pwrite_pwrite_pf0_0_common,
    { { &setup_pwrite_pwrite_pf0_0_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf0_1",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_pf4_1_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf0_2",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_pf0_2_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pf0_3",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_pf4_3_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pe_0",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_3_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pe_1",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_4_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd8_0",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_3_proc0 }, { &setup_pwrite_pwrite_pf8_3_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd8_1",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_4_proc0 }, { &setup_pwrite_pwrite_pf8_3_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd8_2",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_3_proc0 }, { &setup_pwrite_pwrite_pf8_4_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd8_3",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_4_proc0 }, { &setup_pwrite_pwrite_pf8_4_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd4_0",
    &setup_pwrite_pwrite_pf4_0_common,
    { { &setup_pwrite_pwrite_pf8_3_proc0 }, { &setup_pwrite_pwrite_pd4_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd4_1",
    &setup_pwrite_pwrite_pf4_1_common,
    { { &setup_pwrite_pwrite_pf8_3_proc0 }, { &setup_pwrite_pwrite_pd4_1_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd4_2",
    &setup_pwrite_pwrite_pf4_1_common,
    { { &setup_pwrite_pwrite_pf8_4_proc0 }, { &setup_pwrite_pwrite_pd4_2_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd4_3",
    &setup_pwrite_pwrite_pf4_0_common,
    { { &setup_pwrite_pwrite_pf8_4_proc0 }, { &setup_pwrite_pwrite_pd4_1_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd0_0",
    &setup_pwrite_pwrite_pf0_0_common,
    { { &setup_pwrite_pwrite_pf8_3_proc0 }, { &setup_pwrite_pwrite_pd0_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd0_1",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_pf8_3_proc0 }, { &setup_pwrite_pwrite_pd4_1_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd0_2",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_pf8_4_proc0 }, { &setup_pwrite_pwrite_pd4_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pd0_3",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_pf8_4_proc0 }, { &setup_pwrite_pwrite_pd4_1_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pc_0",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_3_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pc_1",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_4_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pf8_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pbc_0",
    &setup_pwrite_pwrite_pf4_0_common,
    { { &setup_pwrite_pwrite_pbc_0_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pbc_1",
    &setup_pwrite_pwrite_pf4_1_common,
    { { &setup_pwrite_pwrite_pbc_1_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pbc_2",
    &setup_pwrite_pwrite_pf4_1_common,
    { { &setup_pwrite_pwrite_pbc_2_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pbc_3",
    &setup_pwrite_pwrite_pf4_1_common,
    { { &setup_pwrite_pwrite_pbc_3_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pba_0",
    &setup_pwrite_pwrite_pba_0_common,
    { { &setup_pwrite_pwrite_pba_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pba_1",
    &setup_pwrite_pwrite_pba_1_common,
    { { &setup_pwrite_pwrite_pba_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pba_1_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb90_0",
    &setup_pwrite_pwrite_pb90_0_common,
    { { &setup_pwrite_pwrite_pb90_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb90_1",
    &setup_pwrite_pwrite_pb90_0_common,
    { { &setup_pwrite_pwrite_pb90_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_0_0, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb90_2",
    &setup_pwrite_pwrite_pb90_2_common,
    { { &setup_pwrite_pwrite_pb90_2_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb90_3",
    &setup_pwrite_pwrite_pb90_2_common,
    { { &setup_pwrite_pwrite_pb90_3_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb90_4",
    &setup_pwrite_pwrite_pb90_4_common,
    { { &setup_pwrite_pwrite_pb90_4_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb80_0",
    &setup_pwrite_pwrite_pb80_0_common,
    { { &setup_pwrite_pwrite_pb90_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb80_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb80_1",
    &setup_pwrite_pwrite_pb80_1_common,
    { { &setup_pwrite_pwrite_pb80_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb80_2",
    &setup_pwrite_pwrite_pb80_2_common,
    { { &setup_pwrite_pwrite_pb80_2_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb80_3",
    &setup_pwrite_pwrite_pb80_3_common,
    { { &setup_pwrite_pwrite_pb80_3_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb80_4",
    &setup_pwrite_pwrite_pb80_4_common,
    { { &setup_pwrite_pwrite_pb80_4_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb80_5",
    &setup_pwrite_pwrite_pb80_2_common,
    { { &setup_pwrite_pwrite_pb80_5_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb80_6",
    &setup_pwrite_pwrite_pb80_6_common,
    { { &setup_pwrite_pwrite_pb90_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb80_6_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_6_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb80_7",
    &setup_pwrite_pwrite_pb80_2_common,
    { { &setup_pwrite_pwrite_pb80_7_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_7_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb0_0",
    &setup_pwrite_pwrite_pb0_0_common,
    { { &setup_pwrite_pwrite_pb0_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pb0_1",
    &setup_pwrite_pwrite_pb0_0_common,
    { { &setup_pwrite_pwrite_pb0_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pac_0",
    &setup_pwrite_pwrite_pf4_0_common,
    { { &setup_pwrite_pwrite_pd4_2_proc1 }, { &setup_pwrite_pwrite_pf8_3_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pac_1",
    &setup_pwrite_pwrite_pf4_1_common,
    { { &setup_pwrite_pwrite_pd4_1_proc1 }, { &setup_pwrite_pwrite_pf8_3_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pac_2",
    &setup_pwrite_pwrite_pf4_1_common,
    { { &setup_pwrite_pwrite_pac_2_proc0 }, { &setup_pwrite_pwrite_pf8_4_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pac_3",
    &setup_pwrite_pwrite_pf4_0_common,
    { { &setup_pwrite_pwrite_pd4_1_proc1 }, { &setup_pwrite_pwrite_pf8_4_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_paa_0",
    &setup_pwrite_pwrite_pb80_1_common,
    { { &setup_pwrite_pwrite_pb90_1_proc0 }, { &setup_pwrite_pwrite_paa_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_paa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_paa_1",
    &setup_pwrite_pwrite_paa_1_common,
    { { &setup_pwrite_pwrite_paa_1_proc0 }, { &setup_pwrite_pwrite_paa_1_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_paa_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_paa_2",
    &setup_pwrite_pwrite_paa_2_common,
    { { &setup_pwrite_pwrite_paa_2_proc0 }, { &setup_pwrite_pwrite_paa_2_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pba_1_0, 0, "pwrite" },
      { &test_pwrite_pwrite_paa_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pa90_0",
    &setup_pwrite_pwrite_pa90_0_common,
    { { &setup_pwrite_pwrite_pb90_1_proc0 }, { &setup_pwrite_pwrite_pb90_1_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pba_1_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_1_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pa90_1",
    &setup_pwrite_pwrite_pb90_0_common,
    { { &setup_pwrite_pwrite_pa90_1_proc0 }, { &setup_pwrite_pwrite_pa90_1_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pa90_2",
    &setup_pwrite_pwrite_pb90_0_common,
    { { &setup_pwrite_pwrite_pa90_1_proc0 }, { &setup_pwrite_pwrite_pa90_1_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pa80_0",
    &setup_pwrite_pwrite_pb80_6_common,
    { { &setup_pwrite_pwrite_pb90_1_proc0 }, { &setup_pwrite_pwrite_pb90_1_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb80_6_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_6_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pa80_1",
    &setup_pwrite_pwrite_pa80_1_common,
    { { &setup_pwrite_pwrite_pa80_1_proc0 }, { &setup_pwrite_pwrite_pa80_1_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pa80_1_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pa80_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pa80_2",
    &setup_pwrite_pwrite_pb80_2_common,
    { { &setup_pwrite_pwrite_pb90_4_proc0 }, { &setup_pwrite_pwrite_pa90_1_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_7_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pa80_3",
    &setup_pwrite_pwrite_pb80_1_common,
    { { &setup_pwrite_pwrite_pb90_4_proc0 }, { &setup_pwrite_pwrite_pa80_3_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pa80_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pa80_4",
    &setup_pwrite_pwrite_pa80_4_common,
    { { &setup_pwrite_pwrite_pa90_1_proc0 }, { &setup_pwrite_pwrite_pb80_7_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pa80_3_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pa0_0",
    &setup_pwrite_pwrite_pb0_0_common,
    { { &setup_pwrite_pwrite_pb0_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_pa0_1",
    &setup_pwrite_pwrite_pb0_0_common,
    { { &setup_pwrite_pwrite_pb0_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9c_0",
    &setup_pwrite_pwrite_pf0_0_common,
    { { &setup_pwrite_pwrite_p9c_0_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9c_1",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_pbc_1_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9c_2",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_p9c_2_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9c_3",
    &setup_pwrite_pwrite_p9c_3_common,
    { { &setup_pwrite_pwrite_pbc_3_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9a_0",
    &setup_pwrite_pwrite_p9a_0_common,
    { { &setup_pwrite_pwrite_pb90_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9a_1",
    &setup_pwrite_pwrite_p9a_1_common,
    { { &setup_pwrite_pwrite_p9a_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pa80_1_0, 0, "pwrite" },
      { &test_pwrite_pwrite_p9a_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9a_2",
    &setup_pwrite_pwrite_pb80_4_common,
    { { &setup_pwrite_pwrite_p9a_2_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_p9a_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9a_3",
    &setup_pwrite_pwrite_p9a_3_common,
    { { &setup_pwrite_pwrite_p9a_3_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9a_4",
    &setup_pwrite_pwrite_p9a_0_common,
    { { &setup_pwrite_pwrite_p9a_4_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9a_5",
    &setup_pwrite_pwrite_pb80_2_common,
    { { &setup_pwrite_pwrite_pb90_3_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9a_6",
    &setup_pwrite_pwrite_pb80_0_common,
    { { &setup_pwrite_pwrite_pb90_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pa80_1_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pa80_1_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p9a_7",
    &setup_pwrite_pwrite_pb80_6_common,
    { { &setup_pwrite_pwrite_p9a_7_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_p9a_7_0, 0, "pwrite" },
      { &test_pwrite_pwrite_p9a_7_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_0",
    &setup_pwrite_pwrite_pb80_0_common,
    { { &setup_pwrite_pwrite_pb90_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pa80_1_0, 0, "pwrite" },
      { &test_pwrite_pwrite_p9a_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_1",
    &setup_pwrite_pwrite_p98_1_common,
    { { &setup_pwrite_pwrite_p98_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_p9a_2_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_2",
    &setup_pwrite_pwrite_pb80_4_common,
    { { &setup_pwrite_pwrite_p98_2_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_3",
    &setup_pwrite_pwrite_p98_3_common,
    { { &setup_pwrite_pwrite_pb80_3_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_p98_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_4",
    &setup_pwrite_pwrite_p98_4_common,
    { { &setup_pwrite_pwrite_p98_4_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_p98_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_5",
    &setup_pwrite_pwrite_pa80_4_common,
    { { &setup_pwrite_pwrite_pb80_5_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pba_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_6",
    &setup_pwrite_pwrite_pa80_4_common,
    { { &setup_pwrite_pwrite_pb90_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pa80_3_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_7",
    &setup_pwrite_pwrite_pb80_6_common,
    { { &setup_pwrite_pwrite_p98_7_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_p9a_7_0, 0, "pwrite" },
      { &test_pwrite_pwrite_paa_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_8",
    &setup_pwrite_pwrite_pb90_2_common,
    { { &setup_pwrite_pwrite_p98_8_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_p98_8_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_9",
    &setup_pwrite_pwrite_pb90_2_common,
    { { &setup_pwrite_pwrite_p98_9_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_p98_8_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_10",
    &setup_pwrite_pwrite_pb90_2_common,
    { { &setup_pwrite_pwrite_p98_10_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_p98_8_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_11",
    &setup_pwrite_pwrite_pb90_2_common,
    { { &setup_pwrite_pwrite_p98_11_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_12",
    &setup_pwrite_pwrite_pb90_2_common,
    { { &setup_pwrite_pwrite_pb80_5_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_p98_8_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p98_13",
    &setup_pwrite_pwrite_pb90_2_common,
    { { &setup_pwrite_pwrite_pb90_4_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p90_0",
    &setup_pwrite_pwrite_p90_0_common,
    { { &setup_pwrite_pwrite_p90_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p90_1",
    &setup_pwrite_pwrite_p90_0_common,
    { { &setup_pwrite_pwrite_pb0_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8c_0",
    &setup_pwrite_pwrite_pf0_0_common,
    { { &setup_pwrite_pwrite_p8c_0_proc0 }, { &setup_pwrite_pwrite_pf8_3_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8c_1",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_pd4_1_proc1 }, { &setup_pwrite_pwrite_pf8_3_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8c_2",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_pd4_2_proc1 }, { &setup_pwrite_pwrite_pf8_4_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8c_3",
    &setup_pwrite_pwrite_pf0_1_common,
    { { &setup_pwrite_pwrite_pd4_1_proc1 }, { &setup_pwrite_pwrite_pf8_4_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8a_0",
    &setup_pwrite_pwrite_p9a_0_common,
    { { &setup_pwrite_pwrite_pb90_1_proc0 }, { &setup_pwrite_pwrite_pb90_1_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_7_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8a_1",
    &setup_pwrite_pwrite_p8a_1_common,
    { { &setup_pwrite_pwrite_p8a_1_proc0 }, { &setup_pwrite_pwrite_pa80_1_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pa80_1_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pa80_1_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8a_2",
    &setup_pwrite_pwrite_p9a_0_common,
    { { &setup_pwrite_pwrite_pb0_1_proc0 }, { &setup_pwrite_pwrite_p8a_2_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_7_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8a_3",
    &setup_pwrite_pwrite_paa_2_common,
    { { &setup_pwrite_pwrite_p8a_1_proc0 }, { &setup_pwrite_pwrite_p8a_3_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pb80_0_0, 0, "pwrite" },
      { &test_pwrite_pwrite_paa_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8a_4",
    &setup_pwrite_pwrite_p8a_4_common,
    { { &setup_pwrite_pwrite_pa80_1_proc0 }, { &setup_pwrite_pwrite_p9a_7_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb80_6_0, 0, "pwrite" },
      { &test_pwrite_pwrite_paa_2_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8a_5",
    &setup_pwrite_pwrite_p8a_5_common,
    { { &setup_pwrite_pwrite_p8a_5_proc0 }, { &setup_pwrite_pwrite_p8a_5_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_p9a_7_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_6_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p8a_6",
    &setup_pwrite_pwrite_p8a_5_common,
    { { &setup_pwrite_pwrite_p98_7_proc0 }, { &setup_pwrite_pwrite_p8a_5_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_p9a_7_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_6_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p88_0",
    &setup_pwrite_pwrite_pb80_0_common,
    { { &setup_pwrite_pwrite_pb90_1_proc0 }, { &setup_pwrite_pwrite_pb90_1_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pa80_1_0, 0, "pwrite" },
      { &test_pwrite_pwrite_paa_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p88_1",
    &setup_pwrite_pwrite_p88_1_common,
    { { &setup_pwrite_pwrite_p9a_7_proc0 }, { &setup_pwrite_pwrite_p88_1_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pa80_1_0, 0, "pwrite" },
      { &test_pwrite_pwrite_p9a_7_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p88_2",
    &setup_pwrite_pwrite_p8a_4_common,
    { { &setup_pwrite_pwrite_p9a_7_proc0 }, { &setup_pwrite_pwrite_p9a_7_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb80_6_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_6_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p88_3",
    &setup_pwrite_pwrite_p88_3_common,
    { { &setup_pwrite_pwrite_p88_3_proc0 }, { &setup_pwrite_pwrite_p88_3_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb80_6_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb80_6_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p88_4",
    &setup_pwrite_pwrite_p88_4_common,
    { { &setup_pwrite_pwrite_pb90_4_proc0 }, { &setup_pwrite_pwrite_p88_4_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_p88_4_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p88_5",
    &setup_pwrite_pwrite_pb90_0_common,
    { { &setup_pwrite_pwrite_pb80_7_proc0 }, { &setup_pwrite_pwrite_p88_5_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_2_0, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_2_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p88_6",
    &setup_pwrite_pwrite_pb90_2_common,
    { { &setup_pwrite_pwrite_p88_5_proc1 }, { &setup_pwrite_pwrite_pb90_4_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_4_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p88_7",
    &setup_pwrite_pwrite_pb90_2_common,
    { { &setup_pwrite_pwrite_pb90_4_proc0 }, { &setup_pwrite_pwrite_pb90_4_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pb90_4_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pb90_4_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p80_0",
    &setup_pwrite_pwrite_p90_0_common,
    { { &setup_pwrite_pwrite_p90_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p80_1",
    &setup_pwrite_pwrite_p90_0_common,
    { { &setup_pwrite_pwrite_pb0_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pd4_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p7_0",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_p7_0_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p7_1",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_p7_1_proc0 }, { &setup_pwrite_pwrite_pf8_0_proc1 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p68_0",
    &setup_pwrite_pwrite_pb0_0_common,
    { { &setup_pwrite_pwrite_p68_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p68_1",
    &setup_pwrite_pwrite_pb0_0_common,
    { { &setup_pwrite_pwrite_p68_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p60_0",
    &setup_pwrite_pwrite_p90_0_common,
    { { &setup_pwrite_pwrite_p60_0_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p60_1",
    &setup_pwrite_pwrite_p90_0_common,
    { { &setup_pwrite_pwrite_p68_1_proc0 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf4_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p4_0",
    &setup_pwrite_pwrite_p4_0_common,
    { { &setup_pwrite_pwrite_pba_0_proc1 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_procfinal,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pe_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p4_1",
    &setup_pwrite_pwrite_p4_0_common,
    { { &setup_pwrite_pwrite_pba_0_proc1 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_procfinal,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p3_0",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_0_proc1 }, { &setup_pwrite_pwrite_pf8_3_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p3_1",
    &setup_pwrite_pwrite_pf8_0_common,
    { { &setup_pwrite_pwrite_pf8_0_proc1 }, { &setup_pwrite_pwrite_pf8_4_proc0 } },
    &setup_pwrite_pwrite_pf8_0_procfinal,
    &setup_pwrite_pwrite_pf8_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pf8_0_0, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p28_0",
    &setup_pwrite_pwrite_pb0_0_common,
    { { &setup_pwrite_pwrite_pba_0_proc1 }, { &setup_pwrite_pwrite_p28_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p28_1",
    &setup_pwrite_pwrite_pb0_0_common,
    { { &setup_pwrite_pwrite_pba_0_proc1 }, { &setup_pwrite_pwrite_pb0_1_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p20_0",
    &setup_pwrite_pwrite_p90_0_common,
    { { &setup_pwrite_pwrite_pba_0_proc1 }, { &setup_pwrite_pwrite_p20_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p20_1",
    &setup_pwrite_pwrite_p90_0_common,
    { { &setup_pwrite_pwrite_pba_0_proc1 }, { &setup_pwrite_pwrite_pb0_1_proc0 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pb90_0_final,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pd4_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_pwrite_p0_0",
    &setup_pwrite_pwrite_p4_0_common,
    { { &setup_pwrite_pwrite_pba_0_proc1 }, { &setup_pwrite_pwrite_pba_0_proc1 } },
    &setup_pwrite_pwrite_pba_0_procfinal,
    &setup_pwrite_pwrite_pba_0_procfinal,
    { { &test_pwrite_pwrite_pc_0_1, 0, "pwrite" },
      { &test_pwrite_pwrite_pc_0_1, 1, "pwrite" } },
    &cleanup },
  { "fs-pwrite_read_pfc_0",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_pfc_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pfc_1",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_pfc_1_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pfc_2",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_pfc_2_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pfb_0",
    &setup_pwrite_read_pfb_0_common,
    { { &setup_pwrite_read_pfb_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pfb_1",
    &setup_pwrite_read_pfb_0_common,
    { { &setup_pwrite_read_pfb_1_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pfb_2",
    &setup_pwrite_read_pfb_0_common,
    { { &setup_pwrite_read_pfb_2_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_2_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pfa_0",
    &setup_pwrite_read_pfa_0_common,
    { { &setup_pwrite_read_pfa_0_proc0 }, { &setup_pwrite_read_pfa_0_proc1 } },
    &setup_pwrite_read_pfa_0_procfinal,
    &setup_pwrite_read_pfa_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pfa_1",
    &setup_pwrite_read_pfa_1_common,
    { { &setup_pwrite_read_pfb_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pfa_2",
    &setup_pwrite_read_pfa_1_common,
    { { &setup_pwrite_read_pfb_2_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pfa_3",
    &setup_pwrite_read_pfa_3_common,
    { { &setup_pwrite_read_pfa_3_proc0 }, { &setup_pwrite_read_pfa_0_proc1 } },
    &setup_pwrite_read_pfa_0_procfinal,
    &setup_pwrite_read_pfa_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pf8_0",
    &setup_pwrite_read_pf8_0_common,
    { { &setup_pwrite_read_pfb_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pf8_1",
    &setup_pwrite_read_pf8_0_common,
    { { &setup_pwrite_read_pfb_1_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pf8_2",
    &setup_pwrite_read_pf8_0_common,
    { { &setup_pwrite_read_pfb_2_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pf4_0",
    &setup_pwrite_read_pf4_0_common,
    { { &setup_pwrite_read_pf4_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pf4_1",
    &setup_pwrite_read_pf4_1_common,
    { { &setup_pwrite_read_pf4_1_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pf0_0",
    &setup_pwrite_read_pf0_0_common,
    { { &setup_pwrite_read_pf0_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pf0_1",
    &setup_pwrite_read_pf0_1_common,
    { { &setup_pwrite_read_pf0_1_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pe_0",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_pfb_2_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pe_1",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_pfc_2_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pdc_0",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_pfb_2_proc0 }, { &setup_pwrite_read_pfc_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pdc_1",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_pfc_2_proc0 }, { &setup_pwrite_read_pfc_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pdb_0",
    &setup_pwrite_read_pfb_0_common,
    { { &setup_pwrite_read_pfb_2_proc0 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pdb_1",
    &setup_pwrite_read_pfb_0_common,
    { { &setup_pwrite_read_pfc_2_proc0 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pda_0",
    &setup_pwrite_read_pda_0_common,
    { { &setup_pwrite_read_pda_0_proc0 }, { &setup_pwrite_read_pda_0_proc1 } },
    &setup_pwrite_read_pda_0_procfinal,
    &setup_pwrite_read_pda_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pda_1",
    &setup_pwrite_read_pfa_3_common,
    { { &setup_pwrite_read_pda_1_proc0 }, { &setup_pwrite_read_pda_1_proc1 } },
    &setup_pwrite_read_pfa_0_procfinal,
    &setup_pwrite_read_pfa_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pda_2",
    &setup_pwrite_read_pfa_1_common,
    { { &setup_pwrite_read_pda_2_proc0 }, { &setup_pwrite_read_pda_2_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pd8_0",
    &setup_pwrite_read_pf8_0_common,
    { { &setup_pwrite_read_pfb_2_proc0 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pd8_1",
    &setup_pwrite_read_pf8_0_common,
    { { &setup_pwrite_read_pfc_2_proc0 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pd4_0",
    &setup_pwrite_read_pf4_0_common,
    { { &setup_pwrite_read_pfb_2_proc0 }, { &setup_pwrite_read_pd4_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pd4_1",
    &setup_pwrite_read_pf4_0_common,
    { { &setup_pwrite_read_pfc_2_proc0 }, { &setup_pwrite_read_pd4_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pd0_0",
    &setup_pwrite_read_pf0_0_common,
    { { &setup_pwrite_read_pfb_2_proc0 }, { &setup_pwrite_read_pd0_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pd0_1",
    &setup_pwrite_read_pf0_0_common,
    { { &setup_pwrite_read_pfc_2_proc0 }, { &setup_pwrite_read_pd0_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pc_0",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_pfb_2_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pc_1",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_pfc_2_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pfc_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pbe_0",
    &setup_pwrite_read_pf4_1_common,
    { { &setup_pwrite_read_pbe_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pbe_1",
    &setup_pwrite_read_pbe_1_common,
    { { &setup_pwrite_read_pbe_1_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pbd8_0",
    &setup_pwrite_read_pbd8_0_common,
    { { &setup_pwrite_read_pbd8_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbd8_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pbd8_1",
    &setup_pwrite_read_pbd8_1_common,
    { { &setup_pwrite_read_pbd8_1_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbd8_1_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pbd0_0",
    &setup_pwrite_read_pbd8_0_common,
    { { &setup_pwrite_read_pbd0_0_proc0 }, { &setup_pwrite_read_pbd0_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbd8_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pbd0_1",
    &setup_pwrite_read_pbd8_1_common,
    { { &setup_pwrite_read_pbd0_1_proc0 }, { &setup_pwrite_read_pbd0_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbd8_1_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pbc0_0",
    &setup_pwrite_read_pbc0_0_common,
    { { &setup_pwrite_read_pbc0_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pbc0_1",
    &setup_pwrite_read_pbc0_0_common,
    { { &setup_pwrite_read_pbc0_1_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pba_0",
    &setup_pwrite_read_pba_0_common,
    { { &setup_pwrite_read_pba_0_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pba_1",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_pba_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pba_2",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_pba_2_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pba_3",
    &setup_pwrite_read_pba_0_common,
    { { &setup_pwrite_read_pba_3_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pba_4",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_pba_4_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pb80_0",
    &setup_pwrite_read_pb80_0_common,
    { { &setup_pwrite_read_pb80_0_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pb80_0_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pb80_1",
    &setup_pwrite_read_pb80_1_common,
    { { &setup_pwrite_read_pb80_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_1_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pb80_2",
    &setup_pwrite_read_pb80_2_common,
    { { &setup_pwrite_read_pb80_2_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pb80_3",
    &setup_pwrite_read_pb80_3_common,
    { { &setup_pwrite_read_pb80_3_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_3_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pb80_4",
    &setup_pwrite_read_pb80_1_common,
    { { &setup_pwrite_read_pba_2_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_1_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pb0_0",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_pb0_0_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pb0_1",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_pae_0",
    &setup_pwrite_read_pf4_1_common,
    { { &setup_pwrite_read_pae_0_proc0 }, { &setup_pwrite_read_pfc_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pae_1",
    &setup_pwrite_read_pf4_1_common,
    { { &setup_pwrite_read_pd0_0_proc1 }, { &setup_pwrite_read_pfc_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pad8_0",
    &setup_pwrite_read_pbd8_0_common,
    { { &setup_pwrite_read_pad8_0_proc0 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbd8_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pad8_1",
    &setup_pwrite_read_pbd8_1_common,
    { { &setup_pwrite_read_pad8_1_proc0 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbd8_1_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pad0_0",
    &setup_pwrite_read_pbd8_0_common,
    { { &setup_pwrite_read_pad0_0_proc0 }, { &setup_pwrite_read_pda_2_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbd8_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pad0_1",
    &setup_pwrite_read_pbd8_1_common,
    { { &setup_pwrite_read_pad0_1_proc0 }, { &setup_pwrite_read_pda_2_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbd8_1_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pac0_0",
    &setup_pwrite_read_pbc0_0_common,
    { { &setup_pwrite_read_pac0_0_proc0 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pac0_1",
    &setup_pwrite_read_pbc0_0_common,
    { { &setup_pwrite_read_pd0_0_proc1 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_paa_0",
    &setup_pwrite_read_pba_0_common,
    { { &setup_pwrite_read_paa_0_proc0 }, { &setup_pwrite_read_paa_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_paa_1",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_pba_2_proc0 }, { &setup_pwrite_read_pba_2_proc0 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_paa_2",
    &setup_pwrite_read_pba_0_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_paa_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_paa_3",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_pba_2_proc0 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pa80_0",
    &setup_pwrite_read_pb80_0_common,
    { { &setup_pwrite_read_pa80_0_proc0 }, { &setup_pwrite_read_pa80_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pb80_0_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pa80_1",
    &setup_pwrite_read_pb80_1_common,
    { { &setup_pwrite_read_pa80_0_proc0 }, { &setup_pwrite_read_pba_2_proc0 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_1_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pa80_2",
    &setup_pwrite_read_pb80_2_common,
    { { &setup_pwrite_read_pba_2_proc0 }, { &setup_pwrite_read_pa80_2_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pa80_3",
    &setup_pwrite_read_pa80_3_common,
    { { &setup_pwrite_read_pa80_3_proc0 }, { &setup_pwrite_read_pa80_3_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbd8_0_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pa80_4",
    &setup_pwrite_read_pa80_3_common,
    { { &setup_pwrite_read_pa80_4_proc0 }, { &setup_pwrite_read_pa80_3_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbd8_0_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pa0_0",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_pb0_0_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_pa0_1",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9e_0",
    &setup_pwrite_read_pf0_0_common,
    { { &setup_pwrite_read_p9e_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9e_1",
    &setup_pwrite_read_pf0_1_common,
    { { &setup_pwrite_read_pbe_1_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9d8_0",
    &setup_pwrite_read_p9d8_0_common,
    { { &setup_pwrite_read_p9d8_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9d8_1",
    &setup_pwrite_read_pbd8_0_common,
    { { &setup_pwrite_read_pbd8_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p9d8_1_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9d0_0",
    &setup_pwrite_read_p9d8_0_common,
    { { &setup_pwrite_read_p9d0_0_proc0 }, { &setup_pwrite_read_pbd0_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9d0_1",
    &setup_pwrite_read_pbd8_0_common,
    { { &setup_pwrite_read_pbd0_0_proc0 }, { &setup_pwrite_read_pbd0_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p9d8_1_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9c0_0",
    &setup_pwrite_read_p9c0_0_common,
    { { &setup_pwrite_read_pbc0_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9c0_1",
    &setup_pwrite_read_pf0_0_common,
    { { &setup_pwrite_read_pbc0_1_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9a_0",
    &setup_pwrite_read_p9a_0_common,
    { { &setup_pwrite_read_p9a_0_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9a_1",
    &setup_pwrite_read_p9a_1_common,
    { { &setup_pwrite_read_p9a_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_p9d8_1_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9a_2",
    &setup_pwrite_read_p9a_2_common,
    { { &setup_pwrite_read_p9a_2_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9a_3",
    &setup_pwrite_read_p9a_2_common,
    { { &setup_pwrite_read_p9a_3_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p9a_4",
    &setup_pwrite_read_p9a_4_common,
    { { &setup_pwrite_read_p9a_4_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_3_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p990_0",
    &setup_pwrite_read_pb80_0_common,
    { { &setup_pwrite_read_p990_0_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p990_1",
    &setup_pwrite_read_pb80_1_common,
    { { &setup_pwrite_read_p990_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p990_2",
    &setup_pwrite_read_p990_2_common,
    { { &setup_pwrite_read_p990_2_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p990_3",
    &setup_pwrite_read_p990_3_common,
    { { &setup_pwrite_read_p990_3_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p990_4",
    &setup_pwrite_read_p990_3_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p990_5",
    &setup_pwrite_read_p990_3_common,
    { { &setup_pwrite_read_p990_5_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p990_6",
    &setup_pwrite_read_p990_6_common,
    { { &setup_pwrite_read_pba_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p990_7",
    &setup_pwrite_read_p990_7_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p90_0",
    &setup_pwrite_read_p9a_2_common,
    { { &setup_pwrite_read_p90_0_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p90_1",
    &setup_pwrite_read_p9a_2_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8e_0",
    &setup_pwrite_read_pf0_0_common,
    { { &setup_pwrite_read_pac0_0_proc0 }, { &setup_pwrite_read_pfc_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8e_1",
    &setup_pwrite_read_pf0_1_common,
    { { &setup_pwrite_read_pd0_0_proc1 }, { &setup_pwrite_read_pfc_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8d8_0",
    &setup_pwrite_read_p9d8_0_common,
    { { &setup_pwrite_read_p8d8_0_proc0 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8d8_1",
    &setup_pwrite_read_pbd8_0_common,
    { { &setup_pwrite_read_pad8_0_proc0 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p9d8_1_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8d0_0",
    &setup_pwrite_read_p9d8_0_common,
    { { &setup_pwrite_read_pad0_0_proc0 }, { &setup_pwrite_read_pda_2_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8d0_1",
    &setup_pwrite_read_pbd8_0_common,
    { { &setup_pwrite_read_p8d0_1_proc0 }, { &setup_pwrite_read_pda_2_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p9d8_1_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8c0_0",
    &setup_pwrite_read_p9c0_0_common,
    { { &setup_pwrite_read_pac0_0_proc0 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8c0_1",
    &setup_pwrite_read_pf0_1_common,
    { { &setup_pwrite_read_pd0_0_proc1 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8a_0",
    &setup_pwrite_read_p9a_0_common,
    { { &setup_pwrite_read_p8a_0_proc0 }, { &setup_pwrite_read_p8a_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8a_1",
    &setup_pwrite_read_p8a_1_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_p8a_1_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8a_2",
    &setup_pwrite_read_p9a_2_common,
    { { &setup_pwrite_read_p8a_2_proc0 }, { &setup_pwrite_read_p8a_2_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p8a_3",
    &setup_pwrite_read_p9a_2_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_p8a_3_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p890_0",
    &setup_pwrite_read_p890_0_common,
    { { &setup_pwrite_read_p890_0_proc0 }, { &setup_pwrite_read_p890_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p890_1",
    &setup_pwrite_read_pb80_1_common,
    { { &setup_pwrite_read_pa80_0_proc0 }, { &setup_pwrite_read_pb0_1_proc0 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p890_2",
    &setup_pwrite_read_p890_2_common,
    { { &setup_pwrite_read_pba_2_proc0 }, { &setup_pwrite_read_p890_2_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p890_3",
    &setup_pwrite_read_pb80_1_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_pb0_1_proc0 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p890_4",
    &setup_pwrite_read_pb80_1_common,
    { { &setup_pwrite_read_pba_2_proc0 }, { &setup_pwrite_read_pb0_1_proc0 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pb80_4_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p890_5",
    &setup_pwrite_read_p990_6_common,
    { { &setup_pwrite_read_pba_2_proc0 }, { &setup_pwrite_read_pba_2_proc0 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pb80_2_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p80_0",
    &setup_pwrite_read_p9a_2_common,
    { { &setup_pwrite_read_p90_0_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p80_1",
    &setup_pwrite_read_p9a_2_common,
    { { &setup_pwrite_read_pb0_1_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_pbe_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p78_0",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_p78_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p76_0",
    &setup_pwrite_read_pfb_0_common,
    { { &setup_pwrite_read_p76_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p74_0",
    &setup_pwrite_read_pfa_1_common,
    { { &setup_pwrite_read_p74_0_proc0 }, { &setup_pwrite_read_pbd0_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p70_0",
    &setup_pwrite_read_pf8_0_common,
    { { &setup_pwrite_read_p76_0_proc0 }, { &setup_pwrite_read_pfc_0_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p68_0",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_p68_0_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p60_0",
    &setup_pwrite_read_p9a_2_common,
    { { &setup_pwrite_read_p60_0_proc0 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p4_0",
    &setup_pwrite_read_p4_0_common,
    { { &setup_pwrite_read_pba_0_proc1 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_procfinal,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p4_1",
    &setup_pwrite_read_p4_0_common,
    { { &setup_pwrite_read_pba_0_proc1 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_procfinal,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 0, "read" } },
    &cleanup },
  { "fs-pwrite_read_p38_0",
    &setup_pwrite_read_pfc_0_common,
    { { &setup_pwrite_read_pfc_0_proc1 }, { &setup_pwrite_read_pfc_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p36_0",
    &setup_pwrite_read_pfb_0_common,
    { { &setup_pwrite_read_pfc_0_proc1 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfb_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p34_0",
    &setup_pwrite_read_pfa_1_common,
    { { &setup_pwrite_read_pbd0_0_proc1 }, { &setup_pwrite_read_pda_2_proc1 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p30_0",
    &setup_pwrite_read_pf8_0_common,
    { { &setup_pwrite_read_pfc_0_proc1 }, { &setup_pwrite_read_pfb_2_proc0 } },
    &setup_pwrite_read_pfc_0_procfinal,
    &setup_pwrite_read_pfc_0_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p28_0",
    &setup_pwrite_read_pba_1_common,
    { { &setup_pwrite_read_pba_0_proc1 }, { &setup_pwrite_read_p28_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfa_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p20_0",
    &setup_pwrite_read_p9a_2_common,
    { { &setup_pwrite_read_pba_0_proc1 }, { &setup_pwrite_read_pb0_1_proc0 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_1_final,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pf8_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_read_p0_0",
    &setup_pwrite_read_p4_0_common,
    { { &setup_pwrite_read_pba_0_proc1 }, { &setup_pwrite_read_pba_0_proc1 } },
    &setup_pwrite_read_pba_0_procfinal,
    &setup_pwrite_read_pba_0_procfinal,
    { { &test_pwrite_read_p78_0_0, 0, "pwrite" },
      { &test_pwrite_read_pfc_2_1, 1, "read" } },
    &cleanup },
  { "fs-pwrite_rename_pf_0",
    &setup_pwrite_rename_pf_0_common,
    { { &setup_pwrite_rename_pf_0_proc0 }, { &setup_pwrite_rename_pf_0_proc1 } },
    &setup_pwrite_rename_pf_0_procfinal,
    &setup_pwrite_rename_pf_0_final,
    { { &test_pwrite_rename_pf_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pf_1",
    &setup_pwrite_rename_pf_0_common,
    { { &setup_pwrite_rename_pf_1_proc0 }, { &setup_pwrite_rename_pf_0_proc1 } },
    &setup_pwrite_rename_pf_0_procfinal,
    &setup_pwrite_rename_pf_0_final,
    { { &test_pwrite_rename_pf_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pe8_0",
    &setup_pwrite_rename_pe8_0_common,
    { { &setup_pwrite_rename_pf_0_proc0 }, { &setup_pwrite_rename_pf_0_proc1 } },
    &setup_pwrite_rename_pf_0_procfinal,
    &setup_pwrite_rename_pf_0_final,
    { { &test_pwrite_rename_pf_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pe8_1",
    &setup_pwrite_rename_pe8_0_common,
    { { &setup_pwrite_rename_pf_1_proc0 }, { &setup_pwrite_rename_pf_0_proc1 } },
    &setup_pwrite_rename_pf_0_procfinal,
    &setup_pwrite_rename_pf_0_final,
    { { &test_pwrite_rename_pf_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pe0_0",
    &setup_pwrite_rename_pf_0_common,
    { { &setup_pwrite_rename_pf_0_proc0 }, { &setup_pwrite_rename_pf_0_proc1 } },
    &setup_pwrite_rename_pf_0_procfinal,
    &setup_pwrite_rename_pf_0_final,
    { { &test_pwrite_rename_pf_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pe0_1",
    &setup_pwrite_rename_pf_0_common,
    { { &setup_pwrite_rename_pf_1_proc0 }, { &setup_pwrite_rename_pf_0_proc1 } },
    &setup_pwrite_rename_pf_0_procfinal,
    &setup_pwrite_rename_pf_0_final,
    { { &test_pwrite_rename_pf_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pc_0",
    &setup_pwrite_rename_pc_0_common,
    { { &setup_pwrite_rename_pf_0_proc0 }, { &setup_pwrite_rename_pf_0_proc1 } },
    &setup_pwrite_rename_pf_0_procfinal,
    &setup_pwrite_rename_pf_0_final,
    { { &test_pwrite_rename_pf_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pc_1",
    &setup_pwrite_rename_pc_0_common,
    { { &setup_pwrite_rename_pf_1_proc0 }, { &setup_pwrite_rename_pf_0_proc1 } },
    &setup_pwrite_rename_pf_0_procfinal,
    &setup_pwrite_rename_pf_0_final,
    { { &test_pwrite_rename_pf_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pb8_0",
    &setup_pwrite_rename_pb8_0_common,
    { { &setup_pwrite_rename_pb8_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pb8_1",
    &setup_pwrite_rename_pb8_0_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pb4_0",
    &setup_pwrite_rename_pb4_0_common,
    { { &setup_pwrite_rename_pb4_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb4_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pb4_1",
    &setup_pwrite_rename_pb4_0_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb4_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pb4_2",
    &setup_pwrite_rename_pb4_2_common,
    { { &setup_pwrite_rename_pb4_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb4_2_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pb4_3",
    &setup_pwrite_rename_pb4_3_common,
    { { &setup_pwrite_rename_pb4_3_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pb4_4",
    &setup_pwrite_rename_pb4_2_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb4_2_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pb4_5",
    &setup_pwrite_rename_pb4_3_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pb0_0",
    &setup_pwrite_rename_pb8_0_common,
    { { &setup_pwrite_rename_pb8_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pb0_1",
    &setup_pwrite_rename_pb8_0_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pa0_0",
    &setup_pwrite_rename_pa0_0_common,
    { { &setup_pwrite_rename_pb8_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_pa0_1",
    &setup_pwrite_rename_pa0_0_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p98_0",
    &setup_pwrite_rename_p98_0_common,
    { { &setup_pwrite_rename_p98_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p98_1",
    &setup_pwrite_rename_p98_0_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p94_0",
    &setup_pwrite_rename_p94_0_common,
    { { &setup_pwrite_rename_p94_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb4_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p94_1",
    &setup_pwrite_rename_p94_1_common,
    { { &setup_pwrite_rename_p94_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb4_2_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p94_2",
    &setup_pwrite_rename_p94_0_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb4_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p94_3",
    &setup_pwrite_rename_p94_3_common,
    { { &setup_pwrite_rename_p94_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p94_4",
    &setup_pwrite_rename_p94_1_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb4_2_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p94_5",
    &setup_pwrite_rename_p94_3_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p90_0",
    &setup_pwrite_rename_p98_0_common,
    { { &setup_pwrite_rename_p98_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p90_1",
    &setup_pwrite_rename_p98_0_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p80_0",
    &setup_pwrite_rename_p80_0_common,
    { { &setup_pwrite_rename_p98_0_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p80_1",
    &setup_pwrite_rename_p80_0_common,
    { { &setup_pwrite_rename_pb8_1_proc0 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p6_0",
    &setup_pwrite_rename_pb8_0_common,
    { { &setup_pwrite_rename_pb8_0_proc1 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_p6_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p50_0",
    &setup_pwrite_rename_pb4_3_common,
    { { &setup_pwrite_rename_pb8_0_proc1 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_p6_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p4_0",
    &setup_pwrite_rename_pb8_0_common,
    { { &setup_pwrite_rename_pb8_0_proc1 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_final,
    { { &test_pwrite_rename_p6_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pe8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_rename_p0_0",
    &setup_pwrite_rename_p0_0_common,
    { { &setup_pwrite_rename_pb8_0_proc1 }, { &setup_pwrite_rename_pb8_0_proc1 } },
    &setup_pwrite_rename_pb8_0_procfinal,
    &setup_pwrite_rename_pb8_0_procfinal,
    { { &test_pwrite_rename_p6_0_0, 0, "pwrite" },
      { &test_pwrite_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-pwrite_stat_pe_0",
    &setup_pwrite_stat_pe_0_common,
    { { &setup_pwrite_stat_pe_0_proc0 }, { &setup_pwrite_stat_pe_0_proc1 } },
    &setup_pwrite_stat_pe_0_procfinal,
    &setup_pwrite_stat_pe_0_final,
    { { &test_pwrite_stat_pe_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_pe_1",
    &setup_pwrite_stat_pe_0_common,
    { { &setup_pwrite_stat_pe_1_proc0 }, { &setup_pwrite_stat_pe_0_proc1 } },
    &setup_pwrite_stat_pe_0_procfinal,
    &setup_pwrite_stat_pe_0_final,
    { { &test_pwrite_stat_pe_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_pc_0",
    &setup_pwrite_stat_pc_0_common,
    { { &setup_pwrite_stat_pe_0_proc0 }, { &setup_pwrite_stat_pe_0_proc1 } },
    &setup_pwrite_stat_pe_0_procfinal,
    &setup_pwrite_stat_pe_0_final,
    { { &test_pwrite_stat_pe_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_pc_1",
    &setup_pwrite_stat_pc_0_common,
    { { &setup_pwrite_stat_pe_1_proc0 }, { &setup_pwrite_stat_pe_0_proc1 } },
    &setup_pwrite_stat_pe_0_procfinal,
    &setup_pwrite_stat_pe_0_final,
    { { &test_pwrite_stat_pe_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_pb8_0",
    &setup_pwrite_stat_pb8_0_common,
    { { &setup_pwrite_stat_pb8_0_proc0 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pb8_0_final,
    { { &test_pwrite_stat_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pb8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_pb8_1",
    &setup_pwrite_stat_pb8_1_common,
    { { &setup_pwrite_stat_pb8_1_proc0 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pb8_0_final,
    { { &test_pwrite_stat_pb8_1_0, 0, "pwrite" },
      { &test_pwrite_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_pa0_0",
    &setup_pwrite_stat_pa0_0_common,
    { { &setup_pwrite_stat_pa0_0_proc0 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pa0_0_final,
    { { &test_pwrite_stat_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_pa0_1",
    &setup_pwrite_stat_pa0_0_common,
    { { &setup_pwrite_stat_pa0_1_proc0 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pa0_0_final,
    { { &test_pwrite_stat_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_p9c_0",
    &setup_pwrite_stat_p9c_0_common,
    { { &setup_pwrite_stat_pa0_0_proc0 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pb8_0_final,
    { { &test_pwrite_stat_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_stat_p9c_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_p9c_1",
    &setup_pwrite_stat_p9c_1_common,
    { { &setup_pwrite_stat_p9c_1_proc0 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pa0_0_final,
    { { &test_pwrite_stat_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_stat_p9c_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_p9c_2",
    &setup_pwrite_stat_p9c_0_common,
    { { &setup_pwrite_stat_pa0_1_proc0 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pb8_0_final,
    { { &test_pwrite_stat_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_stat_p9c_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_p9c_3",
    &setup_pwrite_stat_p9c_1_common,
    { { &setup_pwrite_stat_pa0_1_proc0 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pa0_0_final,
    { { &test_pwrite_stat_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_stat_p9c_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_p80_0",
    &setup_pwrite_stat_p80_0_common,
    { { &setup_pwrite_stat_p80_0_proc0 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pa0_0_final,
    { { &test_pwrite_stat_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_p80_1",
    &setup_pwrite_stat_p80_0_common,
    { { &setup_pwrite_stat_pa0_1_proc0 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pa0_0_final,
    { { &test_pwrite_stat_pb8_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_p4_0",
    &setup_pwrite_stat_p4_0_common,
    { { &setup_pwrite_stat_pb8_0_proc1 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pa0_0_final,
    { { &test_pwrite_stat_p4_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_stat_p0_0",
    &setup_pwrite_stat_p0_0_common,
    { { &setup_pwrite_stat_pb8_0_proc1 }, { &setup_pwrite_stat_pb8_0_proc1 } },
    &setup_pwrite_stat_pb8_0_procfinal,
    &setup_pwrite_stat_pb8_0_procfinal,
    { { &test_pwrite_stat_p4_0_0, 0, "pwrite" },
      { &test_pwrite_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-pwrite_unlink_pe_0",
    &setup_pwrite_unlink_pe_0_common,
    { { &setup_pwrite_unlink_pe_0_proc0 }, { &setup_pwrite_unlink_pe_0_proc1 } },
    &setup_pwrite_unlink_pe_0_procfinal,
    &setup_pwrite_unlink_pe_0_final,
    { { &test_pwrite_unlink_pe_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_pe_1",
    &setup_pwrite_unlink_pe_0_common,
    { { &setup_pwrite_unlink_pe_1_proc0 }, { &setup_pwrite_unlink_pe_0_proc1 } },
    &setup_pwrite_unlink_pe_0_procfinal,
    &setup_pwrite_unlink_pe_0_final,
    { { &test_pwrite_unlink_pe_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_pc_0",
    &setup_pwrite_unlink_pc_0_common,
    { { &setup_pwrite_unlink_pe_0_proc0 }, { &setup_pwrite_unlink_pe_0_proc1 } },
    &setup_pwrite_unlink_pe_0_procfinal,
    &setup_pwrite_unlink_pe_0_final,
    { { &test_pwrite_unlink_pe_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_pc_1",
    &setup_pwrite_unlink_pc_0_common,
    { { &setup_pwrite_unlink_pe_1_proc0 }, { &setup_pwrite_unlink_pe_0_proc1 } },
    &setup_pwrite_unlink_pe_0_procfinal,
    &setup_pwrite_unlink_pe_0_final,
    { { &test_pwrite_unlink_pe_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_pb0_0",
    &setup_pwrite_unlink_pb0_0_common,
    { { &setup_pwrite_unlink_pb0_0_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_0_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_pb0_1",
    &setup_pwrite_unlink_pb0_1_common,
    { { &setup_pwrite_unlink_pb0_1_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_1_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_pb0_2",
    &setup_pwrite_unlink_pb0_0_common,
    { { &setup_pwrite_unlink_pb0_2_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_0_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_pb0_3",
    &setup_pwrite_unlink_pb0_1_common,
    { { &setup_pwrite_unlink_pb0_2_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_1_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_pa0_0",
    &setup_pwrite_unlink_pa0_0_common,
    { { &setup_pwrite_unlink_pa0_0_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_1_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_pa0_1",
    &setup_pwrite_unlink_pa0_0_common,
    { { &setup_pwrite_unlink_pb0_2_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_1_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_p90_0",
    &setup_pwrite_unlink_p90_0_common,
    { { &setup_pwrite_unlink_p90_0_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_0_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_p90_1",
    &setup_pwrite_unlink_p90_1_common,
    { { &setup_pwrite_unlink_p90_0_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_1_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_p90_2",
    &setup_pwrite_unlink_p90_0_common,
    { { &setup_pwrite_unlink_pb0_2_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_0_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_p90_3",
    &setup_pwrite_unlink_p90_1_common,
    { { &setup_pwrite_unlink_pb0_2_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_1_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_p80_0",
    &setup_pwrite_unlink_p80_0_common,
    { { &setup_pwrite_unlink_p80_0_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_1_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_p80_1",
    &setup_pwrite_unlink_p80_0_common,
    { { &setup_pwrite_unlink_pb0_2_proc0 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_1_final,
    { { &test_pwrite_unlink_pb0_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_p4_0",
    &setup_pwrite_unlink_pb0_1_common,
    { { &setup_pwrite_unlink_pb0_0_proc1 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_1_final,
    { { &test_pwrite_unlink_p4_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_unlink_p0_0",
    &setup_pwrite_unlink_p0_0_common,
    { { &setup_pwrite_unlink_pb0_0_proc1 }, { &setup_pwrite_unlink_pb0_0_proc1 } },
    &setup_pwrite_unlink_pb0_0_procfinal,
    &setup_pwrite_unlink_pb0_0_procfinal,
    { { &test_pwrite_unlink_p4_0_0, 0, "pwrite" },
      { &test_pwrite_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-pwrite_write_pfe_0",
    &setup_pwrite_write_pfe_0_common,
    { { &setup_pwrite_write_pfe_0_proc0 }, { &setup_pwrite_write_pfe_0_proc1 } },
    &setup_pwrite_write_pfe_0_procfinal,
    &setup_pwrite_write_pfe_0_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pfe_1",
    &setup_pwrite_write_pfe_0_common,
    { { &setup_pwrite_write_pfe_1_proc0 }, { &setup_pwrite_write_pfe_0_proc1 } },
    &setup_pwrite_write_pfe_0_procfinal,
    &setup_pwrite_write_pfe_0_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pfe_2",
    &setup_pwrite_write_pfe_2_common,
    { { &setup_pwrite_write_pfe_2_proc0 }, { &setup_pwrite_write_pfe_2_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pfe_3",
    &setup_pwrite_write_pfe_2_common,
    { { &setup_pwrite_write_pfe_3_proc0 }, { &setup_pwrite_write_pfe_2_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_3_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pfc_0",
    &setup_pwrite_write_pfc_0_common,
    { { &setup_pwrite_write_pfc_0_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pfc_1",
    &setup_pwrite_write_pfc_0_common,
    { { &setup_pwrite_write_pfc_1_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pfc_2",
    &setup_pwrite_write_pfc_0_common,
    { { &setup_pwrite_write_pfc_2_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pf8_0",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_pf8_0_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pf8_1",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_pf8_1_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pf8_2",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_pf8_2_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pf4_0",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pf4_0_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pf4_1",
    &setup_pwrite_write_pf4_1_common,
    { { &setup_pwrite_write_pf4_1_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pf0_0",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_pf4_0_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pf0_1",
    &setup_pwrite_write_pf0_1_common,
    { { &setup_pwrite_write_pf4_1_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pe_0",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_pf8_2_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pe_1",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_pfc_2_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pde_0",
    &setup_pwrite_write_pde_0_common,
    { { &setup_pwrite_write_pde_0_proc0 }, { &setup_pwrite_write_pde_0_proc1 } },
    &setup_pwrite_write_pfe_0_procfinal,
    &setup_pwrite_write_pfe_0_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pde_1",
    &setup_pwrite_write_pde_0_common,
    { { &setup_pwrite_write_pde_1_proc0 }, { &setup_pwrite_write_pde_0_proc1 } },
    &setup_pwrite_write_pfe_0_procfinal,
    &setup_pwrite_write_pfe_0_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pde_2",
    &setup_pwrite_write_pde_2_common,
    { { &setup_pwrite_write_pfe_3_proc0 }, { &setup_pwrite_write_pfe_3_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pdc_0",
    &setup_pwrite_write_pfc_0_common,
    { { &setup_pwrite_write_pf8_2_proc0 }, { &setup_pwrite_write_pfc_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pdc_1",
    &setup_pwrite_write_pfc_0_common,
    { { &setup_pwrite_write_pfc_2_proc0 }, { &setup_pwrite_write_pfc_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pd8_0",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_pf8_2_proc0 }, { &setup_pwrite_write_pf8_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pd8_1",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_pfc_2_proc0 }, { &setup_pwrite_write_pf8_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pd4_0",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pf8_2_proc0 }, { &setup_pwrite_write_pd4_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pd4_1",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pfc_2_proc0 }, { &setup_pwrite_write_pd4_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pd0_0",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_pf8_2_proc0 }, { &setup_pwrite_write_pd4_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pd0_1",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_pfc_2_proc0 }, { &setup_pwrite_write_pd4_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pc_0",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_pf8_2_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pc_1",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_pfc_2_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pfe_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pbf0_0",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pbf0_0_proc0 }, { &setup_pwrite_write_pfe_2_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pbf0_1",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pbf0_1_proc0 }, { &setup_pwrite_write_pfe_2_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pbe0_0",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pbe0_0_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pbe0_1",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pbe0_1_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pbc_0",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pbc_0_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pbc_1",
    &setup_pwrite_write_pf4_1_common,
    { { &setup_pwrite_write_pbc_1_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pba_0",
    &setup_pwrite_write_pba_0_common,
    { { &setup_pwrite_write_pba_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pba_0_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pba_1",
    &setup_pwrite_write_pba_1_common,
    { { &setup_pwrite_write_pba_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb90_0",
    &setup_pwrite_write_pb90_0_common,
    { { &setup_pwrite_write_pb90_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pba_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb90_1",
    &setup_pwrite_write_pb90_1_common,
    { { &setup_pwrite_write_pb90_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb90_2",
    &setup_pwrite_write_pb90_1_common,
    { { &setup_pwrite_write_pb90_2_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb80_0",
    &setup_pwrite_write_pb80_0_common,
    { { &setup_pwrite_write_pb80_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pb80_0_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb80_1",
    &setup_pwrite_write_pb80_1_common,
    { { &setup_pwrite_write_pb80_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb80_0_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb80_2",
    &setup_pwrite_write_pb80_2_common,
    { { &setup_pwrite_write_pb80_2_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb80_3",
    &setup_pwrite_write_pb80_3_common,
    { { &setup_pwrite_write_pb90_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb80_3_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb80_4",
    &setup_pwrite_write_pb80_3_common,
    { { &setup_pwrite_write_pb80_4_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb80_3_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb80_5",
    &setup_pwrite_write_pb80_1_common,
    { { &setup_pwrite_write_pb80_5_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb80_0_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb0_0",
    &setup_pwrite_write_pb0_0_common,
    { { &setup_pwrite_write_pb0_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_pb0_1",
    &setup_pwrite_write_pb0_0_common,
    { { &setup_pwrite_write_pb0_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_paf0_0",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_paf0_0_proc0 }, { &setup_pwrite_write_pfe_3_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_paf0_1",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_paf0_1_proc0 }, { &setup_pwrite_write_pfe_3_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pae0_0",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pae0_0_proc0 }, { &setup_pwrite_write_pfc_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pae0_1",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pd4_0_proc1 }, { &setup_pwrite_write_pfc_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pac_0",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pac_0_proc0 }, { &setup_pwrite_write_pf8_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pac_1",
    &setup_pwrite_write_pf4_0_common,
    { { &setup_pwrite_write_pd4_0_proc1 }, { &setup_pwrite_write_pf8_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_paa_0",
    &setup_pwrite_write_paa_0_common,
    { { &setup_pwrite_write_paa_0_proc0 }, { &setup_pwrite_write_paa_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pb80_3_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_paa_1",
    &setup_pwrite_write_paa_0_common,
    { { &setup_pwrite_write_paa_1_proc0 }, { &setup_pwrite_write_paa_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pb80_3_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pa90_0",
    &setup_pwrite_write_pb90_0_common,
    { { &setup_pwrite_write_pa90_0_proc0 }, { &setup_pwrite_write_pa90_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pba_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pa90_1",
    &setup_pwrite_write_pb90_0_common,
    { { &setup_pwrite_write_pa90_0_proc1 }, { &setup_pwrite_write_pa90_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pba_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pa80_0",
    &setup_pwrite_write_pa80_0_common,
    { { &setup_pwrite_write_pa90_0_proc0 }, { &setup_pwrite_write_pa80_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pa80_0_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pa80_1",
    &setup_pwrite_write_pb80_2_common,
    { { &setup_pwrite_write_pb90_2_proc0 }, { &setup_pwrite_write_pa80_1_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pa80_2",
    &setup_pwrite_write_pa80_2_common,
    { { &setup_pwrite_write_pa80_0_proc1 }, { &setup_pwrite_write_pa80_2_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pa80_2_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pa0_0",
    &setup_pwrite_write_pb0_0_common,
    { { &setup_pwrite_write_pb0_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_pa0_1",
    &setup_pwrite_write_pb0_0_common,
    { { &setup_pwrite_write_pb0_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p9f0_0",
    &setup_pwrite_write_p9f0_0_common,
    { { &setup_pwrite_write_p9f0_0_proc0 }, { &setup_pwrite_write_pfe_2_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p9f0_1",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_pbf0_1_proc0 }, { &setup_pwrite_write_pfe_2_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p9e0_0",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_p9e0_0_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p9e0_1",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_pbe0_1_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p9c_0",
    &setup_pwrite_write_p9f0_0_common,
    { { &setup_pwrite_write_p9c_0_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p9c_1",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_pbc_1_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p9a_0",
    &setup_pwrite_write_pb80_1_common,
    { { &setup_pwrite_write_p9a_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_p9a_0_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p9a_1",
    &setup_pwrite_write_p9a_1_common,
    { { &setup_pwrite_write_p9a_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pb80_3_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p9a_2",
    &setup_pwrite_write_p9a_2_common,
    { { &setup_pwrite_write_p9a_2_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p9a_3",
    &setup_pwrite_write_pb80_1_common,
    { { &setup_pwrite_write_pa80_2_proc1 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_p9a_0_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p98_0",
    &setup_pwrite_write_p98_0_common,
    { { &setup_pwrite_write_p98_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb80_3_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p98_1",
    &setup_pwrite_write_p98_1_common,
    { { &setup_pwrite_write_p98_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pa80_2_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p98_2",
    &setup_pwrite_write_pb80_0_common,
    { { &setup_pwrite_write_p98_2_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p98_3",
    &setup_pwrite_write_p98_0_common,
    { { &setup_pwrite_write_p98_3_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p98_4",
    &setup_pwrite_write_p98_0_common,
    { { &setup_pwrite_write_paa_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p98_5",
    &setup_pwrite_write_p98_5_common,
    { { &setup_pwrite_write_pb90_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p98_6",
    &setup_pwrite_write_p98_5_common,
    { { &setup_pwrite_write_pb90_2_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p90_0",
    &setup_pwrite_write_p90_0_common,
    { { &setup_pwrite_write_p90_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p90_1",
    &setup_pwrite_write_p90_0_common,
    { { &setup_pwrite_write_pb0_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8f0_0",
    &setup_pwrite_write_p9f0_0_common,
    { { &setup_pwrite_write_p8f0_0_proc0 }, { &setup_pwrite_write_pfe_3_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8f0_1",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_paf0_1_proc0 }, { &setup_pwrite_write_pfe_3_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8e0_0",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_p8e0_0_proc0 }, { &setup_pwrite_write_pfc_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8e0_1",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_pd4_0_proc1 }, { &setup_pwrite_write_pfc_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8c_0",
    &setup_pwrite_write_p9f0_0_common,
    { { &setup_pwrite_write_p8c_0_proc0 }, { &setup_pwrite_write_pf8_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8c_1",
    &setup_pwrite_write_pf0_0_common,
    { { &setup_pwrite_write_pd4_0_proc1 }, { &setup_pwrite_write_pf8_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8a_0",
    &setup_pwrite_write_pb80_1_common,
    { { &setup_pwrite_write_paa_0_proc0 }, { &setup_pwrite_write_pa80_2_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_p9a_0_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8a_1",
    &setup_pwrite_write_p8a_1_common,
    { { &setup_pwrite_write_p8a_1_proc0 }, { &setup_pwrite_write_p8a_1_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8a_2",
    &setup_pwrite_write_p98_1_common,
    { { &setup_pwrite_write_pa90_0_proc1 }, { &setup_pwrite_write_pa90_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pa80_0_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8a_3",
    &setup_pwrite_write_pa80_2_common,
    { { &setup_pwrite_write_pa80_2_proc1 }, { &setup_pwrite_write_pa80_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb80_0_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p8a_4",
    &setup_pwrite_write_p8a_4_common,
    { { &setup_pwrite_write_pb90_2_proc0 }, { &setup_pwrite_write_p8a_4_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p88_0",
    &setup_pwrite_write_p98_1_common,
    { { &setup_pwrite_write_pa90_0_proc0 }, { &setup_pwrite_write_pb90_2_proc0 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb80_3_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p88_1",
    &setup_pwrite_write_pa80_0_common,
    { { &setup_pwrite_write_pa80_2_proc1 }, { &setup_pwrite_write_pa80_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb80_0_0, 0, "pwrite" },
      { &test_pwrite_write_pb80_5_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p88_2",
    &setup_pwrite_write_p98_5_common,
    { { &setup_pwrite_write_p88_2_proc0 }, { &setup_pwrite_write_pb90_2_proc0 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p88_3",
    &setup_pwrite_write_p98_5_common,
    { { &setup_pwrite_write_pb90_2_proc0 }, { &setup_pwrite_write_pb90_2_proc0 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pb90_1_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p80_0",
    &setup_pwrite_write_p90_0_common,
    { { &setup_pwrite_write_p90_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p80_1",
    &setup_pwrite_write_p90_0_common,
    { { &setup_pwrite_write_pb0_1_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_pbf0_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p7c_0",
    &setup_pwrite_write_pfe_2_common,
    { { &setup_pwrite_write_p7c_0_proc0 }, { &setup_pwrite_write_pfe_2_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p78_0",
    &setup_pwrite_write_pfc_0_common,
    { { &setup_pwrite_write_p78_0_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p70_0",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_p70_0_proc0 }, { &setup_pwrite_write_pfc_0_proc1 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p68_0",
    &setup_pwrite_write_pb0_0_common,
    { { &setup_pwrite_write_p68_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p60_0",
    &setup_pwrite_write_p90_0_common,
    { { &setup_pwrite_write_p68_0_proc0 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p4_0",
    &setup_pwrite_write_p4_0_common,
    { { &setup_pwrite_write_pba_0_proc1 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_procfinal,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p4_1",
    &setup_pwrite_write_p4_0_common,
    { { &setup_pwrite_write_pba_0_proc1 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_procfinal,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 0, "write" } },
    &cleanup },
  { "fs-pwrite_write_p3c_0",
    &setup_pwrite_write_pde_2_common,
    { { &setup_pwrite_write_pfe_2_proc1 }, { &setup_pwrite_write_pfe_3_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfe_3_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p38_0",
    &setup_pwrite_write_pfc_0_common,
    { { &setup_pwrite_write_pfc_0_proc1 }, { &setup_pwrite_write_pfc_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p30_0",
    &setup_pwrite_write_pf8_0_common,
    { { &setup_pwrite_write_pfc_0_proc1 }, { &setup_pwrite_write_pf8_2_proc0 } },
    &setup_pwrite_write_pfe_2_procfinal,
    &setup_pwrite_write_pfe_2_final,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p28_0",
    &setup_pwrite_write_pb0_0_common,
    { { &setup_pwrite_write_pba_0_proc1 }, { &setup_pwrite_write_pb0_1_proc0 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p20_0",
    &setup_pwrite_write_p90_0_common,
    { { &setup_pwrite_write_pba_0_proc1 }, { &setup_pwrite_write_pb0_1_proc0 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pb90_0_final,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pfc_2_1, 1, "write" } },
    &cleanup },
  { "fs-pwrite_write_p0_0",
    &setup_pwrite_write_p4_0_common,
    { { &setup_pwrite_write_pba_0_proc1 }, { &setup_pwrite_write_pba_0_proc1 } },
    &setup_pwrite_write_pba_0_procfinal,
    &setup_pwrite_write_pba_0_procfinal,
    { { &test_pwrite_write_p7c_0_0, 0, "pwrite" },
      { &test_pwrite_write_pf8_2_1, 1, "write" } },
    &cleanup },
  { "fs-read_read_pfe_0",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_pfe_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pfe_1",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_pfe_1_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfe_0_0, 0, "read" } },
    &cleanup },
  { "fs-read_read_pfd8_0",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_pfd8_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pfd0_0",
    &setup_read_read_pfd0_0_common,
    { { &setup_read_read_pfd0_0_proc0 }, { &setup_read_read_pfd0_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pfc_0",
    &setup_read_read_pfc_0_common,
    { { &setup_read_read_pfd8_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pfa_0",
    &setup_read_read_pfa_0_common,
    { { &setup_read_read_pfa_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pf8_0",
    &setup_read_read_pf8_0_common,
    { { &setup_read_read_pf8_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pf0_0",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_pfe_1_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pee_0",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_pfe_1_proc0 }, { &setup_read_read_pfe_1_proc0 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_ped8_0",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_pfe_1_proc0 }, { &setup_read_read_ped8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_ped8_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_ped0_0",
    &setup_read_read_pfd0_0_common,
    { { &setup_read_read_ped0_0_proc0 }, { &setup_read_read_ped0_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pec_0",
    &setup_read_read_pfc_0_common,
    { { &setup_read_read_pfe_1_proc0 }, { &setup_read_read_ped8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pea_0",
    &setup_read_read_pfa_0_common,
    { { &setup_read_read_pfe_1_proc0 }, { &setup_read_read_pea_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pe8_0",
    &setup_read_read_pf8_0_common,
    { { &setup_read_read_pfe_1_proc0 }, { &setup_read_read_pe8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pe0_0",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_pfe_1_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_pdf8_0",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_pdf8_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pdf6_0",
    &setup_read_read_pdf6_0_common,
    { { &setup_read_read_pdf6_0_proc0 }, { &setup_read_read_pdf6_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pdf6_1",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_pdf6_1_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pdf6_2",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_ped8_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pdf4_0",
    &setup_read_read_pfd0_0_common,
    { { &setup_read_read_pdf4_0_proc0 }, { &setup_read_read_pfd0_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pdf0_0",
    &setup_read_read_pdf0_0_common,
    { { &setup_read_read_pdf6_0_proc0 }, { &setup_read_read_pdf6_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pde8_0",
    &setup_read_read_pde8_0_common,
    { { &setup_read_read_pde8_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pde0_0",
    &setup_read_read_pde0_0_common,
    { { &setup_read_read_pde0_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pdc_0",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pdb8_0",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pfe_1_proc0 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_pdb6_0",
    &setup_read_read_pdf6_0_common,
    { { &setup_read_read_pdb6_0_proc0 }, { &setup_read_read_pdb6_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_ped8_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pdb6_1",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_ped8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_ped8_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pdb4_0",
    &setup_read_read_pfd0_0_common,
    { { &setup_read_read_pdb4_0_proc0 }, { &setup_read_read_ped0_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pdb0_0",
    &setup_read_read_pdf0_0_common,
    { { &setup_read_read_pdb6_0_proc0 }, { &setup_read_read_pdb6_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pda8_0",
    &setup_read_read_pde8_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pea_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pda0_0",
    &setup_read_read_pde0_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pda0_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pd8_0",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped8_0_1, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_pd78_0",
    &setup_read_read_pdf6_0_common,
    { { &setup_read_read_pd78_0_proc0 }, { &setup_read_read_pd78_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pd76_0",
    &setup_read_read_pfd0_0_common,
    { { &setup_read_read_pd76_0_proc0 }, { &setup_read_read_pd78_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pd74_0",
    &setup_read_read_pfd0_0_common,
    { { &setup_read_read_pd74_0_proc0 }, { &setup_read_read_pd74_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pd74_1",
    &setup_read_read_pd74_1_common,
    { { &setup_read_read_pd74_1_proc0 }, { &setup_read_read_pd74_1_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pd74_2",
    &setup_read_read_pd74_1_common,
    { { &setup_read_read_pd74_2_proc0 }, { &setup_read_read_pd74_1_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pd70_0",
    &setup_read_read_pd70_0_common,
    { { &setup_read_read_pd76_0_proc0 }, { &setup_read_read_pd78_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pd68_0",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_pd68_0_proc0 }, { &setup_read_read_pd74_1_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pd60_0",
    &setup_read_read_pde0_0_common,
    { { &setup_read_read_pd60_0_proc0 }, { &setup_read_read_pd74_1_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pd4_0",
    &setup_read_read_pd74_1_common,
    { { &setup_read_read_pd74_2_proc0 }, { &setup_read_read_pd74_1_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pd38_0",
    &setup_read_read_pfd0_0_common,
    { { &setup_read_read_pd38_0_proc0 }, { &setup_read_read_pd38_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_pd36_0",
    &setup_read_read_pfd0_0_common,
    { { &setup_read_read_pd38_0_proc0 }, { &setup_read_read_pd36_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped8_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pd34_0",
    &setup_read_read_pfd0_0_common,
    { { &setup_read_read_pd34_0_proc0 }, { &setup_read_read_pd34_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pd34_1",
    &setup_read_read_pd74_1_common,
    { { &setup_read_read_pd74_2_proc0 }, { &setup_read_read_pd74_2_proc0 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pd30_0",
    &setup_read_read_pd70_0_common,
    { { &setup_read_read_pd38_0_proc0 }, { &setup_read_read_pd36_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pd28_0",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_pd74_2_proc0 }, { &setup_read_read_pd28_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pd20_0",
    &setup_read_read_pde0_0_common,
    { { &setup_read_read_pd74_2_proc0 }, { &setup_read_read_pd20_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pd0_0",
    &setup_read_read_pd74_1_common,
    { { &setup_read_read_pd74_2_proc0 }, { &setup_read_read_pd74_1_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_pcf_0",
    &setup_read_read_pfc_0_common,
    { { &setup_read_read_pdf8_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pcee_0",
    &setup_read_read_pcee_0_common,
    { { &setup_read_read_pdf6_0_proc0 }, { &setup_read_read_pdf6_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pcea_0",
    &setup_read_read_pcee_0_common,
    { { &setup_read_read_pdf4_0_proc0 }, { &setup_read_read_pfd0_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pce4_0",
    &setup_read_read_pce4_0_common,
    { { &setup_read_read_pdf6_1_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pce4_1",
    &setup_read_read_pce4_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pcd_0",
    &setup_read_read_pcd_0_common,
    { { &setup_read_read_pde8_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pcc0_0",
    &setup_read_read_pcc0_0_common,
    { { &setup_read_read_pde0_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pc8_0",
    &setup_read_read_pfc_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pc7_0",
    &setup_read_read_pfc_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pfe_1_proc0 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_pc6e_0",
    &setup_read_read_pcee_0_common,
    { { &setup_read_read_pdb6_0_proc0 }, { &setup_read_read_pdb6_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_ped8_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pc6a_0",
    &setup_read_read_pc6a_0_common,
    { { &setup_read_read_pdb4_0_proc0 }, { &setup_read_read_ped0_0_proc1 } },
    &setup_read_read_pfd0_0_procfinal,
    &setup_read_read_pfd0_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pc64_0",
    &setup_read_read_pce4_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_ped8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pc5_0",
    &setup_read_read_pcd_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pea_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pc40_0",
    &setup_read_read_pcc0_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pda0_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pc0_0",
    &setup_read_read_pfc_0_common,
    { { &setup_read_read_ped8_0_proc1 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_pbe_0",
    &setup_read_read_pfa_0_common,
    { { &setup_read_read_pbe_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pbd8_0",
    &setup_read_read_pde8_0_common,
    { { &setup_read_read_pbd8_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pbd0_0",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_pbd0_0_proc0 }, { &setup_read_read_pd74_1_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pbc_0",
    &setup_read_read_pcd_0_common,
    { { &setup_read_read_pbd8_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pba_0",
    &setup_read_read_pba_0_common,
    { { &setup_read_read_pba_0_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pba_1",
    &setup_read_read_pba_1_common,
    { { &setup_read_read_pba_1_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pba_2",
    &setup_read_read_pba_1_common,
    { { &setup_read_read_pba_2_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pba_3",
    &setup_read_read_pba_1_common,
    { { &setup_read_read_pba_3_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pb8_0",
    &setup_read_read_pb8_0_common,
    { { &setup_read_read_pb8_0_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pb8_1",
    &setup_read_read_pb8_1_common,
    { { &setup_read_read_pb8_1_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pb0_0",
    &setup_read_read_pba_1_common,
    { { &setup_read_read_pb0_0_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_pae_0",
    &setup_read_read_pfa_0_common,
    { { &setup_read_read_pea_0_proc1 }, { &setup_read_read_pfe_1_proc0 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_pad8_0",
    &setup_read_read_pde8_0_common,
    { { &setup_read_read_pea_0_proc1 }, { &setup_read_read_ped8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped8_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pad0_0",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_pd28_0_proc1 }, { &setup_read_read_pd74_2_proc0 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pac_0",
    &setup_read_read_pcd_0_common,
    { { &setup_read_read_pea_0_proc1 }, { &setup_read_read_ped8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_paa_0",
    &setup_read_read_pba_0_common,
    { { &setup_read_read_pb0_0_proc0 }, { &setup_read_read_paa_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_paa_1",
    &setup_read_read_pba_1_common,
    { { &setup_read_read_pb0_0_proc0 }, { &setup_read_read_pba_3_proc0 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_paa_2",
    &setup_read_read_pba_1_common,
    { { &setup_read_read_pba_3_proc0 }, { &setup_read_read_pba_3_proc0 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pa8_0",
    &setup_read_read_pb8_0_common,
    { { &setup_read_read_pb0_0_proc0 }, { &setup_read_read_pa8_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_0_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pa8_1",
    &setup_read_read_pa8_1_common,
    { { &setup_read_read_pa8_1_proc0 }, { &setup_read_read_pa8_1_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_pa0_0",
    &setup_read_read_pba_1_common,
    { { &setup_read_read_pb0_0_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_ped0_0_1, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_p9e_0",
    &setup_read_read_pf8_0_common,
    { { &setup_read_read_p9e_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p9d8_0",
    &setup_read_read_pde0_0_common,
    { { &setup_read_read_p9d8_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p9d0_0",
    &setup_read_read_pde0_0_common,
    { { &setup_read_read_p9d0_0_proc0 }, { &setup_read_read_pd74_1_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p9c0_0",
    &setup_read_read_p9c0_0_common,
    { { &setup_read_read_p9c0_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p9b0_0",
    &setup_read_read_p9b0_0_common,
    { { &setup_read_read_p9b0_0_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_p9b0_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p9b0_1",
    &setup_read_read_p9b0_1_common,
    { { &setup_read_read_p9b0_1_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p990_0",
    &setup_read_read_p990_0_common,
    { { &setup_read_read_p990_0_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p90_0",
    &setup_read_read_pa8_1_common,
    { { &setup_read_read_pa8_1_proc1 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p8e_0",
    &setup_read_read_pf8_0_common,
    { { &setup_read_read_pe8_0_proc1 }, { &setup_read_read_pfe_1_proc0 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_p8d8_0",
    &setup_read_read_pde0_0_common,
    { { &setup_read_read_pda0_0_proc1 }, { &setup_read_read_ped8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_ped8_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p8d0_0",
    &setup_read_read_pde0_0_common,
    { { &setup_read_read_pd20_0_proc1 }, { &setup_read_read_pd74_2_proc0 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p8c0_0",
    &setup_read_read_p9c0_0_common,
    { { &setup_read_read_pe8_0_proc1 }, { &setup_read_read_ped8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p8a_0",
    &setup_read_read_p8a_0_common,
    { { &setup_read_read_pa8_1_proc1 }, { &setup_read_read_paa_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_0_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p8a_1",
    &setup_read_read_pa8_1_common,
    { { &setup_read_read_pa8_1_proc1 }, { &setup_read_read_p8a_1_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p88_0",
    &setup_read_read_p88_0_common,
    { { &setup_read_read_p88_0_proc0 }, { &setup_read_read_p88_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p80_0",
    &setup_read_read_pa8_1_common,
    { { &setup_read_read_pa8_1_proc1 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_pec_0_1, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_p78_0",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_p78_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p76_0",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_p76_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfd8_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p74_0",
    &setup_read_read_pd74_1_common,
    { { &setup_read_read_p74_0_proc0 }, { &setup_read_read_pd74_1_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p70_0",
    &setup_read_read_pfc_0_common,
    { { &setup_read_read_p76_0_proc0 }, { &setup_read_read_pfe_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p68_0",
    &setup_read_read_pba_1_common,
    { { &setup_read_read_p68_0_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfd0_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p60_0",
    &setup_read_read_pa8_1_common,
    { { &setup_read_read_p60_0_proc0 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfc_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p4_0",
    &setup_read_read_p4_0_common,
    { { &setup_read_read_pba_0_proc1 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_0_procfinal,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfe_0_1, 0, "read" } },
    &cleanup },
  { "fs-read_read_p4_1",
    &setup_read_read_p4_0_common,
    { { &setup_read_read_pba_0_proc1 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_0_procfinal,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfe_0_0, 0, "read" } },
    &cleanup },
  { "fs-read_read_p38_0",
    &setup_read_read_pfe_0_common,
    { { &setup_read_read_pfe_0_proc1 }, { &setup_read_read_pfe_1_proc0 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_read_p36_0",
    &setup_read_read_pfd8_0_common,
    { { &setup_read_read_pfe_0_proc1 }, { &setup_read_read_ped8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_ped8_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p34_0",
    &setup_read_read_pd74_1_common,
    { { &setup_read_read_pd74_1_proc1 }, { &setup_read_read_pd74_2_proc0 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p30_0",
    &setup_read_read_pfc_0_common,
    { { &setup_read_read_pfe_0_proc1 }, { &setup_read_read_ped8_0_proc1 } },
    &setup_read_read_pfe_0_procfinal,
    &setup_read_read_pfe_0_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p28_0",
    &setup_read_read_pba_1_common,
    { { &setup_read_read_pba_0_proc1 }, { &setup_read_read_pb0_0_proc0 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_ped0_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p20_0",
    &setup_read_read_pa8_1_common,
    { { &setup_read_read_pba_0_proc1 }, { &setup_read_read_pa8_1_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_1_final,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pec_0_1, 1, "read" } },
    &cleanup },
  { "fs-read_read_p0_0",
    &setup_read_read_p4_0_common,
    { { &setup_read_read_pba_0_proc1 }, { &setup_read_read_pba_0_proc1 } },
    &setup_read_read_pba_0_procfinal,
    &setup_read_read_pba_0_procfinal,
    { { &test_read_read_pfe_0_0, 0, "read" },
      { &test_read_read_pfe_0_0, 1, "read" } },
    &cleanup },
  { "fs-read_rename_pf8_0",
    &setup_read_rename_pf8_0_common,
    { { &setup_read_rename_pf8_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pf8_0_0, 0, "read" },
      { &test_read_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pf4_0",
    &setup_read_rename_pf4_0_common,
    { { &setup_read_rename_pf8_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pf8_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pf0_0",
    &setup_read_rename_pf8_0_common,
    { { &setup_read_rename_pf8_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pf8_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pe_0",
    &setup_read_rename_pe_0_common,
    { { &setup_read_rename_pf8_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pf8_0_0, 0, "read" },
      { &test_read_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pde_0",
    &setup_read_rename_pde_0_common,
    { { &setup_read_rename_pde_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pde_0_0, 0, "read" },
      { &test_read_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pdd0_0",
    &setup_read_rename_pdd0_0_common,
    { { &setup_read_rename_pde_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pde_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pdc_0",
    &setup_read_rename_pde_0_common,
    { { &setup_read_rename_pde_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pde_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pd8_0",
    &setup_read_rename_pd8_0_common,
    { { &setup_read_rename_pde_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pde_0_0, 0, "read" },
      { &test_read_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pd6_0",
    &setup_read_rename_pd6_0_common,
    { { &setup_read_rename_pd6_0_proc0 }, { &setup_read_rename_pd6_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pd6_0_0, 0, "read" },
      { &test_read_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pd50_0",
    &setup_read_rename_pd50_0_common,
    { { &setup_read_rename_pd6_0_proc0 }, { &setup_read_rename_pd6_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pd6_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pd4_0",
    &setup_read_rename_pd6_0_common,
    { { &setup_read_rename_pd6_0_proc0 }, { &setup_read_rename_pd6_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pd6_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pd0_0",
    &setup_read_rename_pd0_0_common,
    { { &setup_read_rename_pd6_0_proc0 }, { &setup_read_rename_pd6_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pd6_0_0, 0, "read" },
      { &test_read_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pcc_0",
    &setup_read_rename_pcc_0_common,
    { { &setup_read_rename_pde_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pcc_0_0, 0, "read" },
      { &test_read_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pca_0",
    &setup_read_rename_pca_0_common,
    { { &setup_read_rename_pde_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pcc_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pc8_0",
    &setup_read_rename_pcc_0_common,
    { { &setup_read_rename_pde_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pcc_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pc0_0",
    &setup_read_rename_pc0_0_common,
    { { &setup_read_rename_pde_0_proc0 }, { &setup_read_rename_pf8_0_proc1 } },
    &setup_read_rename_pf8_0_procfinal,
    &setup_read_rename_pf8_0_final,
    { { &test_read_rename_pcc_0_0, 0, "read" },
      { &test_read_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pb8_0",
    &setup_read_rename_pb8_0_common,
    { { &setup_read_rename_pb8_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pd6_0_0, 0, "read" },
      { &test_read_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pb4_0",
    &setup_read_rename_pb4_0_common,
    { { &setup_read_rename_pb4_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb4_0_final,
    { { &test_read_rename_pd6_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pb4_1",
    &setup_read_rename_pb4_1_common,
    { { &setup_read_rename_pb8_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb4_0_final,
    { { &test_read_rename_pd6_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pb4_2",
    &setup_read_rename_pb4_2_common,
    { { &setup_read_rename_pb8_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pd6_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pb0_0",
    &setup_read_rename_pb8_0_common,
    { { &setup_read_rename_pb8_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pd6_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_pa_0",
    &setup_read_rename_pa_0_common,
    { { &setup_read_rename_pb8_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pd6_0_0, 0, "read" },
      { &test_read_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_p98_0",
    &setup_read_rename_p98_0_common,
    { { &setup_read_rename_p98_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pcc_0_0, 0, "read" },
      { &test_read_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_p94_0",
    &setup_read_rename_p94_0_common,
    { { &setup_read_rename_p94_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb4_0_final,
    { { &test_read_rename_pcc_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_p94_1",
    &setup_read_rename_p94_1_common,
    { { &setup_read_rename_p98_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb4_0_final,
    { { &test_read_rename_pcc_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_p94_2",
    &setup_read_rename_p94_2_common,
    { { &setup_read_rename_p98_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pcc_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_p90_0",
    &setup_read_rename_p98_0_common,
    { { &setup_read_rename_p98_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pcc_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_p80_0",
    &setup_read_rename_p80_0_common,
    { { &setup_read_rename_p98_0_proc0 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pcc_0_0, 0, "read" },
      { &test_read_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_p6_0",
    &setup_read_rename_pb8_0_common,
    { { &setup_read_rename_pb8_0_proc1 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pf8_0_0, 0, "read" },
      { &test_read_rename_pf8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_p50_0",
    &setup_read_rename_pb4_2_common,
    { { &setup_read_rename_pb8_0_proc1 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pf8_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_p4_0",
    &setup_read_rename_pb8_0_common,
    { { &setup_read_rename_pb8_0_proc1 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_final,
    { { &test_read_rename_pf8_0_0, 0, "read" },
      { &test_read_rename_pf4_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_rename_p0_0",
    &setup_read_rename_p0_0_common,
    { { &setup_read_rename_pb8_0_proc1 }, { &setup_read_rename_pb8_0_proc1 } },
    &setup_read_rename_pb8_0_procfinal,
    &setup_read_rename_pb8_0_procfinal,
    { { &test_read_rename_pf8_0_0, 0, "read" },
      { &test_read_rename_pe_0_1, 0, "rename" } },
    &cleanup },
  { "fs-read_stat_pf_0",
    &setup_read_stat_pf_0_common,
    { { &setup_read_stat_pf_0_proc0 }, { &setup_read_stat_pf_0_proc1 } },
    &setup_read_stat_pf_0_procfinal,
    &setup_read_stat_pf_0_final,
    { { &test_read_stat_pf_0_0, 0, "read" },
      { &test_read_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_pe_0",
    &setup_read_stat_pe_0_common,
    { { &setup_read_stat_pf_0_proc0 }, { &setup_read_stat_pf_0_proc1 } },
    &setup_read_stat_pf_0_procfinal,
    &setup_read_stat_pf_0_final,
    { { &test_read_stat_pf_0_0, 0, "read" },
      { &test_read_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_pdc_0",
    &setup_read_stat_pdc_0_common,
    { { &setup_read_stat_pdc_0_proc0 }, { &setup_read_stat_pf_0_proc1 } },
    &setup_read_stat_pf_0_procfinal,
    &setup_read_stat_pf_0_final,
    { { &test_read_stat_pdc_0_0, 0, "read" },
      { &test_read_stat_pdc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_pd8_0",
    &setup_read_stat_pd8_0_common,
    { { &setup_read_stat_pdc_0_proc0 }, { &setup_read_stat_pf_0_proc1 } },
    &setup_read_stat_pf_0_procfinal,
    &setup_read_stat_pf_0_final,
    { { &test_read_stat_pdc_0_0, 0, "read" },
      { &test_read_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_pd4_0",
    &setup_read_stat_pdc_0_common,
    { { &setup_read_stat_pd4_0_proc0 }, { &setup_read_stat_pd4_0_proc1 } },
    &setup_read_stat_pf_0_procfinal,
    &setup_read_stat_pf_0_final,
    { { &test_read_stat_pd4_0_0, 0, "read" },
      { &test_read_stat_pdc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_pd0_0",
    &setup_read_stat_pd8_0_common,
    { { &setup_read_stat_pd4_0_proc0 }, { &setup_read_stat_pd4_0_proc1 } },
    &setup_read_stat_pf_0_procfinal,
    &setup_read_stat_pf_0_final,
    { { &test_read_stat_pd4_0_0, 0, "read" },
      { &test_read_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_pc8_0",
    &setup_read_stat_pc8_0_common,
    { { &setup_read_stat_pdc_0_proc0 }, { &setup_read_stat_pf_0_proc1 } },
    &setup_read_stat_pf_0_procfinal,
    &setup_read_stat_pf_0_final,
    { { &test_read_stat_pc8_0_0, 0, "read" },
      { &test_read_stat_pdc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_pc0_0",
    &setup_read_stat_pc0_0_common,
    { { &setup_read_stat_pdc_0_proc0 }, { &setup_read_stat_pf_0_proc1 } },
    &setup_read_stat_pf_0_procfinal,
    &setup_read_stat_pf_0_final,
    { { &test_read_stat_pc8_0_0, 0, "read" },
      { &test_read_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_pb_0",
    &setup_read_stat_pb_0_common,
    { { &setup_read_stat_pb_0_proc0 }, { &setup_read_stat_pb_0_proc1 } },
    &setup_read_stat_pb_0_procfinal,
    &setup_read_stat_pb_0_final,
    { { &test_read_stat_pd4_0_0, 0, "read" },
      { &test_read_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_pa_0",
    &setup_read_stat_pa_0_common,
    { { &setup_read_stat_pb_0_proc0 }, { &setup_read_stat_pb_0_proc1 } },
    &setup_read_stat_pb_0_procfinal,
    &setup_read_stat_pb_0_final,
    { { &test_read_stat_pd4_0_0, 0, "read" },
      { &test_read_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_p98_0",
    &setup_read_stat_p98_0_common,
    { { &setup_read_stat_p98_0_proc0 }, { &setup_read_stat_pb_0_proc1 } },
    &setup_read_stat_pb_0_procfinal,
    &setup_read_stat_p98_0_final,
    { { &test_read_stat_pc8_0_0, 0, "read" },
      { &test_read_stat_p98_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_p98_1",
    &setup_read_stat_p98_1_common,
    { { &setup_read_stat_p98_1_proc0 }, { &setup_read_stat_pb_0_proc1 } },
    &setup_read_stat_pb_0_procfinal,
    &setup_read_stat_pb_0_final,
    { { &test_read_stat_pc8_0_0, 0, "read" },
      { &test_read_stat_p98_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_p80_0",
    &setup_read_stat_p80_0_common,
    { { &setup_read_stat_p98_1_proc0 }, { &setup_read_stat_pb_0_proc1 } },
    &setup_read_stat_pb_0_procfinal,
    &setup_read_stat_pb_0_final,
    { { &test_read_stat_pc8_0_0, 0, "read" },
      { &test_read_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_p4_0",
    &setup_read_stat_pb_0_common,
    { { &setup_read_stat_pb_0_proc1 }, { &setup_read_stat_pb_0_proc1 } },
    &setup_read_stat_pb_0_procfinal,
    &setup_read_stat_pb_0_final,
    { { &test_read_stat_pf_0_0, 0, "read" },
      { &test_read_stat_pf_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_stat_p0_0",
    &setup_read_stat_p0_0_common,
    { { &setup_read_stat_pb_0_proc1 }, { &setup_read_stat_pb_0_proc1 } },
    &setup_read_stat_pb_0_procfinal,
    &setup_read_stat_pb_0_procfinal,
    { { &test_read_stat_pf_0_0, 0, "read" },
      { &test_read_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-read_unlink_pf0_0",
    &setup_read_unlink_pf0_0_common,
    { { &setup_read_unlink_pf0_0_proc0 }, { &setup_read_unlink_pf0_0_proc1 } },
    &setup_read_unlink_pf0_0_procfinal,
    &setup_read_unlink_pf0_0_final,
    { { &test_read_unlink_pf0_0_0, 0, "read" },
      { &test_read_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_pe_0",
    &setup_read_unlink_pe_0_common,
    { { &setup_read_unlink_pf0_0_proc0 }, { &setup_read_unlink_pf0_0_proc1 } },
    &setup_read_unlink_pf0_0_procfinal,
    &setup_read_unlink_pf0_0_final,
    { { &test_read_unlink_pf0_0_0, 0, "read" },
      { &test_read_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_pdc_0",
    &setup_read_unlink_pdc_0_common,
    { { &setup_read_unlink_pdc_0_proc0 }, { &setup_read_unlink_pf0_0_proc1 } },
    &setup_read_unlink_pf0_0_procfinal,
    &setup_read_unlink_pf0_0_final,
    { { &test_read_unlink_pdc_0_0, 0, "read" },
      { &test_read_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_pd8_0",
    &setup_read_unlink_pd8_0_common,
    { { &setup_read_unlink_pdc_0_proc0 }, { &setup_read_unlink_pf0_0_proc1 } },
    &setup_read_unlink_pf0_0_procfinal,
    &setup_read_unlink_pf0_0_final,
    { { &test_read_unlink_pdc_0_0, 0, "read" },
      { &test_read_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_pd4_0",
    &setup_read_unlink_pd4_0_common,
    { { &setup_read_unlink_pd4_0_proc0 }, { &setup_read_unlink_pd4_0_proc1 } },
    &setup_read_unlink_pf0_0_procfinal,
    &setup_read_unlink_pf0_0_final,
    { { &test_read_unlink_pd4_0_0, 0, "read" },
      { &test_read_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_pd0_0",
    &setup_read_unlink_pd0_0_common,
    { { &setup_read_unlink_pd4_0_proc0 }, { &setup_read_unlink_pd4_0_proc1 } },
    &setup_read_unlink_pf0_0_procfinal,
    &setup_read_unlink_pf0_0_final,
    { { &test_read_unlink_pd4_0_0, 0, "read" },
      { &test_read_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_pc8_0",
    &setup_read_unlink_pc8_0_common,
    { { &setup_read_unlink_pdc_0_proc0 }, { &setup_read_unlink_pf0_0_proc1 } },
    &setup_read_unlink_pf0_0_procfinal,
    &setup_read_unlink_pf0_0_final,
    { { &test_read_unlink_pc8_0_0, 0, "read" },
      { &test_read_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_pc0_0",
    &setup_read_unlink_pc0_0_common,
    { { &setup_read_unlink_pdc_0_proc0 }, { &setup_read_unlink_pf0_0_proc1 } },
    &setup_read_unlink_pf0_0_procfinal,
    &setup_read_unlink_pf0_0_final,
    { { &test_read_unlink_pc8_0_0, 0, "read" },
      { &test_read_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_pb0_0",
    &setup_read_unlink_pb0_0_common,
    { { &setup_read_unlink_pb0_0_proc0 }, { &setup_read_unlink_pb0_0_proc1 } },
    &setup_read_unlink_pb0_0_procfinal,
    &setup_read_unlink_pb0_0_final,
    { { &test_read_unlink_pd4_0_0, 0, "read" },
      { &test_read_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_pb0_1",
    &setup_read_unlink_pb0_1_common,
    { { &setup_read_unlink_pb0_1_proc0 }, { &setup_read_unlink_pb0_0_proc1 } },
    &setup_read_unlink_pb0_0_procfinal,
    &setup_read_unlink_pb0_1_final,
    { { &test_read_unlink_pd4_0_0, 0, "read" },
      { &test_read_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_pa_0",
    &setup_read_unlink_pa_0_common,
    { { &setup_read_unlink_pb0_1_proc0 }, { &setup_read_unlink_pb0_0_proc1 } },
    &setup_read_unlink_pb0_0_procfinal,
    &setup_read_unlink_pb0_1_final,
    { { &test_read_unlink_pd4_0_0, 0, "read" },
      { &test_read_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_p90_0",
    &setup_read_unlink_p90_0_common,
    { { &setup_read_unlink_pb0_0_proc0 }, { &setup_read_unlink_pb0_0_proc1 } },
    &setup_read_unlink_pb0_0_procfinal,
    &setup_read_unlink_pb0_0_final,
    { { &test_read_unlink_pc8_0_0, 0, "read" },
      { &test_read_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_p90_1",
    &setup_read_unlink_p90_1_common,
    { { &setup_read_unlink_pb0_1_proc0 }, { &setup_read_unlink_pb0_0_proc1 } },
    &setup_read_unlink_pb0_0_procfinal,
    &setup_read_unlink_pb0_1_final,
    { { &test_read_unlink_pc8_0_0, 0, "read" },
      { &test_read_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_p80_0",
    &setup_read_unlink_p80_0_common,
    { { &setup_read_unlink_pb0_1_proc0 }, { &setup_read_unlink_pb0_0_proc1 } },
    &setup_read_unlink_pb0_0_procfinal,
    &setup_read_unlink_pb0_1_final,
    { { &test_read_unlink_pc8_0_0, 0, "read" },
      { &test_read_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_p4_0",
    &setup_read_unlink_pb0_1_common,
    { { &setup_read_unlink_pb0_0_proc1 }, { &setup_read_unlink_pb0_0_proc1 } },
    &setup_read_unlink_pb0_0_procfinal,
    &setup_read_unlink_pb0_1_final,
    { { &test_read_unlink_pf0_0_0, 0, "read" },
      { &test_read_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_unlink_p0_0",
    &setup_read_unlink_p0_0_common,
    { { &setup_read_unlink_pb0_0_proc1 }, { &setup_read_unlink_pb0_0_proc1 } },
    &setup_read_unlink_pb0_0_procfinal,
    &setup_read_unlink_pb0_0_procfinal,
    { { &test_read_unlink_pf0_0_0, 0, "read" },
      { &test_read_unlink_pe_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-read_write_pff_0",
    &setup_read_write_pff_0_common,
    { { &setup_read_write_pff_0_proc0 }, { &setup_read_write_pff_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pff_1",
    &setup_read_write_pff_1_common,
    { { &setup_read_write_pff_1_proc0 }, { &setup_read_write_pff_1_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pff_2",
    &setup_read_write_pff_1_common,
    { { &setup_read_write_pff_2_proc0 }, { &setup_read_write_pff_1_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pff_2_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pfe_0",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_pfe_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pfe_1",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_pfe_1_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pfc_0",
    &setup_read_write_pfc_0_common,
    { { &setup_read_write_pfc_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pfa_0",
    &setup_read_write_pfa_0_common,
    { { &setup_read_write_pfa_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pf8_0",
    &setup_read_write_pf8_0_common,
    { { &setup_read_write_pfa_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pf0_0",
    &setup_read_write_pfc_0_common,
    { { &setup_read_write_pfe_1_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pef_0",
    &setup_read_write_pef_0_common,
    { { &setup_read_write_pef_0_proc0 }, { &setup_read_write_pef_0_proc1 } },
    &setup_read_write_pef_0_procfinal,
    &setup_read_write_pef_0_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pff_2_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pef_1",
    &setup_read_write_pef_1_common,
    { { &setup_read_write_pff_2_proc0 }, { &setup_read_write_pff_2_proc0 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pff_2_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pee_0",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_pfe_1_proc0 }, { &setup_read_write_pfe_1_proc0 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pec_0",
    &setup_read_write_pfc_0_common,
    { { &setup_read_write_pfe_1_proc0 }, { &setup_read_write_pec_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pea_0",
    &setup_read_write_pfa_0_common,
    { { &setup_read_write_pfe_1_proc0 }, { &setup_read_write_pea_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pe8_0",
    &setup_read_write_pf8_0_common,
    { { &setup_read_write_pfe_1_proc0 }, { &setup_read_write_pea_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pe0_0",
    &setup_read_write_pfc_0_common,
    { { &setup_read_write_pfe_1_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pdfc_0",
    &setup_read_write_pdfc_0_common,
    { { &setup_read_write_pdfc_0_proc0 }, { &setup_read_write_pff_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pdfa_0",
    &setup_read_write_pdfa_0_common,
    { { &setup_read_write_pdfa_0_proc0 }, { &setup_read_write_pdfa_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pdf0_0",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_pdf0_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pdf0_1",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pde8_0",
    &setup_read_write_pde8_0_common,
    { { &setup_read_write_pde8_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pde0_0",
    &setup_read_write_pde0_0_common,
    { { &setup_read_write_pde8_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pdc_0",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pdbc_0",
    &setup_read_write_pdfc_0_common,
    { { &setup_read_write_pdbc_0_proc0 }, { &setup_read_write_pdbc_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pff_2_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pdba_0",
    &setup_read_write_pdfa_0_common,
    { { &setup_read_write_pdba_0_proc0 }, { &setup_read_write_pdba_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pdb0_0",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pec_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pda8_0",
    &setup_read_write_pde8_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pda8_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pda0_0",
    &setup_read_write_pde0_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pda8_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pd8_0",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pdfc_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pd7c_0",
    &setup_read_write_pd7c_0_common,
    { { &setup_read_write_pd7c_0_proc0 }, { &setup_read_write_pd7c_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pd78_0",
    &setup_read_write_pd78_0_common,
    { { &setup_read_write_pd78_0_proc0 }, { &setup_read_write_pd78_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pd70_0",
    &setup_read_write_pd70_0_common,
    { { &setup_read_write_pd70_0_proc0 }, { &setup_read_write_pd70_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pd70_1",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_pd70_1_proc0 }, { &setup_read_write_pd70_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pd68_0",
    &setup_read_write_pde8_0_common,
    { { &setup_read_write_pd68_0_proc0 }, { &setup_read_write_pd70_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pd60_0",
    &setup_read_write_pde0_0_common,
    { { &setup_read_write_pd68_0_proc0 }, { &setup_read_write_pd70_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pd4_0",
    &setup_read_write_pd70_0_common,
    { { &setup_read_write_pd70_1_proc0 }, { &setup_read_write_pd70_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pd3c_0",
    &setup_read_write_pdfc_0_common,
    { { &setup_read_write_pd3c_0_proc0 }, { &setup_read_write_pd3c_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pff_2_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pd38_0",
    &setup_read_write_pd78_0_common,
    { { &setup_read_write_pd38_0_proc0 }, { &setup_read_write_pd38_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pd30_0",
    &setup_read_write_pdfc_0_common,
    { { &setup_read_write_pd30_0_proc0 }, { &setup_read_write_pd30_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pd30_1",
    &setup_read_write_pd70_0_common,
    { { &setup_read_write_pd70_1_proc0 }, { &setup_read_write_pd70_1_proc0 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pd28_0",
    &setup_read_write_pde8_0_common,
    { { &setup_read_write_pd70_1_proc0 }, { &setup_read_write_pd28_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pd20_0",
    &setup_read_write_pde0_0_common,
    { { &setup_read_write_pd70_1_proc0 }, { &setup_read_write_pd28_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pd0_0",
    &setup_read_write_pd70_0_common,
    { { &setup_read_write_pd70_1_proc0 }, { &setup_read_write_pd70_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pcf8_0",
    &setup_read_write_pcf8_0_common,
    { { &setup_read_write_pdfc_0_proc0 }, { &setup_read_write_pff_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pcf0_0",
    &setup_read_write_pcf0_0_common,
    { { &setup_read_write_pcf0_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pcf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pce_0",
    &setup_read_write_pce_0_common,
    { { &setup_read_write_pdf0_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pce_1",
    &setup_read_write_pce_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pcd0_0",
    &setup_read_write_pcd0_0_common,
    { { &setup_read_write_pcd0_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pcc0_0",
    &setup_read_write_pcc0_0_common,
    { { &setup_read_write_pde8_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pc8_0",
    &setup_read_write_pce_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pc78_0",
    &setup_read_write_pc78_0_common,
    { { &setup_read_write_pdbc_0_proc0 }, { &setup_read_write_pdbc_0_proc1 } },
    &setup_read_write_pff_0_procfinal,
    &setup_read_write_pff_0_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pff_2_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pc70_0",
    &setup_read_write_pcf0_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pfe_1_proc0 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pc70_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pc6_0",
    &setup_read_write_pce_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pec_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pc50_0",
    &setup_read_write_pcd0_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pea_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pc40_0",
    &setup_read_write_pcc0_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pda8_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pc0_0",
    &setup_read_write_pce_0_common,
    { { &setup_read_write_pec_0_proc1 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pbf_0",
    &setup_read_write_pbf_0_common,
    { { &setup_read_write_pbf_0_proc0 }, { &setup_read_write_pff_1_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pbe_0",
    &setup_read_write_pfa_0_common,
    { { &setup_read_write_pbe_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pbc_0",
    &setup_read_write_pbf_0_common,
    { { &setup_read_write_pbc_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pbb0_0",
    &setup_read_write_pbb0_0_common,
    { { &setup_read_write_pbb0_0_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_0_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pbb0_1",
    &setup_read_write_pbb0_1_common,
    { { &setup_read_write_pbb0_1_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pbb0_2",
    &setup_read_write_pbb0_1_common,
    { { &setup_read_write_pbb0_2_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pb8_0",
    &setup_read_write_pb8_0_common,
    { { &setup_read_write_pb8_0_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_0_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pb8_1",
    &setup_read_write_pb8_1_common,
    { { &setup_read_write_pb8_1_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_pb0_0",
    &setup_read_write_pbb0_1_common,
    { { &setup_read_write_pb0_0_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_paf_0",
    &setup_read_write_pbf_0_common,
    { { &setup_read_write_paf_0_proc0 }, { &setup_read_write_pff_2_proc0 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pff_2_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pae_0",
    &setup_read_write_pfa_0_common,
    { { &setup_read_write_pae_0_proc0 }, { &setup_read_write_pfe_1_proc0 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pac_0",
    &setup_read_write_pbf_0_common,
    { { &setup_read_write_pac_0_proc0 }, { &setup_read_write_pec_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pab0_0",
    &setup_read_write_pab0_0_common,
    { { &setup_read_write_pab0_0_proc0 }, { &setup_read_write_pab0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_0_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pab0_1",
    &setup_read_write_pbb0_1_common,
    { { &setup_read_write_pab0_1_proc0 }, { &setup_read_write_pbb0_2_proc0 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pa8_0",
    &setup_read_write_pb8_0_common,
    { { &setup_read_write_pb0_0_proc0 }, { &setup_read_write_pa8_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_0_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pa8_1",
    &setup_read_write_pa8_1_common,
    { { &setup_read_write_pa8_1_proc0 }, { &setup_read_write_pbb0_2_proc0 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_pa0_0",
    &setup_read_write_pbb0_1_common,
    { { &setup_read_write_pb0_0_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pd7c_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p9f0_0",
    &setup_read_write_p9f0_0_common,
    { { &setup_read_write_p9f0_0_proc0 }, { &setup_read_write_pff_1_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p9e0_0",
    &setup_read_write_pf8_0_common,
    { { &setup_read_write_p9e0_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p9c_0",
    &setup_read_write_p9f0_0_common,
    { { &setup_read_write_p9c_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p90_0",
    &setup_read_write_pa8_1_common,
    { { &setup_read_write_pbb0_2_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p8f0_0",
    &setup_read_write_p9f0_0_common,
    { { &setup_read_write_p8f0_0_proc0 }, { &setup_read_write_pff_2_proc0 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pff_2_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p8e0_0",
    &setup_read_write_pf8_0_common,
    { { &setup_read_write_pea_0_proc1 }, { &setup_read_write_pfe_1_proc0 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p8c_0",
    &setup_read_write_p9f0_0_common,
    { { &setup_read_write_pea_0_proc1 }, { &setup_read_write_pec_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p8a_0",
    &setup_read_write_p8a_0_common,
    { { &setup_read_write_p8a_0_proc0 }, { &setup_read_write_p8a_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pc70_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p8a_1",
    &setup_read_write_p8a_1_common,
    { { &setup_read_write_pab0_1_proc0 }, { &setup_read_write_p8a_1_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_0_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pc70_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p890_0",
    &setup_read_write_p890_0_common,
    { { &setup_read_write_pab0_1_proc0 }, { &setup_read_write_p890_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_0_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pc70_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p890_1",
    &setup_read_write_p890_1_common,
    { { &setup_read_write_p890_1_proc0 }, { &setup_read_write_p890_1_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pc70_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p890_2",
    &setup_read_write_p890_2_common,
    { { &setup_read_write_pab0_1_proc0 }, { &setup_read_write_pab0_1_proc0 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p80_0",
    &setup_read_write_pa8_1_common,
    { { &setup_read_write_pbb0_2_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pcf8_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p7c_0",
    &setup_read_write_pff_1_common,
    { { &setup_read_write_p7c_0_proc0 }, { &setup_read_write_pff_1_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pff_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p78_0",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_p78_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p70_0",
    &setup_read_write_pfc_0_common,
    { { &setup_read_write_p70_0_proc0 }, { &setup_read_write_pfe_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p68_0",
    &setup_read_write_pbb0_1_common,
    { { &setup_read_write_p68_0_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p60_0",
    &setup_read_write_pa8_1_common,
    { { &setup_read_write_p68_0_proc0 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p4_0",
    &setup_read_write_p4_0_common,
    { { &setup_read_write_pbb0_0_proc1 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_0_procfinal,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p4_1",
    &setup_read_write_p4_0_common,
    { { &setup_read_write_pbb0_0_proc1 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_0_procfinal,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 0, "write" } },
    &cleanup },
  { "fs-read_write_p3c_0",
    &setup_read_write_pef_1_common,
    { { &setup_read_write_pff_1_proc1 }, { &setup_read_write_pff_2_proc0 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pff_2_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p38_0",
    &setup_read_write_pfe_0_common,
    { { &setup_read_write_pfe_0_proc1 }, { &setup_read_write_pfe_1_proc0 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p30_0",
    &setup_read_write_pfc_0_common,
    { { &setup_read_write_pfe_0_proc1 }, { &setup_read_write_pec_0_proc1 } },
    &setup_read_write_pff_1_procfinal,
    &setup_read_write_pff_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p28_0",
    &setup_read_write_pbb0_1_common,
    { { &setup_read_write_pbb0_0_proc1 }, { &setup_read_write_pbb0_2_proc0 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p20_0",
    &setup_read_write_pa8_1_common,
    { { &setup_read_write_pbb0_0_proc1 }, { &setup_read_write_pbb0_2_proc0 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_1_final,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pfe_1_1, 1, "write" } },
    &cleanup },
  { "fs-read_write_p0_0",
    &setup_read_write_p4_0_common,
    { { &setup_read_write_pbb0_0_proc1 }, { &setup_read_write_pbb0_0_proc1 } },
    &setup_read_write_pbb0_0_procfinal,
    &setup_read_write_pbb0_0_procfinal,
    { { &test_read_write_pff_0_0, 0, "read" },
      { &test_read_write_pec_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_rename_pf_0",
    &setup_rename_rename_pf_0_common,
    { { &setup_rename_rename_pf_0_proc0 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pf_0_0, 0, "rename" },
      { &test_rename_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pf_1",
    &setup_rename_rename_pf_1_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pf_0_0, 0, "rename" },
      { &test_rename_rename_pf_0_0, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pec_0",
    &setup_rename_rename_pec_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pf_0_0, 0, "rename" },
      { &test_rename_rename_pec_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pec_1",
    &setup_rename_rename_pf_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pf_0_0, 0, "rename" },
      { &test_rename_rename_pec_1_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pe4_0",
    &setup_rename_rename_pf_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pf_0_0, 0, "rename" },
      { &test_rename_rename_pec_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pc_0",
    &setup_rename_rename_pf_1_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pf_0_0, 0, "rename" },
      { &test_rename_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pb8_0",
    &setup_rename_rename_pec_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pb8_1",
    &setup_rename_rename_pf_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pb6_0",
    &setup_rename_rename_pb6_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pb6_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pb6_1",
    &setup_rename_rename_pb6_1_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb6_1_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pb10_0",
    &setup_rename_rename_pb10_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pb10_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pb10_1",
    &setup_rename_rename_pec_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_pa0_0",
    &setup_rename_rename_pf_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pa0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p9c_0",
    &setup_rename_rename_p9c_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb8_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p970_0",
    &setup_rename_rename_p970_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_p970_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p970_1",
    &setup_rename_rename_p970_1_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pb10_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p970_2",
    &setup_rename_rename_p970_2_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p960_0",
    &setup_rename_rename_p9c_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb6_1_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p92_0",
    &setup_rename_rename_p9c_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pb6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p80_0",
    &setup_rename_rename_pf_1_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_pb8_0_0, 0, "rename" },
      { &test_rename_rename_pa0_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p6_0",
    &setup_rename_rename_p6_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_p6_0_0, 0, "rename" },
      { &test_rename_rename_pf_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p50_0",
    &setup_rename_rename_p50_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_p50_0_0, 0, "rename" },
      { &test_rename_rename_pb6_1_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p50_1",
    &setup_rename_rename_p50_1_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_p50_0_0, 0, "rename" },
      { &test_rename_rename_pb6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p40_0",
    &setup_rename_rename_p40_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_p50_0_0, 0, "rename" },
      { &test_rename_rename_pb6_1_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p40_1",
    &setup_rename_rename_p50_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_final,
    { { &test_rename_rename_p50_0_0, 0, "rename" },
      { &test_rename_rename_pb6_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p0_0",
    &setup_rename_rename_p0_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_procfinal,
    { { &test_rename_rename_p6_0_0, 0, "rename" },
      { &test_rename_rename_pc_0_1, 0, "rename" } },
    &cleanup },
  { "fs-rename_rename_p0_1",
    &setup_rename_rename_p0_0_common,
    { { &setup_rename_rename_pf_0_proc1 }, { &setup_rename_rename_pf_0_proc1 } },
    &setup_rename_rename_pf_0_procfinal,
    &setup_rename_rename_pf_0_procfinal,
    { { &test_rename_rename_p6_0_0, 0, "rename" },
      { &test_rename_rename_p6_0_0, 0, "rename" } },
    &cleanup },
  { "fs-rename_stat_pe_0",
    &setup_rename_stat_pe_0_common,
    { { &setup_rename_stat_pe_0_proc0 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pe_0_final,
    { { &test_rename_stat_pe_0_0, 0, "rename" },
      { &test_rename_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_stat_pe_1",
    &setup_rename_stat_pe_1_common,
    { { &setup_rename_stat_pe_0_proc1 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pe_0_final,
    { { &test_rename_stat_pe_0_0, 0, "rename" },
      { &test_rename_stat_pe_1_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_stat_pc_0",
    &setup_rename_stat_pe_1_common,
    { { &setup_rename_stat_pe_0_proc1 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pe_0_final,
    { { &test_rename_stat_pe_0_0, 0, "rename" },
      { &test_rename_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_stat_pbfc_0",
    &setup_rename_stat_pbfc_0_common,
    { { &setup_rename_stat_pe_0_proc1 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pbfc_0_final,
    { { &test_rename_stat_pbfc_0_0, 0, "rename" },
      { &test_rename_stat_pbfc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_stat_pbfc_1",
    &setup_rename_stat_pbfc_1_common,
    { { &setup_rename_stat_pe_0_proc1 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pbfc_0_final,
    { { &test_rename_stat_pbfc_0_0, 0, "rename" },
      { &test_rename_stat_pbfc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_stat_pa0_0",
    &setup_rename_stat_pe_0_common,
    { { &setup_rename_stat_pe_0_proc1 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pe_0_final,
    { { &test_rename_stat_pbfc_0_0, 0, "rename" },
      { &test_rename_stat_pa0_0_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_stat_p98_0",
    &setup_rename_stat_p98_0_common,
    { { &setup_rename_stat_pe_0_proc1 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pe_0_final,
    { { &test_rename_stat_pbfc_0_0, 0, "rename" },
      { &test_rename_stat_p98_0_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_stat_p80_0",
    &setup_rename_stat_pe_1_common,
    { { &setup_rename_stat_pe_0_proc1 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pe_0_final,
    { { &test_rename_stat_pbfc_0_0, 0, "rename" },
      { &test_rename_stat_pa0_0_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_stat_p4_0",
    &setup_rename_stat_p4_0_common,
    { { &setup_rename_stat_pe_0_proc1 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pe_0_final,
    { { &test_rename_stat_p4_0_0, 0, "rename" },
      { &test_rename_stat_pe_0_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_stat_p0_0",
    &setup_rename_stat_p0_0_common,
    { { &setup_rename_stat_pe_0_proc1 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pe_0_procfinal,
    { { &test_rename_stat_p4_0_0, 0, "rename" },
      { &test_rename_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_stat_p0_1",
    &setup_rename_stat_p0_0_common,
    { { &setup_rename_stat_pe_0_proc1 }, { &setup_rename_stat_pe_0_proc1 } },
    &setup_rename_stat_pe_0_procfinal,
    &setup_rename_stat_pe_0_procfinal,
    { { &test_rename_stat_p4_0_0, 0, "rename" },
      { &test_rename_stat_p0_1_1, 0, "stat" } },
    &cleanup },
  { "fs-rename_unlink_pf0_0",
    &setup_rename_unlink_pf0_0_common,
    { { &setup_rename_unlink_pf0_0_proc0 }, { &setup_rename_unlink_pf0_0_proc1 } },
    &setup_rename_unlink_pf0_0_procfinal,
    &setup_rename_unlink_pf0_0_final,
    { { &test_rename_unlink_pf0_0_0, 0, "rename" },
      { &test_rename_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-rename_unlink_pc_0",
    &setup_rename_unlink_pc_0_common,
    { { &setup_rename_unlink_pf0_0_proc1 }, { &setup_rename_unlink_pf0_0_proc1 } },
    &setup_rename_unlink_pf0_0_procfinal,
    &setup_rename_unlink_pf0_0_final,
    { { &test_rename_unlink_pf0_0_0, 0, "rename" },
      { &test_rename_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-rename_unlink_pb8_0",
    &setup_rename_unlink_pb8_0_common,
    { { &setup_rename_unlink_pf0_0_proc1 }, { &setup_rename_unlink_pf0_0_proc1 } },
    &setup_rename_unlink_pf0_0_procfinal,
    &setup_rename_unlink_pf0_0_final,
    { { &test_rename_unlink_pb8_0_0, 0, "rename" },
      { &test_rename_unlink_pb8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-rename_unlink_pa0_0",
    &setup_rename_unlink_pf0_0_common,
    { { &setup_rename_unlink_pf0_0_proc1 }, { &setup_rename_unlink_pf0_0_proc1 } },
    &setup_rename_unlink_pf0_0_procfinal,
    &setup_rename_unlink_pf0_0_final,
    { { &test_rename_unlink_pb8_0_0, 0, "rename" },
      { &test_rename_unlink_pa0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-rename_unlink_p98_0",
    &setup_rename_unlink_p98_0_common,
    { { &setup_rename_unlink_pf0_0_proc1 }, { &setup_rename_unlink_pf0_0_proc1 } },
    &setup_rename_unlink_pf0_0_procfinal,
    &setup_rename_unlink_pf0_0_final,
    { { &test_rename_unlink_pb8_0_0, 0, "rename" },
      { &test_rename_unlink_pb8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-rename_unlink_p80_0",
    &setup_rename_unlink_pc_0_common,
    { { &setup_rename_unlink_pf0_0_proc1 }, { &setup_rename_unlink_pf0_0_proc1 } },
    &setup_rename_unlink_pf0_0_procfinal,
    &setup_rename_unlink_pf0_0_final,
    { { &test_rename_unlink_pb8_0_0, 0, "rename" },
      { &test_rename_unlink_pa0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-rename_unlink_p4_0",
    &setup_rename_unlink_p4_0_common,
    { { &setup_rename_unlink_pf0_0_proc1 }, { &setup_rename_unlink_pf0_0_proc1 } },
    &setup_rename_unlink_pf0_0_procfinal,
    &setup_rename_unlink_pf0_0_final,
    { { &test_rename_unlink_p4_0_0, 0, "rename" },
      { &test_rename_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-rename_unlink_p0_0",
    &setup_rename_unlink_p0_0_common,
    { { &setup_rename_unlink_pf0_0_proc1 }, { &setup_rename_unlink_pf0_0_proc1 } },
    &setup_rename_unlink_pf0_0_procfinal,
    &setup_rename_unlink_pf0_0_procfinal,
    { { &test_rename_unlink_p4_0_0, 0, "rename" },
      { &test_rename_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-rename_unlink_p0_1",
    &setup_rename_unlink_p0_0_common,
    { { &setup_rename_unlink_pf0_0_proc1 }, { &setup_rename_unlink_pf0_0_proc1 } },
    &setup_rename_unlink_pf0_0_procfinal,
    &setup_rename_unlink_pf0_0_procfinal,
    { { &test_rename_unlink_p4_0_0, 0, "rename" },
      { &test_rename_unlink_p0_1_1, 0, "unlink" } },
    &cleanup },
  { "fs-rename_write_pfe_0",
    &setup_rename_write_pfe_0_common,
    { { &setup_rename_write_pfe_0_proc0 }, { &setup_rename_write_pfe_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pfc_0",
    &setup_rename_write_pfc_0_common,
    { { &setup_rename_write_pfc_0_proc0 }, { &setup_rename_write_pfc_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pf8_0",
    &setup_rename_write_pf8_0_common,
    { { &setup_rename_write_pf8_0_proc0 }, { &setup_rename_write_pfc_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pf4_0",
    &setup_rename_write_pf4_0_common,
    { { &setup_rename_write_pf4_0_proc0 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pf0_0",
    &setup_rename_write_pf0_0_common,
    { { &setup_rename_write_pf4_0_proc0 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pe_0",
    &setup_rename_write_pf4_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pde_0",
    &setup_rename_write_pfe_0_common,
    { { &setup_rename_write_pfe_0_proc1 }, { &setup_rename_write_pfe_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_pdc_0",
    &setup_rename_write_pfc_0_common,
    { { &setup_rename_write_pfc_0_proc1 }, { &setup_rename_write_pfc_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_pd8_0",
    &setup_rename_write_pf8_0_common,
    { { &setup_rename_write_pfc_0_proc1 }, { &setup_rename_write_pf8_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_pd4_0",
    &setup_rename_write_pf4_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc0 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_pd0_0",
    &setup_rename_write_pf0_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc0 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_pc_0",
    &setup_rename_write_pf4_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pfe_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_pbf0_0",
    &setup_rename_write_pbf0_0_common,
    { { &setup_rename_write_pfe_0_proc0 }, { &setup_rename_write_pfe_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pbe0_0",
    &setup_rename_write_pbe0_0_common,
    { { &setup_rename_write_pfc_0_proc0 }, { &setup_rename_write_pfc_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pbc_0",
    &setup_rename_write_pbe0_0_common,
    { { &setup_rename_write_pf8_0_proc0 }, { &setup_rename_write_pfc_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pba_0",
    &setup_rename_write_pba_0_common,
    { { &setup_rename_write_pba_0_proc0 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pb8_0",
    &setup_rename_write_pb8_0_common,
    { { &setup_rename_write_pba_0_proc0 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_pb0_0",
    &setup_rename_write_pb0_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_paf0_0",
    &setup_rename_write_pbf0_0_common,
    { { &setup_rename_write_pfe_0_proc1 }, { &setup_rename_write_pfe_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_pae0_0",
    &setup_rename_write_pbe0_0_common,
    { { &setup_rename_write_pfc_0_proc1 }, { &setup_rename_write_pfc_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_pac_0",
    &setup_rename_write_pbe0_0_common,
    { { &setup_rename_write_pfc_0_proc1 }, { &setup_rename_write_pf8_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_paa_0",
    &setup_rename_write_pba_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pba_0_proc0 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_pa8_0",
    &setup_rename_write_pb8_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pba_0_proc0 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_pa0_0",
    &setup_rename_write_pb0_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p9f_0",
    &setup_rename_write_pfe_0_common,
    { { &setup_rename_write_pfe_0_proc0 }, { &setup_rename_write_pfe_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p9e_0",
    &setup_rename_write_pfc_0_common,
    { { &setup_rename_write_pfc_0_proc0 }, { &setup_rename_write_pfc_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p9c_0",
    &setup_rename_write_pf8_0_common,
    { { &setup_rename_write_pf8_0_proc0 }, { &setup_rename_write_pfc_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p9a_0",
    &setup_rename_write_pf4_0_common,
    { { &setup_rename_write_pf4_0_proc0 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p98_0",
    &setup_rename_write_pf0_0_common,
    { { &setup_rename_write_pf4_0_proc0 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p90_0",
    &setup_rename_write_pf4_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p8f_0",
    &setup_rename_write_pfe_0_common,
    { { &setup_rename_write_pfe_0_proc1 }, { &setup_rename_write_pfe_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p8e_0",
    &setup_rename_write_pfc_0_common,
    { { &setup_rename_write_pfc_0_proc1 }, { &setup_rename_write_pfc_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p8c_0",
    &setup_rename_write_pf8_0_common,
    { { &setup_rename_write_pfc_0_proc1 }, { &setup_rename_write_pf8_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p8a_0",
    &setup_rename_write_pf4_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc0 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p88_0",
    &setup_rename_write_pf0_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc0 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p80_0",
    &setup_rename_write_pf4_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_pbf0_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p7c_0",
    &setup_rename_write_p7c_0_common,
    { { &setup_rename_write_pfe_0_proc0 }, { &setup_rename_write_pfe_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p78_0",
    &setup_rename_write_p78_0_common,
    { { &setup_rename_write_pfc_0_proc0 }, { &setup_rename_write_pfc_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p70_0",
    &setup_rename_write_p70_0_common,
    { { &setup_rename_write_pf8_0_proc0 }, { &setup_rename_write_pfc_0_proc1 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p68_0",
    &setup_rename_write_p68_0_common,
    { { &setup_rename_write_pf4_0_proc0 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p60_0",
    &setup_rename_write_p60_0_common,
    { { &setup_rename_write_pf4_0_proc0 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p4_0",
    &setup_rename_write_p4_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_procfinal,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-rename_write_p3c_0",
    &setup_rename_write_p7c_0_common,
    { { &setup_rename_write_pfe_0_proc1 }, { &setup_rename_write_pfe_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pfe_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p38_0",
    &setup_rename_write_p78_0_common,
    { { &setup_rename_write_pfc_0_proc1 }, { &setup_rename_write_pfc_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p30_0",
    &setup_rename_write_p70_0_common,
    { { &setup_rename_write_pfc_0_proc1 }, { &setup_rename_write_pf8_0_proc0 } },
    &setup_rename_write_pfe_0_procfinal,
    &setup_rename_write_pfe_0_final,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p28_0",
    &setup_rename_write_p68_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc0 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p20_0",
    &setup_rename_write_p60_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc0 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_final,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-rename_write_p0_0",
    &setup_rename_write_p4_0_common,
    { { &setup_rename_write_pf4_0_proc1 }, { &setup_rename_write_pf4_0_proc1 } },
    &setup_rename_write_pf4_0_procfinal,
    &setup_rename_write_pf4_0_procfinal,
    { { &test_rename_write_p7c_0_0, 0, "rename" },
      { &test_rename_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_stat_pc_0",
    &setup_stat_stat_pc_0_common,
    { { &setup_stat_stat_pc_0_proc0 }, { &setup_stat_stat_pc_0_proc1 } },
    &setup_stat_stat_pc_0_procfinal,
    &setup_stat_stat_pc_0_final,
    { { &test_stat_stat_pc_0_0, 0, "stat" },
      { &test_stat_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-stat_stat_pc_1",
    &setup_stat_stat_pc_1_common,
    { { &setup_stat_stat_pc_0_proc1 }, { &setup_stat_stat_pc_0_proc1 } },
    &setup_stat_stat_pc_0_procfinal,
    &setup_stat_stat_pc_0_final,
    { { &test_stat_stat_pc_0_0, 0, "stat" },
      { &test_stat_stat_pc_0_0, 0, "stat" } },
    &cleanup },
  { "fs-stat_stat_p8_0",
    &setup_stat_stat_pc_1_common,
    { { &setup_stat_stat_pc_0_proc1 }, { &setup_stat_stat_pc_0_proc1 } },
    &setup_stat_stat_pc_0_procfinal,
    &setup_stat_stat_pc_0_final,
    { { &test_stat_stat_pc_0_0, 0, "stat" },
      { &test_stat_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-stat_stat_p4_0",
    &setup_stat_stat_p4_0_common,
    { { &setup_stat_stat_pc_0_proc1 }, { &setup_stat_stat_pc_0_proc1 } },
    &setup_stat_stat_pc_0_procfinal,
    &setup_stat_stat_pc_0_final,
    { { &test_stat_stat_p4_0_0, 0, "stat" },
      { &test_stat_stat_pc_0_1, 0, "stat" } },
    &cleanup },
  { "fs-stat_stat_p0_0",
    &setup_stat_stat_p0_0_common,
    { { &setup_stat_stat_pc_0_proc1 }, { &setup_stat_stat_pc_0_proc1 } },
    &setup_stat_stat_pc_0_procfinal,
    &setup_stat_stat_pc_0_procfinal,
    { { &test_stat_stat_p4_0_0, 0, "stat" },
      { &test_stat_stat_p8_0_1, 0, "stat" } },
    &cleanup },
  { "fs-stat_stat_p0_1",
    &setup_stat_stat_p0_0_common,
    { { &setup_stat_stat_pc_0_proc1 }, { &setup_stat_stat_pc_0_proc1 } },
    &setup_stat_stat_pc_0_procfinal,
    &setup_stat_stat_pc_0_procfinal,
    { { &test_stat_stat_p4_0_0, 0, "stat" },
      { &test_stat_stat_p4_0_0, 0, "stat" } },
    &cleanup },
  { "fs-stat_unlink_pf0_0",
    &setup_stat_unlink_pf0_0_common,
    { { &setup_stat_unlink_pf0_0_proc0 }, { &setup_stat_unlink_pf0_0_proc1 } },
    &setup_stat_unlink_pf0_0_procfinal,
    &setup_stat_unlink_pf0_0_final,
    { { &test_stat_unlink_pf0_0_0, 0, "stat" },
      { &test_stat_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-stat_unlink_p8_0",
    &setup_stat_unlink_p8_0_common,
    { { &setup_stat_unlink_pf0_0_proc1 }, { &setup_stat_unlink_pf0_0_proc1 } },
    &setup_stat_unlink_pf0_0_procfinal,
    &setup_stat_unlink_p8_0_final,
    { { &test_stat_unlink_p8_0_0, 0, "stat" },
      { &test_stat_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-stat_unlink_p4_0",
    &setup_stat_unlink_p4_0_common,
    { { &setup_stat_unlink_pf0_0_proc1 }, { &setup_stat_unlink_pf0_0_proc1 } },
    &setup_stat_unlink_pf0_0_procfinal,
    &setup_stat_unlink_p8_0_final,
    { { &test_stat_unlink_p4_0_0, 0, "stat" },
      { &test_stat_unlink_pf0_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-stat_unlink_p0_0",
    &setup_stat_unlink_p0_0_common,
    { { &setup_stat_unlink_pf0_0_proc1 }, { &setup_stat_unlink_pf0_0_proc1 } },
    &setup_stat_unlink_pf0_0_procfinal,
    &setup_stat_unlink_pf0_0_procfinal,
    { { &test_stat_unlink_p4_0_0, 0, "stat" },
      { &test_stat_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-stat_unlink_p0_1",
    &setup_stat_unlink_p0_0_common,
    { { &setup_stat_unlink_pf0_0_proc1 }, { &setup_stat_unlink_pf0_0_proc1 } },
    &setup_stat_unlink_pf0_0_procfinal,
    &setup_stat_unlink_pf0_0_procfinal,
    { { &test_stat_unlink_p4_0_0, 0, "stat" },
      { &test_stat_unlink_p0_1_1, 0, "unlink" } },
    &cleanup },
  { "fs-stat_write_pfc_0",
    &setup_stat_write_pfc_0_common,
    { { &setup_stat_write_pfc_0_proc0 }, { &setup_stat_write_pfc_0_proc1 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_pfc_0_0, 0, "stat" },
      { &test_stat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_pf8_0",
    &setup_stat_write_pf8_0_common,
    { { &setup_stat_write_pf8_0_proc0 }, { &setup_stat_write_pf8_0_proc1 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_pfc_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_pf0_0",
    &setup_stat_write_pf0_0_common,
    { { &setup_stat_write_pf0_0_proc0 }, { &setup_stat_write_pf8_0_proc1 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_pf0_0_0, 0, "stat" },
      { &test_stat_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_pec_0",
    &setup_stat_write_pec_0_common,
    { { &setup_stat_write_pec_0_proc0 }, { &setup_stat_write_pec_0_proc1 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pec_0_final,
    { { &test_stat_write_pec_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_pe6_0",
    &setup_stat_write_pe6_0_common,
    { { &setup_stat_write_pec_0_proc0 }, { &setup_stat_write_pec_0_proc1 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pec_0_final,
    { { &test_stat_write_pe6_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_pe6_1",
    &setup_stat_write_pe6_1_common,
    { { &setup_stat_write_pe6_1_proc0 }, { &setup_stat_write_pec_0_proc1 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pe6_1_final,
    { { &test_stat_write_pe6_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_pc_0",
    &setup_stat_write_pc_0_common,
    { { &setup_stat_write_pec_0_proc1 }, { &setup_stat_write_pec_0_proc1 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pe6_1_final,
    { { &test_stat_write_pf0_0_0, 0, "stat" },
      { &test_stat_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_pbc_0",
    &setup_stat_write_pfc_0_common,
    { { &setup_stat_write_pfc_0_proc1 }, { &setup_stat_write_pfc_0_proc0 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_pfc_0_0, 0, "stat" },
      { &test_stat_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_pb8_0",
    &setup_stat_write_pf8_0_common,
    { { &setup_stat_write_pf8_0_proc1 }, { &setup_stat_write_pf8_0_proc0 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_pfc_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_pb0_0",
    &setup_stat_write_pf0_0_common,
    { { &setup_stat_write_pf8_0_proc1 }, { &setup_stat_write_pf0_0_proc0 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_pf0_0_0, 0, "stat" },
      { &test_stat_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_pac_0",
    &setup_stat_write_pec_0_common,
    { { &setup_stat_write_pec_0_proc1 }, { &setup_stat_write_pec_0_proc0 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pec_0_final,
    { { &test_stat_write_pec_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_pa6_0",
    &setup_stat_write_pe6_0_common,
    { { &setup_stat_write_pec_0_proc1 }, { &setup_stat_write_pec_0_proc0 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pec_0_final,
    { { &test_stat_write_pe6_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_pa6_1",
    &setup_stat_write_pe6_1_common,
    { { &setup_stat_write_pec_0_proc1 }, { &setup_stat_write_pe6_1_proc0 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pe6_1_final,
    { { &test_stat_write_pe6_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_p8_0",
    &setup_stat_write_pc_0_common,
    { { &setup_stat_write_pec_0_proc1 }, { &setup_stat_write_pec_0_proc1 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pe6_1_final,
    { { &test_stat_write_pf0_0_0, 0, "stat" },
      { &test_stat_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_p7c_0",
    &setup_stat_write_p7c_0_common,
    { { &setup_stat_write_pfc_0_proc0 }, { &setup_stat_write_pfc_0_proc1 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_p78_0",
    &setup_stat_write_p78_0_common,
    { { &setup_stat_write_pf8_0_proc0 }, { &setup_stat_write_pf8_0_proc1 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_p70_0",
    &setup_stat_write_p70_0_common,
    { { &setup_stat_write_pf0_0_proc0 }, { &setup_stat_write_pf8_0_proc1 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_p68_0",
    &setup_stat_write_p68_0_common,
    { { &setup_stat_write_pe6_1_proc0 }, { &setup_stat_write_pec_0_proc1 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pe6_1_final,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_p60_0",
    &setup_stat_write_p60_0_common,
    { { &setup_stat_write_pe6_1_proc0 }, { &setup_stat_write_pec_0_proc1 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pe6_1_final,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_p4_0",
    &setup_stat_write_p4_0_common,
    { { &setup_stat_write_pec_0_proc1 }, { &setup_stat_write_pec_0_proc1 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pec_0_procfinal,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-stat_write_p3c_0",
    &setup_stat_write_p7c_0_common,
    { { &setup_stat_write_pfc_0_proc1 }, { &setup_stat_write_pfc_0_proc0 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_p38_0",
    &setup_stat_write_p78_0_common,
    { { &setup_stat_write_pf8_0_proc1 }, { &setup_stat_write_pf8_0_proc0 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_p30_0",
    &setup_stat_write_p70_0_common,
    { { &setup_stat_write_pf8_0_proc1 }, { &setup_stat_write_pf0_0_proc0 } },
    &setup_stat_write_pfc_0_procfinal,
    &setup_stat_write_pfc_0_final,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_p28_0",
    &setup_stat_write_p68_0_common,
    { { &setup_stat_write_pec_0_proc1 }, { &setup_stat_write_pe6_1_proc0 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pe6_1_final,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_p20_0",
    &setup_stat_write_p60_0_common,
    { { &setup_stat_write_pec_0_proc1 }, { &setup_stat_write_pe6_1_proc0 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pe6_1_final,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pf8_0_1, 1, "write" } },
    &cleanup },
  { "fs-stat_write_p0_0",
    &setup_stat_write_p4_0_common,
    { { &setup_stat_write_pec_0_proc1 }, { &setup_stat_write_pec_0_proc1 } },
    &setup_stat_write_pec_0_procfinal,
    &setup_stat_write_pec_0_procfinal,
    { { &test_stat_write_p7c_0_0, 0, "stat" },
      { &test_stat_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_unlink_pc_0",
    &setup_unlink_unlink_pc_0_common,
    { { &setup_unlink_unlink_pc_0_proc0 }, { &setup_unlink_unlink_pc_0_proc1 } },
    &setup_unlink_unlink_pc_0_procfinal,
    &setup_unlink_unlink_pc_0_final,
    { { &test_unlink_unlink_pc_0_0, 0, "unlink" },
      { &test_unlink_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-unlink_unlink_p8_0",
    &setup_unlink_unlink_p8_0_common,
    { { &setup_unlink_unlink_pc_0_proc1 }, { &setup_unlink_unlink_pc_0_proc1 } },
    &setup_unlink_unlink_pc_0_procfinal,
    &setup_unlink_unlink_pc_0_final,
    { { &test_unlink_unlink_pc_0_0, 0, "unlink" },
      { &test_unlink_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-unlink_unlink_p4_0",
    &setup_unlink_unlink_p4_0_common,
    { { &setup_unlink_unlink_pc_0_proc1 }, { &setup_unlink_unlink_pc_0_proc1 } },
    &setup_unlink_unlink_pc_0_procfinal,
    &setup_unlink_unlink_pc_0_final,
    { { &test_unlink_unlink_p4_0_0, 0, "unlink" },
      { &test_unlink_unlink_pc_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-unlink_unlink_p0_0",
    &setup_unlink_unlink_p0_0_common,
    { { &setup_unlink_unlink_pc_0_proc1 }, { &setup_unlink_unlink_pc_0_proc1 } },
    &setup_unlink_unlink_pc_0_procfinal,
    &setup_unlink_unlink_pc_0_procfinal,
    { { &test_unlink_unlink_p4_0_0, 0, "unlink" },
      { &test_unlink_unlink_p8_0_1, 0, "unlink" } },
    &cleanup },
  { "fs-unlink_unlink_p0_1",
    &setup_unlink_unlink_p0_0_common,
    { { &setup_unlink_unlink_pc_0_proc1 }, { &setup_unlink_unlink_pc_0_proc1 } },
    &setup_unlink_unlink_pc_0_procfinal,
    &setup_unlink_unlink_pc_0_procfinal,
    { { &test_unlink_unlink_p4_0_0, 0, "unlink" },
      { &test_unlink_unlink_p4_0_0, 0, "unlink" } },
    &cleanup },
  { "fs-unlink_write_pfc_0",
    &setup_unlink_write_pfc_0_common,
    { { &setup_unlink_write_pfc_0_proc0 }, { &setup_unlink_write_pfc_0_proc1 } },
    &setup_unlink_write_pfc_0_procfinal,
    &setup_unlink_write_pfc_0_final,
    { { &test_unlink_write_pfc_0_0, 0, "unlink" },
      { &test_unlink_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_pf0_0",
    &setup_unlink_write_pf0_0_common,
    { { &setup_unlink_write_pf0_0_proc0 }, { &setup_unlink_write_pf0_0_proc1 } },
    &setup_unlink_write_pfc_0_procfinal,
    &setup_unlink_write_pfc_0_final,
    { { &test_unlink_write_pfc_0_0, 0, "unlink" },
      { &test_unlink_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_pe8_0",
    &setup_unlink_write_pe8_0_common,
    { { &setup_unlink_write_pe8_0_proc0 }, { &setup_unlink_write_pe8_0_proc1 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_final,
    { { &test_unlink_write_pfc_0_0, 0, "unlink" },
      { &test_unlink_write_pe8_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_pe0_0",
    &setup_unlink_write_pe0_0_common,
    { { &setup_unlink_write_pe8_0_proc0 }, { &setup_unlink_write_pe8_0_proc1 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_final,
    { { &test_unlink_write_pfc_0_0, 0, "unlink" },
      { &test_unlink_write_pe8_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_pc_0",
    &setup_unlink_write_pc_0_common,
    { { &setup_unlink_write_pe8_0_proc1 }, { &setup_unlink_write_pe8_0_proc1 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_final,
    { { &test_unlink_write_pfc_0_0, 0, "unlink" },
      { &test_unlink_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_pbc_0",
    &setup_unlink_write_pfc_0_common,
    { { &setup_unlink_write_pfc_0_proc1 }, { &setup_unlink_write_pfc_0_proc0 } },
    &setup_unlink_write_pfc_0_procfinal,
    &setup_unlink_write_pfc_0_final,
    { { &test_unlink_write_pfc_0_0, 0, "unlink" },
      { &test_unlink_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_write_pb0_0",
    &setup_unlink_write_pf0_0_common,
    { { &setup_unlink_write_pf0_0_proc1 }, { &setup_unlink_write_pf0_0_proc0 } },
    &setup_unlink_write_pfc_0_procfinal,
    &setup_unlink_write_pfc_0_final,
    { { &test_unlink_write_pfc_0_0, 0, "unlink" },
      { &test_unlink_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_write_pa8_0",
    &setup_unlink_write_pe8_0_common,
    { { &setup_unlink_write_pe8_0_proc1 }, { &setup_unlink_write_pe8_0_proc0 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_final,
    { { &test_unlink_write_pfc_0_0, 0, "unlink" },
      { &test_unlink_write_pe8_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_write_pa0_0",
    &setup_unlink_write_pe0_0_common,
    { { &setup_unlink_write_pe8_0_proc1 }, { &setup_unlink_write_pe8_0_proc0 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_final,
    { { &test_unlink_write_pfc_0_0, 0, "unlink" },
      { &test_unlink_write_pe8_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_write_p8_0",
    &setup_unlink_write_pc_0_common,
    { { &setup_unlink_write_pe8_0_proc1 }, { &setup_unlink_write_pe8_0_proc1 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_final,
    { { &test_unlink_write_pfc_0_0, 0, "unlink" },
      { &test_unlink_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_write_p7c_0",
    &setup_unlink_write_p7c_0_common,
    { { &setup_unlink_write_pfc_0_proc0 }, { &setup_unlink_write_pfc_0_proc1 } },
    &setup_unlink_write_pfc_0_procfinal,
    &setup_unlink_write_pfc_0_final,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pfc_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_p78_0",
    &setup_unlink_write_p78_0_common,
    { { &setup_unlink_write_p78_0_proc0 }, { &setup_unlink_write_pf0_0_proc1 } },
    &setup_unlink_write_pfc_0_procfinal,
    &setup_unlink_write_pfc_0_final,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pe8_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_p70_0",
    &setup_unlink_write_p70_0_common,
    { { &setup_unlink_write_pf0_0_proc0 }, { &setup_unlink_write_pf0_0_proc1 } },
    &setup_unlink_write_pfc_0_procfinal,
    &setup_unlink_write_pfc_0_final,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_p68_0",
    &setup_unlink_write_p68_0_common,
    { { &setup_unlink_write_p68_0_proc0 }, { &setup_unlink_write_pe8_0_proc1 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_final,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pe8_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_p60_0",
    &setup_unlink_write_p60_0_common,
    { { &setup_unlink_write_p68_0_proc0 }, { &setup_unlink_write_pe8_0_proc1 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_final,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pe8_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_p4_0",
    &setup_unlink_write_p4_0_common,
    { { &setup_unlink_write_pe8_0_proc1 }, { &setup_unlink_write_pe8_0_proc1 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_procfinal,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pf0_0_1, 0, "write" } },
    &cleanup },
  { "fs-unlink_write_p3c_0",
    &setup_unlink_write_p7c_0_common,
    { { &setup_unlink_write_pfc_0_proc1 }, { &setup_unlink_write_pfc_0_proc0 } },
    &setup_unlink_write_pfc_0_procfinal,
    &setup_unlink_write_pfc_0_final,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pfc_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_write_p38_0",
    &setup_unlink_write_p78_0_common,
    { { &setup_unlink_write_pf0_0_proc1 }, { &setup_unlink_write_p78_0_proc0 } },
    &setup_unlink_write_pfc_0_procfinal,
    &setup_unlink_write_pfc_0_final,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pe8_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_write_p30_0",
    &setup_unlink_write_p70_0_common,
    { { &setup_unlink_write_pf0_0_proc1 }, { &setup_unlink_write_pf0_0_proc0 } },
    &setup_unlink_write_pfc_0_procfinal,
    &setup_unlink_write_pfc_0_final,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_write_p28_0",
    &setup_unlink_write_p68_0_common,
    { { &setup_unlink_write_pe8_0_proc1 }, { &setup_unlink_write_p68_0_proc0 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_final,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pe8_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_write_p20_0",
    &setup_unlink_write_p60_0_common,
    { { &setup_unlink_write_pe8_0_proc1 }, { &setup_unlink_write_p68_0_proc0 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_final,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pe8_0_1, 1, "write" } },
    &cleanup },
  { "fs-unlink_write_p0_0",
    &setup_unlink_write_p4_0_common,
    { { &setup_unlink_write_pe8_0_proc1 }, { &setup_unlink_write_pe8_0_proc1 } },
    &setup_unlink_write_pe8_0_procfinal,
    &setup_unlink_write_pe8_0_procfinal,
    { { &test_unlink_write_p7c_0_0, 0, "unlink" },
      { &test_unlink_write_pf0_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pff8_0",
    &setup_write_write_pff8_0_common,
    { { &setup_write_write_pff8_0_proc0 }, { &setup_write_write_pff8_0_proc1 } },
    &setup_write_write_pff8_0_procfinal,
    &setup_write_write_pff8_0_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pff8_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pff8_1",
    &setup_write_write_pff8_1_common,
    { { &setup_write_write_pff8_1_proc0 }, { &setup_write_write_pff8_1_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pff8_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pff8_2",
    &setup_write_write_pff8_1_common,
    { { &setup_write_write_pff8_2_proc0 }, { &setup_write_write_pff8_1_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pff8_0_0, 0, "write" } },
    &cleanup },
  { "fs-write_write_pff0_0",
    &setup_write_write_pff0_0_common,
    { { &setup_write_write_pff0_0_proc0 }, { &setup_write_write_pff0_0_proc1 } },
    &setup_write_write_pff8_0_procfinal,
    &setup_write_write_pff8_0_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pfe_0",
    &setup_write_write_pff8_0_common,
    { { &setup_write_write_pfe_0_proc0 }, { &setup_write_write_pff0_0_proc1 } },
    &setup_write_write_pff8_0_procfinal,
    &setup_write_write_pff8_0_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pfd0_0",
    &setup_write_write_pfd0_0_common,
    { { &setup_write_write_pfd0_0_proc0 }, { &setup_write_write_pff8_1_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pfc0_0",
    &setup_write_write_pfc0_0_common,
    { { &setup_write_write_pfd0_0_proc0 }, { &setup_write_write_pff8_1_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pf8_0",
    &setup_write_write_pff8_1_common,
    { { &setup_write_write_pff8_2_proc0 }, { &setup_write_write_pff8_1_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pf78_0",
    &setup_write_write_pf78_0_common,
    { { &setup_write_write_pf78_0_proc0 }, { &setup_write_write_pf78_0_proc1 } },
    &setup_write_write_pff8_0_procfinal,
    &setup_write_write_pff8_0_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pff8_0_0, 1, "write" } },
    &cleanup },
  { "fs-write_write_pf78_1",
    &setup_write_write_pf78_1_common,
    { { &setup_write_write_pff8_2_proc0 }, { &setup_write_write_pff8_2_proc0 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pff8_0_0, 1, "write" } },
    &cleanup },
  { "fs-write_write_pf70_0",
    &setup_write_write_pff0_0_common,
    { { &setup_write_write_pf70_0_proc0 }, { &setup_write_write_pf70_0_proc1 } },
    &setup_write_write_pff8_0_procfinal,
    &setup_write_write_pff8_0_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pf6_0",
    &setup_write_write_pf78_0_common,
    { { &setup_write_write_pf70_0_proc0 }, { &setup_write_write_pf6_0_proc1 } },
    &setup_write_write_pff8_0_procfinal,
    &setup_write_write_pff8_0_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pf50_0",
    &setup_write_write_pfd0_0_common,
    { { &setup_write_write_pff8_2_proc0 }, { &setup_write_write_pf50_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pf40_0",
    &setup_write_write_pfc0_0_common,
    { { &setup_write_write_pff8_2_proc0 }, { &setup_write_write_pf50_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pf0_0",
    &setup_write_write_pf78_1_common,
    { { &setup_write_write_pff8_2_proc0 }, { &setup_write_write_pff8_1_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pff8_0_0, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pef8_0",
    &setup_write_write_pff0_0_common,
    { { &setup_write_write_pef8_0_proc0 }, { &setup_write_write_pef8_0_proc1 } },
    &setup_write_write_pff8_0_procfinal,
    &setup_write_write_pff8_0_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff8_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pef0_0",
    &setup_write_write_pef0_0_common,
    { { &setup_write_write_pef0_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pef0_1",
    &setup_write_write_pef0_0_common,
    { { &setup_write_write_pef0_1_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pee_0",
    &setup_write_write_pee_0_common,
    { { &setup_write_write_pee_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_ped0_0",
    &setup_write_write_ped0_0_common,
    { { &setup_write_write_ped0_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pec0_0",
    &setup_write_write_pec0_0_common,
    { { &setup_write_write_ped0_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pe8_0",
    &setup_write_write_pee_0_common,
    { { &setup_write_write_pef0_1_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pe78_0",
    &setup_write_write_pff0_0_common,
    { { &setup_write_write_pe78_0_proc0 }, { &setup_write_write_pe78_0_proc1 } },
    &setup_write_write_pff8_0_procfinal,
    &setup_write_write_pff8_0_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff8_0_0, 1, "write" } },
    &cleanup },
  { "fs-write_write_pe70_0",
    &setup_write_write_pef0_0_common,
    { { &setup_write_write_pef0_1_proc0 }, { &setup_write_write_pef0_1_proc0 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pe6_0",
    &setup_write_write_pee_0_common,
    { { &setup_write_write_pef0_1_proc0 }, { &setup_write_write_pe6_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pe50_0",
    &setup_write_write_ped0_0_common,
    { { &setup_write_write_pef0_1_proc0 }, { &setup_write_write_pe50_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pe40_0",
    &setup_write_write_pec0_0_common,
    { { &setup_write_write_pef0_1_proc0 }, { &setup_write_write_pe50_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pe0_0",
    &setup_write_write_pee_0_common,
    { { &setup_write_write_pef0_1_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pdf_0",
    &setup_write_write_pff8_0_common,
    { { &setup_write_write_pdf_0_proc0 }, { &setup_write_write_pef8_0_proc1 } },
    &setup_write_write_pff8_0_procfinal,
    &setup_write_write_pff8_0_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pff8_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pde_0",
    &setup_write_write_pee_0_common,
    { { &setup_write_write_pde_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pdc_0",
    &setup_write_write_pdc_0_common,
    { { &setup_write_write_pdc_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pdc_1",
    &setup_write_write_pdc_0_common,
    { { &setup_write_write_pe6_0_proc1 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pda_0",
    &setup_write_write_pfd0_0_common,
    { { &setup_write_write_pda_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pd8_0",
    &setup_write_write_pfc0_0_common,
    { { &setup_write_write_pda_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pd0_0",
    &setup_write_write_pdc_0_common,
    { { &setup_write_write_pe6_0_proc1 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pcf_0",
    &setup_write_write_pf78_0_common,
    { { &setup_write_write_pcf_0_proc0 }, { &setup_write_write_pe78_0_proc1 } },
    &setup_write_write_pff8_0_procfinal,
    &setup_write_write_pff8_0_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pff8_0_0, 1, "write" } },
    &cleanup },
  { "fs-write_write_pce_0",
    &setup_write_write_pee_0_common,
    { { &setup_write_write_pe6_0_proc1 }, { &setup_write_write_pef0_1_proc0 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pcc_0",
    &setup_write_write_pdc_0_common,
    { { &setup_write_write_pe6_0_proc1 }, { &setup_write_write_pe6_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pca_0",
    &setup_write_write_pfd0_0_common,
    { { &setup_write_write_pe6_0_proc1 }, { &setup_write_write_pca_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pc8_0",
    &setup_write_write_pfc0_0_common,
    { { &setup_write_write_pe6_0_proc1 }, { &setup_write_write_pca_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pc0_0",
    &setup_write_write_pdc_0_common,
    { { &setup_write_write_pe6_0_proc1 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pbf0_0",
    &setup_write_write_pfd0_0_common,
    { { &setup_write_write_pbf0_0_proc0 }, { &setup_write_write_pff8_1_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff8_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pbe0_0",
    &setup_write_write_pfd0_0_common,
    { { &setup_write_write_pbe0_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pbc_0",
    &setup_write_write_pfd0_0_common,
    { { &setup_write_write_pbc_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pba_0",
    &setup_write_write_pba_0_common,
    { { &setup_write_write_pba_0_proc0 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_0_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pba_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pba_1",
    &setup_write_write_pba_1_common,
    { { &setup_write_write_pba_1_proc0 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pb90_0",
    &setup_write_write_pba_1_common,
    { { &setup_write_write_pb90_0_proc0 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_pb0_0",
    &setup_write_write_pb0_0_common,
    { { &setup_write_write_pb0_0_proc0 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_paf0_0",
    &setup_write_write_pfd0_0_common,
    { { &setup_write_write_pf50_0_proc1 }, { &setup_write_write_pff8_2_proc0 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff8_0_0, 1, "write" } },
    &cleanup },
  { "fs-write_write_pae0_0",
    &setup_write_write_pfd0_0_common,
    { { &setup_write_write_pca_0_proc1 }, { &setup_write_write_pef0_1_proc0 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pac_0",
    &setup_write_write_pfd0_0_common,
    { { &setup_write_write_pca_0_proc1 }, { &setup_write_write_pe6_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pa90_0",
    &setup_write_write_pa90_0_common,
    { { &setup_write_write_pa90_0_proc0 }, { &setup_write_write_pa90_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pa80_0",
    &setup_write_write_pa80_0_common,
    { { &setup_write_write_pa80_0_proc0 }, { &setup_write_write_pa80_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pa80_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pa80_1",
    &setup_write_write_pa80_1_common,
    { { &setup_write_write_pba_1_proc0 }, { &setup_write_write_pa80_1_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_0_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pa80_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_pa0_0",
    &setup_write_write_pb0_0_common,
    { { &setup_write_write_pb0_0_proc0 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p9f0_0",
    &setup_write_write_pfc0_0_common,
    { { &setup_write_write_pbf0_0_proc0 }, { &setup_write_write_pff8_1_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff8_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p9e0_0",
    &setup_write_write_pfc0_0_common,
    { { &setup_write_write_pbe0_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p9c_0",
    &setup_write_write_pfc0_0_common,
    { { &setup_write_write_pbc_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p9a0_0",
    &setup_write_write_pa90_0_common,
    { { &setup_write_write_p9a0_0_proc0 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p90_0",
    &setup_write_write_p90_0_common,
    { { &setup_write_write_pb0_0_proc0 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p8f0_0",
    &setup_write_write_pfc0_0_common,
    { { &setup_write_write_pf50_0_proc1 }, { &setup_write_write_pff8_2_proc0 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pff8_0_0, 1, "write" } },
    &cleanup },
  { "fs-write_write_p8e0_0",
    &setup_write_write_pfc0_0_common,
    { { &setup_write_write_pca_0_proc1 }, { &setup_write_write_pef0_1_proc0 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p8c_0",
    &setup_write_write_pfc0_0_common,
    { { &setup_write_write_pca_0_proc1 }, { &setup_write_write_pe6_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p8a_0",
    &setup_write_write_p8a_0_common,
    { { &setup_write_write_p9a0_0_proc0 }, { &setup_write_write_pa90_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pa80_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p8a_1",
    &setup_write_write_p8a_1_common,
    { { &setup_write_write_pba_1_proc0 }, { &setup_write_write_pa80_1_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_0_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pa80_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p88_0",
    &setup_write_write_p8a_0_common,
    { { &setup_write_write_p9a0_0_proc0 }, { &setup_write_write_pba_1_proc0 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pa80_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p88_1",
    &setup_write_write_p88_1_common,
    { { &setup_write_write_pba_1_proc0 }, { &setup_write_write_pba_1_proc0 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p80_0",
    &setup_write_write_p90_0_common,
    { { &setup_write_write_pb0_0_proc0 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf70_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p7c_0",
    &setup_write_write_pff8_1_common,
    { { &setup_write_write_p7c_0_proc0 }, { &setup_write_write_pff8_1_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pff8_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p78_0",
    &setup_write_write_pee_0_common,
    { { &setup_write_write_p78_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p70_0",
    &setup_write_write_pdc_0_common,
    { { &setup_write_write_p70_0_proc0 }, { &setup_write_write_pef0_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p68_0",
    &setup_write_write_pb0_0_common,
    { { &setup_write_write_p68_0_proc0 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p60_0",
    &setup_write_write_p90_0_common,
    { { &setup_write_write_p68_0_proc0 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pff0_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p4_0",
    &setup_write_write_p4_0_common,
    { { &setup_write_write_pba_0_proc1 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_0_procfinal,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pfe_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p4_1",
    &setup_write_write_p4_0_common,
    { { &setup_write_write_pba_0_proc1 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_0_procfinal,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 0, "write" } },
    &cleanup },
  { "fs-write_write_p3c_0",
    &setup_write_write_pf78_1_common,
    { { &setup_write_write_pff8_1_proc1 }, { &setup_write_write_pff8_2_proc0 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pff8_0_0, 1, "write" } },
    &cleanup },
  { "fs-write_write_p38_0",
    &setup_write_write_pee_0_common,
    { { &setup_write_write_pef0_0_proc1 }, { &setup_write_write_pef0_1_proc0 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p30_0",
    &setup_write_write_pdc_0_common,
    { { &setup_write_write_pef0_0_proc1 }, { &setup_write_write_pe6_0_proc1 } },
    &setup_write_write_pff8_1_procfinal,
    &setup_write_write_pff8_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p28_0",
    &setup_write_write_pb0_0_common,
    { { &setup_write_write_pba_0_proc1 }, { &setup_write_write_pb0_0_proc0 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p20_0",
    &setup_write_write_p90_0_common,
    { { &setup_write_write_pba_0_proc1 }, { &setup_write_write_pb0_0_proc0 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_1_final,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf70_0_1, 1, "write" } },
    &cleanup },
  { "fs-write_write_p0_0",
    &setup_write_write_p4_0_common,
    { { &setup_write_write_pba_0_proc1 }, { &setup_write_write_pba_0_proc1 } },
    &setup_write_write_pba_0_procfinal,
    &setup_write_write_pba_0_procfinal,
    { { &test_write_write_pf6_0_1, 0, "write" },
      { &test_write_write_pf6_0_1, 1, "write" } },
    &cleanup },
  {}
};
